@@ -21,6 +21,7 @@
 
 #include <gtk/gtk.h>
 #include "../lib/version.h"
+#include "../lib/compat.h"
 #include "libgimp/gimpintl.h"
 
 #include "about_dialog.h"
@@ -184,7 +185,13 @@ about_dialog_create (int timeout)
     {
       char title[256];
       snprintf( title, 256, "%s " PROGRAM_NAME " " PROGRAM_VERSION, _("About"));
+#if GTK_MAJOR_VERSION > 1
+      about_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_type_hint (GTK_WINDOW(about_dialog),
+                                GDK_WINDOW_TYPE_HINT_DIALOG);
+#else
       about_dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+#endif
       minimize_register(about_dialog);
       gtk_window_set_wmclass (GTK_WINDOW (about_dialog), "about_dialog", "cinepaint");
       gtk_window_set_title (GTK_WINDOW (about_dialog), title);
@@ -229,12 +236,16 @@ about_dialog_create (int timeout)
 
 
       style = gtk_style_new ();
-      gdk_font_unref (style->font);
-      style->font = gdk_font_load ("-Adobe-Helvetica-Medium-R-Normal--*-140-*-*-*-*-*-*");
+#if 0 
+#__APPLE__
+      gdk_font_unref (gtk_style_get_font(style));
+      gtk_style_set_font(style, gdk_font_load ("-Adobe-Helvetica-Medium-R-Normal--*-140-*-*-*-*-*-*"));
+#endif
+#if GTK_MAJOR_VERSION < 2
       gtk_widget_push_style (style);
 
       gtk_widget_pop_style ();
-
+#endif
 
       alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
       gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, TRUE, 0);
