@@ -96,6 +96,7 @@ static void splash_logo_draw (GtkWidget *widget);
 static void splash_text_draw (GtkWidget *widget);
 static void splash_logo_expose (GtkWidget *widget);
 static void server_start(int port, char *log);  /* added by IMAGEWORKS (doug creel 02/21/02) */
+static void app_update_prefix (void);
 
 static gint is_app_exit_finish_done = FALSE;
 
@@ -174,9 +175,6 @@ gimp_init (int    gimp_argc,
   int serverPort;
   char *serverLog;
 
-  /* Initialize the application */
-  app_init ();
-
   /* Parse the rest of the command line arguments as images to load */
   /* except for server arguments */
   if (gimp_argc > 0)
@@ -426,7 +424,13 @@ make_initialization_status_window(void)
 	  GtkWidget *vbox;
 	  GtkStyle *style;
 
-	  win_initstatus = gtk_window_new(GTK_WINDOW_DIALOG);
+#if GTK_MAJOR_VERSION > 1
+          win_initstatus = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+          gtk_window_set_type_hint (GTK_WINDOW(win_initstatus),
+                                    GDK_WINDOW_TYPE_HINT_DIALOG);
+#else
+          win_initstatus = gtk_window_new (GTK_WINDOW_DIALOG);
+#endif
 	  gtk_signal_connect (GTK_OBJECT (win_initstatus), "delete_event",
 			      GTK_SIGNAL_FUNC (gtk_true),
 			      NULL);
@@ -710,7 +714,7 @@ app_exit (int kill_it)
 */
 }
 
-void
+static void
 app_update_prefix (void)
 {
     if(strcmp(GetDirStaticPrefix(), GetDirPrefix()) != 0)
