@@ -42,6 +42,7 @@
 #include "paint_funcs_area.h"
 
 #include "../lib/wire/c_typedefs.h"
+#include "libgimp/gimpintl.h"
 
 #define IM_FILM_LOOKUP_START 14862
 #define IM_FILM_LOOKUP_END 16726
@@ -154,7 +155,7 @@ static void   blend_motion                  (Tool *, GdkEventMotion *, gpointer)
 static void   blend_cursor_update           (Tool *, GdkEventMotion *, gpointer);
 static void   blend_control                 (Tool *, int, gpointer);
 
-static void   blend                         (GImage *gimage, CanvasDrawable *drawable,
+static void   cp_blend                      (GImage *gimage, CanvasDrawable *drawable,
 					     BlendMode blend_mode, int paint_mode,
 					     GradientType gradient_type,
 					     double opacity, double offset,
@@ -361,11 +362,34 @@ create_blend_options ()
   options->max_depth     = 3;
   options->threshold     = 0.2;
 
+  /* translate items */
+  blend_option_items[0].label = _("FG to BG (RGB)");
+  blend_option_items[1].label = _("FG to BG (HSV)");
+  blend_option_items[2].label = _("FG to Transparent");
+  blend_option_items[3].label = _("Custom (from editor)");
+
+  gradient_option_items[0].label = _("Linear");
+  gradient_option_items[1].label = _("Bi-Linear");
+  gradient_option_items[2].label = _("Radial");
+  gradient_option_items[3].label = _("Square");
+  gradient_option_items[4].label = _("Conical (symmetric)");
+  gradient_option_items[5].label = _("Conical (asymmetric)");
+  gradient_option_items[6].label = _("Log");
+  gradient_option_items[7].label = _("Film Log");
+#if 0
+  gradient_option_items[8].label = _("Shapeburst (angular)");
+  gradient_option_items[9].label = _("Shapeburst (spherical)");
+  gradient_option_items[10].label = _("Shapeburst (dimpled)");
+#endif
+  repeat_option_items[0].label = _("None");
+  repeat_option_items[1].label = _("Sawtooth wave");
+  repeat_option_items[2].label = _("Triangular wave");
+
   /*  the main vbox  */
   vbox = gtk_vbox_new (FALSE, 2);
 
   /*  the main label  */
-  label = gtk_label_new ("Blend Options");
+  label = gtk_label_new (_("Blend Options"));
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -375,7 +399,7 @@ create_blend_options ()
   gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, TRUE, 0);
 
   /*  the opacity scale  */
-  label = gtk_label_new ("Opacity:");
+  label = gtk_label_new (_("Opacity:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -393,7 +417,7 @@ create_blend_options ()
   gtk_widget_show (opacity_scale);
 
   /*  the offset scale  */
-  label = gtk_label_new ("Offset:");
+  label = gtk_label_new (_("Offset:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -411,7 +435,7 @@ create_blend_options ()
   gtk_widget_show (offset_scale);
 
   /*  the paint mode menu  */
-  label = gtk_label_new ("Mode:");
+  label = gtk_label_new (_("Mode:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -424,7 +448,7 @@ create_blend_options ()
   gtk_widget_show (pm_option_menu);
 
   /*  the blend mode menu  */
-  label = gtk_label_new ("Blend:");
+  label = gtk_label_new (_("Blend:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -437,7 +461,7 @@ create_blend_options ()
   gtk_widget_show (bm_option_menu);
 
   /*  the gradient type menu  */
-  label = gtk_label_new ("Gradient:");
+  label = gtk_label_new (_("Gradient:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -451,7 +475,7 @@ create_blend_options ()
 
   /* the repeat option */
 
-  label = gtk_label_new("Repeat:");
+  label = gtk_label_new(_("Repeat:"));
   gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6,
 		   GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -493,7 +517,7 @@ create_blend_options ()
 
   /* max depth scale */
 
-  label = gtk_label_new("Max depth:");
+  label = gtk_label_new(_("Max depth:"));
   gtk_misc_set_alignment(GTK_MISC(label), 0.0, 1.0);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
 		   GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -512,7 +536,7 @@ create_blend_options ()
 
   /* threshold scale */
 
-  label = gtk_label_new("Threshold:");
+  label = gtk_label_new(_("Threshold:"));
   gtk_misc_set_alignment(GTK_MISC(label), 0.0, 1.0);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
 		   GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 2);
@@ -565,7 +589,7 @@ int x;
 
   if (tag_format (drawable_tag (gimage_active_drawable (gdisp->gimage))) == FORMAT_INDEXED)
     {
-      g_message ("Blend: Invalid for indexed images.");
+      g_message (_("Blend: Invalid for indexed images."));
       return;
     }
 
@@ -637,7 +661,7 @@ blend_button_release (Tool           *tool,
       if (return_vals[0].value.pdb_int == PDB_SUCCESS)
 	gdisplays_flush ();
       else
-	g_message ("Blend operation failed.");
+	g_message (_("Blend operation failed."));
 
       procedural_db_destroy_args (return_vals, nreturn_vals);
     }
@@ -750,7 +774,7 @@ blend_control (Tool     *tool,
 
 /*  The actual blending procedure  */
 static void
-blend (GImage       *gimage,
+cp_blend (GImage       *gimage,
        CanvasDrawable *drawable,
        BlendMode     blend_mode,
        int           paint_mode,
@@ -1301,7 +1325,7 @@ gradient_render_pixel(double x, double y, gfloat *color, void *render_data)
       break;
 
     default:
-      fatal_error("gradient_render_pixel(): unknown gradient type %d",
+      fatal_error(_("gradient_render_pixel(): unknown gradient type %d"),
 		  (int) rbd->gradient_type);
       return;
     }
@@ -1449,7 +1473,7 @@ gradient_fill_region (GImage       *gimage,
       break;
 
     default:
-      fatal_error("gradient_fill_region(): unknown blend mode %d",
+      fatal_error(_("gradient_fill_region(): unknown blend mode %d"),
 		  (int) blend_mode);
       break;
     }
@@ -1490,7 +1514,7 @@ gradient_fill_region (GImage       *gimage,
       break;
 
     default:
-      fatal_error("gradient_fill_region(): unknown gradient type %d",
+      fatal_error(_("gradient_fill_region(): unknown gradient type %d"),
 		  (int) gradient_type);
       break;
     }
@@ -1512,7 +1536,7 @@ gradient_fill_region (GImage       *gimage,
       break;
 
     default:
-      fatal_error("gradient_fill_region(): unknown repeat mode %d",
+      fatal_error(_("gradient_fill_region(): unknown repeat mode %d"),
 		  (int) repeat);
       break;
     }
@@ -1854,11 +1878,11 @@ ProcArg blend_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "The image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "The affected drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "blend_mode",
@@ -2093,7 +2117,7 @@ blend_invoker (Argument *args)
   /*  call the blend procedure  */
   if (success)
     {
-      blend (gimage, drawable, blend_mode, paint_mode, gradient_type,
+      cp_blend (gimage, drawable, blend_mode, paint_mode, gradient_type,
 	     opacity, offset, repeat, supersample, max_depth, threshold, x1, y1, x2, y2);
     }
 
