@@ -202,7 +202,7 @@ brush_edit_generated_new ()
   begw->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (begw->shell), "generatedbrusheditor",PROGRAM_NAME);
   gtk_window_set_title (GTK_WINDOW (begw->shell), _("Brush Editor"));
-  gtk_window_set_policy(GTK_WINDOW(begw->shell), FALSE, TRUE, FALSE);
+  /* gtk_window_set_policy(GTK_WINDOW(begw->shell), FALSE, TRUE, FALSE); */
   gtk_widget_set_uposition(begw->shell, brush_edit_x, brush_edit_y);
   minimize_register(begw->shell);
   layout_connect_window_position(begw->shell, &brush_edit_x, &brush_edit_y, TRUE);
@@ -248,7 +248,7 @@ brush_edit_generated_new ()
   label = gtk_label_new (_("Radius:"));
   gtk_misc_set_alignment (GTK_MISC(label), 1.0, 0.5);
 /*  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 0, 1, 0, 0, 0, 0); */
-  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 0, 1, 3, 0, 0, 0);
+  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
   begw->radius_data = GTK_ADJUSTMENT (gtk_adjustment_new (10.0, 0.0, 300.0, 0.1, 1.0, 0.0));
   slider = gtk_hscale_new (begw->radius_data);
   gtk_table_attach_defaults(GTK_TABLE (table), slider, 1, 2, 0, 1);
@@ -264,7 +264,7 @@ brush_edit_generated_new ()
   
   label = gtk_label_new (_("Hardness:"));
   gtk_misc_set_alignment (GTK_MISC(label), 1.0, 0.5);
-  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 1, 2, 0, 0, 0, 0);
+  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
   begw->hardness_data = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 1.0, 0.01, 0.01, 0.0));
   slider = gtk_hscale_new (begw->hardness_data);
   gtk_table_attach_defaults(GTK_TABLE (table), slider, 1, 2, 1, 2);
@@ -280,7 +280,7 @@ brush_edit_generated_new ()
   
   label = gtk_label_new (_("Aspect Ratio:"));
   gtk_misc_set_alignment (GTK_MISC(label), 1.0, 0.5);
-  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 2, 3, 0, 0, 0, 0);
+  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
   begw->aspect_ratio_data = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 1.0, 20.0, 0.1, 1.0, 0.0));
   slider = gtk_hscale_new (begw->aspect_ratio_data);
   gtk_table_attach_defaults(GTK_TABLE (table), slider, 1, 2, 2, 3);
@@ -296,7 +296,7 @@ brush_edit_generated_new ()
 
   label = gtk_label_new (_("Angle:"));
   gtk_misc_set_alignment (GTK_MISC(label), 1.0, 0.5);
-  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 3, 4, 0, 0, 0, 0);
+  gtk_table_attach(GTK_TABLE (table), label, 0, 1, 3, 4, GTK_FILL, 0, 0, 0);
   begw->angle_data = GTK_ADJUSTMENT (gtk_adjustment_new (00.0, 0.0, 180.0, 0.1, 1.0, 0.0));
   slider = gtk_hscale_new (begw->angle_data);
   gtk_table_attach_defaults(GTK_TABLE (table), slider, 1, 2, 3, 4);
