@@ -104,7 +104,7 @@ gimp_brush_list_class_init (GimpBrushListClass *klass)
   gimp_list_class = GIMP_LIST_CLASS(klass);
   gimp_list_class->add = gimp_brush_list_add_func;
   gimp_list_class->remove = gimp_brush_list_remove_func;
-  parent_class = gtk_type_class (gimp_list_get_type ());
+  parent_class = gtk_type_class (GIMP_TYPE_LIST);
 }
 
 void
@@ -118,6 +118,23 @@ GtkType gimp_brush_list_get_type(void)
   static GtkType type;
   if(!type)
   {
+#if GTK_MAJOR_VERSION > 1
+      static const GTypeInfo info =
+      {
+        sizeof (GimpBrushListClass),
+        (GBaseInitFunc) NULL,
+        (GBaseFinalizeFunc) NULL,
+        (GClassInitFunc) gimp_brush_list_class_init,
+        NULL,           /* class_finalize */
+        NULL,           /* class_data     */
+        sizeof (GimpBrushList),
+        0,              /* n_preallocs    */
+        (GInstanceInitFunc) gimp_brush_list_init,
+      };
+      type = g_type_register_static (GIMP_TYPE_LIST,
+                                              "GimpBrushList",
+                                              &info, 0);
+#else
     GtkTypeInfo info={
       "GimpBrushList",
       sizeof(GimpBrushList),
@@ -126,7 +143,8 @@ GtkType gimp_brush_list_get_type(void)
       (GtkObjectInitFunc)gimp_brush_list_init,
       NULL,
       NULL };
-    type=gtk_type_unique(gimp_list_get_type(), &info);
+    type=gtk_type_unique(GIMP_TYPE_LIST, &info);
+#endif
   }
   return type;
 }
@@ -134,10 +152,19 @@ GtkType gimp_brush_list_get_type(void)
 GimpBrushList *
 gimp_brush_list_new ()
 {
-  GimpBrushList *list=GIMP_BRUSH_LIST(gtk_type_new(gimp_brush_list_get_type()));
+#if 1
+  GimpBrushList *list=GIMP_BRUSH_LIST(gtk_type_new(GIMP_TYPE_BRUSH_LIST));
+#else
+  GtkObject *obj = NULL;
+  GimpBrushList *list = NULL;
+  GtkType type = GIMP_TYPE_BRUSH_LIST;
+
+  GTK_TYPE_IS_OBJECT(type);
+  obj = gtk_type_new(type);
+  list = GIMP_BRUSH_LIST(obj);
+#endif
   GIMP_LIST(list)->type = GIMP_TYPE_BRUSH;
   GIMP_LIST(list)->weak = 0;
-  
   return list;
 }
 
