@@ -16,6 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #include <stdlib.h>
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "depth/brush_select.h"
 #include "bucket_fill.h"
@@ -136,7 +137,7 @@ create_bucket_options (void)
   vbox = gtk_vbox_new (FALSE, 1);
 
   /*  the main label  */
-  label = gtk_label_new ("Bucket Fill Options");
+  label = gtk_label_new (_("Bucket Fill Options"));
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -144,7 +145,7 @@ create_bucket_options (void)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Fill Opacity");
+  label = gtk_label_new (_("Fill Opacity"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -163,7 +164,7 @@ create_bucket_options (void)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Fill Threshold");
+  label = gtk_label_new (_("Fill Threshold"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -182,7 +183,7 @@ create_bucket_options (void)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (hbox), 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  label = gtk_label_new ("Mode:");
+  label = gtk_label_new (_("Mode:"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
   menu = create_paint_mode_menu (bucket_fill_paint_mode_callback, NULL);
   option_menu = gtk_option_menu_new ();
@@ -193,7 +194,7 @@ create_bucket_options (void)
   gtk_widget_show (hbox);
 
   /*  the sample merged toggle  */
-  sample_merged_toggle = gtk_check_button_new_with_label ("Sample Merged");
+  sample_merged_toggle = gtk_check_button_new_with_label (_("Sample Merged"));
   gtk_signal_connect (GTK_OBJECT (sample_merged_toggle), "toggled",
 		      (GtkSignalFunc) bucket_fill_toggle_update,
 		      &options->sample_merged);
@@ -285,7 +286,7 @@ bucket_fill_button_release (tool, bevent, gdisp_ptr)
       if (return_vals[0].value.pdb_int == PDB_SUCCESS)
 	gdisplays_flush ();
       else
-	g_message ("Bucket Fill operation failed.");
+	g_message (_("Bucket Fill operation failed."));
 
       procedural_db_destroy_args (return_vals, nreturn_vals);
     }
@@ -371,7 +372,7 @@ bucket_fill (gimage, drawable, fill_mode, paint_mode,
     case BgColorFill:
       break;
     default:
-      g_warning ("bad fill type");
+      g_warning (_("bad fill type"));
       return;
     }
 
@@ -482,7 +483,7 @@ bucket_fill (gimage, drawable, fill_mode, paint_mode,
         break;
       
       default:
-        g_warning ("bad fill type");
+        g_warning (_("bad fill type"));
         return;
       }
 
