@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "boundary.h"
 #include "by_color_select.h"
@@ -436,10 +437,10 @@ by_color_select_new_dialog ()
   guint i;
   char *button_names[4] =
   {
-    "Replace",
-    "Add",
-    "Subtract",
-    "Intersect"
+    _("Replace"),
+    _("Add"),
+    _("Subtract"),
+    _("Intersect")
   };
   int button_values[4] =
   {
@@ -457,7 +458,7 @@ by_color_select_new_dialog ()
   /*  The shell and main vbox  */
   bcd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (bcd->shell), "by_color_selection", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (bcd->shell), "By Color Selection");
+  gtk_window_set_title (GTK_WINDOW (bcd->shell), _("By Color Selection"));
   gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (bcd->shell)->action_area), 2);
   minimize_register(bcd->shell);
 
@@ -481,7 +482,7 @@ by_color_select_new_dialog ()
   gtk_box_pack_start (GTK_BOX (hbox), options_box, TRUE, TRUE, 0);
 
   /*  Create the selection mode radio box  */
-  frame = gtk_frame_new ("Selection Mode");
+  frame = gtk_frame_new (_("Selection Mode"));
   gtk_box_pack_start (GTK_BOX (options_box), frame, FALSE, FALSE, 0);
 
   radio_box = gtk_vbox_new (FALSE, 2);
@@ -504,7 +505,7 @@ by_color_select_new_dialog ()
   /*  Create the opacity scale widget  */
   util_box = gtk_vbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (options_box), util_box, FALSE, FALSE, 0);
-  label = gtk_label_new ("Fuzziness Threshold");
+  label = gtk_label_new (_("Fuzziness Threshold"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
   data = gtk_adjustment_new (bcd->threshold, 0.0, 1.0, 0.01, 0.1, 0.0);
   slider = gtk_hscale_new (GTK_ADJUSTMENT (data));
@@ -520,7 +521,7 @@ by_color_select_new_dialog ()
   gtk_widget_show (util_box);
 
   /*  The reset push button  */
-  push_button = gtk_button_new_with_label ("Reset");
+  push_button = gtk_button_new_with_label (_("Reset"));
   GTK_WIDGET_SET_FLAGS (push_button, GTK_CAN_DEFAULT);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (bcd->shell)->action_area), push_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (push_button), "clicked",
@@ -530,7 +531,7 @@ by_color_select_new_dialog ()
   gtk_widget_show (push_button);
 
   /*  The close push button  */
-  push_button = gtk_button_new_with_label ("Close");
+  push_button = gtk_button_new_with_label (_("Close"));
   GTK_WIDGET_SET_FLAGS (push_button, GTK_CAN_DEFAULT);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (bcd->shell)->action_area), push_button, TRUE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (push_button), "clicked",
