@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "canvas.h"
@@ -110,7 +111,7 @@ channel_ops_offset (void *gimage_ptr)
 
   off_d->dlg = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (off_d->dlg), "offset", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (off_d->dlg), "Offset");
+  gtk_window_set_title (GTK_WINDOW (off_d->dlg), _("Offset"));
 
   minimize_register(off_d->dlg);
   gtk_widget_set_uposition(off_d->dlg, generic_window_x, generic_window_y);
@@ -122,7 +123,7 @@ channel_ops_offset (void *gimage_ptr)
 		      off_d);
 
   /*  Action area  */
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) offset_ok_callback,
@@ -131,7 +132,7 @@ channel_ops_offset (void *gimage_ptr)
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) offset_cancel_callback,
@@ -148,7 +149,7 @@ channel_ops_offset (void *gimage_ptr)
   table = gtk_table_new (2, 2, FALSE);
   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
 
-  label = gtk_label_new ("Offset X:");
+  label = gtk_label_new (_("Offset X:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
   off_d->off_x_entry = gtk_entry_new ();
@@ -158,7 +159,7 @@ channel_ops_offset (void *gimage_ptr)
   gtk_widget_show (label);
   gtk_widget_show (off_d->off_x_entry);
 
-  label = gtk_label_new ("Offset Y:");
+  label = gtk_label_new (_("Offset Y:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
   off_d->off_y_entry = gtk_entry_new ();
@@ -170,19 +171,19 @@ channel_ops_offset (void *gimage_ptr)
   gtk_widget_show (table);
 
   /*  the wrap around option  */
-  check = gtk_check_button_new_with_label ("Wrap-Around");
+  check = gtk_check_button_new_with_label (_("Wrap-Around"));
   gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, FALSE, 0);
   gtk_widget_show (check);
 
   /*  The fill options  */
-  off_d->fill_options = gtk_frame_new ("Fill Options");
+  off_d->fill_options = gtk_frame_new (_("Fill Options"));
   gtk_frame_set_shadow_type (GTK_FRAME (off_d->fill_options), GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_start (GTK_BOX (vbox), off_d->fill_options, FALSE, TRUE, 0);
   toggle_vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (toggle_vbox), 5);
   gtk_container_add (GTK_CONTAINER (off_d->fill_options), toggle_vbox);
 
-  toggle = gtk_radio_button_new_with_label (group, "Background");
+  toggle = gtk_radio_button_new_with_label (group, _("Background"));
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
   gtk_box_pack_start (GTK_BOX (toggle_vbox), toggle, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -193,7 +194,7 @@ channel_ops_offset (void *gimage_ptr)
 
   if (drawable_has_alpha (drawable))
     {
-      toggle = gtk_radio_button_new_with_label (group, "Transparent");
+      toggle = gtk_radio_button_new_with_label (group, _("Transparent"));
       group = gtk_radio_button_group (GTK_RADIO_BUTTON (toggle));
       gtk_box_pack_start (GTK_BOX (toggle_vbox), toggle, FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -204,7 +205,7 @@ channel_ops_offset (void *gimage_ptr)
     }
 
   /*  the by half height and half width offtion */
-  push = gtk_button_new_with_label ("Offset by (x/2),(y/2)");
+  push = gtk_button_new_with_label (_("Offset by (x/2),(y/2)"));
   gtk_box_pack_start (GTK_BOX (vbox), push, FALSE, FALSE,0);
   gtk_widget_show (push);
 
