@@ -134,6 +134,7 @@ static void channels_dialog_channel_to_sel_callback (GtkWidget *, gpointer);
 /*  channel widget function prototypes  */
 static ChannelWidget *channel_widget_get_ID (Channel *);
 static ChannelWidget *create_channel_widget (GImage *, Channel *, ChannelType);
+static gint channel_widget_list_pos (ChannelType);
 static void channel_widget_delete (ChannelWidget *);
 static void channel_widget_select_update (GtkWidget *, gpointer);
 static gint channel_widget_button_events (GtkWidget *, GdkEvent *);
@@ -638,19 +639,19 @@ channels_dialog_set_menu_sensitivity ()
 
   /* new channel */
   gtk_widget_set_sensitive (channels_ops[0].widget, !fs_sensitive);
-  ops_button_set_sensitive (channels_ops_buttons[0], !fs_sensitive);
+  ops_button_set_sensitive (&channels_ops_buttons[0], !fs_sensitive);
   /* raise channel */
   gtk_widget_set_sensitive (channels_ops[1].widget, !fs_sensitive && aux_sensitive);
-  ops_button_set_sensitive (channels_ops_buttons[1], !fs_sensitive && aux_sensitive);
+  ops_button_set_sensitive (&channels_ops_buttons[1], !fs_sensitive && aux_sensitive);
   /* lower channel */
   gtk_widget_set_sensitive (channels_ops[2].widget, !fs_sensitive && aux_sensitive);
-  ops_button_set_sensitive (channels_ops_buttons[2], !fs_sensitive && aux_sensitive);
+  ops_button_set_sensitive (&channels_ops_buttons[2], !fs_sensitive && aux_sensitive);
   /* duplicate channel */
   gtk_widget_set_sensitive (channels_ops[3].widget, !fs_sensitive && aux_sensitive);
-  ops_button_set_sensitive (channels_ops_buttons[3], !fs_sensitive && aux_sensitive);
+  ops_button_set_sensitive (&channels_ops_buttons[3], !fs_sensitive && aux_sensitive);
   /* delete channel */
   gtk_widget_set_sensitive (channels_ops[4].widget, !fs_sensitive && aux_sensitive);
-  ops_button_set_sensitive (channels_ops_buttons[4], !fs_sensitive && aux_sensitive);
+  ops_button_set_sensitive (&channels_ops_buttons[4], !fs_sensitive && aux_sensitive);
   /* channel to selection */
   gtk_widget_set_sensitive (channels_ops[5].widget, aux_sensitive);
 }
@@ -686,26 +687,9 @@ channels_dialog_set_channel (ChannelWidget *channel_widget)
     {
       if (state != GTK_STATE_SELECTED)
 	{
+          gint pos = channel_widget_list_pos( channel_widget->type );
 	  gtk_object_set_user_data (GTK_OBJECT (channel_widget->list_item), NULL);
-	  switch (channel_widget->type)
-	    {
-	    case Red: case Gray: case Indexed:
-	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 0);
-	      break;
-	    case Green:
-	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 1);
-	      break;
-	    case Blue:
-	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 2);
-	      break;
-        case Matte:
-	      gtk_list_select_item (GTK_LIST (channelsD->channel_list), 3);
-	      break;
-	    case Auxillary:
-	      g_error ("error Matte in %s at %d: this shouldn't happen.",
-		       __FILE__, __LINE__);
-	      break;
-	    }
+	  gtk_list_select_item (GTK_LIST (channelsD->channel_list), pos);
 	  gtk_object_set_user_data (GTK_OBJECT (channel_widget->list_item), channel_widget);
 	}
     }
@@ -743,26 +727,9 @@ channels_dialog_unset_channel (ChannelWidget * channel_widget)
     {
       if (state == GTK_STATE_SELECTED)
 	{
+          gint pos = channel_widget_list_pos( channel_widget->type );
 	  gtk_object_set_user_data (GTK_OBJECT (channel_widget->list_item), NULL);
-	  switch (channel_widget->type)
-	    {
-	    case Red: case Gray: case Indexed:
-	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 0);
-	      break;
-	    case Green:
-	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 1);
-	      break;
-	    case Blue:
-	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 2);
-	      break;
-        case Matte:
-	      gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), 3);
-	      break;
-	    case Auxillary:
-	      g_error ("error Matte[2] in %s at %d: this shouldn't happen.",
-		       __FILE__, __LINE__);
-	      break;
-	    }
+	  gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), pos);
 	  gtk_object_set_user_data (GTK_OBJECT (channel_widget->list_item), channel_widget);
 	}
     }
@@ -770,6 +737,31 @@ channels_dialog_unset_channel (ChannelWidget * channel_widget)
   suspend_gimage_notify--;
 }
 
+static gint
+channel_widget_list_pos (ChannelType type)
+{
+  gint pos = 0;
+  switch (type)
+    {
+    case Red: case Gray: case Indexed:
+      pos = 0;
+      break;
+    case Green:
+      pos = 1;
+      break;
+    case Blue:
+      pos = 2;
+      break;
+    case Matte:
+      pos = 3;
+      break;
+    case Auxillary:
+      g_error ("error Matte[2] in %s at %d: this shouldn't happen.",
+	       __FILE__, __LINE__);
+      break;
+    }
+  return pos;
+}
 
 static void
 channels_dialog_position_channel (ChannelWidget *channel_widget,
@@ -1217,11 +1209,9 @@ channel_widget_select_update (GtkWidget *w,
     {
       if (channel_widget->type == Auxillary)
 	{
-	  if (w->state == GTK_STATE_SELECTED)
-	    {
+	  if (!channel_widget->gimage->active_channel)
 	    /*  set the gimage's active channel to be this channel  */
-	      gimage_set_active_channel (channel_widget->gimage, channel_widget->channel);
-	    }
+	    gimage_set_active_channel (channel_widget->gimage, channel_widget->channel);
 	  else
 	    /*  unset the gimage's active channel  */
 	    gimage_unset_active_channel (channel_widget->gimage, channel_widget->channel);
@@ -1230,10 +1220,24 @@ channel_widget_select_update (GtkWidget *w,
 	}
       else if (channel_widget->type != Auxillary)
 	{
+          gint pos = channel_widget_list_pos( channel_widget->type );
+#if GTK_MAJOR_VERSION > 1
+	  if (!channel_widget->gimage->active[ channel_widget->type ])
+#else
 	  if (w->state == GTK_STATE_SELECTED)
+#endif
 	    gimage_set_component_active (channel_widget->gimage, channel_widget->type, TRUE);
 	  else
 	    gimage_set_component_active (channel_widget->gimage, channel_widget->type, FALSE);
+#if GTK_MAJOR_VERSION > 1
+          /* update the list view */
+          ++suspend_gimage_notify;
+          if(channel_widget->gimage->active[ channel_widget->type ])
+            gtk_list_select_item (GTK_LIST (channelsD->channel_list), pos);
+          else
+            gtk_list_unselect_item (GTK_LIST (channelsD->channel_list), pos);
+          --suspend_gimage_notify;
+#endif
 	}
     }
 }
