@@ -1,6 +1,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "../lib/version.h"
+#include "../lib/compat.h"
 #include "color_correction.h"
 #include "color_correction_gui.h"
 #include "image_map.h"
@@ -925,6 +926,8 @@ _color_correction_gui_draw_wheel_handle (GtkWidget *drawing_area, _ColorCorrecti
 		   data->position[X], data->position[Y]);
     {
       GdkRectangle update_area = {data->position[X]-5, data->position[Y]-5, 11, 11};
+      update_area.x = data->position[X]-5;
+      update_area.y = data->position[Y]-5;
       gtk_widget_draw(drawing_area, &update_area);
     }
 }
@@ -933,6 +936,8 @@ _color_correction_gui_draw_wheel_handle (GtkWidget *drawing_area, _ColorCorrecti
 static void
 _color_correction_gui_erase_wheel_handle (GtkWidget *drawing_area, _ColorCorrectionGuiWheel *data)
 {   GdkRectangle update_area = {data->position[X]-5, data->position[Y]-5, 11, 11};
+    update_area.x = data->position[X]-5;
+    update_area.y = data->position[Y]-5;
     /* overwrite the handle with the corresponding bit of the original pixmap */
     gdk_draw_pixmap(data->display_buffer, data->gc,
 		    data->pixmap, 
@@ -959,7 +964,7 @@ _color_correction_gui_draw_wheel_toggle(GtkWidget *drawing_area)
 	gdk_draw_line(data->display_buffer, data->gc, 4,4,26,4);
 	gdk_draw_line(data->display_buffer, data->gc, 4,4,4,19);
 	gdk_gc_set_foreground(data->gc, &GTK_WIDGET(drawing_area)->style->mid[GTK_STATE_NORMAL]);
-	gdk_draw_text(data->display_buffer, GTK_WIDGET(drawing_area)->style->font,
+	gdk_draw_text(data->display_buffer, gtk_style_get_font(GTK_WIDGET(drawing_area)->style),
 		      GTK_WIDGET(drawing_area)->style->light_gc[GTK_STATE_NORMAL], 5, 17, 
 		      color_correction_wheel_labels[data->range], 3);
     }
@@ -976,7 +981,7 @@ _color_correction_gui_draw_wheel_toggle(GtkWidget *drawing_area)
 	gdk_draw_line(data->display_buffer, data->gc, 4,21,27,21);
 	gdk_draw_line(data->display_buffer, data->gc, 27,4,27,21);
 	gdk_gc_set_foreground(data->gc, &GTK_WIDGET(drawing_area)->style->mid[GTK_STATE_NORMAL]);
-	gdk_draw_text(data->display_buffer, GTK_WIDGET(drawing_area)->style->font,
+	gdk_draw_text(data->display_buffer, gtk_style_get_font( GTK_WIDGET(drawing_area)->style ),
 		      GTK_WIDGET(drawing_area)->style->light_gc[GTK_STATE_NORMAL], 5, 17, 
 		      color_correction_wheel_labels[data->range], 3);
     }
@@ -1130,6 +1135,7 @@ _color_correction_gui_draw_lslider_handle (GtkWidget *drawing_area, _ColorCorrec
 		  0, data->position+2, LSLIDER_WIDTH, data->position+2);
     {
       GdkRectangle update_area = {0, data->position-2, LSLIDER_WIDTH, 5};
+      update_area.y = data->position-2;
       gtk_widget_draw(drawing_area, &update_area);
     }
 }
@@ -1138,6 +1144,7 @@ _color_correction_gui_draw_lslider_handle (GtkWidget *drawing_area, _ColorCorrec
 static void
 _color_correction_gui_erase_lslider_handle (GtkWidget *drawing_area, _ColorCorrectionGuiLSlider *data)
 {   GdkRectangle update_area = {0, data->position-2, LSLIDER_WIDTH, 5};
+    update_area.y = data->position-2;
     gdk_draw_pixmap(data->display_buffer, data->gc,
 		    data->pixmap, 
 		    update_area.x, update_area.y,
