@@ -311,6 +311,7 @@ convert_image_colorspace (void *gimage_ptr, CMSProfile *new_profile,
     DWORD lcms_format_out;
     CMSTransform *transform;
     DWORD cms_flags = 0;
+    Tag tag;
 
     /*  get the profiles */
     GSList *profiles = NULL;
@@ -328,13 +329,11 @@ convert_image_colorspace (void *gimage_ptr, CMSProfile *new_profile,
     { layer_add_alpha( image->active_layer );
     }
 
+    tag = drawable_tag(GIMP_DRAWABLE(image->active_layer));
+
     /* assuming all layers have homogenous alpha */
-    lcms_format_in  = cms_get_lcms_format(
-                              drawable_tag(GIMP_DRAWABLE(image->active_layer)),
-                              image_profile  );
-    lcms_format_out = cms_get_lcms_format(
-                              drawable_tag(GIMP_DRAWABLE(image->active_layer)),
-                              new_profile  );
+    lcms_format_in  = cms_get_lcms_format( tag, image_profile  );
+    lcms_format_out = cms_get_lcms_format( tag, new_profile  );
     if  (!(int)lcms_format_in || !(int)lcms_format_out)
     {   g_warning("%s:%d %s(): wrong lcms_format %d|%d",
                   __FILE__,__LINE__,__func__,
@@ -352,7 +351,7 @@ convert_image_colorspace (void *gimage_ptr, CMSProfile *new_profile,
 
     transform = cms_get_transform(profiles, lcms_format_in, lcms_format_out,
                                             lcms_intent, cms_flags,
-                                            0, NULL);
+                                            0, tag, NULL);
     g_slist_free(profiles);
     if(!transform)
     {   g_warning("%s:%d %s(): transform failed", __FILE__,__LINE__,__func__);
@@ -574,7 +573,7 @@ convert_to_indexed (void *gimage_ptr)
       dialog->num_cols = 255;
       if (!shown_message_already)
 	{
-	  g_message (_("Note:  You are attempting to convert an image\nwith alpha/layers.  It is recommended that you quantize\nto no more than 255 colors if you wish to make\na transparent or animated GIF from it.\n\nYou won't get this message again\nuntil the next time you run GIMP.\nHave a nice day!"));
+	  g_message (_("Note:  You are attempting to convert an image\nwith alpha/layers.  It is recommended that you quantize\nto no more than 255 colors if you wish to make\na transparent or animated GIF from it.\n \nThis message will not be shown again\nuntil after restart."));
 	  shown_message_already = True;
 	}
     }
