@@ -38,15 +38,15 @@
 
 #define TEXT_WIDTH 45
 #define TEXT_HEIGHT 25
-#define SLIDER_WIDTH 200
-#define SLIDER_HEIGHT 35
+#define SLIDER_WIDTH 300
+#define SLIDER_HEIGHT 40
 
 #define BRIGHTNESS_SLIDER 0x1
 #define CONTRAST_SLIDER   0x2
 #define BRIGHTNESS_TEXT   0x4
 #define CONTRAST_TEXT     0x8
 #define ALL               0xF
-
+  
 typedef struct BrightnessContrast BrightnessContrast;
 
 struct BrightnessContrast
@@ -74,10 +74,6 @@ struct BrightnessContrastDialog
   gint         preview;
 };
 
-/* brightness and contrast transfer luts */
-static PixelRow brightness_lut;
-static PixelRow contrast_lut;
-
 /*  brightness contrast action functions  */
 
 static void   brightness_contrast_button_press   (Tool *, GdkEventButton *, gpointer);
@@ -105,30 +101,20 @@ static BrightnessContrastDialog *brightness_contrast_dialog = NULL;
 
 static Argument * brightness_contrast_invoker  (Argument *);
 
-static double brightness_func (double, double);
-static double contrast_func (double, double);
-
 static void brightness_contrast_funcs (Tag); 
 
 /* data type function pointers */
-typedef void (*BrightnessContrastInitTransfersFunc)(void *);
-static BrightnessContrastInitTransfersFunc brightness_contrast_init_transfers;
 typedef void (*BrightnessContrastFunc)(PixelArea *, PixelArea *, void *);
 static BrightnessContrastFunc brightness_contrast;
 
-static void brightness_contrast_init_transfers_u8 (void *);
 static void brightness_contrast_u8 (PixelArea *, PixelArea *, void *);
 
-static void brightness_contrast_init_transfers_u16 (void *);
 static void brightness_contrast_u16 (PixelArea *, PixelArea *, void *);
 
-static void brightness_contrast_init_transfers_float(void *);
 static void brightness_contrast_float (PixelArea *, PixelArea *, void *);
 
-static void brightness_contrast_init_transfers_float16(void *);
 static void brightness_contrast_float16 (PixelArea *, PixelArea *, void *);
 
-static void brightness_contrast_init_transfers_bfp (void *);
 static void brightness_contrast_bfp (PixelArea *, PixelArea *, void *);
 
 static void
@@ -138,227 +124,37 @@ brightness_contrast_funcs (Tag drawable_tag)
   {
   case PRECISION_U8:
     brightness_contrast = brightness_contrast_u8;
-    brightness_contrast_init_transfers = brightness_contrast_init_transfers_u8;
     break;
   case PRECISION_U16:
     brightness_contrast = brightness_contrast_u16;
-    brightness_contrast_init_transfers = brightness_contrast_init_transfers_u16;
     break;
   case PRECISION_FLOAT:
     brightness_contrast = brightness_contrast_float;
-    brightness_contrast_init_transfers = brightness_contrast_init_transfers_float;
     break;
   case PRECISION_FLOAT16:
     brightness_contrast = brightness_contrast_float16;
-    brightness_contrast_init_transfers = brightness_contrast_init_transfers_float16;
     break;
   case PRECISION_BFP:
     brightness_contrast = brightness_contrast_bfp;
-    brightness_contrast_init_transfers = brightness_contrast_init_transfers_bfp;
     break;
   default:
     brightness_contrast = NULL;
-    brightness_contrast_init_transfers = NULL;
     break; 
   }
 }
 
-/*  brightness contrast machinery  */
+/* 
+Brightness Contrast Functions
 
-#if 0
-static double brightness_func (double x, double b)
-{
-  if (b < 0)
-    return  x * (1.0 + b);
-  else
-    return x + (1.0 - x) * b; 
-}
+Note on the calculation of the contrast
+   
+Gain is computed from the contrast setting as follows:
 
-static double contrast_func (double x, double c)
-{
-  double value, power;
-  value = (x > .5) ? (1.0 - x) : x;
-  if (c < 0)
-  {
-    /*value = value ? value : .0039215;*/
-    power = 1.0 +  2.0 * c;
-  }
-  else
-  {
-    power = (c == .5) ? .5 : 1.0 / (1.0 - 2.0*c);
-  }
-  value = .5 * pow ( 2.0 * value , power );  
-  value = BOUNDS (value, 0.0, 1.0);
-  return (x > .5) ? (1.0 - value) : value;
-}
-#endif
-
-static float mean = .5;
-
-static double brightness_func (double x, double b)
-{
-  return  (x  + .392 * b);
-}
-
-static double contrast_func (double x, double c)
-{
-  if (c==0.0)
-   return x;
-  else if (c > 0.0 && c <1.0)
-   {                              /* note: clipping here */
-     float x0;
-     float slope;
-     float x1;
-       x0 = c * mean;
-       slope = mean/(mean - x0);
-       x1 = x0 + 1/slope;
-    if (x <= x0)
-	  return 0;
-	else if ( x > x0 && x < x1)
-	  return slope * (x-x0);
-	else if (x >= x1 && x <= 1.0)
-	  return 1.0;
-	else if (x > 1.0)
-	  return x; 
-   }
-  else if (c == 1.0)
-   {
-      if (x < mean) return 0.0;	      /* note: clipping here */
-      else if (x >= mean && x <=1.0) 
-		return 1.0;	
-	  else if (x > 1.0)
-		return x;
-   }
-   else if (c < 0.0 && c > -1.0)
-   {
-      float y0;
-      float slope;
-	y0 = -c * mean;
-	slope = (mean - y0)/mean;
-	return slope * x + y0;
-   }
-  else if (c == -1.0)
-   {
-     return mean; 
-   }
-  
- g_warning("contrast_func out of range");
- return 0;
-}
-
-static void 
-brightness_contrast_init_transfers_u8 (void * user_data)
-{
-  gint i;
-  BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  guint8 *brightness_data = (guint8*) pixelrow_data (&brightness_lut);
-  guint8 *contrast_data = (guint8*) pixelrow_data (&contrast_lut);
-  Tag lut_tag = tag_new (PRECISION_U8, FORMAT_GRAY, ALPHA_NO);
-  gdouble brightness = bcd->brightness;
-  gdouble contrast = bcd->contrast;
-  
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!brightness_data && !contrast_data)
-  {
-    brightness_data = (guint8 *)g_malloc ( sizeof (guint8) * 256 );
-    contrast_data = (guint8 *)g_malloc ( sizeof (guint8) * 256 );
-  }
-  
-  for (i = 0; i < 256; i++)
-    brightness_data[i] = (guint8) (255.0 * brightness_func ( (gdouble)i/255.0,
-				      brightness*2.0));
-
-  for (i = 0; i < 256; i++)
-    contrast_data[i] = (guint8) (255.0 * contrast_func ( (gdouble)i/255.0,
-				      contrast*2.0));
-  
-  pixelrow_init (&brightness_lut, lut_tag, brightness_data, 256); 
-  pixelrow_init (&contrast_lut, lut_tag, contrast_data, 256); 
-}
-
-static void 
-brightness_contrast_init_transfers_u16 (void * user_data)
-{
-  gint i;
-  BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  guint16 *brightness_data = (guint16*) pixelrow_data (&brightness_lut);
-  guint16 *contrast_data = (guint16*) pixelrow_data (&contrast_lut);
-  Tag lut_tag = tag_new (PRECISION_U16, FORMAT_GRAY, ALPHA_NO);
-  gdouble brightness = bcd->brightness;
-  gdouble contrast = bcd->contrast;
- 
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!brightness_data && !contrast_data)
-  {
-    brightness_data = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
-    contrast_data = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
-  }
-  
-  for (i = 0; i < 65536; i++)
-    brightness_data[i] = (guint16) (65535.0 * brightness_func ( (gdouble)i/65535.0,
-				      brightness*2.0));
-  for (i = 0; i < 65536; i++)
-    contrast_data[i] = (guint16) (65535.0 * contrast_func ( (double)i/65535.0,
-				      contrast*2.0));
-  
-  pixelrow_init (&brightness_lut, lut_tag, (guchar*)brightness_data, 65536); 
-  pixelrow_init (&contrast_lut, lut_tag, (guchar*)contrast_data, 65536); 
-}
-
-static void 
-brightness_contrast_init_transfers_float (void * user_data)
-{
-}
-
-static void 
-brightness_contrast_init_transfers_float16 (void * user_data)
-{
-}
-
-static void 
-brightness_contrast_init_transfers_bfp (void * user_data)
-{
-  gint i;
-  BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  guint16 *brightness_data = (guint16*) pixelrow_data (&brightness_lut);
-  guint16 *contrast_data = (guint16*) pixelrow_data (&contrast_lut);
-  Tag lut_tag = tag_new (PRECISION_BFP, FORMAT_GRAY, ALPHA_NO);
-  gdouble brightness = bcd->brightness;
-  gdouble contrast = bcd->contrast;
- 
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!brightness_data && !contrast_data)
-  {
-    brightness_data = (guint16 *)g_malloc ( sizeof (guint16) * 65535);
-    contrast_data = (guint16 *)g_malloc ( sizeof (guint16) * 65535 );
-  }
-  
-  /* note: 32768.0 is ONE_BFP in float */
-  for (i = 0; i < 65536; i++)
-    brightness_data[i] = (guint16) (32768.0 * brightness_func ( (gdouble)i/ONE_BFP,
-				      brightness*2.0));
-  for (i = 0; i < 65536; i++)
-    contrast_data[i] = (guint16) (32768.0 * contrast_func ( (double)i/ONE_BFP,
-				      contrast*2.0));
-  
-  pixelrow_init (&brightness_lut, lut_tag, (guchar*)brightness_data, 65536); 
-  pixelrow_init (&contrast_lut, lut_tag, (guchar*)contrast_data, 65536); 
-}
-
-static void 
-brightness_contrast_free_transfers (void)
-{
-  guchar * brightness_lut_data = pixelrow_data (&brightness_lut);
-  guchar * contrast_lut_data = pixelrow_data (&contrast_lut);
-
-  if (brightness_lut_data) 
-    g_free (brightness_lut_data);
-  if (contrast_lut_data)
-    g_free (contrast_lut_data);
-
-  pixelrow_init (&brightness_lut, tag_null(), NULL, 0);
-  pixelrow_init (&contrast_lut, tag_null(), NULL, 0);
-}
+     if -1 <= contrast < 0 ,  0 <= gain < 1
+     if contrast = 0 ; gain = 1  or no change
+     if 0 > contrast < 1 , 1 < gain < infinity
+     
+*/
 
 static void
 brightness_contrast_u8 (PixelArea *src_area,
@@ -375,8 +171,10 @@ brightness_contrast_u8 (PixelArea *src_area,
   int alpha;
   int w, h, b;
   BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  gdouble brightness = (gfloat)bcd->brightness;
-  gdouble contrast = (gfloat)bcd->contrast;
+  gfloat brightness = 255.0f * 0.392f * (gfloat)bcd->brightness;
+  gfloat contrast = (gfloat)bcd->contrast;
+  gfloat tmp, gain = 1.0f ;
+  gfloat dist_shift;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -384,28 +182,54 @@ brightness_contrast_u8 (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+  
+  if (contrast != 0.0f)
+  {
+     if (contrast > 0.0f)
+     {
+        gain = 1.0f / (1.0f - contrast) ;
+     }
+     else if (contrast < 0.0f)
+     {
+        gain = 1.0f + contrast ;
+     }
+  }
+  
+  /* shift after gain application is 1/2(gain * max_value - max_value), max_value = 2^8-1 */
+  /* we also pre-add the rounding factor */
+  dist_shift = (gain * 127.5f - 127.5) - 0.5f ;
+
   while (h--)
-    {
+  {
       s = (guint8*)src;
       d = (guint8*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  // Added by IMAGEWORKS thedoug (01/02)
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(255 * contrast_func(brightness_func(s[b]/255., 
-		   2.*brightness), 2.*contrast), 0, 255);
+	  {
+        for (b = 0; b < alpha; b++)
+        {
+            tmp = brightness + s[b] ;         /* brightness correction */
+            tmp = gain*tmp - dist_shift ;     /* contrast correction */
+             
+            if (tmp < 0.0f)                   
+              tmp = 0.0f ;
+            else if (tmp > 255.0f)
+              tmp = 255.0f ;
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+            d[b] = (guint8)(tmp) ;
+        } 
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+	    if (has_alpha)
+	       d[alpha] = s[alpha];
+
+	    s += src_num_channels;
+	    d += dest_num_channels; 
+	  }
 
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
-    }
+  }
 }
 
 static void
@@ -423,8 +247,10 @@ brightness_contrast_u16 (PixelArea *src_area,
   int alpha;
   int w, h, b;
   BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  gdouble brightness = (gfloat)bcd->brightness;
-  gdouble contrast = (gfloat)bcd->contrast;
+  gfloat brightness = 65535.0f * 0.392f * (gfloat)bcd->brightness;
+  gfloat contrast = (gfloat)bcd->contrast;
+  gfloat tmp, gain;
+  gfloat dist_shift;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -432,24 +258,52 @@ brightness_contrast_u16 (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
+  gain = 1.0f ;
+
+  if (contrast != 0.0f)
+  {
+     if (contrast > 0.0f)
+     {
+        gain = 1.0f / (1.0f - contrast) ;
+     }
+     else if (contrast < 0.0f)
+     {
+        gain = 1.0f + contrast ;
+     }
+  }
+  
+  /* shift after gain application is 1/2(gain * max_value - max_value), max_value = 2^16-1 */
+  /* we also pre-add the rounding factor */
+  dist_shift = (gain * 32767.5f - 32767.5f) - 0.5f ;
+
   while (h--)
     {
       s = (guint16*)src;
       d = (guint16*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  // Added by IMAGEWORKS thedoug (01/02)
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(65535 * contrast_func(brightness_func(s[b]/65535., 
-	           2.*brightness), 2.*contrast), 0, 65535);
+      {
+          for (b = 0; b < alpha; b++)
+          {
+              tmp = brightness + s[b] ;         /* brightness correction */
+              tmp = gain*tmp - dist_shift ;     /* contrast correction */
+             
+              if (tmp < 0.0f)                   
+                tmp = 0.0f ;
+              else if (tmp > 65535.0f)
+                  tmp = 65535.0f ;
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+              d[b] = (guint16)(tmp) ;
+          } 
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+          if (has_alpha)
+            d[alpha] = s[alpha];
+
+          s += src_num_channels;
+          d += dest_num_channels; 
+      }
 
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
@@ -471,8 +325,10 @@ brightness_contrast_float (PixelArea *src_area,
   int alpha;
   int w, h, b;
   BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  gdouble brightness = (gfloat)bcd->brightness;
-  gdouble contrast = (gfloat)bcd->contrast;
+  gfloat brightness = 0.392f * (gfloat)bcd->brightness;
+  gfloat contrast = (gfloat)bcd->contrast;
+  gfloat tmp, gain = 1.0f ;
+  gfloat dist_shift;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -480,26 +336,54 @@ brightness_contrast_float (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
+
+  if (contrast != 0.0f)
+  {
+     if (contrast > 0.0f)
+     {
+        gain = 1.0f / (1.0f - contrast) ;
+     }
+     else if (contrast < 0.0f)
+     {
+        gain = 1.0f + contrast ;
+     }
+  }
+  
+  /* shift after gain application is 1/2(gain * max_value - max_value), max_value = 1.0 */
+  dist_shift = gain * 0.5f - 0.5f ;
+
   while (h--)
-    {
+  {
       s = (gfloat*)src;
       d = (gfloat*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(contrast_func(brightness_func(s[b], 2.*brightness), 2.*contrast), 0, 1);
+	  {
+        for (b = 0; b < alpha; b++)
+        {
+           tmp = brightness + s[b] ;         /* brightness correction */
+           tmp = gain*tmp - dist_shift ;     /* contrast correction */
+             
+           if (tmp < 0.0f)                   
+             tmp = 0.0f ;
+           else if (tmp > 1.0f)
+              tmp = 1.0f ;
+
+           d[b] = tmp ;
+        } 
 
 	  if (has_alpha)
 	    d[alpha] = s[alpha];
 
 	  s += src_num_channels;
 	  d += dest_num_channels; 
-	}
+ 	}
 
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
-    }
+  }
 }
 
 static void
@@ -517,10 +401,12 @@ brightness_contrast_float16 (PixelArea *src_area,
   int alpha;
   int w, h, b;
   BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  gdouble brightness = (gfloat)bcd->brightness;
-  gdouble contrast = (gfloat)bcd->contrast;
+  gfloat brightness = 0.392f * (gfloat)bcd->brightness;
+  gfloat contrast = (gfloat)bcd->contrast;
   ShortsFloat u;
-  gfloat sb, db;
+  gfloat sb ;
+  gfloat tmp, gain = 1.0f ;
+  gfloat dist_shift;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -528,30 +414,55 @@ brightness_contrast_float16 (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
+
+  if (contrast != 0.0f)
+  {
+     if (contrast > 0.0f)
+     {
+        gain = 1.0f / (1.0f - contrast) ;
+     }
+     else if (contrast < 0.0f)
+     {
+        gain = 1 + contrast ;
+     }
+  }
+  
+  /* shift after gain application is 1/2(gain * max - max), max = 1.0 */
+  dist_shift = gain * 0.5f - 0.5f ;
+
   while (h--)
-    {
+  {
       s = (guint16*)src;
       d = (guint16*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  for (b = 0; b < alpha; b++)
 	  {
-	    sb = FLT (s[b], u);
-	    db = contrast_func (brightness_func(sb, 2.0*brightness), 2.0*contrast);
-	    d[b] = FLT16 (db, u);
-	  }
+         for (b = 0; b < alpha; b++)
+         {
+           sb = FLT (s[b], u);
+           tmp = brightness + sb ;         /* brightness correction */
+           tmp = gain*tmp - dist_shift ;   /* contrast correction */
+                 
+           if (tmp < 0.0f)                   
+              tmp = 0.0f ;
+           else if (tmp > 1.0f)
+              tmp = 1.0f ;
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+           d[b] = FLT16 (tmp, u);
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+          if (has_alpha)
+            d[alpha] = s[alpha];
 
-      src += pixelarea_rowstride (src_area);
-      dest += pixelarea_rowstride (dest_area);
-    }
+          s += src_num_channels;
+          d += dest_num_channels; 
+        }
+
+        src += pixelarea_rowstride (src_area);
+        dest += pixelarea_rowstride (dest_area);
+      }
+  }
 }
 
 static void
@@ -569,8 +480,10 @@ brightness_contrast_bfp (PixelArea *src_area,
   int alpha;
   int w, h, b;
   BrightnessContrastDialog *bcd = (BrightnessContrastDialog *) user_data;
-  gdouble brightness = (gfloat)bcd->brightness;
-  gdouble contrast = (gfloat)bcd->contrast;
+  gfloat brightness = BFP_MAX_IN_FLOAT * 0.392f * (gfloat)bcd->brightness;
+  gfloat contrast = (gfloat)bcd->contrast;
+  gfloat tmp, gain = 1.0f ;
+  gfloat dist_shift;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -578,28 +491,53 @@ brightness_contrast_bfp (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
+  if (contrast != 0.0f)
+  {
+     if (contrast > 0.0f)
+     {
+        gain = 1.0f / (1.0f - contrast) ;
+     }
+     else if (contrast < 0.0f)
+     {
+        gain = 1 + contrast ;
+     }
+  }
+  
+  dist_shift = BFP_MAX_IN_FLOAT*(gain * 0.5f - 0.5f) ;
+
   while (h--)
-    {
-      s = (guint16*)src;
-      d = (guint16*)dest;
-      w = pixelarea_width (src_area);
-      while (w--)
-	{
+  {
+     s = (guint16*)src;
+     d = (guint16*)dest;
+     w = pixelarea_width (src_area);
+
+     while (w--)
+	 {
           /* note: 32768. is ONE_BFP in float */
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(32768. * contrast_func(brightness_func(s[b]/32768., 
-	           2.*brightness), 2.*contrast), 0, 65535);
+        for (b = 0; b < alpha; b++)
+        {
+              tmp = brightness + s[b] ;         /* brightness correction */
+              tmp = gain*tmp - dist_shift ;     /* contrast correction */
+             
+              if (tmp < 0.0f)                   
+                tmp = 0.0f ;
+              else if (tmp > BFP_MAX)
+                  tmp = BFP_MAX ;
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+              d[b] = (guint16)(tmp) ;
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+               if (has_alpha)
+	              d[alpha] = s[alpha];
 
-      src += pixelarea_rowstride (src_area);
-      dest += pixelarea_rowstride (dest_area);
-    }
+	           s += src_num_channels;
+	           d += dest_num_channels; 
+	    }
+
+        src += pixelarea_rowstride (src_area);
+        dest += pixelarea_rowstride (dest_area);
+     }
+  }
 }
 
 static void
@@ -655,7 +593,6 @@ brightness_contrast_control (Tool     *tool,
 	  active_tool->preserve = TRUE;
           image_map_abort (brightness_contrast_dialog->image_map);
           active_tool->preserve = FALSE;
-          brightness_contrast_free_transfers();
 	  brightness_contrast_dialog->image_map = NULL;
 	  brightness_contrast_cancel_callback (NULL, (gpointer) brightness_contrast_dialog);
 	}
@@ -733,10 +670,7 @@ brightness_contrast_initialize (void *gdisp_ptr)
   drawable = gimage_active_drawable (gdisp->gimage);
   
   /* Set up the function pointers for our data type */
-  brightness_contrast_funcs (drawable_tag (drawable));
-  
-  pixelrow_init (&brightness_lut, tag_null(), NULL , 0); 
-  pixelrow_init (&contrast_lut, tag_null(), NULL, 0); 
+  brightness_contrast_funcs (drawable_tag (drawable)); 
   
   /*  Initialize dialog fields  */
   brightness_contrast_dialog->image_map = NULL;
@@ -802,7 +736,7 @@ brightness_contrast_new_dialog ()
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
 
-  data = gtk_adjustment_new (0, -.5, .51, .001, .01, .01);
+  data = gtk_adjustment_new (0, -1.0, 1.0, .001, .01, .01);
   bcd->brightness_data = GTK_ADJUSTMENT (data);
   slider = gtk_hscale_new (GTK_ADJUSTMENT (data));
   gtk_widget_set_usize (slider, SLIDER_WIDTH, SLIDER_HEIGHT);
@@ -836,7 +770,7 @@ brightness_contrast_new_dialog ()
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
 
-  data = gtk_adjustment_new (0, -.5, .51, .001, .01, .01);
+  data = gtk_adjustment_new (0, -1.0, 1.00, .001, .01, .01);
   bcd->contrast_data = GTK_ADJUSTMENT (data);
   slider = gtk_hscale_new (GTK_ADJUSTMENT (data));
   gtk_widget_set_usize (slider, SLIDER_WIDTH, SLIDER_HEIGHT);
@@ -929,7 +863,6 @@ brightness_contrast_preview (BrightnessContrastDialog *bcd)
   if (!bcd->image_map)
     g_message (_("brightness_contrast_preview(): No image map"));
   active_tool->preserve = TRUE;
-  (*brightness_contrast_init_transfers) ((void *)bcd); 
   image_map_apply (bcd->image_map, brightness_contrast, (void *) bcd);
   active_tool->preserve = FALSE;
 }
@@ -949,15 +882,12 @@ brightness_contrast_ok_callback (GtkWidget *widget,
 
   if (!bcd->preview)
   {
-    (*brightness_contrast_init_transfers) ((void *)bcd); 
+    /*(*brightness_contrast_init_transfers) ((void *)bcd); */
     image_map_apply (bcd->image_map, brightness_contrast, (void *) bcd);
   }
 
   if (bcd->image_map)
-  {
     image_map_commit (bcd->image_map);
-    brightness_contrast_free_transfers();
-  }
 
   active_tool->preserve = FALSE;
 
@@ -988,7 +918,6 @@ brightness_contrast_cancel_callback (GtkWidget *widget,
     {
       active_tool->preserve = TRUE;
       image_map_abort (bcd->image_map);
-      brightness_contrast_free_transfers();
       active_tool->preserve = FALSE;
       gdisplays_flush ();
     }
@@ -1079,7 +1008,7 @@ brightness_contrast_brightness_text_check (
 {
   gfloat value;
 
-  value = BOUNDS (atof (str), -.5, .5);
+  value = BOUNDS (atof (str), -1.0, 1.0);
   if (bcd->brightness != value)
   {
       bcd->brightness = value;
@@ -1112,7 +1041,7 @@ brightness_contrast_contrast_text_check  (
 {
   gfloat value;
 
-  value = BOUNDS (atof (str), -.5, .5);
+  value = BOUNDS (atof (str), -1.0, 1.0);
   if (bcd->contrast != value)
   {
       bcd->contrast = value;
@@ -1229,9 +1158,6 @@ brightness_contrast_invoker (Argument *args)
       bcd.contrast = contrast;
         
       brightness_contrast_funcs(drawable_tag (drawable));
-      pixelrow_init (&brightness_lut, tag_null(), NULL , 0); 
-      pixelrow_init (&contrast_lut, tag_null(), NULL, 0); 
-      (*brightness_contrast_init_transfers)(&bcd);
       
       /*  The application should occur only within selection bounds  */
       drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
@@ -1246,7 +1172,6 @@ brightness_contrast_invoker (Argument *args)
 		pr = pixelarea_process (pr))
 	(*brightness_contrast) (&src_area, &dest_area, (void *) &bcd);
 
-      brightness_contrast_free_transfers();
       drawable_merge_shadow (drawable, TRUE);
       drawable_update (drawable, x1, y1, (x2 - x1), (y2 - y1));
     }
