@@ -259,7 +259,7 @@ brush_select_new (gchar * title,
 	gotinitbrush = TRUE;
     }
 
-  gtk_window_set_policy(GTK_WINDOW(bsp->shell), FALSE, FALSE, TRUE);
+  /* gtk_window_set_policy(GTK_WINDOW(bsp->shell), FALSE, FALSE, TRUE); */
   vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (vbox), 2);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (bsp->shell)->vbox), vbox, FALSE, FALSE, 0);
@@ -363,7 +363,7 @@ brush_select_new (gchar * title,
   gtk_box_pack_start (GTK_BOX (bsp->options_box), util_box, FALSE, FALSE, 0);
   label = gtk_label_new (_("Spacing:"));
   gtk_box_pack_start (GTK_BOX (util_box), label, FALSE, FALSE, 2);
-  bsp->spacing_data = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 1.0, 1000.0, 1.0, 1.0, 0.0));
+  bsp->spacing_data = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 1.0, 300.0, 10.0, 1.0, 0.0));
   slider = gtk_hscale_new (bsp->spacing_data);
   gtk_box_pack_start (GTK_BOX (util_box), slider, TRUE, TRUE, 0);
   gtk_scale_set_value_pos (GTK_SCALE (slider), GTK_POS_TOP);
@@ -477,10 +477,9 @@ brush_select_new (gchar * title,
     }
 
   /*  The action area  */
-  { int i;
-    for(i = 0; i < 2; ++i)
-      action_items[i].label = _(action_items[i].label);
-  }
+  action_items[0].label = _("Close");
+  action_items[1].label = _("Refresh");
+
   action_items[0].user_data = bsp;
   action_items[1].user_data = bsp;
   build_action_area (GTK_DIALOG (bsp->shell), action_items, 2, 0);
@@ -674,7 +673,11 @@ connect_signals_to_brush(GimpBrushP brush, BrushSelectP bsp)
 static void
 disconnect_signals_from_brush(GimpBrushP brush, BrushSelectP bsp)
 {
+#if GTK_MAJOR_VERSION > 1
+  if (!brush)
+#else
   if (!GTK_OBJECT_DESTROYED(brush))
+#endif
     gtk_signal_disconnect_by_data(GTK_OBJECT(brush), bsp);
 }
 
@@ -718,7 +721,7 @@ brush_popup_open (BrushSelectP bsp,
 
       bsp->brush_popup = gtk_window_new (GTK_WINDOW_POPUP);
       minimize_register(bsp->brush_popup);
-      gtk_window_set_policy (GTK_WINDOW (bsp->brush_popup), FALSE, FALSE, TRUE);
+      /* gtk_window_set_policy (GTK_WINDOW (bsp->brush_popup), FALSE, FALSE, TRUE); */
 
       frame = gtk_frame_new (NULL);
       gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
@@ -747,7 +750,12 @@ brush_popup_open (BrushSelectP bsp,
   y = (y + h > scr_h) ? scr_h - h : y;
   gtk_preview_size (GTK_PREVIEW (bsp->brush_preview), w, h);
 
+#if GTK_MAJOR_VERSION > 1
+  gtk_widget_show (bsp->brush_popup);
+  gtk_window_move (GTK_WINDOW(bsp->brush_popup), x, y); 
+#else
   gtk_widget_popup (bsp->brush_popup, x, y);
+#endif
   
   /*  Draw the brush  */
   buf = g_new (gchar, w);
@@ -1489,10 +1497,10 @@ paint_mode_menu_callback (GtkWidget *w,
   BrushSelectP bsp = (BrushSelectP)gtk_object_get_user_data(GTK_OBJECT(w));
   
   if(bsp == brush_select_dialog)
-    gimp_brush_set_paint_mode ((int) client_data);
+    gimp_brush_set_paint_mode ((intptr_t) client_data);
   else
     {
-      bsp->paint_mode = (int) client_data;
+      bsp->paint_mode = (intptr_t) client_data;
       brush_change_callbacks(bsp,0);
     }
 }
