@@ -146,6 +146,218 @@ GimpBrushGenerated *gimp_brush_generated_new(float radius, float hardness,
   return brush;
 }
 
+#if GTK_MAJOR_VERSION > 1
+#include <errno.h>
+GimpBrushGenerated *
+gimp_brush_generated_load (const gchar  *filename)
+{
+  GimpBrushGenerated      *brush;
+  FILE                    *file;
+  gchar                    string[256];
+  gchar                   *name       = NULL;
+  /*GimpBrushGeneratedShape  shape      = GIMP_BRUSH_GENERATED_CIRCLE;*/
+  gboolean                 have_shape = FALSE;
+  gint                     spikes     = 2;
+  gdouble                  spacing;
+  gdouble                  radius;
+  gdouble                  hardness;
+  gdouble                  aspect_ratio;
+  gdouble                  angle;
+
+  g_return_val_if_fail (filename != NULL, NULL);
+  g_return_val_if_fail (g_path_is_absolute (filename), NULL);
+  /*g_return_val_if_fail (error == NULL || *error == NULL, NULL);*/
+
+  file = fopen (filename, "rb");
+
+  if (! file)
+    {
+      printf ( _("Could not open '%s' for reading: %s"),
+                   /*gimp_filename_to_utf8*/ (filename), g_strerror (errno));
+      return NULL;
+    }
+
+  /* make sure the file we are reading is the right type */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+
+  if (strncmp (string, "GIMP-VBR", 8) != 0)
+    {
+      printf( _("Fatal parse error in brush file '%s': "
+                     "Not a GIMP brush file."),
+                   /*gimp_filename_to_utf8*/ (filename));
+      goto failed;
+    }
+
+  /* make sure we are reading a compatible version */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+
+  if (strncmp (string, "1.0", 3))
+    {
+      if (strncmp (string, "1.5", 3))
+        {
+          printf ( _("Fatal parse error in brush file '%s': "
+                         "Unknown GIMP brush version."),
+                       /*gimp_filename_to_utf8*/ (filename));
+          goto failed;
+        }
+      else
+        {
+          have_shape = TRUE;
+        }
+    }
+
+  /* read name */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+
+  g_strstrip (string);
+  name = strdup/*gimp_any_to_utf8 (string, -1,
+                           _("Invalid UTF-8 string in brush file '%s'."),*/
+                           /*gimp_filename_to_utf8*/ (filename);
+
+  /*if (have_shape)
+    {
+      GEnumClass *enum_class;
+      GEnumValue *shape_val;
+
+      enum_class = g_type_class_peek (GIMP_TYPE_BRUSH_GENERATED_SHAPE);
+
+      *//* read shape *//*
+      errno = 0;
+      if (! fgets (string, sizeof (string), file))
+        goto failed;
+
+      g_strstrip (string);
+      shape_val = g_enum_get_value_by_nick (enum_class, string);
+
+      if (!shape_val)
+        {
+          printf ( _("Fatal parse error in brush file '%s': "
+                         "Unknown GIMP brush shape."),
+                       gimp_filename_to_utf8 (filename));
+          goto failed;
+        }
+
+      shape = shape_val->value;
+    } */
+
+  /* read brush spacing */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+  spacing = g_ascii_strtod (string, NULL);
+
+  /* read brush radius */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+  radius = g_ascii_strtod (string, NULL);
+
+  if (have_shape)
+    {
+      /* read brush radius */
+      errno = 0;
+      if (! fgets (string, sizeof (string), file))
+        goto failed;
+      spikes = CLAMP (atoi (string), 2, 20);
+    }
+
+  /* read brush hardness */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+  hardness = g_ascii_strtod (string, NULL);
+
+  /* read brush aspect_ratio */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+  aspect_ratio = g_ascii_strtod (string, NULL);
+
+  /* read brush angle */
+  errno = 0;
+  if (! fgets (string, sizeof (string), file))
+    goto failed;
+  angle = g_ascii_strtod (string, NULL);
+
+  fclose (file);
+
+  /* create new brush */
+/*
+  brush = g_object_new (GIMP_TYPE_BRUSH_GENERATED,
+                        "name",         name,
+                        "shape",        shape,
+                        "radius",       radius,
+                        "spikes",       spikes,
+                        "hardness",     hardness,
+                        "aspect-ratio", aspect_ratio,
+                        "angle",        angle,
+                        NULL);
+  g_free (name);
+
+  GIMP_BRUSH (brush)->spacing = spacing;
+*/
+  /* render brush mask */
+  /*gimp_data_dirty (GIMP_DATA (brush));*/
+
+/* create new brush */
+  brush = GIMP_BRUSH_GENERATED(gimp_type_new(gimp_brush_generated_get_type()));
+  GIMP_BRUSH(brush)->filename = g_strdup (filename);
+  gimp_brush_generated_freeze(brush);
+
+/* read name */
+  GIMP_BRUSH(brush)->name = g_strdup (name);
+/* read brush spacing */
+  GIMP_BRUSH(brush)->spacing = spacing;
+/* read brush radius */
+  gimp_brush_generated_set_radius(brush, radius);
+/* read brush hardness */
+  gimp_brush_generated_set_hardness(brush, hardness);
+/* read brush aspect_ratio */
+  gimp_brush_generated_set_aspect_ratio(brush, aspect_ratio);
+/* read brush angle */
+  gimp_brush_generated_set_angle(brush, angle);
+
+
+  gimp_brush_generated_thaw(brush);
+
+#if 1 
+  {
+    char * basename = strrchr (filename, '/' );
+    if (basename && default_brush) 
+      {
+	basename++; 
+	if (strcmp(default_brush, basename) == 0) 
+	  {
+	    select_brush (GIMP_BRUSH(brush));
+	    set_have_default_brush (TRUE); 
+	  }
+      } 
+  }
+#endif
+
+  return brush;
+
+ failed:
+
+  fclose (file);
+
+  if (name)
+    g_free (name);
+
+  /*if (error && *error == NULL)*/
+    printf ( _("Error while reading brush file '%s': %s"),
+                 /*gimp_filename_to_utf8*/ (filename),
+                 errno ? g_strerror (errno) : _("File is truncated"));
+
+  return NULL;
+}
+#else
 GimpBrushGenerated *
 gimp_brush_generated_load (const char *file_name)
 {
@@ -209,17 +421,27 @@ gimp_brush_generated_load (const char *file_name)
 
   return brush;
 }
+#endif
 
 void
 gimp_brush_generated_save (GimpBrushGenerated *brush, 
 			  const char *file_name)
 {
   FILE *fp;
+  char *lnc = 0, *tmp;
   if ((fp = fopen(file_name, "wb")) == NULL)
   {
     g_warning("Unable to save file %s", file_name);
     return;
   }
+#ifdef ENABLE_NLS
+  lnc = setlocale(LC_NUMERIC, 0);
+  if(lnc) {
+    tmp= strdup(lnc);
+    lnc = tmp;
+  }
+  setlocale(LC_NUMERIC, "C");
+#endif
 /* write magic header */
   fprintf(fp, "GIMP-VBR\n");
 /* write version */
@@ -236,6 +458,10 @@ gimp_brush_generated_save (GimpBrushGenerated *brush,
   fprintf(fp, "%f\n", brush->aspect_ratio);
 /* write brush angle */
   fprintf(fp, "%f\n", brush->angle);
+#ifdef ENABLE_NLS
+  setlocale(LC_NUMERIC, lnc);
+  if(lnc) free(lnc);
+#endif
 
   fclose(fp);
 }
