@@ -64,8 +64,13 @@ gimp_channel_get_type ()
 	sizeof (GimpChannelClass),
 	(GtkClassInitFunc) gimp_channel_class_init,
 	(GtkObjectInitFunc) gimp_channel_init,
+#if GTK_MAJOR_VERSION > 1
+	NULL,
+	NULL,
+#else
 	(GtkArgSetFunc) NULL,
 	(GtkArgGetFunc) NULL,
+#endif
       };
 
       channel_type = gtk_type_unique (gimp_drawable_get_type (), &channel_info);
