@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../canvas.h"
@@ -921,7 +922,7 @@ tools_new_color_balance ()
 
   /*  The tool options  */
   if (!color_balance_options)
-    color_balance_options = tools_register_no_options (COLOR_BALANCE, "Color Balance Options");
+    color_balance_options = tools_register_no_options (COLOR_BALANCE, _("Color Balance Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (ColorBalance *) g_malloc_zero (sizeof (ColorBalance));
@@ -969,7 +970,7 @@ color_balance_initialize (void *gdisp_ptr)
 
   if (! drawable_color (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Color balance operates only on RGB color drawables.");
+      g_message (_("Color balance operates only on RGB color drawables."));
       return;
     }
 
@@ -1029,18 +1030,17 @@ color_balance_new_dialog ()
   GtkObject *data;
   GSList *group = NULL;
   int i;
-  char *appl_mode_names[3] =
-  {
-    "Shadows",
-    "Midtones",
-    "Highlights"
-  };
   ActionCallback appl_mode_callbacks[3] =
   {
     color_balance_shadows_callback,
     color_balance_midtones_callback,
     color_balance_highlights_callback
   };
+  char *appl_mode_names[3];
+
+  appl_mode_names[0] = _("Shadows");
+  appl_mode_names[1] = _("Midtones");
+  appl_mode_names[2] = _("Highlights");
 
   cbd = g_malloc_zero (sizeof (ColorBalanceDialog));
   cbd->preserve_luminosity = TRUE;
@@ -1050,7 +1050,7 @@ color_balance_new_dialog ()
   /*  The shell and main vbox  */
   cbd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (cbd->shell), "color_balance", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (cbd->shell), "Color Balance");
+  gtk_window_set_title (GTK_WINDOW (cbd->shell), _("Color Balance"));
   minimize_register(cbd->shell);
 
   /* handle the wm close signal */
@@ -1066,7 +1066,7 @@ color_balance_new_dialog ()
   hbox = gtk_hbox_new (TRUE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Color Levels: ");
+  label = gtk_label_new (_("Color Levels: "));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
@@ -1105,7 +1105,7 @@ color_balance_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the cyan-red scale widget  */
-  start_label = gtk_label_new ("Cyan");
+  start_label = gtk_label_new (_("Cyan"));
   gtk_misc_set_alignment (GTK_MISC (start_label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), start_label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1122,7 +1122,7 @@ color_balance_new_dialog ()
   gtk_signal_connect (GTK_OBJECT (data), "value_changed",
 		      (GtkSignalFunc) color_balance_cr_scale_update,
 		      cbd);
-  end_label = gtk_label_new ("Red");
+  end_label = gtk_label_new (_("Red"));
   gtk_misc_set_alignment (GTK_MISC (end_label), 0.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), end_label, 2, 3, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1132,7 +1132,7 @@ color_balance_new_dialog ()
   gtk_widget_show (slider);
 
   /*  Create the magenta-green scale widget  */
-  start_label = gtk_label_new ("Magenta");
+  start_label = gtk_label_new (_("Magenta"));
   gtk_misc_set_alignment (GTK_MISC (start_label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), start_label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1149,7 +1149,7 @@ color_balance_new_dialog ()
   gtk_signal_connect (GTK_OBJECT (data), "value_changed",
 		      (GtkSignalFunc) color_balance_mg_scale_update,
 		      cbd);
-  end_label = gtk_label_new ("Green");
+  end_label = gtk_label_new (_("Green"));
   gtk_misc_set_alignment (GTK_MISC (end_label), 0.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), end_label, 2, 3, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1159,7 +1159,7 @@ color_balance_new_dialog ()
   gtk_widget_show (slider);
 
   /*  Create the yellow-blue scale widget  */
-  start_label = gtk_label_new ("Yellow");
+  start_label = gtk_label_new (_("Yellow"));
   gtk_misc_set_alignment (GTK_MISC (start_label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), start_label, 0, 1, 2, 3,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1176,7 +1176,7 @@ color_balance_new_dialog ()
   gtk_signal_connect (GTK_OBJECT (data), "value_changed",
 		      (GtkSignalFunc) color_balance_yb_scale_update,
 		      cbd);
-  end_label = gtk_label_new ("Blue");
+  end_label = gtk_label_new (_("Blue"));
   gtk_misc_set_alignment (GTK_MISC (end_label), 0.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), end_label, 2, 3, 2, 3,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -1190,7 +1190,7 @@ color_balance_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), cbd->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1199,7 +1199,7 @@ color_balance_new_dialog ()
   gtk_widget_show (toggle);
 
   /*  The preserve luminosity toggle  */
-  toggle = gtk_check_button_new_with_label ("Preserve Luminosity");
+  toggle = gtk_check_button_new_with_label (_("Preserve Luminosity"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), cbd->preserve_luminosity);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1226,6 +1226,10 @@ color_balance_new_dialog ()
   gtk_widget_show (hbox);
 
   /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = cbd;
   action_items[1].user_data = cbd;
   build_action_area (GTK_DIALOG (cbd->shell), action_items, 2, 0);
@@ -1279,7 +1283,7 @@ static void
 color_balance_preview (ColorBalanceDialog *cbd)
 {
   if (!cbd->image_map)
-    g_message ("color_balance_preview(): No image map");
+    g_message (_("color_balance_preview(): No image map"));
   active_tool->preserve = TRUE;
   image_map_apply (cbd->image_map, color_balance, (void *) cbd);
   active_tool->preserve = FALSE;
@@ -1548,11 +1552,11 @@ ProcArg color_balance_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "transfer_mode",
