@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include <stdio.h>
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../canvas.h"
@@ -110,12 +111,12 @@ create_color_picker_options (void)
   vbox = gtk_vbox_new (FALSE, 1);
 
   /*  the main label  */
-  label = gtk_label_new ("Color Picker Options");
+  label = gtk_label_new (_("Color Picker Options"));
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
   /*  the sample merged toggle button  */
-  sample_merged_toggle = gtk_check_button_new_with_label ("Sample Merged");
+  sample_merged_toggle = gtk_check_button_new_with_label (_("Sample Merged"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (sample_merged_toggle), options->sample_merged);
   gtk_box_pack_start (GTK_BOX (vbox), sample_merged_toggle, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (sample_merged_toggle), "toggled",
@@ -157,9 +158,9 @@ color_picker_button_press (Tool           *tool,
       if (color_picker_info)
 	info_dialog_free (color_picker_info);
 
-      color_picker_info = info_dialog_new ("Color Picker",
+      color_picker_info = info_dialog_new (_("Color Picker"),
 					    gimp_standard_help_func,
-					    "UNKNOWN");
+					    _("UNKNOWN"));
       active_drawable = gimage_active_drawable (gdisp->gimage);
 
       color_space_channel_names = gimage_get_channel_names(gdisp->gimage);
@@ -171,22 +172,22 @@ color_picker_button_press (Tool           *tool,
 	  info_dialog_add_field (color_picker_info, color_space_channel_names[GREEN_PIX], green_buf);
 	  info_dialog_add_field (color_picker_info, color_space_channel_names[BLUE_PIX], blue_buf);
 	  info_dialog_add_field (color_picker_info, color_space_channel_names[ALPHA_PIX], alpha_buf);
-	  info_dialog_add_field (color_picker_info, "Hex Triplet", hex_buf);
+	  info_dialog_add_field (color_picker_info, _("Hex Triplet"), hex_buf);
 	  break;
 
 	case FORMAT_INDEXED:
-	  info_dialog_add_field (color_picker_info, "Index", index_buf);
-	  info_dialog_add_field (color_picker_info, "Alpha", alpha_buf);
-	  info_dialog_add_field (color_picker_info, "Red", red_buf);
-	  info_dialog_add_field (color_picker_info, "Green", green_buf);
-	  info_dialog_add_field (color_picker_info, "Blue", blue_buf);
-	  info_dialog_add_field (color_picker_info, "Hex Triplet", hex_buf);
+	  info_dialog_add_field (color_picker_info, _("Index"), index_buf);
+	  info_dialog_add_field (color_picker_info, _("Alpha"), alpha_buf);
+	  info_dialog_add_field (color_picker_info, _("Red"), red_buf);
+	  info_dialog_add_field (color_picker_info, _("Green"), green_buf);
+	  info_dialog_add_field (color_picker_info, _("Blue"), blue_buf);
+	  info_dialog_add_field (color_picker_info, _("Hex Triplet"), hex_buf);
 	  break;
 
 	case FORMAT_GRAY:
-	  info_dialog_add_field (color_picker_info, "Intensity", gray_buf);
-	  info_dialog_add_field (color_picker_info, "Alpha", alpha_buf);
-	  info_dialog_add_field (color_picker_info, "Hex Triplet", hex_buf);
+	  info_dialog_add_field (color_picker_info, _("Intensity"), gray_buf);
+	  info_dialog_add_field (color_picker_info, _("Alpha"), alpha_buf);
+	  info_dialog_add_field (color_picker_info, _("Hex Triplet"), hex_buf);
 	  break;
 
 	default :
@@ -194,6 +195,7 @@ color_picker_button_press (Tool           *tool,
 	}
 
       /* Create the action area  */
+      action_items[0].label = _(action_items[0].label);
       action_items[0].user_data = color_picker_info;
       build_action_area (GTK_DIALOG (color_picker_info->shell), action_items, 1, 0);
     }
@@ -364,7 +366,7 @@ color_picker_info_update_u8  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [3]);
       else
-        sprintf (alpha_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
       sprintf (hex_buf, "#%.2x%.2x%.2x",
                src [0], src [1], src [2]);
       break;
@@ -374,11 +376,11 @@ color_picker_info_update_u8  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [1]);
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_GRAY:
@@ -386,14 +388,14 @@ color_picker_info_update_u8  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [1]);
       else
-        sprintf (alpha_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
       sprintf (hex_buf, "#%.2x%.2x%.2x", src [0],
                src [0], src [0]);
       break;
           
     case FORMAT_NONE:
     default:
-      g_warning ("bad format");
+      g_warning (_("bad format"));
       break;
     }
 }
@@ -415,7 +417,7 @@ color_picker_info_update_u16  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [3]);
       else
-        sprintf (alpha_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
       sprintf (hex_buf, "#%.4x %.4x %.4x",
                src [0], src [1], src [2]);
       break;
@@ -425,11 +427,11 @@ color_picker_info_update_u16  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [1]);
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_GRAY:
@@ -437,14 +439,14 @@ color_picker_info_update_u16  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%d", src [1]);
       else
-        sprintf (alpha_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
       sprintf (hex_buf, "#%.4x %.4x %.4x", src [0],
                src [0], src [0]);
       break;
           
     case FORMAT_NONE:
     default:
-      g_warning ("bad format");
+      g_warning (_("bad format"));
       break;
     }
 }
@@ -466,17 +468,17 @@ color_picker_info_update_float  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", src [3]);
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_INDEXED:
-      sprintf (index_buf, "N/A");
-      sprintf (alpha_buf, "N/A");
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+      sprintf (index_buf, _("N/A"));
+      sprintf (alpha_buf, _("N/A"));
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_GRAY:
@@ -484,13 +486,13 @@ color_picker_info_update_float  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", src [1]);
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
           
     case FORMAT_NONE:
     default:
-      g_warning ("bad format");
+      g_warning (_("bad format"));
       break;
     }
 }
@@ -513,17 +515,17 @@ color_picker_info_update_float16  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", FLT (src [3], u));
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_INDEXED:
-      sprintf (index_buf, "N/A");
-      sprintf (alpha_buf, "N/A");
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+      sprintf (index_buf, _("N/A"));
+      sprintf (alpha_buf, _("N/A"));
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_GRAY:
@@ -531,13 +533,13 @@ color_picker_info_update_float16  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", FLT (src [1], u));
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
           
     case FORMAT_NONE:
     default:
-      g_warning ("bad format");
+      g_warning (_("bad format"));
       break;
     }
 }
@@ -560,17 +562,17 @@ color_picker_info_update_bfp  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", BFP_TO_FLOAT (src [3]));
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_INDEXED:
-      sprintf (index_buf, "N/A");
-      sprintf (alpha_buf, "N/A");
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+      sprintf (index_buf, _("N/A"));
+      sprintf (alpha_buf, _("N/A"));
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
 
     case FORMAT_GRAY:
@@ -578,13 +580,13 @@ color_picker_info_update_bfp  (
       if (tag_alpha (sample_tag) == ALPHA_YES)
         sprintf (alpha_buf, "%7.6f", BFP_TO_FLOAT (src [1]));
       else
-        sprintf (alpha_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+        sprintf (alpha_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
       break;
           
     case FORMAT_NONE:
     default:
-      g_warning ("bad format");
+      g_warning (_("bad format"));
       break;
     }
 }
@@ -598,13 +600,13 @@ color_picker_info_update  (
 {
   if (!valid)
     {
-      sprintf (red_buf, "N/A");
-      sprintf (green_buf, "N/A");
-      sprintf (blue_buf, "N/A");
-      sprintf (alpha_buf, "N/A");
-      sprintf (index_buf, "N/A");
-      sprintf (gray_buf, "N/A");
-      sprintf (hex_buf, "N/A");
+      sprintf (red_buf, _("N/A"));
+      sprintf (green_buf, _("N/A"));
+      sprintf (blue_buf, _("N/A"));
+      sprintf (alpha_buf, _("N/A"));
+      sprintf (index_buf, _("N/A"));
+      sprintf (gray_buf, _("N/A"));
+      sprintf (hex_buf, _("N/A"));
     }
   else
     {
@@ -632,7 +634,7 @@ color_picker_info_update  (
 	
 	case PRECISION_NONE:
         default:
-          g_warning ("bad precision");
+          g_warning (_("bad precision"));
           break;
 	}
     }
@@ -682,11 +684,11 @@ ProcArg color_picker_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_FLOAT,
     "x",
