@@ -317,6 +317,9 @@ color_select_new (PixelRow           * col,
                                             0.0));
 
       slider = gtk_hscale_new (csp->slider_data[i]);
+#if GTK_MAJOR_VERSION > 1
+      gtk_widget_set_usize (GTK_WIDGET (slider), 70, 0);
+#endif
       gtk_table_attach (GTK_TABLE (table), slider, 1, 2, i, i+1,
 			GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 0);
       gtk_scale_set_value_pos (GTK_SCALE (slider), GTK_POS_TOP);
