@@ -21,6 +21,7 @@
 #include <math.h>
 #include <gtk/gtk.h>
 #include "../../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../buildmenu.h"
@@ -39,7 +40,6 @@
 #include "../minimize.h"
 #include "../rc.h"
 
-#define _(translation_text) translation_text
 
 #define ROUND(x)  ((int) ((x) + 0.5))
 
@@ -537,6 +537,8 @@ curves_button_press (Tool           *tool,
   GDisplay *gdisp;
 
   gdisp = gdisp_ptr;
+  if(gdisp != tool->gdisp_ptr)
+    curves_free();
   tool->drawable = gimage_active_drawable (gdisp->gimage);
 }
 
@@ -601,7 +603,7 @@ tools_new_curves ()
 
   /*  The tool options  */
   if (!curves_options)
-    curves_options = tools_register_no_options (CURVES, "Curves Options");
+    curves_options = tools_register_no_options (CURVES, _("Curves Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (Curves *) g_malloc_zero (sizeof (Curves));
@@ -674,7 +676,7 @@ curves_initialize (void *gdisp_ptr)
 
   if (drawable_indexed (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Curves for indexed drawables cannot be adjusted.");
+      g_message (_("Curves for indexed drawables cannot be adjusted."));
       return;
     }
 
@@ -683,7 +685,7 @@ curves_initialize (void *gdisp_ptr)
   curves_funcs( drawable_tag (gimage_active_drawable (gdisp->gimage)));
 
   if (curves_alloc_curves == NULL){
-    g_message ("Curves for this image type cannot be adjusted.");
+    g_message (_("Curves for this image type cannot be adjusted."));
     return;
   }
 
@@ -866,6 +868,14 @@ curves_new_dialog ()
     for (j = 0; j < 256; j++)
       cd->curve[i][j] = j;
 
+  { int i;
+    for(i = 0; i < 3; ++i)
+      action_items[i].label = _(action_items[i].label);
+    for(i = 0; i < 6; ++i)
+      channel_items[i].label = _(channel_items[i].label);
+    for(i = 0; i < 2; ++i)
+      curve_type_items[i].label = _(curve_type_items[i].label);
+  }
   for (i = 0; i < CURVES; i++)
     channel_items [i].user_data = (gpointer) cd;
   for (i = 0; i < 2; i++)
@@ -874,7 +884,7 @@ curves_new_dialog ()
   /*  The shell and main vbox  */
   cd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (cd->shell), "curves", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (cd->shell), "Curves");
+  gtk_window_set_title (GTK_WINDOW (cd->shell), _("Curves"));
   minimize_register(cd->shell);
 
   gtk_signal_connect (GTK_OBJECT (cd->shell), "delete_event",
@@ -889,7 +899,7 @@ curves_new_dialog ()
   channel_hbox = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), channel_hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Modify Curves for Channel: ");
+  label = gtk_label_new (_("Modify Curves for Channel: "));
   gtk_box_pack_start (GTK_BOX (channel_hbox), label, FALSE, FALSE, 0);
 
   menu = build_menu (channel_items, NULL);
@@ -980,7 +990,7 @@ curves_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The option menu for selecting the drawing method  */
-  label = gtk_label_new ("Curve Type: ");
+  label = gtk_label_new (_("Curve Type: "));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
   /*  Horizontal button box for load / save  */
@@ -989,7 +999,7 @@ curves_new_dialog ()
   gtk_button_box_set_layout (GTK_BUTTON_BOX (hbbox), GTK_BUTTONBOX_SPREAD);
   gtk_box_pack_end (GTK_BOX (vbox), hbbox, FALSE, FALSE, 0);
 
-  button = gtk_button_new_with_label ("Load");
+  button = gtk_button_new_with_label (_("Load"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_box_pack_start (GTK_BOX (hbbox), button, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -997,7 +1007,7 @@ curves_new_dialog ()
 		      cd->shell);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Save");
+  button = gtk_button_new_with_label (_("Save"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_box_pack_start (GTK_BOX (hbbox), button, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -1017,7 +1027,7 @@ curves_new_dialog ()
   gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), cd->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1502,7 +1512,7 @@ static void
 curves_preview (CurvesDialog *cd)
 {
   if (!cd->image_map)
-    g_message ("curves_preview(): No image map");
+    g_message (_("curves_preview(): No image map"));
 
   active_tool->preserve = TRUE;  /* Going to dirty the display... */
 
@@ -1802,10 +1812,33 @@ curves_preview_update (GtkWidget *w,
   if (GTK_TOGGLE_BUTTON (w)->active)
     {
       cd->preview = TRUE;
+      curves_update (cd, ALL);
       curves_preview (cd);
     }
   else
-    cd->preview = FALSE;
+    {
+      /* copy the ui points to points */
+      gdouble points[CURVES][17][2];
+      gint i,j,k;
+  
+      for (k = 0; k < CURVES; k++)  
+        for (i = 0; i < 17; i++)
+          for(j= 0; j < 2; j++)
+            points[k][i][j] = cd->points[k][i][j];
+      curves_reset_callback (w,data);
+
+      curves_preview (cd);
+      
+      /* copy the originals back */
+      for (k = 0; k < CURVES; k++)  
+        for (i = 0; i < 17; i++)
+          for(j= 0; j < 2; j++)
+            cd->points[k][i][j] = points[k][i][j];
+      curves_calculate_ui_curve (cd);
+      curves_update (cd, GRAPH | XRANGE_TOP | DRAW);
+
+      cd->preview = FALSE;
+    }
 }
 
 static gint
@@ -2066,7 +2099,7 @@ curves_load_callback (GtkWidget *widget,
 
   load_save = TRUE;
 
-  gtk_window_set_title (GTK_WINDOW (file_dlg), "Load Curves");
+  gtk_window_set_title (GTK_WINDOW (file_dlg), _("Load Curves"));
   gtk_widget_show (file_dlg);
 }
 
@@ -2081,7 +2114,7 @@ curves_save_callback (GtkWidget *widget,
 
   load_save = FALSE;
 
-  gtk_window_set_title (GTK_WINDOW (file_dlg), "Save Curves");
+  gtk_window_set_title (GTK_WINDOW (file_dlg), _("Save Curves"));
   gtk_widget_show (file_dlg);
 }
 
@@ -2090,7 +2123,7 @@ file_dialog_create (GtkWidget *parent)
 {
   gchar *temp;
 
-  file_dlg = gtk_file_selection_new ("Load/Save Curves");
+  file_dlg = gtk_file_selection_new (_("Load/Save Curves"));
   gtk_window_set_wmclass (GTK_WINDOW (file_dlg), "load_save_curves", PROGRAM_NAME);
   gtk_window_set_position (GTK_WINDOW (file_dlg), GTK_WIN_POS_MOUSE);
 
@@ -2132,13 +2165,13 @@ file_dialog_ok_callback (GtkWidget *widget,
 
       if (!f)
 	{
-	  g_message ("Unable to open file: %s", filename);
+	  g_message (_("Unable to open file: %s"), filename);
 	  return;
 	}
 
       if (!curves_read_from_file (f))
 	{
-	  g_message ("Error in reading file %s", filename);
+	  g_message (_("Error in reading file %s"), filename);
 	  return;
 	}
 
@@ -2150,7 +2183,7 @@ file_dialog_ok_callback (GtkWidget *widget,
 
       if (!f)
 	{
-	  g_message ("Unable to open file: %s", filename);
+	  g_message (_("Unable to open file: %s"), filename);
 	  return;
 	}
 
@@ -2281,11 +2314,11 @@ ProcArg curves_spline_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "channel",
@@ -2456,11 +2489,11 @@ ProcArg curves_explicit_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "channel",
