@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../canvas.h"
 #include "../drawable.h"
@@ -73,7 +74,7 @@ image_desaturate (gimage_ptr)
 
   if (! drawable_color (drawable))
     {
-      g_message ("Desaturate operates only on RGB color drawables.");
+      g_message (_("Desaturate operates only on RGB color drawables."));
       return;
     }
   desaturate (drawable);
@@ -321,11 +322,11 @@ ProcArg desaturate_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   }
 };
 
