@@ -191,7 +191,7 @@ display_u8_from_float16 (guint16 code)
 	ShortsFloat u;
 	gfloat c = FLT(code, u);
 
-#if 0
+#ifndef RNH_FLOAT
 
 return (guint8) (c>1?1:c * 255);
 #else
