@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../brush.h"
 #include "../brushlist.h"
@@ -167,12 +168,12 @@ create_dodgeburn_options(void)
   GtkWidget *scale;
   GtkWidget *frame;
 
-  gchar* type_label[2] = { "Dodge", "Burn" };
+  gchar* type_label[2] = { _("Dodge"), _("Burn") };
   gint   type_value[2] = { DODGE, BURN };
 
-  gchar* mode_label[3] = { "Highlights", 
-			   "Midtones",
-			   "Shadows" };
+  gchar* mode_label[3] = { _("Highlights"), 
+			   _("Midtones"),
+			   _("Shadows") };
 
   gint   mode_value[3] = { DODGEBURN_HIGHLIGHTS, 
 			   DODGEBURN_MIDTONES, 
@@ -191,7 +192,7 @@ create_dodgeburn_options(void)
   hbox = gtk_hbox_new (FALSE, 4);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Exposure:");
+  label = gtk_label_new (_("Exposure:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
@@ -211,7 +212,7 @@ create_dodgeburn_options(void)
   gtk_widget_show (hbox);
 
   /* the type (dodge or burn) */
-  frame = dodgeburn_radio_buttons_new ("Type", 
+  frame = dodgeburn_radio_buttons_new (_("Type"), 
 					  &options->type,
 					   options->type_w,
 					   type_label,
@@ -222,7 +223,7 @@ create_dodgeburn_options(void)
   gtk_widget_show (frame);
 
   /*  mode (highlights, midtones, or shadows)  */
-  frame = dodgeburn_radio_buttons_new ("Mode", 
+  frame = dodgeburn_radio_buttons_new (_("Mode"), 
 					  &options->mode,
 					   options->mode_w,
 					   mode_label,
