@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../drawable.h"
 #include "../equalize.h"
@@ -46,7 +47,7 @@ image_equalize (gimage_ptr)
 
   if (drawable_indexed (drawable))
     {
-      g_message ("Equalize does not operate on indexed drawables.");
+      g_message (_("Equalize does not operate on indexed drawables."));
       return;
     }
   equalize (gimage, drawable, mask_only);
@@ -443,11 +444,11 @@ ProcArg equalize_args[] =
 {
   { PDB_IMAGE,
     "image",
-    "the image"
+    "The Image"
   },
   { PDB_DRAWABLE,
     "drawable",
-    "the drawable"
+    "The Drawable"
   },
   { PDB_INT32,
     "mask_only",
