@@ -77,9 +77,11 @@ struct GammaExposeDialog
   GDisplay    *gdisp;
 };
 
-/* gamma and expose transfer luts */
-static PixelRow gamma_lut;
-static PixelRow expose_lut;
+/* gamma luts */
+static guint16 *gamma_lut16 ;
+static guint8  *gamma_lut8  ;
+
+/* static PixelRow expose_luti */
 
 /*  gamma expose action functions  */
 
@@ -109,9 +111,6 @@ static GammaExposeDialog *gamma_expose_dialog = NULL;
 
 static Argument * gamma_expose_invoker  (Argument *);
 
-static double gamma_func (double, double);
-static double expose_func (double, double);
-
 static void gamma_expose_funcs (Tag); 
 
 /* data type function pointers */
@@ -126,18 +125,20 @@ static void gamma_expose_u8 (PixelArea *, PixelArea *, void *);
 static void gamma_expose_init_transfers_u16 (void *);
 static void gamma_expose_u16 (PixelArea *, PixelArea *, void *);
 
-static void gamma_expose_init_transfers_float(void *);
 static void gamma_expose_float (PixelArea *, PixelArea *, void *);
-
-static void gamma_expose_init_transfers_float16(void *);
 static void gamma_expose_float16 (PixelArea *, PixelArea *, void *);
 
-static void gamma_expose_init_transfers_bfp (void *);
+/* static void gamma_expose_init_transfers_bfp (void *); */
 static void gamma_expose_bfp (PixelArea *, PixelArea *, void *);
 
+/*  Initalize gamma look up tables for integer data types */
+
 static void
 gamma_expose_funcs (Tag drawable_tag)
 {
+  gamma_lut16 = NULL ;
+  gamma_lut8 =  NULL ;
+
   switch (tag_precision (drawable_tag))
   {
   case PRECISION_U8:
@@ -150,15 +151,15 @@ gamma_expose_funcs (Tag drawable_tag)
     break;
   case PRECISION_FLOAT:
     gamma_expose = gamma_expose_float;
-    gamma_expose_init_transfers = gamma_expose_init_transfers_float;
+    gamma_expose_init_transfers = NULL ; 
     break;
   case PRECISION_FLOAT16:
     gamma_expose = gamma_expose_float16;
-    gamma_expose_init_transfers = gamma_expose_init_transfers_float16;
+    gamma_expose_init_transfers = NULL ; 
     break;
   case PRECISION_BFP:
     gamma_expose = gamma_expose_bfp;
-    gamma_expose_init_transfers = gamma_expose_init_transfers_bfp;
+    gamma_expose_init_transfers = NULL ; 
     break;
   default:
     gamma_expose = NULL;
@@ -167,49 +168,29 @@ gamma_expose_funcs (Tag drawable_tag)
   }
 }
 
-/*  gamma expose machinery  */
-
-
-static float mean = .5;
-
-static double gamma_func (double x, double b)
-{
-    return pow(x, 1 / b);
-}
-
-static double expose_func (double x, double c)
-{
-    return x * pow(2.0f, c);
-}
 
 static void 
 gamma_expose_init_transfers_u8 (void * user_data)
 {
   gint i;
   GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
-  guint8 *gamma_data = (guint8*) pixelrow_data (&gamma_lut);
-  guint8 *expose_data = (guint8*) pixelrow_data (&expose_lut);
-  Tag lut_tag = tag_new (PRECISION_U8, FORMAT_GRAY, ALPHA_NO);
-  gdouble gamma = bcd->gamma;
-  gdouble expose = bcd->expose;
+  gfloat gamma = 1.0f/(gfloat)bcd->gamma;
+  gfloat expose = powf(2.0f,(gfloat)bcd->expose)/255.0f;
+  gfloat tmp ;
   
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!gamma_data && !expose_data)
-  {
-    gamma_data = (guint8 *)g_malloc ( sizeof (guint8) * 256 );
-    expose_data = (guint8 *)g_malloc ( sizeof (guint8) * 256 );
-  }
-  
-  for (i = 0; i < 256; i++)
-    gamma_data[i] = (guint8) (255.0 * gamma_func ( (gdouble)i/255.0,
-			 gamma*2.0));
+  gamma_lut8 = (guint8 *)g_malloc ( sizeof (guint8) * 256 );
 
   for (i = 0; i < 256; i++)
-    expose_data[i] = (guint8) (255.0 * expose_func ( (gdouble)i/255.0,
-		       expose*2.0));
-  
-  pixelrow_init (&gamma_lut, lut_tag, gamma_data, 256); 
-  pixelrow_init (&expose_lut, lut_tag, expose_data, 256); 
+  {
+    tmp = 0.5f + 255.0f * powf((gfloat)i*expose, gamma); 
+    
+    if (tmp < 0.5f)
+      gamma_lut8[i] = 0 ;
+    else if (tmp >= 255.0f)
+      gamma_lut8[i] = 255 ;
+    else
+      gamma_lut8[i] = (guint8)(tmp) ;
+  }
 }
 
 static void 
@@ -217,78 +198,26 @@ gamma_expose_init_transfers_u16 (void * user_data)
 {
   gint i;
   GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
-  guint16 *gamma_data = (guint16*) pixelrow_data (&gamma_lut);
-  guint16 *expose_data = (guint16*) pixelrow_data (&expose_lut);
-  Tag lut_tag = tag_new (PRECISION_U16, FORMAT_GRAY, ALPHA_NO);
-  gdouble gamma = bcd->gamma;
-  gdouble expose = bcd->expose;
+  gfloat gamma = 1.0f/(gfloat)bcd->gamma;
+  gfloat expose = powf(2.0f,(gfloat)bcd->expose)/65535.0f;
+  gfloat tmp ;
  
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!gamma_data && !expose_data)
+  gamma_lut16 = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
+
+  for (i = 0; i < 65536; i++)
   {
-    gamma_data = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
-    expose_data = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
-  }
-  
-  for (i = 0; i < 65536; i++)
-    gamma_data[i] = (guint16) (65535.0 * gamma_func ( (gdouble)i/65535.0,
-				      gamma*2.0));
-  for (i = 0; i < 65536; i++)
-    expose_data[i] = (guint16) (65535.0 * expose_func ( (double)i/65535.0,
-				      expose*2.0));
-  
-  pixelrow_init (&gamma_lut, lut_tag, (guchar*)gamma_data, 65536); 
-  pixelrow_init (&expose_lut, lut_tag, (guchar*)expose_data, 65536); 
+    tmp = 0.5f + 65535.f * powf( (gfloat)i*expose, gamma); 
+    
+    if (tmp < 0.5f)
+      gamma_lut16[i] = 0 ;
+    else if (tmp > 65535.0f)
+      gamma_lut16[i] = 65535 ;
+    else
+      gamma_lut16[i] = (guint16)(tmp) ;
+  } 
 }
 
-static void 
-gamma_expose_init_transfers_float (void * user_data)
-{
-#if 0
-  gint i;
-  GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
-  gfloat *gamma_data = (gfloat*) pixelrow_data (&gamma_lut);
-  gfloat *expose_data = (gfloat*) pixelrow_data (&expose_lut);
-  Tag lut_tag = tag_new (PRECISION_FLOAT, FORMAT_GRAY, ALPHA_NO);
-  gdouble gamma = bcd->gamma;
-  gdouble expose = bcd->expose;
- 
-  /* allocate memory for the transfers if we dont have it yet */
-  if (!gamma_data && !expose_data)
-  {
-    gamma_data = (gfloat *)g_malloc ( sizeof (gfloat) * 65536 );
-    expose_data = (gfloat *)g_malloc ( sizeof (gfloat) * 65536 );
-  }
-  
-  for (i = 0; i < 65536; i++)
-    gamma_data[i] = (gfloat) (gamma_func ( (gdouble)i, gamma*2.0));
-  for (i = 0; i < 65536; i++)
-    expose_data[i] = (gfloat) (expose_func ( (double)i, expose*2.0));
-  
-  pixelrow_init (&gamma_lut, lut_tag, (guchar*)gamma_data, 1); 
-  pixelrow_init (&expose_lut, lut_tag, (guchar*)expose_data, 1); 
-#endif  
-}
-
-static void 
-gamma_expose_init_transfers_float16 (void * user_data)
-{
-}
-
-static void 
-gamma_expose_free_transfers (void)
-{
-  guchar * gamma_lut_data = pixelrow_data (&gamma_lut);
-  guchar * expose_lut_data = pixelrow_data (&expose_lut);
-
-  if (gamma_lut_data) 
-    g_free (gamma_lut_data);
-  if (expose_lut_data)
-    g_free (expose_lut_data);
-
-  pixelrow_init (&gamma_lut, tag_null(), NULL, 0);
-  pixelrow_init (&expose_lut, tag_null(), NULL, 0);
-}
+#if 0 
 
 static void 
 gamma_expose_init_transfers_bfp (void * user_data)
@@ -301,7 +230,6 @@ gamma_expose_init_transfers_bfp (void * user_data)
   gfloat gamma = bcd->gamma;
   gfloat expose = bcd->expose;
  
-  /* allocate memory for the transfers if we dont have it yet */
   if (!gamma_data && !expose_data)
   {
     gamma_data = (guint16 *)g_malloc ( sizeof (guint16) * 65536 );
@@ -318,6 +246,24 @@ gamma_expose_init_transfers_bfp (void * user_data)
   pixelrow_init (&gamma_lut, lut_tag, (guchar*)gamma_data, 65536); 
   pixelrow_init (&expose_lut, lut_tag, (guchar*)expose_data, 65536); 
 }
+#endif 
+
+static void gamma_expose_free_transfers (void)
+{
+
+  if (gamma_lut8) 
+  {
+    g_free (gamma_lut8);
+    gamma_lut8 = NULL ;
+  }
+
+  if (gamma_lut16)
+  {
+    g_free(gamma_lut16) ;
+    gamma_lut16 = NULL ;
+  }
+}
+
 
 static void
 gamma_expose_u8 (PixelArea *src_area,
@@ -333,34 +279,31 @@ gamma_expose_u8 (PixelArea *src_area,
   int has_alpha;
   int alpha;
   int w, h, b;
-  GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
-  gfloat gamma = 1.f/(gfloat)bcd->gamma;
-  gfloat expose = pow(2.0,(gfloat)bcd->expose);
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
-  
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
   while (h--)
     {
       s = (guint8*)src;
       d = (guint8*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  // Added by IMAGEWORKS thedoug (01/02)
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(255 * pow(s[b]/255.*expose, 
-		   gamma), 0, 255);
+      {
+          /* Added by IMAGEWORKS thedoug (01/02) */
+          for (b = 0; b < alpha; b++)
+            d[b] = gamma_lut8[s[b]] ; 
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+          if (has_alpha)
+            d[alpha] = s[alpha];
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+          s += src_num_channels;
+          d += dest_num_channels; 
+      }
 
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
@@ -381,34 +324,31 @@ gamma_expose_u16 (PixelArea *src_area,
   int has_alpha;
   int alpha;
   int w, h, b;
-  GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
-  gfloat gamma = 1.f/(gfloat)bcd->gamma;
-  gfloat expose = pow(2.0,(gfloat)bcd->expose);
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
-  
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
   while (h--)
     {
       s = (guint16*)src;
       d = (guint16*)dest;
       w = pixelarea_width (src_area);
+
       while (w--)
-	{
-	  // Added by IMAGEWORKS thedoug (01/02)
-	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(65535 * pow(s[b]/65535.*expose, 
-	           gamma), 0, 65535);
+      {
+          // Added by IMAGEWORKS thedoug (01/02) 
+          for (b = 0; b < alpha; b++)
+            d[b] = gamma_lut16[s[b]] ;
 
-	  if (has_alpha)
-	    d[alpha] = s[alpha];
+          if (has_alpha)
+            d[alpha] = s[alpha];
 
-	  s += src_num_channels;
-	  d += dest_num_channels; 
-	}
+          s += src_num_channels;
+          d += dest_num_channels; 
+      }
 
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
@@ -431,7 +371,7 @@ gamma_expose_float (PixelArea *src_area,
   int w, h, b;
   GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
   gfloat gamma = 1.f/(gfloat)bcd->gamma;
-  gfloat expose = pow(2.0,(gfloat)bcd->expose);
+  gfloat expose = powf(2.0f,(gfloat)bcd->expose);
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -447,8 +387,8 @@ gamma_expose_float (PixelArea *src_area,
       while (w--)
 	{
 	  for (b = 0; b < alpha; b++) {
-          d[b] = pow(s[b] * expose, gamma);
-          //expose_func (gamma_func(s[b], gamma), expose);
+          d[b] = powf(s[b] * expose, gamma);
+
           if (bcd->forceexpose) { /* clamp */
               if (d[b] > 1.0f) d[b] = 1.0f;
               else if (d[b] < 0.0f) d[b] = 0.0f;
@@ -461,7 +401,6 @@ gamma_expose_float (PixelArea *src_area,
 	  s += src_num_channels;
 	  d += dest_num_channels; 
 	}
-
       src += pixelarea_rowstride (src_area);
       dest += pixelarea_rowstride (dest_area);
     }
@@ -483,7 +422,7 @@ gamma_expose_float16 (PixelArea *src_area,
   int w, h, b;
   GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
   gfloat gamma = 1.f/(gfloat)bcd->gamma;
-  gfloat expose = pow(2.0,(gfloat)bcd->expose);
+  gfloat expose = powf(2.0f,(gfloat)bcd->expose);
   ShortsFloat u;
   gfloat sb, db;
 
@@ -503,7 +442,7 @@ gamma_expose_float16 (PixelArea *src_area,
 	  for (b = 0; b < alpha; b++)
 	  {
 	    sb = FLT (s[b], u);
-	    db = pow (sb*expose, gamma);
+	    db = powf(sb*expose, gamma);
 	    d[b] = FLT16 (db, u);
 	  }
 
@@ -535,7 +474,8 @@ gamma_expose_bfp (PixelArea *src_area,
   int w, h, b;
   GammaExposeDialog *bcd = (GammaExposeDialog *) user_data;
   gfloat gamma = 1.f/(gfloat)bcd->gamma;
-  gfloat expose = pow(2.0,(gfloat)bcd->expose);
+  gfloat expose = pow(2.0,(gfloat)bcd->expose)/32768.f ;
+  gfloat tmp ;
 
   src = (guchar *)pixelarea_data (src_area);
   dest = (guchar *)pixelarea_data (dest_area);
@@ -543,6 +483,7 @@ gamma_expose_bfp (PixelArea *src_area,
   has_alpha = tag_alpha (src_tag) == ALPHA_YES ? TRUE: FALSE;
   alpha = has_alpha ? src_num_channels - 1 : src_num_channels;
   h = pixelarea_height (src_area);
+
   while (h--)
     {
       s = (guint16*)src;
@@ -552,8 +493,10 @@ gamma_expose_bfp (PixelArea *src_area,
 	{
 	  // Added by IMAGEWORKS thedoug (01/02)
 	  for (b = 0; b < alpha; b++)
-	    d[b] = CLAMP(32768.f * pow(s[b]/32768.f*expose, 
-	           gamma), 0, 65535);
+      {
+        tmp =32768.f * pow(s[b]*expose, gamma) ;
+	    d[b] = CLAMP(tmp, 0, 65535);
+      }
 
 	  if (has_alpha)
 	    d[alpha] = s[alpha];
@@ -694,9 +637,6 @@ gamma_expose_initialize (void *gdisp_ptr)
   /* Set up the function pointers for our data type */
   gamma_expose_funcs (drawable_tag (drawable));
   
-  pixelrow_init (&gamma_lut, tag_null(), NULL , 0); 
-  pixelrow_init (&expose_lut, tag_null(), NULL, 0); 
-  
 
   /*  The gamma-expose dialog  */
   if (init_dialog)
@@ -863,18 +803,15 @@ gamma_expose_new_dialog (GammaExposeDialog * bcd)
   gtk_widget_show (toggle);
   gtk_widget_show (hbox);
 
-  /*  The expose toggle  */
   forceexpose = gtk_check_button_new_with_label (_("Clamp"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (forceexpose), bcd->forceexpose);
   gtk_box_pack_start (GTK_BOX (hbox), forceexpose, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (forceexpose), "toggled",
-		      (GtkSignalFunc) gamma_expose_force_update,
-		      bcd);
+              (GtkSignalFunc) gamma_expose_force_update,
+              bcd);
 
-  //gtk_widget_show (label);
   gtk_widget_show (forceexpose);
 
-
   /*  The action area  */
   action_items[0].user_data = bcd;
   action_items[1].user_data = bcd;
@@ -918,8 +855,12 @@ gamma_expose_preview (GammaExposeDialog *bcd)
 {
   if (!bcd->image_map)
     g_message ("gamma_expose_preview(): No image map");
+
   active_tool->preserve = TRUE;
-  (*gamma_expose_init_transfers) ((void *)bcd); 
+
+  if (gamma_expose_init_transfers != NULL)
+      (*gamma_expose_init_transfers) ((void *)bcd); 
+
   image_map_apply (bcd->image_map, gamma_expose, (void *) bcd);
   active_tool->preserve = FALSE;
 }
@@ -939,18 +880,17 @@ gamma_expose_ok_callback (GtkWidget *widget,
 
   if (!bcd->preview)
   {
-    (*gamma_expose_init_transfers) ((void *)bcd); 
+    if (gamma_expose_init_transfers != NULL)
+      (*gamma_expose_init_transfers) ((void *)bcd); 
+    
     image_map_apply (bcd->image_map, gamma_expose, (void *) bcd);
   }
 
   if (bcd->image_map)
-  {
     image_map_commit (bcd->image_map);
-    gamma_expose_free_transfers();
-  }
 
+  gamma_expose_free_transfers();
   active_tool->preserve = FALSE;
-
   bcd->image_map = NULL;
 }
 
@@ -978,9 +918,11 @@ gamma_expose_cancel_callback (GtkWidget *widget,
     {
       active_tool->preserve = TRUE;
       image_map_abort (bcd->image_map);
-      gamma_expose_free_transfers();
+
       active_tool->preserve = FALSE;
     }
+
+  gamma_expose_free_transfers();
   bcd->gdisp->gamma = bcd->old_gamma;
   bcd->gdisp->expose = bcd->old_expose;
   gdisplays_flush ();
@@ -1233,9 +1175,9 @@ gamma_expose_invoker (Argument *args)
       bcd.expose = expose;
         
       gamma_expose_funcs(drawable_tag (drawable));
-      pixelrow_init (&gamma_lut, tag_null(), NULL , 0); 
-      pixelrow_init (&expose_lut, tag_null(), NULL, 0); 
-      (*gamma_expose_init_transfers)(&bcd);
+
+      if (gamma_expose_init_transfers != NULL)
+          (*gamma_expose_init_transfers)(&bcd);
       
       /*  The application should occur only within selection bounds  */
       drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
