@@ -83,6 +83,8 @@ struct RenderInfo
   CMSTransform *transform_buffer;
 };
 
+CMSTransform* render_image_get_cms_transform( GDisplay   * gdisp ,
+                                              RenderInfo * info);
 
 /*  accelerate transparency of image scaling  */
 guchar *blend_dark_check = NULL;
@@ -924,15 +926,97 @@ render_image_init_info (RenderInfo *info,
 
   /* if colormanaged, get the required transform
    */
-  info->transform_buffer =
-        gimage_get_cms_transform( info->gdisp->gimage,
-                                  info->gdisp->look_profile_pipe,
-                                  gdisplay_is_colormanaged(info->gdisp),
-                                  gdisplay_is_proofed(info->gdisp),
-                                  gdisplay_get_cms_intent(info->gdisp),
-                                  gdisplay_get_cms_flags(info->gdisp),
-                                  gdisplay_get_cms_proof_intent(info->gdisp),
-                                  info->gdisp->cms_expensive_transf );
+  info->transform_buffer = render_image_get_cms_transform( info->gdisp, info );
+}
+
+CMSTransform*
+render_image_get_cms_transform( GDisplay * gdisp, RenderInfo * info)
+{
+  CMSTransform *transform_buffer = NULL;
+
+  GImage * image = gdisp->gimage;
+  GSList *look_profile_pipe = gdisp->look_profile_pipe;
+  int colormanaged = gdisplay_is_colormanaged(gdisp);
+  int proofed = gdisplay_is_proofed(gdisp);
+  int cms_intent = gdisplay_get_cms_intent(gdisp);
+  int cms_flags = gdisplay_get_cms_flags(gdisp);
+  int cms_proof_flags = gdisplay_get_cms_proof_intent(gdisp);
+  CMSTransform **cms_expensive_transf = gdisp->cms_expensive_transf;
+
+  Canvas * src_canvas = gimage_projection (image);
+  Tag src_tag = canvas_tag( src_canvas );
+  Tag dest_tag = 0;
+
+  if(info->dest_bpp < 3)
+    dest_tag = tag_new( tag_precision(src_tag), FORMAT_GRAY,
+                        tag_alpha(src_tag));
+  else
+    dest_tag = tag_new( tag_precision(src_tag), FORMAT_RGB,
+                        tag_alpha(src_tag));
+
+  if (colormanaged)
+  {   /* combine profiles */
+      GSList *profiles = NULL;
+      CMSProfile *image_profile = gimage_get_cms_profile(image);
+      CMSProfile *proof_profile = NULL;
+      CMSProfile *display_profile = cms_get_display_profile();
+      if (proofed)
+      {
+          proof_profile = gimage_get_cms_proof_profile(image);
+      }
+      if (image_profile == NULL)
+      {   g_warning("gdisplay_project: cannot colourmanage, image has no profile assigned");
+          transform_buffer = NULL;
+      }
+      else if (display_profile == NULL)
+      {   g_warning("gdisplay_project: cannot colourmanage, no display profile set");
+          transform_buffer = NULL;
+      }
+      else
+      {   profiles = g_slist_append(profiles, (gpointer)image_profile);
+          if(look_profile_pipe)
+              profiles = g_slist_concat(profiles, g_slist_copy(look_profile_pipe));
+          if (proof_profile)
+              profiles = g_slist_append(profiles, (gpointer)proof_profile);
+          else /* lcms crashes on softproofing */
+              cms_flags = cms_flags & (~cmsFLAGS_SOFTPROOFING);
+          profiles = g_slist_append(profiles, (gpointer)display_profile);
+
+          transform_buffer = cms_get_canvas_transform (profiles,
+                               dest_tag, dest_tag,
+                               cms_intent, cms_flags,
+                               cms_proof_flags,
+                               cms_expensive_transf);
+          g_slist_free(profiles);
+      }
+  }
+  /* if we have got look profiles ... */
+  else if (!colormanaged && (look_profile_pipe != NULL))
+  {   GSList *profiles = NULL;
+      CMSProfile *image_profile = gimage_get_cms_profile(image);
+      if (image_profile == NULL)
+      {   image_profile = cms_get_srgb_profile();
+      }
+      profiles = g_slist_append(profiles, (gpointer)image_profile);
+      profiles = g_slist_concat(profiles, g_slist_copy(look_profile_pipe));
+      profiles = g_slist_append(profiles, (gpointer)image_profile);
+      transform_buffer = cms_get_canvas_transform (profiles,
+                               dest_tag, dest_tag,
+                               cms_intent, cms_flags,
+                               cms_proof_flags,
+                               cms_expensive_transf);
+      g_slist_free(profiles);
+  }
+
+  if(!transform_buffer)
+  {
+    GDisplay *disp = gdisplay_get_from_gimage(image);
+    if(disp)
+      /* we must avoid updates in gdisplay_set_colormanaged  */
+      disp->colormanaged = FALSE;
+  }
+
+  return transform_buffer;
 }
 
 static guint*
@@ -1973,9 +2057,18 @@ render_image_rgb_float (RenderInfo *info)
               dest[1] = (guint8) (src[GREEN_PIX] * 255);
               dest[2] = (guint8) (src[BLUE_PIX] * 255);
 #else
-	    dest[0] = float_to_8bit(src[0]);
-	    dest[1] = float_to_8bit(src[1]);
-	    dest[2] = float_to_8bit(src[2]);
+              if ((src[RED_PIX] > 1.0) || (src[GREEN_PIX] > 1.0) || (src[BLUE_PIX] > 1.0))
+              {
+		dest[0] = gamut_alarm_red;
+                dest[1] = gamut_alarm_green;
+                dest[2] = gamut_alarm_blue;
+              }
+              else
+	      {
+	        dest[0] = float_to_8bit(src[0]);
+	        dest[1] = float_to_8bit(src[1]);
+	        dest[2] = float_to_8bit(src[2]);
+              }
 #endif 
 	      src += 3;
 	      dest += 3;
@@ -2040,19 +2133,27 @@ render_image_rgb_a_float (RenderInfo *info)
 	  for (x = info->x; x < xe; x++)
 	    {
 	      a = alpha[float_to_8bit(src[ALPHA_PIX])];
-	      if (dark_light & 0x1)
+              if ((src[RED_PIX] > 1.0) || (src[GREEN_PIX] > 1.0) || (src[BLUE_PIX] > 1.0))
+              {
+		r = gamut_alarm_red;
+                g = gamut_alarm_green;
+                b = gamut_alarm_blue;
+              }
+              else
+	      {
+	        if (dark_light & 0x1)
 		{
 		  r = blend_dark_check[(a | float_to_8bit(src[RED_PIX]))];
 		  g = blend_dark_check[(a | float_to_8bit(src[GREEN_PIX]))];
 		  b = blend_dark_check[(a | float_to_8bit(src[BLUE_PIX]))];
 		}
-	      else
+	        else
 		{
 		  r = blend_light_check[(a | float_to_8bit(src[RED_PIX]))];
 		  g = blend_light_check[(a | float_to_8bit(src[GREEN_PIX]))];
 		  b = blend_light_check[(a | float_to_8bit(src[BLUE_PIX]))];
 		}
-
+              }
 	      src += 4;
 
 	      dest[0] = r;
@@ -2121,9 +2222,18 @@ render_image_gray_float16 (RenderInfo *info)
 	      src8bit = LUT_u8_from_float16[src[GRAY_PIX]] ;
 	      src += 1;
 
-	      dest[0] = src8bit;
-	      dest[1] = src8bit;
-	      dest[2] = src8bit;
+              if (src[GRAY_PIX] > ONE_FLOAT16)
+              {
+		dest[RED_PIX] = gamut_alarm_red;
+                dest[GREEN_PIX] = gamut_alarm_green;
+                dest[BLUE_PIX] = gamut_alarm_blue;
+              }
+              else
+	      {
+	        dest[0] = src8bit;
+	        dest[1] = src8bit;
+	        dest[2] = src8bit;
+              }
 	      dest += 3;
 	    }
 	}
@@ -2193,9 +2303,18 @@ render_image_gray_a_float16 (RenderInfo *info)
 		val = blend_light_check[(a | src8bit)];
 	      src += 2;
 
-	      dest[0] = val;
-	      dest[1] = val;
-	      dest[2] = val;
+              if (src[GRAY_PIX] > ONE_FLOAT16)
+              {
+		dest[RED_PIX] = gamut_alarm_red;
+                dest[GREEN_PIX] = gamut_alarm_green;
+                dest[BLUE_PIX] = gamut_alarm_blue;
+              }
+              else
+	      {
+     	        dest[0] = val;
+	        dest[1] = val;
+	        dest[2] = val;
+              }
 	      dest += 3;
 
 	      if (((x + 1) & check_mod) == 0)
@@ -2257,9 +2376,18 @@ render_image_rgb_float16 (RenderInfo *info)
               dest[1] = (guint8) (FLT (src[GREEN_PIX], u) * 255);
               dest[2] = (guint8) (FLT (src[BLUE_PIX], u) * 255);
 #else
-	      dest[0] = LUT_u8_from_float16 [src[RED_PIX]];
-	      dest[1] = LUT_u8_from_float16 [src[GREEN_PIX]];
-	      dest[2] = LUT_u8_from_float16 [src[BLUE_PIX]];
+              if ((src[RED_PIX] > ONE_FLOAT16) || (src[GREEN_PIX] > ONE_FLOAT16) || (src[BLUE_PIX] > ONE_FLOAT16))
+              {
+		dest[0] = gamut_alarm_red;
+                dest[1] = gamut_alarm_green;
+                dest[2] = gamut_alarm_blue;
+              }
+              else
+	      {
+	        dest[0] = LUT_u8_from_float16 [src[RED_PIX]];
+	        dest[1] = LUT_u8_from_float16 [src[GREEN_PIX]];
+	        dest[2] = LUT_u8_from_float16 [src[BLUE_PIX]];
+              }
 #endif
 	      src += 3;
 	      dest += 3;
@@ -2324,14 +2452,23 @@ render_image_rgb_a_float16 (RenderInfo *info)
           while (dest != last) 
 	    {
               // NB: This assumes that RED_PIX = 0, GREEN_PIX = 1, BLUE_PIX = 2, ALPHA_PIX = 3
-	      r = LUT_u8_from_float16 [*src];
-              ++src;
-    	      g = LUT_u8_from_float16 [*src];
-              ++src;
-	      b = LUT_u8_from_float16 [*src];
-              ++src;
-	      a = alpha[ LUT_u8a_from_float16 [*src] ];
-              ++src;
+              if ((src[RED_PIX] > ONE_FLOAT16) || (src[GREEN_PIX] > ONE_FLOAT16) || (src[BLUE_PIX] > ONE_FLOAT16))
+              {
+		r = gamut_alarm_red;
+                g = gamut_alarm_green;
+                b = gamut_alarm_blue;
+              }
+              else
+	      {
+	        r = LUT_u8_from_float16 [*src];
+                ++src;
+    	        g = LUT_u8_from_float16 [*src];
+                ++src;
+	        b = LUT_u8_from_float16 [*src];
+                ++src;
+	        a = alpha[ LUT_u8a_from_float16 [*src] ];
+                ++src;
+              }
 	      if (dark_light & 0x1)
 		{
 		  r = blend_dark_check[a | r];
@@ -2416,9 +2553,9 @@ render_image_gray_bfp (RenderInfo *info)
               /* check for over-white*/
               if (src[GRAY_PIX] > ONE_BFP)
               {
-		dest[RED_PIX] = gamut_alarm_red;
-                dest[GREEN_PIX] = gamut_alarm_blue;
-                dest[BLUE_PIX] = gamut_alarm_green;
+		dest[RED_PIX] =   gamut_alarm_red;
+                dest[GREEN_PIX] = gamut_alarm_green;
+                dest[BLUE_PIX] =  gamut_alarm_blue;
               }
               else
 	      {
@@ -2655,8 +2792,8 @@ render_image_rgb_a_bfp (RenderInfo *info)
               if ((src[RED_PIX] > ONE_BFP) || (src[GREEN_PIX] > ONE_BFP) || (src[BLUE_PIX] > ONE_BFP)) 
               {
                 r = gamut_alarm_red;
-                b = gamut_alarm_blue;
                 g = gamut_alarm_green;
+                b = gamut_alarm_blue;
               }
               else
 	      {
