@@ -78,8 +78,13 @@ gimp_layer_get_type ()
 	sizeof (GimpLayerClass),
 	(GtkClassInitFunc) gimp_layer_class_init,
 	(GtkObjectInitFunc) gimp_layer_init,
+#if GTK_MAJOR_VERSION > 1
+	NULL,
+	NULL,
+#else
 	(GtkArgSetFunc) NULL,
 	(GtkArgGetFunc) NULL,
+#endif
       };
 
       layer_type = gtk_type_unique (gimp_drawable_get_type (), &layer_info);
@@ -126,8 +131,13 @@ gimp_layer_mask_get_type ()
 	sizeof (GimpLayerMaskClass),
 	(GtkClassInitFunc) gimp_layer_mask_class_init,
 	(GtkObjectInitFunc) gimp_layer_mask_init,
+#if GTK_MAJOR_VERSION > 1
+	NULL,
+	NULL,
+#else
 	(GtkArgSetFunc) NULL,
 	(GtkArgGetFunc) NULL,
+#endif
       };
 
       layer_mask_type = gtk_type_unique (gimp_channel_get_type (), &layer_mask_info);
@@ -535,10 +545,12 @@ gimp_layer_destroy (GtkObject *object)
   /*  if a layer mask exists, free it  */
   if (layer->mask)
     layer_mask_delete (layer->mask);
+  layer->mask = NULL;
 
   /*  free the layer boundary if it exists  */
   if (layer->fs.segs)
     g_free (layer->fs.segs);
+  layer->fs.segs = NULL;
 
   /*  free the floating selection if it exists  */
   if (layer_is_floating_sel (layer))
@@ -729,7 +741,7 @@ layer_remove_alpha (layer)
    */
   gdisplays_update_title (GIMP_DRAWABLE(layer)->gimage_ID);
 
-  if(gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID))
+  if((gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID)))
     lc_dialog_update (gimage);
 }
 
@@ -786,7 +798,7 @@ layer_add_alpha (layer)
    */
   gdisplays_update_title (GIMP_DRAWABLE(layer)->gimage_ID);
 
-  if(gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID))
+  if((gimage = gimage_get_ID(GIMP_DRAWABLE(layer)->gimage_ID)))
     lc_dialog_update (gimage);
 }
 
