@@ -46,6 +46,11 @@
 
 #define    SQR(x) ((x) * (x))
 
+/* was formerly sqrt(x), wacom works better without modify , beku
+ * The pencil should use sqrt while without it feels like a long hair brush.
+ */
+#define    PRESSURE_MODIFY(x)  ( x )
+
 Canvas *  canvas_16_to_16                (Canvas *); /*IMAGEWORKS aland*/
 Canvas *  canvas_16_to_8                 (Canvas *); /*IMAGEWORKS aland*/
 Canvas *  canvas_16_to_float             (Canvas *); /*IMAGEWORKS thedoug*/
@@ -95,9 +100,7 @@ static void      painthit_finish               (CanvasDrawable *, PaintCore16 *,
                                                 Canvas *);
 
 static Canvas *  brush_mask_get                (PaintCore16 *, Canvas *, int, gdouble);
-#ifdef BRUSH_WITH_BORDER 
-static Canvas *  brush_mask_subsample          (Canvas *, double, double);
-#endif
+static Canvas *  brush_mask_subsample          (Canvas *, double, double, double);
 static Canvas *  brush_mask_solidify           (PaintCore16 *, Canvas *);
 static Canvas *  brush_mask_noise  	       (PaintCore16 *, Canvas *);
 
@@ -114,10 +117,12 @@ static void brush_mask_noise_float16 (PaintCore16 *, Canvas *, Canvas *);
 static void      paint_core_calculate_brush_size (Canvas *mask,
 						  gdouble  scale,
 						  gint    *width,
-						  gint    *height);
-static Canvas * paint_core_scale_mask           (Canvas *brush_mask, 
+						  gint    *height,
+                                                  gdouble *ratio);
+static Canvas * paint_core_scale_mask           (Canvas  *brush_mask,
+                                                 gdouble  pos_x,
+                                                 gdouble  pos_y,      
 						 gdouble  scale);
-static gboolean  cache_invalid   = FALSE;
 static Canvas  *scale_brush     = NULL;
 
 /* ------------------------------------------------------------------------
@@ -229,6 +234,7 @@ paint_core_16_init_linked  (
   paint_core->spacing =
     (double) MAX (canvas_height (brush->mask), canvas_width (brush->mask)) *
     ((double) gimp_brush_get_spacing () / 100.0);
+  paint_core->spacing_scale = 1.0;
 
   if (paint_core->spacing < 1.0)
     paint_core->spacing = 1.0;
@@ -325,14 +331,13 @@ void
 paint_core_16_interpolate  (PaintCore16 * paint_core,
                             CanvasDrawable *drawable)
 {
-#define    EPSILON  0.00001
-  int n;
   double dx, dy;
-  double left;
   double t;
   double initial;
   double dist;
   double total;
+  double pressure;
+  double spacing;
 
   /* wacom */
   gdouble dpressure, dxtilt, dytilt;
@@ -358,16 +363,24 @@ paint_core_16_interpolate  (PaintCore16 * paint_core,
   dist = sqrt (SQR (dx) + SQR (dy));
   total = dist + paint_core->distance;
   initial = paint_core->distance;
+  pressure = paint_core->lastpressure;
+
+  paint_core->curx = paint_core->lastx;
+  paint_core->cury = paint_core->lasty;
+  paint_core->curpressure = paint_core->lastpressure;
+  paint_core->curxtilt    = paint_core->lastxtilt;
+  paint_core->curytilt    = paint_core->lastytilt;
 
   while (paint_core->distance < total)
     {
-      n = (int) (paint_core->distance / paint_core->spacing + 1.0 + EPSILON);
-      left = n * paint_core->spacing - paint_core->distance;
-      paint_core->distance += left;
+      spacing = MAX(paint_core->spacing * PRESSURE_MODIFY (paint_core->spacing_scale), 0.2);
+      paint_core->distance += spacing;
+      t = (paint_core->distance - initial) / dist;
+      pressure = ((paint_core->distance - initial) * dpressure) / dist +
+                 paint_core->lastpressure;
 
       if (paint_core->distance <= total)
 	{
-	  t = (paint_core->distance - initial) / dist;
 
 	  paint_core->curx = paint_core->lastx + dx * t;
 	  paint_core->cury = paint_core->lasty + dy * t;
@@ -378,12 +391,7 @@ paint_core_16_interpolate  (PaintCore16 * paint_core,
 	}
     }
 
-  paint_core->distance = total;
-  paint_core->curx = paint_core->lastx + dx;
-  paint_core->cury = paint_core->lasty + dy;
-  paint_core->curpressure = paint_core->lastpressure + dpressure;
-  paint_core->curxtilt    = paint_core->lastxtilt + dxtilt;
-  paint_core->curytilt    = paint_core->lastytilt + dytilt;
+  paint_core->distance -= spacing;
 
 }
 
@@ -545,10 +553,29 @@ paint_core_16_button_press  (Tool * tool,
   paint_core->state = bevent->state;
 
   /* wacom stuff */
+#if GTK_MAJOR_VERSION > 1
+      if (gdk_event_get_axis (bevent, GDK_AXIS_PRESSURE, &paint_core->curpressure))
+        paint_core->curpressure = CLAMP (paint_core->curpressure, .0,
+                                  1.);
+      else
+        paint_core->curpressure = 1.0;
+
+      if (gdk_event_get_axis (bevent, GDK_AXIS_XTILT, &paint_core->curxtilt))
+        paint_core->curxtilt = CLAMP (paint_core->curxtilt, -1.0,
+                               1.0);
+      else
+        paint_core->curxtilt = 0.0;
+
+      if (gdk_event_get_axis (bevent, GDK_AXIS_YTILT, &paint_core->curytilt))
+        paint_core->curytilt = CLAMP (paint_core->curytilt, -1.0,
+                               1.0);
+      else
+        paint_core->curytilt = 0.0;
+#else
   paint_core->curpressure = bevent->pressure;
   paint_core->curxtilt = bevent->xtilt;
   paint_core->curytilt = bevent->ytilt;
-
+#endif
   
   /*  if this is a new image, reinit the core vals  */
   if (gdisp_ptr != tool->gdisp_ptr ||
@@ -666,9 +693,37 @@ paint_core_16_motion  (
 
   paint_core->state = mevent->state;
   /*wacom */
+#if GTK_MAJOR_VERSION > 1
+      if (gdk_event_get_axis (mevent, GDK_AXIS_PRESSURE, &paint_core->curpressure))
+        paint_core->curpressure = CLAMP (paint_core->curpressure, .0,
+                                  1.);
+      else
+        paint_core->curpressure = 1.0;
+
+      if (gdk_event_get_axis (mevent, GDK_AXIS_XTILT, &paint_core->curxtilt))
+      {
+# ifdef DEBUG_
+        printf("curxtilt = %f",paint_core->curxtilt);
+# endif
+        paint_core->curxtilt = CLAMP (paint_core->curxtilt, -1.0,
+                               1.0);
+      } else
+        paint_core->curxtilt = 0.0;
+
+      if (gdk_event_get_axis (mevent, GDK_AXIS_YTILT, &paint_core->curytilt))
+      {
+# ifdef DEBUG_
+        printf("curytilt = %f\n",paint_core->curytilt);
+# endif
+        paint_core->curytilt = CLAMP (paint_core->curytilt, -1.0,
+                               1.0);
+      } else
+        paint_core->curytilt = 0.0;
+#else
   paint_core->curpressure = mevent->pressure;
-  paint_core->curxtilt    = mevent->xtilt;
-  paint_core->curytilt    = mevent->ytilt;
+  paint_core->curxtilt = mevent->xtilt;
+  paint_core->curytilt = mevent->ytilt;
+#endif
 
   
   paint_core_16_interpolate (paint_core, gimage_active_drawable (gdisp->gimage));
@@ -805,17 +860,10 @@ paint_core_16_area_setup  (
   dh = drawable_height (drawable);
 
 #define PAINT_CORE_16_C_4_cw  
-#ifdef BRUSH_WITH_BORDER 
-  x1 = CLAMP (x - 1 , 0, dw);
-  y1 = CLAMP (y - 1, 0, dh);
-  x2 = CLAMP (x + bw + 1, 0, dw);
-  y2 = CLAMP (y + bh + 1, 0, dh);
-#else  
   x1 = CLAMP (x , 0, dw);
   y1 = CLAMP (y , 0, dh);
-  x2 = CLAMP (x + bw , 0, dw);
-  y2 = CLAMP (y + bh , 0, dh);
-#endif
+  x2 = CLAMP (x + bw + 1, 0, dw);
+  y2 = CLAMP (y + bh + 1, 0, dh);
   /* save the boundaries of this paint hit */
   paint_core->x = x1;
   paint_core->y = y1;
@@ -1067,6 +1115,7 @@ paint_core_16_area_paste  (
     brush_mask = paint_core->brush_mask;
 
   //Added by IMAGEWORKS aland to be able to paint on a 8 bit image
+  paint_core->spacing_scale = brush_scale; 
   brush_mask = brush_mask_get (paint_core, brush_mask, brush_hardness, brush_scale);
   if(tag_precision(drawable_tag(drawable)) == PRECISION_U8){
       brush_mask2 = canvas_16_to_8 (brush_mask);
@@ -1318,20 +1367,22 @@ brush_to_canvas_tiles(
   PixelArea srcPR, maskPR;
     int xoff, yoff;
     int x, y;
+    int w = canvas_width (brush_mask),
+        h = canvas_height (brush_mask);
       
-    x = (int) paint_core->curx - (canvas_width (brush_mask) >> 1);
-    y = (int) paint_core->cury - (canvas_height (brush_mask) >> 1);
+    x = (int) paint_core->curx - (w >> 1);
+    y = (int) paint_core->cury - (h >> 1);
     xoff = (x < 0) ? -x : 0;
     yoff = (y < 0) ? -y : 0;
     
     pixelarea_init (&srcPR, paint_core->canvas_tiles,
                     paint_core->x, paint_core->y,
-                    paint_core->canvas_buf_width, paint_core->canvas_buf_height,
+                    w,h,
                     TRUE);      
 
     pixelarea_init (&maskPR, brush_mask,
                     xoff, yoff,
-                    canvas_width (brush_mask), canvas_height (brush_mask),
+                    w,h,
                     TRUE);
 
     combine_mask_and_area (&srcPR, &maskPR, brush_opacity);
@@ -1492,19 +1543,24 @@ brush_mask_get  (
                  )
 {
   Canvas * bm;
+
+#ifndef GDK_CORE_POINTER
+#define GDK_CORE_POINTER 0xfedc
+#endif
+
   if (current_device == GDK_CORE_POINTER || fabs(1.0 - scale)  < 0.001)
     bm = brush_mask;
   else
-    bm = paint_core_scale_mask (brush_mask, scale);
+    bm = paint_core_scale_mask (brush_mask, 
+                                paint_core->curx, paint_core->cury,
+                                scale);
 
   switch (brush_hardness)
     {
     case SOFT:
-#ifdef BRUSH_WITH_BORDER
-      d_printf ("BRUSH_WITH_BORDER\n"); 
-      bm = brush_mask_subsample (brush_mask,
-                                 paint_core->curx, paint_core->cury);
-#endif
+      if (current_device == GDK_CORE_POINTER || fabs(1.0 - scale)  < 0.001)
+        bm = brush_mask_subsample (bm,
+                                   paint_core->curx, paint_core->cury, scale);
       break;
       
     case HARD:
@@ -1519,119 +1575,81 @@ brush_mask_get  (
       break;
     }
 
+
   return bm;
 }
 
 
-#ifdef BRUSH_WITH_BORDER 
 static Canvas * 
 brush_mask_subsample  (
                        Canvas * mask,
-                       double x,
-                       double y
+                       double orig_x,
+                       double orig_y,
+                       double scale
                        )
 {
-#define KERNEL_WIDTH   3
-#define KERNEL_HEIGHT  3
-
-  /*  Brush pixel subsampling kernels  */
-  static int subsample[4][4][9] =
-  {
-    {
-      { 16, 48, 0, 48, 144, 0, 0, 0, 0 },
-      { 0, 64, 0, 0, 192, 0, 0, 0, 0 },
-      { 0, 48, 16, 0, 144, 48, 0, 0, 0 },
-      { 0, 32, 32, 0, 96, 96, 0, 0, 0 },
-    },
-    {
-      { 0, 0, 0, 64, 192, 0, 0, 0, 0 },
-      { 0, 0, 0, 0, 256, 0, 0, 0, 0 },
-      { 0, 0, 0, 0, 192, 64, 0, 0, 0 },
-      { 0, 0, 0, 0, 128, 128, 0, 0, 0 },
-    },
-    {
-      { 0, 0, 0, 48, 144, 0, 16, 48, 0 },
-      { 0, 0, 0, 0, 192, 0, 0, 64, 0 },
-      { 0, 0, 0, 0, 144, 48, 0, 48, 16 },
-      { 0, 0, 0, 0, 96, 96, 0, 32, 32 },
-    },
-    {
-      { 0, 0, 0, 32, 96, 0, 32, 96, 0 },
-      { 0, 0, 0, 0, 128, 0, 0, 128, 0 },
-      { 0, 0, 0, 0, 96, 32, 0, 96, 32 },
-      { 0, 0, 0, 0, 64, 64, 0, 64, 64 },
-    },
-  };
-  
-  static Canvas * kernel_brushes[4][4] = {
-    {NULL, NULL, NULL, NULL},
-    {NULL, NULL, NULL, NULL},
-    {NULL, NULL, NULL, NULL},
-    {NULL, NULL, NULL, NULL}
-  };
-
-  static Canvas * last_brush = NULL;
-
   Canvas * dest;
-  double left;
-  unsigned char * m, * d;
-  int * k;
-  int index1, index2;
-  int * kernel;
-  int new_val;
-  int i, j;
-  int r, s;
+  guint16 * m, * d;
+  float new_val;
+  ShortsFloat u;
+  int x, y;
+  int orig_w = canvas_width (mask);
+  int orig_h = canvas_height (mask);
+  int startx = 0,
+      starty = 0,
+      scal_width = orig_w,
+      scal_height = orig_h,
+      endx = orig_w-1,
+      endy = orig_h-1;
+  double ip;
+  double jump_x = modf( orig_x, &ip ),
+         jump_y = modf( orig_y, &ip );
 
-  x += (x < 0) ? canvas_width (mask) : 0;
-  left = x - ((int) x);
-  index1 = (int) (left * 4);
-  index1 = (index1 < 0) ? 0 : index1;
 
-  y += (y < 0) ? canvas_height (mask) : 0;
-  left = y - ((int) y);
-  index2 = (int) (left * 4);
-  index2 = (index2 < 0) ? 0 : index2;
+  if (current_device != GDK_CORE_POINTER || fabs( scale) > 0.001)
+  {
+    gdouble ratio = 0;
+    paint_core_calculate_brush_size (mask, scale, 
+                                     &scal_width, &scal_height,
+                                     &ratio);
+    startx = (orig_w-scal_width)/2;
+    starty = (orig_h-scal_height)/2;
+    endx = startx + scal_width - 1;
+    endy = starty + scal_height - 1;
+  }
 
-  kernel = subsample[index2][index1];
-
-  if ((mask == last_brush) && kernel_brushes[index2][index1])
-    return kernel_brushes[index2][index1];
-  else if (mask != last_brush)
-    for (i = 0; i < 4; i++)
-      for (j = 0; j < 4; j++)
-	{
-	  if (kernel_brushes[i][j])
-	    canvas_delete (kernel_brushes[i][j]);
-	  kernel_brushes[i][j] = NULL;
-	}
-
-  last_brush = mask;
-  kernel_brushes[index2][index1] = canvas_new (canvas_tag (mask),
-                                               canvas_width (mask) + 2,
-                                               canvas_height (mask) + 2,
-                                               canvas_storage (mask));
-  dest = kernel_brushes[index2][index1];
+  dest = canvas_new (canvas_tag (mask), orig_w + 1, orig_h + 1,
+                     canvas_storage (mask));
 
   /* temp hack */
   canvas_portion_refro (mask, 0, 0);
   canvas_portion_refrw (dest, 0, 0);
 
-  for (i = 0; i < canvas_height (mask); i++)
+  for (y = starty; y <= endy; y++)
     {
-      for (j = 0; j < canvas_width (mask); j++)
+      for (x = startx; x <= endx; x++)
 	{
-          m = canvas_portion_data (mask, j, i);
-	  k = kernel;
-	  for (r = 0; r < KERNEL_HEIGHT; r++)
-	    {
-	      d = canvas_portion_data (dest, j, i+r);
-	      s = KERNEL_WIDTH;
-	      while (s--)
-		{
-		  new_val = *d + ((*m * *k++) >> 8);
-		  *d++ = (new_val > 255) ? 255 : new_val;
-		}
-	    }
+          float old_val;
+          m = (guint16*) canvas_portion_data (mask, x, y);
+	  new_val = FLT( *m, u);
+
+          // work on a square of 2x2; upper left to lower down
+          // gamma?
+          d = (guint16*) canvas_portion_data (dest, x, y);
+	  old_val = FLT( *d, u);
+	  *d = FLT16( old_val + new_val * (1-jump_x) * (1-jump_y), u );
+
+          d = (guint16*) canvas_portion_data (dest, x + 1, y);
+	  old_val = FLT( *d, u);
+	  *d = FLT16( old_val + new_val * (jump_x) * (1-jump_y), u );
+
+	  d = (guint16*) canvas_portion_data (dest, x, y + 1);
+       	  old_val = FLT( *d, u);
+	  *d = FLT16( old_val + new_val * (1-jump_x) * (jump_y), u );
+
+          d = (guint16*) canvas_portion_data (dest, x + 1, y + 1);
+	  old_val = FLT( *d, u);
+	  *d = FLT16( old_val + new_val * jump_x * jump_y, u );
 	}
     }
 
@@ -1641,7 +1659,6 @@ brush_mask_subsample  (
 
   return dest;
 }
-#endif
 
 typedef void  (*BrushMaskNoiseFunc) (PaintCore16 *,Canvas*,Canvas*);
 static BrushMaskNoiseFunc brush_mask_noise_funcs[] =
@@ -1661,17 +1678,10 @@ brush_mask_noise  (
   Canvas * noise_brush = NULL;
   Precision prec = tag_precision (canvas_tag (brush_mask));  
 
-#ifdef BRUSH_WITH_BORDER  
-  noise_brush = canvas_new (canvas_tag (brush_mask),
-                            canvas_width (brush_mask) + 2,
-                            canvas_height (brush_mask) + 2,
-                            canvas_storage (brush_mask));
-#else 
   noise_brush = canvas_new (canvas_tag (brush_mask),
                             canvas_width (brush_mask),
                             canvas_height (brush_mask),
                             canvas_storage (brush_mask));
-#endif
   canvas_portion_refro (brush_mask, 0, 0);
   canvas_portion_refrw (noise_brush, 0, 0);
   
@@ -1692,26 +1702,16 @@ static void brush_mask_noise_u8 (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  guint8* data = (guint8*)canvas_portion_data (noise_brush, 0, 1);
-#else
   guint8* data = (guint8*)canvas_portion_data (noise_brush, 0, 0);
-#endif
   guint8* src = (guint8*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 255 : 0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -1723,26 +1723,16 @@ static void brush_mask_noise_u16 (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  guint16* data = (guint16*)canvas_portion_data (noise_brush, 0, 1);
-#else
   guint16* data = (guint16*)canvas_portion_data (noise_brush, 0, 0);
-#endif
   guint16* src = (guint16*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 65535 : 0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -1753,26 +1743,16 @@ static void brush_mask_noise_float (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  gfloat* data =(gfloat*)canvas_portion_data (noise_brush, 0, 1);
-#else
   gfloat* data =(gfloat*)canvas_portion_data (noise_brush, 0, 0);
-#endif
   gfloat* src = (gfloat*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 1.0 : 0.0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -1801,11 +1781,7 @@ static void brush_mask_noise_float16 (
   gfloat out;
   gfloat c,s,theta,xnew,ynew;
  
-#ifdef BRUSH_WITH_BORDER
-  guint16* data =(guint16*)canvas_portion_data (noise_brush, 0, 1);
-#else
   guint16* data =(guint16*)canvas_portion_data (noise_brush, 0, 0);
-#endif
   guint16* src = (guint16*)canvas_portion_data (brush_mask, 0, 0);
 
   gimp_brush_get_noise_info (&info);
@@ -1838,9 +1814,6 @@ static void brush_mask_noise_float16 (
     {
       y = (i/256.0)  * f + yoff;
 
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < w; j++)
 	{
 	  x = (j/256.0) * f + xoff;
@@ -1862,9 +1835,6 @@ static void brush_mask_noise_float16 (
 
 	  *data++ = FLT16(out *src_val , u);
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -1898,9 +1868,6 @@ canvas_16_to_8 (
 
       for (i = 0; i < canvas_height (c); i++)
         {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
             for (j = 0; j < canvas_width (c); j++)
             {
 	      src_val = FLT(*src, u);
@@ -1909,9 +1876,6 @@ canvas_16_to_8 (
               src++;
               data++;
             }
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
         }
     }
 
@@ -1950,9 +1914,6 @@ canvas_16_to_16 (
 
       for (i = 0; i < canvas_height (c); i++)
         {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
             for (j = 0; j < canvas_width (c); j++)
             {
 	      src_val = FLT(*src, u);
@@ -1961,9 +1922,6 @@ canvas_16_to_16 (
               src++;
               data++;
             }
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
         }
     }
 
@@ -2002,9 +1960,6 @@ canvas_16_to_float (
 
       for (i = 0; i < canvas_height (c); i++)
         {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
             for (j = 0; j < canvas_width (c); j++)
             {
 	      src_val = FLT(*src, u);
@@ -2013,9 +1968,6 @@ canvas_16_to_float (
               src++;
               data++;
             }
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
         }
     }
 
@@ -2063,9 +2015,6 @@ canvas_16_to_bfp (
 
       for (i = 0; i < canvas_height (c); i++)
         {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
             for (j = 0; j < canvas_width (c); j++)
             {
 	      src_val = FLT(*src, u);
@@ -2074,9 +2023,6 @@ canvas_16_to_bfp (
               src++;
               data++;
             }
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
         }
     }
 
@@ -2095,17 +2041,10 @@ brush_mask_solidify  (
   Canvas * solid_brush = NULL;
   Precision prec = tag_precision (canvas_tag (brush_mask));  
 
-#ifdef BRUSH_WITH_BORDER  
-  solid_brush = canvas_new (canvas_tag (brush_mask),
-                            canvas_width (brush_mask) + 2,
-                            canvas_height (brush_mask) + 2,
-                            canvas_storage (brush_mask));
-#else 
   solid_brush = canvas_new (canvas_tag (brush_mask),
                             canvas_width (brush_mask) ,
                             canvas_height (brush_mask) ,
                             canvas_storage (brush_mask));
-#endif
   canvas_portion_refro (brush_mask, 0, 0);
   canvas_portion_refrw (solid_brush, 0, 0);
   
@@ -2126,26 +2065,16 @@ static void brush_solidify_mask_u8 (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  guint8* data = (guint8*)canvas_portion_data (solid_brush, 0, 1);
-#else
   guint8* data = (guint8*)canvas_portion_data (solid_brush, 0, 0);
-#endif
   guint8* src = (guint8*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 255 : 0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -2156,26 +2085,16 @@ static void brush_solidify_mask_u16 (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  guint16* data = (guint16*)canvas_portion_data (solid_brush, 0, 1);
-#else
   guint16* data = (guint16*)canvas_portion_data (solid_brush, 0, 0);
-#endif
   guint16* src = (guint16*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 65535 : 0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -2185,26 +2104,16 @@ static void brush_solidify_mask_float (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  gfloat* data =(gfloat*)canvas_portion_data (solid_brush, 0, 1);
-#else
   gfloat* data =(gfloat*)canvas_portion_data (solid_brush, 0, 0);
-#endif
   gfloat* src = (gfloat*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? 1.0 : 0.0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -2215,26 +2124,16 @@ static void brush_solidify_mask_float16 (
 {  
   /* get the data and advance one line into it  */
   ShortsFloat u;
-#ifdef BRUSH_WITH_BORDER
-  guint16* data =(guint16*)canvas_portion_data (solid_brush, 0, 1);
-#else
   guint16* data =(guint16*)canvas_portion_data (solid_brush, 0, 0);
-#endif
   guint16* src = (guint16*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? FLT16 (1.0, u) : FLT16 (0.0, u);
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -2244,26 +2143,16 @@ static void brush_solidify_mask_bfp (
 		      )
 {  
   /* get the data and advance one line into it  */
-#ifdef BRUSH_WITH_BORDER
-  guint16* data = (guint16*)canvas_portion_data (solid_brush, 0, 1);
-#else
   guint16* data = (guint16*)canvas_portion_data (solid_brush, 0, 0);
-#endif
   guint16* src = (guint16*)canvas_portion_data (brush_mask, 0, 0);
   gint i, j;
 
   for (i = 0; i < canvas_height (brush_mask); i++)
     {
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
       for (j = 0; j < canvas_width (brush_mask); j++)
 	{
 	  *data++ = (*src++) ? ONE_BFP : 0;
 	}
-#ifdef BRUSH_WITH_BORDER
-      data++;
-#endif
     }
 }
 
@@ -2271,10 +2160,13 @@ static void
 paint_core_calculate_brush_size (Canvas *mask,
 				 gdouble  scale,
 				 gint    *width,
-				 gint    *height)
+				 gint    *height,
+                                 gdouble *ratio)
 {
   scale = CLAMP (scale, 0.0, 1.0);
 
+  *ratio = 1.0;
+
   if (current_device == GDK_CORE_POINTER)
     {
       *width  = canvas_width(mask);
@@ -2282,50 +2174,73 @@ paint_core_calculate_brush_size (Canvas *mask,
     }
   else
     {
-      gdouble ratio;
-
       if (scale < 1 / 256)
-	ratio = 1 / 16;
+	*ratio = 1 / 16;
       else
-	ratio = sqrt (scale);
-      
-      *width  = MAX ((gint)(canvas_width(mask) * ratio + 0.5), 1);
-      *height = MAX ((gint)(canvas_height(mask) * ratio + 0.5), 1);
+	*ratio = PRESSURE_MODIFY (scale);
+      // TODO 1.0??
+      *width  = MAX ((gint)(canvas_width(mask) * *ratio + .5), 1);
+      *height = MAX ((gint)(canvas_height(mask) * *ratio + .5), 1);
     }
 }  
 
 static Canvas *
-paint_core_scale_mask (Canvas *brush_mask, 
+paint_core_scale_mask (Canvas  *brush_mask, 
+                       gdouble  orig_x,
+                       gdouble  orig_y,
 		       gdouble  scale)
 {
   static Canvas *last_brush  = NULL;
-  static gint     last_width  = 0.0; 
-  static gint     last_height = 0.0; 
+  static gdouble last_jump_x = 0.0,
+                 last_jump_y = 0.0;
+  static gdouble last_scale  = 0.0;
   gint dest_width;
   gint dest_height;
   PixelArea srcPR, destPR;
+  PixelRow  srow, drow;
+  gdouble   ratio;
+  double    ip;
+  // How much is our cursor position off to the drawing pixel?
+  double    jump_x = modf( orig_x, &ip ),
+            jump_y = modf( orig_y, &ip );
+  guint16 * s = NULL,
+          * d = NULL;
+  float   * buf = NULL;
 
   scale = CLAMP (scale, 0.0, 1.0);
 
-  if (scale == 0.0) 
+  if (scale == 0.0)
     return NULL;
 
   if (scale == 1.0)
     return brush_mask;
 
-  paint_core_calculate_brush_size (brush_mask, scale, 
-				   &dest_width, &dest_height);
+  if(jump_x < 0)
+    jump_x = 1.0 + jump_x;
+  if(jump_y < 0)
+    jump_y = 1.0 + jump_y;
 
-  if (brush_mask == last_brush && !cache_invalid &&
-      dest_width == last_width && dest_height == last_height)
+  paint_core_calculate_brush_size (brush_mask, scale, 
+				   &dest_width, &dest_height,
+                                   &ratio);
+
+  // we need some place to scale and position
+  dest_width  ++;
+  dest_height ++;
+
+  if (brush_mask == last_brush &&
+      jump_x == last_jump_x &&
+      jump_y == last_jump_y &&
+      scale == last_scale)
     return scale_brush;
 
   if (scale_brush)
     canvas_delete (scale_brush);
 
   last_brush  = brush_mask;
-  last_width  = dest_width;
-  last_height = dest_height;
+  last_jump_x = jump_x;
+  last_jump_y = jump_y;
+  last_scale  = scale;
 
   pixelarea_init (&srcPR, brush_mask,
                   0, 0,
@@ -2335,15 +2250,183 @@ paint_core_scale_mask (Canvas *brush_mask,
   /* For varirous strange reasons, the scaled brush must stay the same size */
   /* I believe it has to do with gimage_apply_painthit making assumptions on the size of the painthit */
   scale_brush = canvas_new (canvas_tag (brush_mask),
-                            canvas_width(brush_mask),
-                            canvas_height(brush_mask),
+                            canvas_width(brush_mask) + 1,
+                            canvas_height(brush_mask) + 1,
                             canvas_storage (brush_mask));
   pixelarea_init (&destPR, scale_brush,
-                  (canvas_width(brush_mask)-dest_width)/2, (canvas_height(brush_mask)-dest_height)/2,
+                  (canvas_width(brush_mask)-dest_width/*-1*/)/2,
+                  (canvas_height(brush_mask)-dest_height/*-1*/)/2,
                   dest_width, dest_height,
                   TRUE);
-  scale_area (&srcPR, &destPR);
-  cache_invalid = TRUE;
+
+  canvas_portion_refro (brush_mask, 0, 0);
+  canvas_portion_refrw (scale_brush, 0, 0);
+#if 0
+  scale_area_exact (&srcPR, &destPR, jump_x, jump_y, 1./ratio, 1./ratio);
+#else
+
+  // Get the data
+  // a brush should allways be one channel
+  buf = (float*) g_malloc( sizeof(float) * canvas_width(scale_brush) );
+  memset ( buf, 0, sizeof(float) * canvas_width(scale_brush) );
+
+  /* Die folgenden Berechungen versuchen sowohl Positionierung als auch 
+   * Skalierung auf die Zielkoordinaten zu projizieren.
+   * Damit sind alle Angaben, ausser sx und sy, auf die scale_brush Koordinaten
+   * dx und dy bezogen. 
+   */
+  {
+    // the source brush pixel
+    int sx,sy,
+    // the scaled brush pixel in reference coordinates
+        dx = 0,
+        dy = 0;
+    int swidth   = canvas_width( brush_mask),
+        sheight  = canvas_height(brush_mask);
+    int r, n_x;
+    // position the old brush_mask in the middle of our scale_brush target
+    float edge_x = (swidth - ratio * swidth) / 2.,
+          edge_y = (sheight - ratio * sheight) / 2.;
+    double sx_start, sy_start;
+    double sx_ende,  sy_ende;
+    double x_anteil, y_anteil;
+    int rounds = 0;
+
+    // take the cursor position into account
+    jump_x += edge_x;
+    jump_y += edge_y;
+
+    if( canvas_storage(brush_mask) != STORAGE_FLAT)
+      g_warning("%s:%d %s() Can not handle non flat brush_masks.",__FILE__,__LINE__,__func__);
+    for( sy = 0; sy < sheight; ++sy)
+    {
+      // Wieviel Runden muss sy abgelesen werden?
+      rounds = 1;
+
+      // Der Quellpunkt startet hier ...
+      sy_start    =   jump_y +  sy      * ratio;
+      // ... Ende
+      sy_ende     =   sy_start + ratio;
+      y_anteil   =   ratio;
+
+      dy = (int)sy_start;
+
+      // Reicht der Quellpunkt ueber das Zielquadrat?
+      if(sy_ende > dy + 1)
+        rounds = 2;
+
+      if(sy_start < 0.0 || sy_ende > canvas_height(scale_brush))
+        printf("i%s:%d %s() %fx%f == %d?\n",__FILE__,__LINE__,__func__, sy_start, sy_ende, canvas_height(scale_brush));
+
+      for( r = 0; r < rounds; ++r)
+      {
+        if(r == 0)
+        {
+          // the upper part
+
+          // wohin
+          dy = (int)sy_start;
+
+          y_anteil = ratio;
+          // take the source pixel part up to the projection pixel border
+          if(sy_ende > dy + 1)
+            y_anteil = (dy + 1) - sy_start;
+
+        } else {
+          // the lower part
+
+          // wohin
+          dy = (int)sy_ende;
+
+          // the remaining part of the splittet source pixel
+          y_anteil = sy_ende - dy;
+        }
+
+        for (sx = 0; sx < swidth; ++sx)
+        {
+          ShortsFloat u;
+          guint16 * s = NULL;
+
+          // Der Quellpunkt startet hier ...
+          sx_start   =   jump_x +  sx * ratio;
+          // ... Ende
+          sx_ende    =   sx_start + ratio;
+          x_anteil   =   ratio;
+
+          // wohin
+          dx = (int)sx_start;
+
+          if(sx_start < 0.0 || sx_ende > canvas_width(scale_brush) || dx < 0)
+            printf("i%s:%d %s() %fx%f == %d?\n",__FILE__,__LINE__,__func__, sx_start, sx_ende, canvas_width(scale_brush));
+
+          // unser Quellpunkt
+          s = (guint16*) canvas_portion_data (brush_mask, sx, sy);
+
+          // Reicht der Quellpunkt ueber das Zielquadrat?
+          if(sx_ende > dx + 1)
+          {
+            // 2. Anteil ..
+            x_anteil = sx_ende - (dx + 1);
+            //    .. auf Ziel aufschlagen
+            buf[ dx + 1 ] += FLT(*s,u) * x_anteil * y_anteil;
+
+            // 1. Anteil berechnen
+            x_anteil = (dx + 1) - sx_start;
+          }
+
+          // 1. Anteil auf Ziel aufschlagen
+          buf[ dx ] += FLT(*s,u) * x_anteil * y_anteil;
+        }
+
+        // naechste Zeile? dann schon eintragen
+        if ( sy_ende >= dy + 1 )
+        {
+          n_x = dx;
+          if ( dx < (int)sx_ende )
+            ++n_x;
+          for (dx = 0; dx <= n_x; ++dx)
+          {
+            guint16 *d = (guint16*) canvas_portion_data (scale_brush, dx, dy);
+#ifdef DEBUG
+            if(dx >= canvas_width(scale_brush) || dy >= canvas_height(scale_brush)) {
+            printf("i%s:%d %s() %dx%d ? %dx%d\n",__FILE__,__LINE__,__func__, canvas_width(scale_brush), canvas_height(scale_brush), dx,dy);
+            printf("%fx%f %fx%f %fx%f\n",sx_start, sy_start,
+            sx_ende,  sy_ende,
+            x_anteil, y_anteil);
+            }
+#endif
+            *d = FLT16( buf[dx],u);
+            buf[dx] = 0.0;
+          }
+        }
+      }
+    }
+
+    // .. und den Rest einkehren
+    n_x = dx;
+    if ( dx < (int)sx_ende )
+      ++n_x;
+    for (dx = 0; dx <= n_x; ++dx)
+    {
+          guint16 *d = (guint16*) canvas_portion_data (scale_brush, dx, dy);
+#ifdef DEBUG
+          if(dx >= canvas_width(scale_brush) || dy >= canvas_height(scale_brush)) {
+            printf("i%s:%d %s() %dx%d ? %dx%d\n",__FILE__,__LINE__,__func__, canvas_width(scale_brush), canvas_height(scale_brush), dx,dy);
+            printf("%fx%f %fx%f %fx%f\n",sx_start, sy_start,
+            sx_ende,  sy_ende,
+            x_anteil, y_anteil);
+          }
+#endif
+          *d = FLT16( buf[dx],u);
+          buf[dx] = 0.0;
+    }
+  }
+
+  canvas_portion_unref (scale_brush, 0, 0);
+  canvas_portion_unref (brush_mask, 0, 0);
+  g_free( buf );
+  buf = NULL;
+#endif
 
   return scale_brush;
 }
