@@ -32,8 +32,8 @@
 #define HALF_OPAQUE_FLOAT    .5
 #define TRANSPARENT_FLOAT    0.0
 
-#define OPAQUE_FLOAT16       16256
-#define HALF_OPAQUE_FLOAT16  16128 
+#define OPAQUE_FLOAT16       ONE_FLOAT16
+#define HALF_OPAQUE_FLOAT16  HALF_FLOAT16 
 #define TRANSPARENT_FLOAT16  0
 
 static guint16 no_mask = OPAQUE_FLOAT16;
