@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../drawable.h"
@@ -461,7 +462,7 @@ tools_new_posterize ()
 
   /*  The tool options  */
   if (!posterize_options)
-    posterize_options = tools_register_no_options (POSTERIZE, "Posterize Options");
+    posterize_options = tools_register_no_options (POSTERIZE, _("Posterize Options"));
 
   /*  The posterize dialog  */
   if (!posterize_dialog)
@@ -514,7 +515,7 @@ posterize_initialize (void *gdisp_ptr)
 
   if (drawable_indexed (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Posterize does not operate on indexed drawables.");
+      g_message (_("Posterize does not operate on indexed drawables."));
       return;
     }
 
@@ -558,7 +559,7 @@ posterize_new_dialog ()
   /*  The shell and main vbox  */
   pd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (pd->shell), "posterize", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (pd->shell), "Posterize");
+  gtk_window_set_title (GTK_WINDOW (pd->shell), _("Posterize"));
   minimize_register(pd->shell);
 
   gtk_signal_connect (GTK_OBJECT (pd->shell), "delete_event",
@@ -573,7 +574,7 @@ posterize_new_dialog ()
   hbox = gtk_hbox_new (TRUE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Posterize Levels: ");
+  label = gtk_label_new (_("Posterize Levels: "));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
@@ -594,7 +595,7 @@ posterize_new_dialog ()
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), pd->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -606,6 +607,10 @@ posterize_new_dialog ()
   gtk_widget_show (hbox);
 
   /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = pd;
   action_items[1].user_data = pd;
   build_action_area (GTK_DIALOG (pd->shell), action_items, 2, 0);
@@ -621,7 +626,7 @@ posterize_preview (PosterizeDialog *pd)
 {
   if (!pd->image_map)
   {
-    g_message ("posterize_preview(): No image map");
+    g_message (_("posterize_preview(): No image map"));
   }
   else
   {
