@@ -47,6 +47,7 @@
 #include "../tools.h"
 #include "../undo.h"
 #include "float16.h"
+#include "compat.h"
 
 #define FONT_LIST_WIDTH  125
 #define FONT_LIST_HEIGHT 200
@@ -398,9 +399,9 @@ text_resize_text_widget (TextTool *text_tool)
    GtkStyle *style;
 
    style = gtk_style_new ();
-   gdk_font_unref (style->font);
-   style->font = text_tool->font;
-   gdk_font_ref (style->font);
+   gdk_font_unref (gtk_style_get_font(style));
+   gtk_style_set_font (style, text_tool->font);
+   gdk_font_ref (gtk_style_get_font(style));
 
    gtk_widget_set_style (text_tool->the_text, style);
 }
@@ -604,9 +605,9 @@ text_create_dialog (TextTool *text_tool)
       gtk_option_menu_set_menu (GTK_OPTION_MENU (text_tool->option_menus[i]), text_tool->menus[i]);
     }
 
-#if 0
+#if GTK_MAJOR_VERSION > 1
   /* Create the border text hbox, border text, and label  */
-  border_label = gtk_label_new ("Border");
+  border_label = gtk_label_new (_("Border"));
   gtk_misc_set_alignment (GTK_MISC (border_label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (menu_table), border_label, 0, 1, i, i + 1,
           GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 1);
@@ -1579,7 +1580,7 @@ text_load_font (TextTool *text_tool)
   GdkFont *font;
   char fontname[2048];
   double size;
-  char *size_text;
+  const char *size_text;
   char *foundry_str;
   char *family_str;
   char *weight_str;
@@ -1620,11 +1621,20 @@ text_load_font (TextTool *text_tool)
            registry_str, encoding_str, fontname))
     {
       /* Trap errors with bad fonts -Yosh */
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_push();
+#else
       gdk_error_warnings = 0;
       gdk_error_code = 0;
+#endif
       font = gdk_font_load (fontname);
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_pop();
+#else
       gdk_error_warnings = 1;
+#endif
 
+#if GTK_MAJOR_VERSION < 2
       if (gdk_error_code == -1)
    {
      g_message ("I'm sorry, but the font %s is corrupt.\n"
@@ -1632,6 +1642,7 @@ text_load_font (TextTool *text_tool)
                      family_str);
      return FALSE;
    }
+#endif
 
       if (font)
    {
@@ -2027,11 +2038,23 @@ text_render (GImage *gimage,
   if (!crop) border = 0;
 
   /* load the font in */
-   gdk_error_warnings = 0;
-   gdk_error_code = 0;
-   font = gdk_font_load (fontname);
-   gdk_error_warnings = 1;
-   if (!font || (gdk_error_code == -1))
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_push();
+#else
+      gdk_error_warnings = 0;
+      gdk_error_code = 0;
+#endif
+      font = gdk_font_load (fontname);
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_pop();
+#else
+      gdk_error_warnings = 1;
+#endif
+   if (!font 
+#if GTK_MAJOR_VERSION < 2
+     || (gdk_error_code == -1)
+#endif
+     )
       return NULL;
 
    /* determine the bounding box of the text */
@@ -2272,11 +2295,24 @@ text_get_extents (char *fontname,
   int line_width, line_height;
 
   /* load the font in */
-  gdk_error_warnings = 0;
-  gdk_error_code = 0;
-  font = gdk_font_load (fontname);
-  gdk_error_warnings = 1;
-  if (!font || (gdk_error_code == -1))
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_push();
+#else
+      gdk_error_warnings = 0;
+      gdk_error_code = 0;
+#endif
+      font = gdk_font_load (fontname);
+#if GTK_MAJOR_VERSION > 1
+      gdk_error_trap_pop();
+#else
+      gdk_error_warnings = 1;
+#endif
+
+  if (!font 
+#if GTK_MAJOR_VERSION < 2
+     || (gdk_error_code == -1)
+#endif
+     )
     return FALSE;
 
   /* determine the bounding box of the text */
