@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../actionarea.h"
 #include "../drawable.h"
@@ -1196,7 +1197,7 @@ threshold_new_dialog (Tag tag)
   /*  The shell and main vbox  */
   td->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (td->shell), "threshold", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (td->shell), "Threshold");
+  gtk_window_set_title (GTK_WINDOW (td->shell), _("Threshold"));
   minimize_register(td->shell);
 
   /* handle the wm close signal */
@@ -1212,7 +1213,7 @@ threshold_new_dialog (Tag tag)
   hbox = gtk_hbox_new (TRUE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Threshold Range: ");
+  label = gtk_label_new (_("Threshold Range: "));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -1294,7 +1295,7 @@ threshold_new_dialog (Tag tag)
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   /*  The preview toggle  */
-  toggle = gtk_check_button_new_with_label ("Preview");
+  toggle = gtk_check_button_new_with_label (_("Preview"));
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (toggle), td->preview);
   gtk_box_pack_start (GTK_BOX (hbox), toggle, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
@@ -1306,6 +1307,10 @@ threshold_new_dialog (Tag tag)
   gtk_widget_show (hbox);
 
   /*  The action area  */
+  { int i;
+    for(i = 0; i < 2; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
   action_items[0].user_data = td;
   action_items[1].user_data = td;
   build_action_area (GTK_DIALOG (td->shell), action_items, 2, 0);
@@ -1347,7 +1352,7 @@ static void
 threshold_preview (ThresholdDialog *td)
 {
   if (!td->image_map)
-    g_message ("threshold_preview(): No image map");
+    g_message (_("threshold_preview(): No image map"));
   image_map_apply (td->image_map, threshold, (void *) td);
 }
 
