@@ -18,6 +18,7 @@
 #include <stdlib.h>
 #include <math.h>
 
+#include "libgimp/gimpintl.h"
 #include "../appenv.h"
 #include "../canvas.h"
 #include "../drawable.h"
@@ -148,7 +149,7 @@ transform_core_button_press (tool, bevent, gdisp_ptr)
 	  {
 	    if (layer->mask != NULL && GIMP_DRAWABLE(layer->mask))
 	      {
-		g_message ("Transformations do not work on\nlayers that contain layer masks.");
+		g_message (_("Transformations do not work on\nlayers that contain layer masks."));
 		tool->state = INACTIVE;
 		return;
 	      }
@@ -2057,7 +2058,7 @@ transform_core_paste (gimage, drawable, tiles, new_layer)
 
   if (new_layer)
     {
-      layer = layer_from_tiles (gimage, drawable, tiles, "Transformation", OPAQUE_OPACITY, NORMAL_MODE);
+      layer = layer_from_tiles (gimage, drawable, tiles, _("Transformation"), OPAQUE_OPACITY, NORMAL_MODE);
       GIMP_DRAWABLE(layer)->offset_x = canvas_fixme_getx (tiles);
       GIMP_DRAWABLE(layer)->offset_y = canvas_fixme_gety (tiles);
 
