@@ -18,6 +18,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include "libgimp/gimpintl.h"
 #include "../canvas.h"
 #include "../floating_sel.h"
 #include "../gimage.h"
@@ -356,7 +357,11 @@ xcf_load_invoker (Argument *args)
 	{
 	  if (info.file_version < N_xcf_loaders)
 	    {
-	      gimage = (*(xcf_loaders[info.file_version])) (&info);
+#         ifdef DEBUG
+          printf("%s:%d %s() fileversion: %d\n",__FILE__,__LINE__,__func__, info.file_version);
+#         endif
+	      gimage = 0; /*(*(xcf_loaders[info.file_version])) (&info);*/
+              g_message(_("This XCF file is not supported by CinePaint. You may convert to tiff and try again."));
 	      if (!gimage)
 		success = FALSE;
 	    }
@@ -368,7 +373,7 @@ xcf_load_invoker (Argument *args)
 	     } 
 	  else
 	    {
-	      g_message ("XCF error: unsupported XCF file version %d encountered", info.file_version);
+	      g_message (_("XCF error: unsupported XCF file version %d encountered"), info.file_version);
 	      success = FALSE;
 	    }
 	}
@@ -418,7 +423,7 @@ xcf_save_invoker (Argument *args)
     }
   else
     {
-      g_message ("open failed on %s: %s\n", filename, g_strerror(errno));
+      g_message (_("open failed on %s: %s\n"), filename, g_strerror(errno));
     }
 
   return_args = procedural_db_return_args (&xcf_plug_in_save_proc.db_info, success);
@@ -1370,9 +1375,9 @@ xcf_load_image_props (XcfInfo *info,
 	  if (info->file_version == 0) 
 	    {
 	      int i;
-	      g_message ("XCF warning: version 0 of XCF file format\n"
+	      g_message (_("XCF warning: version 0 of XCF file format\n"
 			 "did not save indexed colormaps correctly.\n"
-			 "Substituting grayscale map.");
+			 "Substituting grayscale map."));
 	      info->cp += xcf_read_int32 (info->fp, (guint32*) &gimage->num_cols, 1);
 	      gimage->cmap = g_new (guchar, gimage->num_cols*3);
 	      xcf_seek_pos (info, info->cp + gimage->num_cols);
@@ -1401,7 +1406,7 @@ xcf_load_image_props (XcfInfo *info,
 		(compression != COMPRESS_ZLIB) &&
 		(compression != COMPRESS_FRACTAL))
 	      {
-		g_message ("unknown compression type: %d", (int) compression);
+		g_message (_("unknown compression type: %d"), (int) compression);
 		return FALSE;
 	      }
 
@@ -1432,7 +1437,7 @@ xcf_load_image_props (XcfInfo *info,
 	  }
 	  break;
 	default:
-	  g_message ("unexpected/unknown image property: %d (skipping)", prop_type);
+	  g_message (_("unexpected/unknown image property: %d (skipping)"), prop_type);
 
 	  {
 	    guint8 buf[16];
@@ -1515,7 +1520,7 @@ xcf_load_layer_props (XcfInfo *info,
 	    }
 	  else
 	    {
-	      g_message("there is already a spline being init'd.");
+	      g_message(_("there is already a spline being init'd."));
 	    }
 	  break;
 	case PROP_SPLINES_CONTINUITY:
@@ -1572,7 +1577,7 @@ xcf_load_layer_props (XcfInfo *info,
 	  xcf_spline=NULL;
 	  break;
 	default:
-	  g_message ("unexpected/unknown layer property: %d (skipping)", prop_type);
+	  g_message (_("unexpected/unknown layer property: %d (skipping)"), prop_type);
 	  {
 	    guint8 buf[16];
 	    guint amount;
@@ -1638,7 +1643,7 @@ xcf_load_channel_props (XcfInfo *info,
 
 	  break;
 	default:
-	  g_message ("unexpected/unknown channel property: %d (skipping)", prop_type);
+	  g_message (_("unexpected/unknown channel property: %d (skipping)"), prop_type);
 	  {
 	    guint8 buf[16];
 	    guint amount;
@@ -2023,7 +2028,7 @@ xcf_swap_func (int       fd,
 
 	  if (err <= 0)
 	    {
-	      g_message ("unable to read tile data from xcf file: %d ( %d ) bytes read", err, nleft);
+	      g_message (_("unable to read tile data from xcf file: %d ( %d ) bytes read"), err, nleft);
 	      return FALSE;
 	    }
 
