@@ -21,6 +21,7 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gtk/gtk.h>
 
 #include <stdio.h>
 #include "appenv.h"
@@ -37,7 +38,11 @@
 typedef struct DeviceInfo DeviceInfo;
 
 struct DeviceInfo {
+#if GTK_MAJOR_VERSION > 1
+  GdkDevice *device;		/* a Gdk device */
+#else
   guint32 device;		/* device ID */
+#endif
   gchar *name;
   
   short is_init;		/* has the user used it? */
@@ -60,8 +65,13 @@ typedef struct DeviceInfoDialog DeviceInfoDialog;
 
 struct DeviceInfoDialog {
   int num_devices;
+#if GTK_MAJOR_VERSION > 1
+  GdkDevice *current;		/* Gdk device */
+  GdkDevice **ids;
+#else
   guint32 current;
   guint32 *ids;
+#endif
 
   GtkWidget *shell;
   GtkWidget *table;
@@ -83,8 +93,13 @@ int suppress_update = FALSE;
 
 /* Local functions */
 static void input_dialog_destroy_callback (GtkWidget *, gpointer);
-void input_dialog_able_callback (GtkWidget *w, guint32 deviceid, 
-				 gpointer data);
+void input_dialog_able_callback (GtkWidget *w, 
+#if GTK_MAJOR_VERSION > 1
+               GdkDevice*
+#else
+               guint32
+#endif
+                                          deviceid, gpointer data);
 static void devices_save_current_info (void);
 static void devices_write_rc_device (DeviceInfo *device_info, FILE *fp);
 static void devices_write_rc (void);
@@ -93,7 +108,11 @@ static void devices_close_callback (GtkWidget *, gpointer);
 static void device_status_update_current ();
 
 /* Global data */
+#if GTK_MAJOR_VERSION > 1
+GdkDevice *current_device = NULL;
+#else
 int current_device = GDK_CORE_POINTER;
+#endif
 
 /*  the action area structure  */
 static ActionAreaItem action_items[] =
@@ -139,7 +158,13 @@ create_input_dialog (void)
 }
 
 void
-input_dialog_able_callback (GtkWidget *w, guint32 deviceid, gpointer data)
+input_dialog_able_callback (GtkWidget *w, 
+#if GTK_MAJOR_VERSION > 1
+               GdkDevice*
+#else
+               guint32
+#endif
+                                          deviceid, gpointer data)
 {
   device_status_update (deviceid);
 }
@@ -160,21 +185,41 @@ devices_init (void)
 
   /* Create device info structures for present devices */
 
+#if GTK_MAJOR_VERSION > 1
+  {
+    GdkDisplay *display = 0;
+    tmp_list = gdk_devices_list ();
+    display = gdk_display_get_default();;
+    if(!current_device)
+      current_device = gdk_display_get_core_pointer (display);
+  }
+#else
   tmp_list = gdk_input_list_devices ();
+#endif
   
   while (tmp_list)
     {
-      GdkDeviceInfo *gdk_info = (GdkDeviceInfo *)tmp_list->data;
       DeviceInfo *device_info = g_new (DeviceInfo, 1);
+#if GTK_MAJOR_VERSION > 1
+      GdkDevice *gdk_info = (GdkDevice *)tmp_list->data;
+
+      device_info->device = gdk_info;
+      device_info->name = g_strdup (gdk_info->name);
+
+      device_info->mode = gdk_info->mode;
+      device_info->num_axes = gdk_info->num_axes;
+#else
+      GdkDeviceInfo *gdk_info = (GdkDeviceInfo *)tmp_list->data;
 
       device_info->device = gdk_info->deviceid;
       device_info->name = g_strdup (gdk_info->name);
 
+      device_info->mode = gdk_info->mode;
+      device_info->num_axes = gdk_info->num_axes;
+#endif
       device_info->is_init = FALSE;
       device_info->is_present = TRUE;
 
-      device_info->mode = gdk_info->mode;
-      device_info->num_axes = gdk_info->num_axes;
       device_info->axes = NULL;
       
       device_info->brush = NULL;
@@ -245,7 +290,7 @@ devices_rc_update (gchar *name, DeviceValues values,
 	{
 	  device_info->num_keys = num_keys;
 	  device_info->keys = g_new (GdkDeviceKey, num_keys);
-	  memcpy (device_info->keys, axes, num_keys * sizeof (GdkDeviceKey));
+	  memcpy (device_info->keys, keys, num_keys * sizeof (GdkDeviceKey));
 	}
 
       if (values & DEVICE_MODE)
@@ -263,14 +308,23 @@ devices_rc_update (gchar *name, DeviceValues values,
     }
   else
     {
+#if GTK_MAJOR_VERSION > 1
+      GdkDevice *gdk_info = NULL;	/* Quiet gcc */
+      tmp_list = gdk_devices_list();
+#else
       GdkDeviceInfo *gdk_info = NULL;	/* Quiet gcc */
-
       tmp_list = gdk_input_list_devices();
+#endif
+
       while (tmp_list)
 	{
+#if GTK_MAJOR_VERSION > 1
+	  GdkDevice *info = (GdkDevice *)tmp_list->data;
+	  if (info == device_info->device)
+#else
 	  GdkDeviceInfo *info = (GdkDeviceInfo *)tmp_list->data;
-	  
 	  if (info->deviceid == device_info->device)
+#endif	  
 	    {
 	      gdk_info = info;
 	      break;
@@ -281,18 +335,30 @@ devices_rc_update (gchar *name, DeviceValues values,
       if (gdk_info != NULL)
 	{
 	  if (values & DEVICE_MODE)
+#if GTK_MAJOR_VERSION > 1
+	    gdk_device_set_mode (gdk_info, mode);
+#else
 	    gdk_input_set_mode (gdk_info->deviceid, mode);
-	  
+#endif	  
 	  if ((values & DEVICE_AXES) && num_axes >= gdk_info->num_axes)
+#if GTK_MAJOR_VERSION > 1
+	    /*gdk_device_set_axes (gdk_info, axes)*/;
+#else
 	    gdk_input_set_axes (gdk_info->deviceid, axes);
+#endif
 	  
 	  if ((values & DEVICE_KEYS) && num_keys >= gdk_info->num_keys)
 	    {
 	      int i;
 	      
 	      for (i=0; i<MAX (num_keys, gdk_info->num_keys); i++)
+#if GTK_MAJOR_VERSION > 1
+		gdk_device_set_key (gdk_info, i,
+				   keys[i].keyval, keys[i].modifiers);
+#else
 		gdk_input_set_key (gdk_info->deviceid, i,
 				   keys[i].keyval, keys[i].modifiers);
+#endif
 	    }
 	}
       else
@@ -322,7 +388,13 @@ devices_rc_update (gchar *name, DeviceValues values,
 }
 
 void 
-select_device (guint32 new_device)
+select_device (
+#if GTK_MAJOR_VERSION > 1
+               GdkDevice*
+#else
+               guint32
+#endif
+                       new_device)
 {
   GList *tmp_list;
   DeviceInfo *device_info;
@@ -377,20 +449,56 @@ select_device (guint32 new_device)
 gint
 devices_check_change (GdkEvent *event)
 {
+#if GTK_MAJOR_VERSION > 1
+  GdkDevice *device = NULL;
+  GtkWidget         *source;
+
+  /* It is possible that the event was propagated from a widget that does not
+     want extension events and therefore always sends core pointer events.
+     This can cause a false switch to the core pointer device. */
+
+  source = gtk_get_event_widget (event);
+
+  if (source &&
+      gtk_widget_get_extension_events (source) == GDK_EXTENSION_EVENTS_NONE)
+    return FALSE;
+
+#else
   int device;
+#endif
 
   switch (event->type)
     {
     case GDK_MOTION_NOTIFY:
+#if GTK_MAJOR_VERSION > 1
+      device = ((GdkEventMotion *)event)->device;
+#else
       device = ((GdkEventMotion *)event)->deviceid;
+#endif
       break;
     case GDK_BUTTON_PRESS:
+    case GDK_2BUTTON_PRESS:
+    case GDK_3BUTTON_PRESS:
     case GDK_BUTTON_RELEASE:
+#if GTK_MAJOR_VERSION > 1
+      device = ((GdkEventButton *)event)->device;
+#else
       device = ((GdkEventButton *)event)->deviceid;
+#endif
       break;
+    case GDK_PROXIMITY_IN:
     case GDK_PROXIMITY_OUT:
+#if GTK_MAJOR_VERSION > 1
+      device = ((GdkEventProximity *)event)->device;
+#else
       device = ((GdkEventProximity *)event)->deviceid;
+#endif
       break;
+#if GTK_MAJOR_VERSION > 1
+    case GDK_SCROLL:
+      device = ((GdkEventScroll *) event)->device;
+      break;
+#endif
     default:
       device = current_device;
     }
@@ -414,7 +522,11 @@ devices_save_current_info (void)
   device_info = NULL;
   while (tmp_list)
     {
-      if (CAST(int) ((DeviceInfo *)tmp_list->data)->device == current_device)
+      if (
+#if GTK_MAJOR_VERSION < 2
+          CAST(int)
+#endif
+          ((DeviceInfo *)tmp_list->data)->device == current_device)
 	{
 	  device_info = (DeviceInfo *)tmp_list->data;
 	  break;
@@ -422,6 +534,9 @@ devices_save_current_info (void)
       tmp_list = tmp_list->next;
     }
 
+  if(!device_info)
+    return;
+
   device_info->is_init = TRUE;
   device_info->device = current_device;
   device_info->brush = get_active_brush ();
@@ -447,7 +562,11 @@ devices_save_current_info (void)
 static void
 devices_write_rc_device (DeviceInfo *device_info, FILE *fp)
 {
+#if GTK_MAJOR_VERSION > 1
+  GdkDevice *gdk_info;
+#else
   GdkDeviceInfo *gdk_info;
+#endif
   GList *tmp_list;
   gchar *mode = NULL;		/* Quiet gcc */
   int i;
@@ -457,12 +576,20 @@ devices_write_rc_device (DeviceInfo *device_info, FILE *fp)
     {
       /* gdk_input_list_devices returns an internal list, so we shouldn't
 	 free it afterwards */
-      tmp_list = gdk_input_list_devices();
+#if GTK_MAJOR_VERSION > 1
+  tmp_list = gdk_devices_list ();
+#else
+  tmp_list = gdk_input_list_devices ();
+#endif
       while (tmp_list)
 	{
+#if GTK_MAJOR_VERSION > 1
+	  GdkDevice *info = (GdkDevice *)tmp_list->data;
+	  if (info == device_info->device)
+#else
 	  GdkDeviceInfo *info = (GdkDeviceInfo *)tmp_list->data;
-	  
 	  if (info->deviceid == device_info->device)
+#endif	  
 	    {
 	      gdk_info = info;
 	      break;
@@ -494,7 +621,11 @@ devices_write_rc_device (DeviceInfo *device_info, FILE *fp)
     {
       gchar *axis_type = NULL;	/* Quiet gcc */
       
-      switch (gdk_info ? gdk_info->axes[i] : device_info->axes[i])
+      switch (gdk_info ? gdk_info->axes[i]
+#if GTK_MAJOR_VERSION > 1
+                                           .use
+#endif
+                                                : device_info->axes[i])
 	{
 	case GDK_AXIS_IGNORE:
 	  axis_type = "ignore";
@@ -514,6 +645,14 @@ devices_write_rc_device (DeviceInfo *device_info, FILE *fp)
 	case GDK_AXIS_YTILT:
 	  axis_type = "ytilt";
 	  break;
+#if GTK_MAJOR_VERSION > 1
+	case GDK_AXIS_WHEEL:
+	  axis_type = "wheel";
+	  break;
+#endif
+	default:
+	  axis_type = "---";
+	  break;
 	}
       fprintf(fp, " %s",axis_type);
     }
@@ -622,7 +761,11 @@ create_device_status (void)
       gtk_widget_realize (deviceD->table);
       gtk_widget_show (deviceD->table);
 
+#if GTK_MAJOR_VERSION > 1
+      deviceD->ids = g_new (GdkDevice*, deviceD->num_devices);
+#else
       deviceD->ids = g_new (guint32, deviceD->num_devices);
+#endif
       deviceD->frames = g_new (GtkWidget *, deviceD->num_devices);
       deviceD->tools = g_new (GtkWidget *, deviceD->num_devices);
       deviceD->colors = g_new (GtkWidget *, deviceD->num_devices);
@@ -686,7 +829,11 @@ create_device_status (void)
       action_items[0].user_data = deviceD->shell;
       build_action_area (GTK_DIALOG (deviceD->shell), action_items, 2, 0);
 
+#if GTK_MAJOR_VERSION > 1
+      deviceD->current = gdk_devices_list()->data; /* random, but doesn't matter */
+#else
       deviceD->current = 0xffffffff; /* random, but doesn't matter */
+#endif
       device_status_update_current ();
 
       gtk_widget_show (deviceD->shell);
@@ -736,7 +883,11 @@ device_status_update_current ()
 	  if (deviceD->ids[i] == deviceD->current)
 	    gtk_frame_set_shadow_type (GTK_FRAME(deviceD->frames[i]), 
 				       GTK_SHADOW_OUT);
-	  else if (CAST(int) deviceD->ids[i] == current_device)
+	  else if (
+#if GTK_MAJOR_VERSION < 2
+                   CAST(int)
+#endif
+                             deviceD->ids[i] == current_device)
 	    gtk_frame_set_shadow_type (GTK_FRAME(deviceD->frames[i]), 
 				       GTK_SHADOW_IN);
 	}
@@ -745,17 +896,32 @@ device_status_update_current ()
 }
 
 void 
-device_status_update (guint32 deviceid)
+device_status_update (
+#if GTK_MAJOR_VERSION > 1
+               GdkDevice*
+#else
+               guint32
+#endif
+                                deviceid)
 {
   int i, j;
   guchar buffer[20*3];
   GList *tmp_list;
   DeviceInfo *device_info;
-  GdkDeviceInfo *gdk_info;
+#if GTK_MAJOR_VERSION > 1
+               GdkDevice
+#else
+               GdkDeviceInfo
+#endif
+  *gdk_info;
 
   if (deviceD && !suppress_update)
     {
-      if (CAST(int) deviceid == current_device)
+      if (
+#if GTK_MAJOR_VERSION < 2
+          CAST(int)
+#endif
+                    deviceid == current_device)
 	{
 	  devices_save_current_info();
 	}
@@ -773,12 +939,21 @@ device_status_update (guint32 deviceid)
       
       g_return_if_fail (tmp_list != NULL);
 
+#if GTK_MAJOR_VERSION > 1
+      tmp_list = gdk_devices_list();
+#else
       tmp_list = gdk_input_list_devices();
+#endif
+
       while (tmp_list)
 	{
+#if GTK_MAJOR_VERSION > 1
+	  gdk_info = (GdkDevice *)tmp_list->data;
+	  if (gdk_info == device_info->device)
+#else
 	  gdk_info = (GdkDeviceInfo *)tmp_list->data;
-	  
-	  if (gdk_info->deviceid == deviceid)
+	  if (gdk_info->deviceid == device_info->device)
+#endif	  
 	    break;
 
 	  tmp_list = tmp_list->next;
