@@ -50,8 +50,9 @@
 #define BUSY_ON    2
 #define BUSY_DOWN  3
 
-#ifdef DEBUG
+#ifdef DEBUG_
 #define DISP_DEBUG
+#define DEBUG_DISPLAY 1
 #endif
 
 static guint gdisp_busy = BUSY_OFF;
@@ -88,14 +89,67 @@ redraw (GDisplay *gdisp,
     }
 }
 
+const char*
+cp_event_type_name(GdkEvent *event)
+{
+  const char *t = "---";
+# define CASE_TO_TEXT( num, text ) case num: text = #num; break;
+  switch (event->type)
+  {
+  CASE_TO_TEXT ( GDK_PROXIMITY_OUT, t)
+  CASE_TO_TEXT ( GDK_PROXIMITY_IN, t)
+  CASE_TO_TEXT ( GDK_BUTTON_PRESS, t)
+  CASE_TO_TEXT ( GDK_2BUTTON_PRESS, t)
+  CASE_TO_TEXT ( GDK_3BUTTON_PRESS, t)
+  CASE_TO_TEXT ( GDK_BUTTON_RELEASE, t)
+  CASE_TO_TEXT ( GDK_MOTION_NOTIFY, t)
+  CASE_TO_TEXT ( GDK_NOTHING ,t)
+  CASE_TO_TEXT ( GDK_DELETE ,t)
+  CASE_TO_TEXT ( GDK_DESTROY ,t)
+  CASE_TO_TEXT ( GDK_EXPOSE ,t)
+  CASE_TO_TEXT ( GDK_KEY_RELEASE ,t)
+  CASE_TO_TEXT ( GDK_KEY_PRESS ,t)
+  CASE_TO_TEXT ( GDK_ENTER_NOTIFY ,t)
+  CASE_TO_TEXT ( GDK_LEAVE_NOTIFY ,t)
+  CASE_TO_TEXT ( GDK_FOCUS_CHANGE ,t)
+  CASE_TO_TEXT ( GDK_CONFIGURE ,t)
+  CASE_TO_TEXT ( GDK_MAP ,t)
+  CASE_TO_TEXT ( GDK_UNMAP ,t)
+  CASE_TO_TEXT ( GDK_PROPERTY_NOTIFY ,t)
+  CASE_TO_TEXT ( GDK_SELECTION_CLEAR ,t)
+  CASE_TO_TEXT ( GDK_SELECTION_REQUEST ,t)
+  CASE_TO_TEXT ( GDK_SELECTION_NOTIFY ,t)
+  CASE_TO_TEXT ( GDK_DRAG_ENTER ,t)
+  CASE_TO_TEXT ( GDK_DRAG_LEAVE ,t)
+  CASE_TO_TEXT ( GDK_DRAG_MOTION ,t)
+  CASE_TO_TEXT ( GDK_DRAG_STATUS ,t)
+  CASE_TO_TEXT ( GDK_DROP_START ,t)
+  CASE_TO_TEXT ( GDK_DROP_FINISHED ,t)
+  CASE_TO_TEXT ( GDK_CLIENT_EVENT ,t)
+  CASE_TO_TEXT ( GDK_VISIBILITY_NOTIFY ,t)
+  CASE_TO_TEXT ( GDK_NO_EXPOSE ,t)
+#if GTK_MAJOR_VERSION > 1
+  CASE_TO_TEXT ( GDK_SCROLL ,t)
+  CASE_TO_TEXT ( GDK_WINDOW_STATE ,t)
+  CASE_TO_TEXT ( GDK_SETTING ,t)
+#endif
+#if GTK_MAJOR_VERSION > 1 && GTK_MINOR_VERSION > 6
+  CASE_TO_TEXT ( GDK_OWNER_CHANGE ,t)
+  CASE_TO_TEXT ( GDK_GRAB_BROKEN ,t)
+#endif
+  }
+  return t;
+}
+
 gint
 gdisplay_shell_events (GtkWidget *widget,
                        GdkEvent  *event,
                        GDisplay  *gdisp)
 {
-#if 0
-  printf("%s (\"%s\", displayID=%d)...\n",__func__,
-         gdk_event_type_name(event), gdisplay_to_ID(gdisp));
+#if DEBUG_DISPLAY
+  char *t = cp_event_type_name(event);
+  int id = gdisplay_to_ID(gdisp);
+  printf("%s (\"%s\", displayID=%d)...\n",__func__, t, id);
 #endif         
   switch (event->type)
     {
@@ -138,13 +192,22 @@ gdisplay_check_device_cursor (GDisplay *gdisp)
   /* gdk_input_list_devices returns an internal list, so we shouldn't
      free it afterwards */
 
-  tmp_list = gdk_input_list_devices();
+#if GTK_MAJOR_VERSION > 1
+      tmp_list = gdk_devices_list();
+#else
+      tmp_list = gdk_input_list_devices();
+#endif
 
   while (tmp_list)
     {
+#if GTK_MAJOR_VERSION > 1
+      GdkDevice *info = (GdkDevice *)tmp_list->data;
+      if (info == current_device)
+#else
       GdkDeviceInfo *info = (GdkDeviceInfo *)tmp_list->data;
+      if (CAST(int)info->deviceid == current_device)
+#endif	  
 
-      if (CAST(int) info->deviceid == current_device)
 	{
 	  gdisp->draw_cursor = !info->has_cursor;
 	  break;
@@ -182,7 +245,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
 #if DEBUG_DISPLAY
   printf("%4d: %s( \"%s\", dispID=%d )... [have window=%d]\n", __LINE__,
-         __func__, gdk_event_type_name(event), gdisplay_to_ID(gdisp), 
+         __func__, cp_event_type_name(event), gdisplay_to_ID(gdisp), 
          canvas->window ? 1 : 0);
 #endif 
 
@@ -231,20 +294,28 @@ gdisplay_canvas_events (GtkWidget *canvas,
   else
   {
     gdk_window_get_pointer (canvas->window, &tx_int, &ty_int, &tmask);
+#if GTK_MAJOR_VERSION < 2
     gdk_input_window_get_pointer (canvas->window, current_device, 
         NULL, NULL, NULL, NULL, NULL, NULL);
+#endif
   }
   tx = tx_int;
   ty = ty_int;
 #endif
 
-  /*print_gdk_event_type(event);*/
+#ifdef DEBUG_
+  print_gdk_event_type(event);
+#endif
   switch (event->type)
   {
     case GDK_EXPOSE:
       eevent = (GdkEventExpose *) event;
       if (active_tool->type == CLONE)
 	clone_expose (); 
+#     ifdef DEBUG_
+      printf("%s:%d %d+%d,%dx%d\n",__FILE__,__LINE__,eevent->area.x,
+          eevent->area.y, eevent->area.width, eevent->area.height);
+#     endif
       redraw (gdisp, eevent->area.x, eevent->area.y,
           eevent->area.width, eevent->area.height);
       return_val = TRUE;
@@ -283,10 +354,10 @@ gdisplay_canvas_events (GtkWidget *canvas,
 	return TRUE;
       if (active_tool->type == CLONE)
 	clone_enter_notify ();
+      lc_dialog_update (gdisp->gimage); /* laid-back if gimage==dialog_img */
       break;
 
     case GDK_FOCUS_CHANGE:              /* hsbo */
-      lc_dialog_update (gdisp->gimage); /* laid-back if gimage==dialog_img */
       break;
       
     case GDK_BUTTON_PRESS:
@@ -486,7 +557,7 @@ gdisplay_canvas_events (GtkWidget *canvas,
 
       if (mevent->is_hint)
 	{
-#if 1
+#if GTK_MAJOR_VERSION < 2
 	  gdk_input_window_get_pointer (canvas->window, current_device, &tx, &ty,
 #ifdef GTK_HAVE_SIX_VALUATORS
 					NULL, NULL, NULL, NULL, NULL
