@@ -40,13 +40,13 @@
 #define SLIDER_WIDTH 200
 #define SLIDER_HEIGHT 35
 
-#define GAMMA_SLIDER 0x1
-#define EXPOSE_SLIDER 0x2
-#define OFFSET_SLIDER 0x4
-#define GAMMA_TEXT   0x8
-#define EXPOSE_TEXT  0x16
-#define OFFSET_TEXT  0x32
-#define ALL          0xF
+#define GAMMA_SLIDER  1
+#define EXPOSE_SLIDER 2
+#define OFFSET_SLIDER 4
+#define GAMMA_TEXT    8
+#define EXPOSE_TEXT  16
+#define OFFSET_TEXT  32
+#define ALL         0xF
 
 
 typedef struct ExposeImage ExposeImage;
@@ -96,9 +96,9 @@ static void   expose_view_offset_scale_update   (GtkAdjustment *, gpointer);
 static void   expose_view_gamma_text_update  (GtkWidget *, gpointer);
 static void   expose_view_expose_text_update    (GtkWidget *, gpointer);
 static void   expose_view_offset_text_update    (GtkWidget *, gpointer);
-static gint   expose_view_gamma_text_check (char *, ExposeImageDialog *);
-static gint   expose_view_expose_text_check (char *, ExposeImageDialog *);
-static gint   expose_view_offset_text_check (char *, ExposeImageDialog *);
+static gint   expose_view_gamma_text_check (const char *, ExposeImageDialog *);
+static gint   expose_view_expose_text_check (const char *, ExposeImageDialog *);
+static gint   expose_view_offset_text_check (const char *, ExposeImageDialog *);
 
 static void *expose_view_options = NULL;
 static ExposeImageDialog *expose_view_dialog = NULL;
@@ -236,7 +236,7 @@ expose_view_initialize (void *gdisp_ptr)
 /*  the action area structure  */
 static ActionAreaItem action_items[] =
 {
-  { "Ok", expose_view_ok_callback, NULL, NULL },
+  { "OK", expose_view_ok_callback, NULL, NULL },
   { "Reset (LDR)", expose_view_reset_callback, NULL, NULL }
 };
 
@@ -251,7 +251,7 @@ expose_view_new_dialog (GDisplay* gdisp)
   GtkWidget *slider;
   GtkObject *data;
 
-  action_items[0].label = _("Ok");
+  action_items[0].label = _("OK");
   action_items[1].label = _("Reset (LDR)");
   bcd = g_malloc_zero (sizeof (ExposeImageDialog));
   bcd->preview = TRUE;
@@ -283,7 +283,7 @@ expose_view_new_dialog (GDisplay* gdisp)
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the expose scale widget  */
-  label = gtk_label_new (_("expose"));
+  label = gtk_label_new (_("Expose"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 2, 2);
@@ -354,7 +354,7 @@ expose_view_new_dialog (GDisplay* gdisp)
 #endif
 
   /*  Create the gamma scale widget  */
-  label = gtk_label_new (_("gamma"));
+  label = gtk_label_new (_("Gamma"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1,
 # if USE_OFFSET
@@ -576,7 +576,7 @@ expose_view_gamma_text_update (GtkWidget *w,
 					    gpointer   data)
 {
   ExposeImageDialog *bcd = (ExposeImageDialog *) data;
-  char *str = gtk_entry_get_text (GTK_ENTRY (w));
+  const char *str = gtk_entry_get_text (GTK_ENTRY (w));
   
   if (expose_view_gamma_text_check (str, bcd))
   {
@@ -588,7 +588,7 @@ expose_view_gamma_text_update (GtkWidget *w,
 
 static gint 
 expose_view_gamma_text_check (
-				char *str, 
+				const char *str, 
 				ExposeImageDialog *bcd
 				)
 {
@@ -608,7 +608,7 @@ expose_view_expose_text_update (GtkWidget *w,
 					  gpointer   data)
 {
   ExposeImageDialog *bcd = (ExposeImageDialog *) data;
-  char *str = gtk_entry_get_text (GTK_ENTRY (w));
+  const char *str = gtk_entry_get_text (GTK_ENTRY (w));
 
   if (expose_view_expose_text_check (str, bcd))
     {
@@ -621,7 +621,7 @@ expose_view_expose_text_update (GtkWidget *w,
 
 static gint 
 expose_view_expose_text_check  (
-				char *str, 
+				const char *str, 
 				ExposeImageDialog *bcd
 				)
 {
@@ -656,7 +656,7 @@ expose_view_offset_text_update (GtkWidget *w,
 
 static gint 
 expose_view_offset_text_check  (
-				char *str, 
+				const char *str, 
 				ExposeImageDialog *bcd
 				)
 {
