@@ -22,12 +22,12 @@
 #include "procedural_db.h"
 
 /*  by_color select functions  */
-Tool *        tools_new_expose_image      (void);
-void          tools_free_expose_image     (Tool *);
+Tool *        tools_new_expose_view      (void);
+void          tools_free_expose_view     (Tool *);
 
-void          expose_image_initialize     (void *);
+void          expose_view_initialize     (void *);
 
 /*  Procedure definition and marshalling function  */
-extern ProcRecord expose_image_proc;
+extern ProcRecord expose_view_proc;
 
 #endif  /*  __EXPOSE_IMAGE_H__  */
