@@ -1039,36 +1039,11 @@ file_load_without_display (char *filename, char* raw_filename, GDisplay *gdispla
 
       /*  set the image to clean  */
       gimage_clean_all (gimage);
-      /* assign profile according to cms_open_action */
-      if (!gimage_get_cms_profile(gimage))
-      { if ((cms_open_action == CMS_ASSIGN_DEFAULT) &&
-	        (cms_default_image_profile_name != NULL)) 
-        { gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
-        }
-        else if (cms_open_action == CMS_ASSIGN_PROMPT)
-        { cms_open_assign_dialog(gimage);
-        }
-      }
 
-      /* assign proof profile allways */
-      if (!gimage_get_cms_proof_profile(gimage) &&
-           (cms_default_proof_profile_name != NULL)) 
-      {   gimage_set_cms_proof_profile(gimage, cms_get_profile_from_file(cms_default_proof_profile_name));
-      }
+      /* assign profiles according to cms settings */
+      cms_gimage_open( gimage );
 
-      /* if a workspace profile is given and it's not equal the 
-	 image profile, check whether to convert */
-      if ((cms_workspace_profile_name != NULL) && (gimage_get_cms_profile(gimage) != NULL))
-      {   CMSProfile *workspace_profile = cms_get_profile_from_file(cms_workspace_profile_name);
-          if ((gimage_get_cms_profile(gimage) != workspace_profile) &&
-	      ((cms_mismatch_action == CMS_MISMATCH_AUTO_CONVERT)  || 
-	       ((cms_mismatch_action == CMS_MISMATCH_PROMPT) && (cms_convert_on_open_prompt(gimage)==TRUE))))
-	  {  convert_image_colorspace(gimage, workspace_profile, cms_default_intent,
-                       cms_default_flags & cmsFLAGS_WHITEBLACKCOMPENSATION ?
-                       cmsFLAGS_WHITEBLACKCOMPENSATION : 0 );
-	  }
-      } 
-   }
+    }
 
   if (return_val)
     return gimage;
@@ -1128,36 +1103,8 @@ file_open (char *filename, char* raw_filename)
       /*  set the image to clean  */
       gimage_clean_all (gimage);
 
-      /* assign profile according to cms_open_action */
-      if (!gimage_get_cms_profile(gimage))
-      { 
-        if ((cms_open_action == CMS_ASSIGN_DEFAULT) &&
-            (cms_default_image_profile_name != NULL))
-        { gimage_set_cms_profile(gimage, cms_get_profile_from_file(cms_default_image_profile_name));
-        }
-        else if (cms_open_action == CMS_ASSIGN_PROMPT)
-        { cms_open_assign_dialog(gimage);
-        }
-      }
-      /* assign proof profile allways */
-      if (!gimage_get_cms_proof_profile(gimage) &&
-           (cms_default_proof_profile_name != NULL)) 
-      {   gimage_set_cms_proof_profile(gimage, cms_get_profile_from_file(cms_default_proof_profile_name));
-      }
-
-      /* if a workspace profile is given and it's not equal the 
-         image profile, check whether to convert */
-      if ((cms_workspace_profile_name != NULL) && (gimage_get_cms_profile(gimage) != NULL))
-      {   CMSProfile *workspace_profile = cms_get_profile_from_file(cms_workspace_profile_name);
-          if ((gimage_get_cms_profile(gimage) != workspace_profile) &&
-               ((cms_mismatch_action == CMS_MISMATCH_AUTO_CONVERT)  || 
-               ((cms_mismatch_action == CMS_MISMATCH_PROMPT) && (cms_convert_on_open_prompt(gimage)==TRUE))))
-          {   convert_image_colorspace(gimage, workspace_profile,
-                       cms_default_intent,
-                       cms_default_flags & cmsFLAGS_WHITEBLACKCOMPENSATION ?
-                       cmsFLAGS_WHITEBLACKCOMPENSATION : 0 );
-          }
-      } 
+      /* assign profiles and popup dialogs according to settings */
+      cms_gimage_open (gimage);
 
       /*  display the image */
       gdisplay_new (gimage, 0x0101);
@@ -1282,7 +1229,10 @@ file_save (int   image_ID,
     }
 
   return_vals = procedural_db_execute (proc->name, args);
-  return_val = (return_vals[0].value.pdb_int == PDB_SUCCESS);
+  if(return_vals)
+    return_val = (return_vals[0].value.pdb_int == PDB_SUCCESS);
+  else
+    return_val = 0;
 
   if (return_val != -1 /*&& !save_layer && !save_copy*/)
     {
@@ -1575,16 +1525,16 @@ file_overwrite (char *filename, char* raw_filename)
     { "Yes", file_overwrite_yes_callback, NULL, NULL },
     { "No", file_overwrite_no_callback, NULL, NULL }
   };
-  { int i;
-    for(i = 0; i < 2; ++i)
-      obox_action_items[i].label = _(obox_action_items[i].label);
-  }
-
   OverwriteBox *overwrite_box;
   GtkWidget *vbox;
   GtkWidget *label;
   char *overwrite_text;
 
+  { int i;
+    for(i = 0; i < 2; ++i)
+      obox_action_items[i].label = _(obox_action_items[i].label);
+  }
+
   overwrite_box = (OverwriteBox *) g_malloc_zero (sizeof (OverwriteBox));
   overwrite_text = (char *) g_malloc (strlen (_(" exists, overwrite?")) + strlen (filename) + 1);
   sprintf (overwrite_text, _("%s exists, overwrite?"), filename);
