@@ -176,11 +176,20 @@ gdisplay_new (GImage       *gimage,
     while (cur_wid_list != NULL) { 
 
       if( strcmp("GtkTearoffMenuItem",
-          gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name) != 0)
+#if GTK_MAJOR_VERSION > 1
+          GTK_OBJECT_TYPE_NAME(cur_wid_list->data)
+#else
+          gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))
+#endif
+          ) != 0)
       {
 #       ifdef DEBUG_
         printf("%s:%d %s() Adding factory component: %s %s |\n", __FILE__,__LINE__,__func__,
+#if GTK_MAJOR_VERSION > 1
+          GTK_OBJECT_TYPE_NAME(cur_wid_list->data),
+#else
           gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name,
+#endif
           ((GtkItemFactoryItem *) cur_wid_list->data)->path);
 #       endif
         g_hash_table_insert(display_ht, cur_wid_list->data, gdisp); 
@@ -230,25 +239,27 @@ gdisplay_format_title (GImage *gimage,
   Tag t = gimage_tag (gimage);
   const char *colour = 0;
   char *alpha_msg = ""; /*"no alpha";*/
-  const char *profile;
+  const char *profile = NULL;
   char *proof = NULL;
 
   if (layer_has_alpha(gimage->active_layer)){
     alpha_msg = _("A"); /*"alpha";*/
   }
 
-  if (gimage_get_cms_profile(gimage) != NULL)
-  {   profile = cms_get_profile_info(gimage_get_cms_profile(gimage))->description;
+  if (gdisplay_is_colormanaged( gdisp ))
+  {
+    if (gimage_get_cms_profile(gimage) != NULL)
+    { profile = cms_get_profile_info(gimage_get_cms_profile(gimage))->description;
       if (gdisplay_is_proofed (gdisp))
         proof = g_strdup(cms_get_profile_info(gimage_get_cms_proof_profile(gimage))->description);
       colour = cms_get_profile_info(gimage->cms_profile)->color_space_name;
       if(strstr(colour,"Cmyk"))
           alpha_msg = "";
+    }
+    else 
+    { profile = _("[no icc profile assigned]");
+    }
   }
-  else 
-  {   profile = _("[no icc profile assigned]");
-  }
-
 
 
   sprintf (title, "%s-%d.%d (%s - %s%s - %s%s%s)%s %d%%",
@@ -257,7 +268,7 @@ gdisplay_format_title (GImage *gimage,
 	   tag_string_precision (tag_precision (t)),
 	   colour ? colour : tag_string_format (tag_format (t)),
 	   alpha_msg,
-	   profile,
+	   profile ? profile : "",
            proof ? _(" | proof: ") : "",
            proof ? proof : "",
            empty ? _(" (empty)") : "",
@@ -292,7 +303,12 @@ gdisplay_delete (GDisplay *gdisp)
       char path[64] = "", *ptr=0;
       const char* type = 0;
 
-      type = gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name, fac_item->path;
+      type = 
+#if GTK_MAJOR_VERSION > 1
+          GTK_OBJECT_TYPE_NAME(cur_wid_list->data);
+#else
+          gtk_type_query(GTK_OBJECT_TYPE(cur_wid_list->data))->type_name; //, fac_item->path;
+#endif
 #     ifdef DEBUG_
       printf("%s:%d %s() Removing factory component: %s\n",
       __FILE__,__LINE__,__func__, type?type:"");
@@ -344,6 +360,7 @@ gdisplay_delete (GDisplay *gdisp)
   if(*gdisp->cms_expensive_transf)
     cms_return_transform ( *gdisp->cms_expensive_transf );
   free (gdisp->cms_expensive_transf);
+  gdisp->cms_expensive_transf = NULL;
 
   if (gdisp->scroll_gc)
     gdk_gc_destroy (gdisp->scroll_gc);
@@ -351,13 +368,16 @@ gdisplay_delete (GDisplay *gdisp)
   /*  free the area lists  */
   gdisplay_free_area_list (gdisp->update_areas);
   gdisplay_free_area_list (gdisp->display_areas);
+  gdisp->display_areas = NULL;
 
   /*  free the gimage  */
   gimage_delete (gdisp->gimage);
+  gdisp->gimage = NULL;
 
   /*  insure that if a window information dialog exists, it is removed  */
   if (gdisp->window_info_dialog)
     info_window_free (gdisp->window_info_dialog);
+  gdisp->window_info_dialog = NULL;
 
   /*  set popup_shell to NULL if appropriate */
   if (popup_shell == gdisp->shell)
@@ -1431,8 +1451,8 @@ gdisplay_set_menu_sensitivity (GDisplay *gdisp)
   menus_set_state (buff,  (gdisp->cms_flags & cmsFLAGS_WHITEBLACKCOMPENSATION) != 0);
   menus_set_state ("<Image>/View/Rendering Intent/Black Point Compensation", (gdisp->cms_flags & cmsFLAGS_WHITEBLACKCOMPENSATION) != 0);
  g_snprintf(buff, 1024, "<Image%d>/View/Colormanage Display", gdisp->unique_id);
-  menus_set_state (buff, gdisp->colormanaged && format == FORMAT_RGB);
-  menus_set_state ("<Image>/View/Colormanage Display", gdisp->colormanaged && format == FORMAT_RGB);
+  menus_set_state (buff, gdisp->colormanaged /*&& format == FORMAT_RGB*/);
+  menus_set_state ("<Image>/View/Colormanage Display", gdisp->colormanaged/* && format == FORMAT_RGB*/);
   g_snprintf(buff, 1024, "<Image%d>/View/Proof Display", gdisp->unique_id);
   menus_set_state (buff,  (gdisp->cms_flags & cmsFLAGS_SOFTPROOFING) != 0);
   menus_set_state ("<Image>/View/Proof Display", (gdisp->cms_flags & cmsFLAGS_SOFTPROOFING) != 0);
@@ -1554,8 +1574,13 @@ gdisplay_active ()
 
 # ifdef DEBUG
   printf("%s:%d %s() could not associate event %s with a gdisplay in display_ht with entries: %d\n",
-  __FILE__,__LINE__,__func__,gtk_type_query(GTK_OBJECT_TYPE(event_widget))->type_name,
-   g_hash_table_size(display_ht));
+  __FILE__,__LINE__,__func__,
+#if GTK_MAJOR_VERSION > 1
+          GTK_OBJECT_TYPE_NAME(event_widget)
+#else
+          gtk_type_query(GTK_OBJECT_TYPE(event_widget))->type_name
+#endif
+   ,g_hash_table_size(display_ht));
 # endif
   return NULL;
 }
@@ -1630,7 +1655,7 @@ gdisplay_to_ID (GDisplay *test_disp)
   while (list)
     {
       gdisp = (GDisplay *) list->data;
-#     ifdef DEBUG
+#     ifdef DEBUG_
       printf("%s:%d %s() ID = %d  0x%x\n",__FILE__,__LINE__,__func__,gdisp->ID, (int)gdisp);
 #     endif
       if (gdisp == test_disp)
