@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "canvas.h"
@@ -306,7 +307,7 @@ edit_paste (GImage      *gimage,
   int cx, cy;
 
   /*  Make a new floating layer  */
-  float_layer = layer_from_tiles (gimage, drawable, paste, "Pasted Layer", OPAQUE_OPACITY, NORMAL);
+  float_layer = layer_from_tiles (gimage, drawable, paste, _("Pasted Layer"), OPAQUE_OPACITY, NORMAL);
 
   if (float_layer)
     {
@@ -643,12 +644,17 @@ paste_named_buffer (GDisplay *gdisp)
   GtkWidget *paste_into;
   GtkWidget *listbox;
 
+  { int i;
+    for(i = 0; i < 3; ++i)
+      action_items[i].label = _(action_items[i].label);
+  }
+
   pn_dlg = (PasteNamedDlg *) g_malloc_zero (sizeof (PasteNamedDlg));
   pn_dlg->gdisp = gdisp;
 
   pn_dlg->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (pn_dlg->shell), "paste_named_buffer", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (pn_dlg->shell), "Paste Named Buffer");
+  gtk_window_set_title (GTK_WINDOW (pn_dlg->shell), _("Paste Named Buffer"));
   gtk_widget_set_uposition(pn_dlg->shell, generic_window_x, generic_window_y);
   layout_connect_window_position(pn_dlg->shell, &generic_window_x, &generic_window_y, FALSE);
   minimize_register(pn_dlg->shell);
@@ -662,7 +668,7 @@ paste_named_buffer (GDisplay *gdisp)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pn_dlg->shell)->vbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
-  label = gtk_label_new ("Select a buffer to paste:");
+  label = gtk_label_new (_("Select a buffer to paste:"));
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -680,7 +686,7 @@ paste_named_buffer (GDisplay *gdisp)
   set_list_of_named_buffers (pn_dlg->list);
   gtk_widget_show (pn_dlg->list);
 
-  paste_into = gtk_check_button_new_with_label ("Replace Current Selection");
+  paste_into = gtk_check_button_new_with_label (_("Replace Current Selection"));
   gtk_box_pack_start (GTK_BOX (vbox), paste_into, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (paste_into), "toggled",
 		      (GtkSignalFunc) named_buffer_paste_into_update,
@@ -746,7 +752,7 @@ named_edit_cut (void *gdisp_ptr)
   gdisp = (GDisplay *) gdisp_ptr;
   active_tool_control (HALT, gdisp_ptr);
 
-  query_string_box ("Cut Named", "Enter a name for this buffer", NULL,
+  query_string_box (_("Cut Named"), _("Enter a name for this buffer"), NULL,
 		    cut_named_buffer_callback, gdisp);
   return TRUE;
 }
@@ -775,7 +781,7 @@ named_edit_copy (void *gdisp_ptr)
 
   gdisp = (GDisplay *) gdisp_ptr;
   
-  query_string_box ("Copy Named", "Enter a name for this buffer", NULL,
+  query_string_box (_("Copy Named"), _("Enter a name for this buffer"), NULL,
 		    copy_named_buffer_callback, gdisp);
   return TRUE;
 }
