@@ -19,6 +19,8 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#include <gtk/gtk.h>
+#include "compat.h"
 #include "gtkhwrapbox.h"
 #include <math.h>
 
@@ -654,3 +656,5 @@ gtk_hwrap_box_size_allocate (GtkWidget     *widget,
   
   layout_rows (wbox, &area);
 }
+
+
