@@ -56,6 +56,18 @@ static void gtk_wrap_box_get_arg       (GtkObject          *object,
 static void gtk_wrap_box_set_arg       (GtkObject          *object,
 					GtkArg             *arg,
 					guint               arg_id);
+#if GTK_MAJOR_VERSION > 1
+static void gtk_wrap_box_set_child_property (GtkContainer    *container,
+                                             GtkWidget       *child,
+                                             guint            property_id,
+                                             const GValue    *value,
+                                             GParamSpec      *pspec);
+static void gtk_wrap_box_get_child_property (GtkContainer    *container,
+                                             GtkWidget       *child,
+                                             guint            property_id,
+                                             GValue          *value,
+                                             GParamSpec      *pspec);
+#else
 static void gtk_wrap_box_set_child_arg (GtkContainer       *container,
 					GtkWidget          *child,
 					GtkArg             *arg,
@@ -64,6 +76,7 @@ static void gtk_wrap_box_get_child_arg (GtkContainer       *container,
 					GtkWidget          *child,
 					GtkArg             *arg,
 					guint               arg_id);
+#endif
 static void gtk_wrap_box_map           (GtkWidget          *widget);
 static void gtk_wrap_box_unmap         (GtkWidget          *widget);
 static void gtk_wrap_box_draw          (GtkWidget          *widget,
@@ -122,22 +135,33 @@ gtk_wrap_box_class_init (GtkWrapBoxClass *class)
   widget_class = GTK_WIDGET_CLASS (class);
   container_class = GTK_CONTAINER_CLASS (class);
   
+#if GTK_MAJOR_VERSION > 1
+  parent_class = g_type_class_peek_parent (class);
+#else
   parent_class = gtk_type_class (GTK_TYPE_CONTAINER);
-  
+#endif
+
   object_class->set_arg = gtk_wrap_box_set_arg;
   object_class->get_arg = gtk_wrap_box_get_arg;
   
   widget_class->map = gtk_wrap_box_map;
   widget_class->unmap = gtk_wrap_box_unmap;
+#if GTK_MAJOR_VERSION < 2
   widget_class->draw = gtk_wrap_box_draw;
+#endif
   widget_class->expose_event = gtk_wrap_box_expose;
   
   container_class->add = gtk_wrap_box_add;
   container_class->remove = gtk_wrap_box_remove;
   container_class->forall = gtk_wrap_box_forall;
   container_class->child_type = gtk_wrap_box_child_type;
+#if GTK_MAJOR_VERSION > 1
+  container_class->set_child_property = gtk_wrap_box_set_child_property;
+  container_class->get_child_property = gtk_wrap_box_get_child_property;
+#else
   container_class->set_child_arg = gtk_wrap_box_set_child_arg;
   container_class->get_child_arg = gtk_wrap_box_get_child_arg;
+#endif
 
   class->rlist_line_children = NULL;
   
@@ -157,6 +181,50 @@ gtk_wrap_box_class_init (GtkWrapBoxClass *class)
 			   GTK_TYPE_FLOAT, GTK_ARG_READABLE, ARG_CURRENT_RATIO);
   gtk_object_add_arg_type ("GtkWrapBox::max_children_per_line",
 			   GTK_TYPE_UINT, GTK_ARG_READWRITE, ARG_CHILD_LIMIT);
+#if GTK_MAJOR_VERSION > 1
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_POSITION,
+                                              g_param_spec_int ("position",
+                                                                NULL,
+                                                                NULL,
+                                                                -1, G_MAXINT, 0,
+                                                                G_PARAM_READWRITE));
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_HEXPAND,
+                                              g_param_spec_boolean ("hexpand",
+                                                                    NULL,
+                                                                    NULL,
+                                                                    FALSE,
+                                                                    G_PARAM_READWRITE));
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_HFILL,
+                                              g_param_spec_boolean ("hfill",
+                                                                    NULL,
+                                                                    NULL,
+                                                                    FALSE,
+                                                                    G_PARAM_READWRITE));
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_VEXPAND,
+                                              g_param_spec_boolean ("vexpand",
+                                                                    NULL,
+                                                                    NULL,
+                                                                    FALSE,
+                                                                    G_PARAM_READWRITE));
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_VFILL,
+                                              g_param_spec_boolean ("vfill",
+                                                                    NULL,
+                                                                    NULL,
+                                                                    FALSE,
+                                                                    G_PARAM_READWRITE));
+  gtk_container_class_install_child_property (container_class,
+                                              CHILD_ARG_FORCED_BREAK,
+                                              g_param_spec_boolean ("wrapped",
+                                                                    NULL,
+                                                                    NULL,
+                                                                    FALSE,
+                                                                    G_PARAM_READWRITE));
+#else
   gtk_container_add_child_arg_type ("GtkWrapBox::position",
 				    GTK_TYPE_INT, GTK_ARG_READWRITE, CHILD_ARG_POSITION);
   gtk_container_add_child_arg_type ("GtkWrapBox::hexpand",
@@ -169,6 +237,7 @@ gtk_wrap_box_class_init (GtkWrapBoxClass *class)
 				    GTK_TYPE_BOOL, GTK_ARG_READWRITE, CHILD_ARG_VFILL);
   gtk_container_add_child_arg_type ("GtkWrapBox::forcebreak",
 				    GTK_TYPE_BOOL, GTK_ARG_READWRITE, CHILD_ARG_FORCED_BREAK);
+#endif
 }
 
 static void
@@ -361,6 +430,120 @@ gtk_wrap_box_child_type	(GtkContainer *container)
   return GTK_TYPE_WIDGET;
 }
 
+#if GTK_MAJOR_VERSION > 1
+static void
+gtk_wrap_box_set_child_property (GtkContainer    *container,
+                                 GtkWidget       *child,
+                                 guint            property_id,
+                                 const GValue    *value,
+                                 GParamSpec      *pspec)
+{
+  GtkWrapBox *wbox = GTK_WRAP_BOX (container);
+  gboolean hexpand = FALSE, hfill = FALSE;
+  gboolean vexpand = FALSE, vfill = FALSE;
+  gboolean wrapped = FALSE;
+
+  if (property_id != CHILD_ARG_POSITION)
+    gtk_wrap_box_query_child_packing (wbox, child,
+                                      &hexpand, &hfill,
+                                      &vexpand, &vfill/*,
+                                      &wrapped*/);
+
+  switch (property_id)
+    {
+    case CHILD_ARG_POSITION:
+      gtk_wrap_box_reorder_child (wbox, child, g_value_get_int (value));
+      break;
+    case CHILD_ARG_HEXPAND:
+      gtk_wrap_box_set_child_packing (wbox, child,
+                                      g_value_get_boolean (value), hfill,
+                                      vexpand, vfill/*,
+                                      wrapped*/);
+      break;
+    case CHILD_ARG_HFILL:
+      gtk_wrap_box_set_child_packing (wbox, child,
+                                      hexpand, g_value_get_boolean (value),
+                                      vexpand, vfill/*,
+                                      wrapped*/);
+      break;
+    case CHILD_ARG_VEXPAND:
+      gtk_wrap_box_set_child_packing (wbox, child,
+                                      hexpand, hfill,
+                                      g_value_get_boolean (value), vfill/*,
+                                      wrapped*/);
+      break;
+    case CHILD_ARG_VFILL:
+      gtk_wrap_box_set_child_packing (wbox, child,
+                                      hexpand, hfill,
+                                      vexpand, g_value_get_boolean (value)/*,
+                                      wrapped*/);
+      break;
+    case CHILD_ARG_FORCED_BREAK /*CHILD_ARG_WRAPPED*/:
+      gtk_wrap_box_set_child_packing (wbox, child,
+                                      hexpand, hfill,
+                                      vexpand, vfill/*,
+                                      g_value_get_boolean (value)*/);
+      break;
+    default:
+      /*GTK_CONTAINER_WARN_INVALID_CHILD_ARGERTY_ID (container, property_id, pspec);*/
+      break;
+    }
+}
+
+static void
+gtk_wrap_box_get_child_property (GtkContainer    *container,
+                                 GtkWidget       *child,
+                                 guint            property_id,
+                                 GValue          *value,
+                                 GParamSpec      *pspec)
+{
+  GtkWrapBox *wbox = GTK_WRAP_BOX (container);
+  gboolean hexpand = FALSE, hfill = FALSE;
+  gboolean vexpand = FALSE, vfill = FALSE;
+  gboolean wrapped = FALSE;
+
+  if (property_id != CHILD_ARG_POSITION)
+    gtk_wrap_box_query_child_packing (wbox, child,
+                                      &hexpand, &hfill,
+                                      &vexpand, &vfill/*,
+                                      &wrapped*/);
+
+  switch (property_id)
+    {
+      GtkWrapBoxChild *child_info;
+      guint i;
+    case CHILD_ARG_POSITION:
+      i = 0;
+      for (child_info = wbox->children; child_info; child_info = child_info->next)
+        {
+          if (child_info->widget == child)
+            break;
+          i += 1;
+        }
+      g_value_set_int (value, child_info ? i : -1);
+      break;
+    case CHILD_ARG_HEXPAND:
+      g_value_set_boolean (value, hexpand);
+      break;
+    case CHILD_ARG_HFILL:
+      g_value_set_boolean (value, hfill);
+      break;
+    case CHILD_ARG_VEXPAND:
+      g_value_set_boolean (value, vexpand);
+      break;
+    case CHILD_ARG_VFILL:
+      g_value_set_boolean (value, vfill);
+      break;
+    case CHILD_ARG_FORCED_BREAK /*CHILD_ARG_WRAPPED*/:
+      g_value_set_boolean (value, wrapped);
+      break;
+    default:
+      /*GTK_CONTAINER_WARN_INVALID_CHILD_ARGERTY_ID (container, property_id, pspec);*/
+      break;
+    }
+}
+#endif
+
 void
 gtk_wrap_box_set_homogeneous (GtkWrapBox *wbox,
 			      gboolean    homogeneous)
@@ -549,7 +732,8 @@ gtk_wrap_box_query_child_packing (GtkWrapBox *wbox,
 				  gboolean   *hexpand,
 				  gboolean   *hfill,
 				  gboolean   *vexpand,
-				  gboolean   *vfill)
+				  gboolean   *vfill/*,
+                                  gboolean   *wrapped*/)
 {
   GtkWrapBoxChild *child_info;
   
@@ -570,6 +754,8 @@ gtk_wrap_box_query_child_packing (GtkWrapBox *wbox,
 	*vexpand = child_info->vexpand;
       if (vfill)
 	*vfill = child_info->vfill;
+      /*if (wrapped)
+        *wrapped = child_info->wrapped;*/
     }
 }
 
@@ -680,7 +866,7 @@ gtk_wrap_box_query_line_lengths (GtkWrapBox *wbox,
   area.height = MAX (1, (gint) allocation->height - border * 2);
 
   next_child = wbox->children;
-  slist = GTK_WRAP_BOX_GET_CLASS (wbox)->rlist_line_children (wbox,
+  slist = GTK_WRAP_BOX_CLASS (wbox)->rlist_line_children (wbox,
 							      &next_child,
 							      &area,
 							      &max_child_size,
@@ -693,7 +879,7 @@ gtk_wrap_box_query_line_lengths (GtkWrapBox *wbox,
       lines[l] = g_slist_length (slist);
       g_slist_free (slist);
 
-      slist = GTK_WRAP_BOX_GET_CLASS (wbox)->rlist_line_children (wbox,
+      slist = GTK_WRAP_BOX_CLASS (wbox)->rlist_line_children (wbox,
 								  &next_child,
 								  &area,
 								  &max_child_size,
@@ -764,7 +950,8 @@ gtk_wrap_box_expose (GtkWidget      *widget,
       if (GTK_WIDGET_DRAWABLE (child->widget) &&
 	  GTK_WIDGET_NO_WINDOW (child->widget) &&
 	  gtk_widget_intersect (child->widget, &event->area, &child_event.area))
-	gtk_widget_event (child->widget, (GdkEvent*) &child_event);
+        GTK_WIDGET_CLASS (parent_class)->expose_event (widget, event);
+	/*gtk_widget_event (child->widget, (GdkEvent*) &child_event);*/
   
   return TRUE;
 }
