@@ -19,6 +19,7 @@
 #include <string.h>
 #include <math.h>
 #include "../lib/version.h"
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
 #include "buildmenu.h"
@@ -173,7 +174,7 @@ tools_new_histogram_tool ()
 
   /*  The tool options  */
   if (!histogram_tool_options)
-    histogram_tool_options = tools_register_no_options (HISTOGRAM, "Histogram Options");
+    histogram_tool_options = tools_register_no_options (HISTOGRAM, _("Histogram Options"));
 
   tool = (Tool *) g_malloc_zero (sizeof (Tool));
   private = (HistogramTool *) g_malloc_zero (sizeof (HistogramTool));
@@ -219,7 +220,7 @@ histogram_tool_initialize (void *gdisp_ptr)
 
   if (drawable_indexed (gimage_active_drawable (gdisp->gimage)))
     {
-      g_message ("Histogram does not operate on indexed drawables.");
+      g_message (_("Histogram does not operate on indexed drawables."));
       return;
     }
 
@@ -354,6 +355,22 @@ histogram_tool_new_dialog ( gint bins )
   int i;
   int x, y;
 
+  histogram_info_names[0] = _("Mean: ");
+  histogram_info_names[1] = _("Std Dev: ");
+  histogram_info_names[2] = _("Median: ");
+  histogram_info_names[3] = _("Pixels: ");
+  histogram_info_names[4] = _("Intensity: ");
+  histogram_info_names[5] = _("Count: ");
+  histogram_info_names[6] = _("Percentile: ");
+
+  color_option_items[0].label = _("Value");
+  color_option_items[1].label = _("Red");
+  color_option_items[2].label = _("Green");
+  color_option_items[3].label = _("Blue");
+  color_option_items[4].label = _("Alpha");
+
+  action_items[0].label = _(action_items[0].label);
+
   htd = (HistogramToolDialog *) g_malloc (sizeof (HistogramToolDialog));
   htd->channel = HISTOGRAM_VALUE;
 
@@ -363,7 +380,7 @@ histogram_tool_new_dialog ( gint bins )
   /*  The shell and main vbox  */
   htd->shell = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (htd->shell), "histogram", PROGRAM_NAME);
-  gtk_window_set_title (GTK_WINDOW (htd->shell), "Histogram");
+  gtk_window_set_title (GTK_WINDOW (htd->shell), _("Histogram"));
   minimize_register(htd->shell);
 
   /* handle the wm close signal */
@@ -382,7 +399,7 @@ histogram_tool_new_dialog ( gint bins )
   channel_hbox = gtk_hbox_new (TRUE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), channel_hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Information on Channel: ");
+  label = gtk_label_new (_("Information on Channel: "));
   gtk_box_pack_start (GTK_BOX (channel_hbox), label, FALSE, FALSE, 0);
   //gtk_box_pack_start (GTK_BOX (htd->channel_menu), label, FALSE, FALSE, 0);
 
