@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include "../lib/version.h"
+#include "compat.h"
 #include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "actionarea.h"
@@ -41,7 +42,7 @@
 #include "rc.h"
 #include "pixmaps.h"
 #include "minimize.h"
-
+#include "tango_tools_pixmaps.h"
 
 /*  local functions  */
 static gint  tools_button_press    (GtkWidget *widget,
@@ -90,6 +91,7 @@ typedef struct ToolButton ToolButton;
 struct ToolButton
 {
   char **icon_data;
+  char **tango_icon_data;
   char  *tool_desc;
   gpointer callback_data;
 };
@@ -131,88 +133,114 @@ struct ToolButton
 static ToolButton tool_data[] =
 {
   { (char **) rect_bits,
+    (char **) stock_tool_rect_select_22,
     "Select rectangular regions",
     (gpointer) RECT_SELECT },
   { (char **) circ_bits,
+    (char **) stock_tool_ellipse_select_22,
     "Select elliptical regions",
     (gpointer) ELLIPSE_SELECT },
   { (char **) free_bits,
+    (char **) stock_tool_free_select_22,
     "Select hand-drawn regions",
     (gpointer) FREE_SELECT },
 
   { (char **) fuzzy_bits,
+    (char **) stock_tool_fuzzy_select_22,
     "Select contiguous regions",
     (gpointer) FUZZY_SELECT },
   { (char **) bezier_bits,
+    (char **) stock_tool_path_22,
     "Select regions using Bezier curves",
     (gpointer) BEZIER_SELECT },
   { (char **) iscissors_bits,
+    (char **) stock_tool_iscissors_22,
     "Select shapes from image",
     (gpointer) ISCISSORS },
 
   { (char **) move_bits,
+    (char **) stock_tool_move_22,
     "Move layers & selections",
     (gpointer) MOVE },
   { (char **) magnify_bits,
+    (char **) stock_tool_zoom_22,
     "Zoom in & out",
     (gpointer) MAGNIFY },
   { (char **) crop_bits,
+    (char **) stock_tool_crop_22,
     "Crop the image",
     (gpointer) CROP },
 
   { (char **) scale_bits,
+    (char **) stock_tool_scale_22,
     "Transform the layer or selection (rotate, scale, share, perspective)",
     (gpointer) ROTATE },
   { (char **) horizflip_bits,
+    (char **) stock_tool_flip_22,
     "Flip the layer or selection",
     (gpointer) FLIP_HORZ },
   { (char **) text_bits,
+    (char **) stock_tool_text_22,
     "Add text to the image",
     (gpointer) TEXT },
   { (char **) spline_bits,
+    (char **) stock_tool_spline_22,
     "Spline",
     (gpointer) SPLINE },
 
   { (char **) colorpicker_bits,
+    (char **) stock_tool_color_picker_22,
     "Pick colors from the image",
     (gpointer) COLOR_PICKER },
   { (char **) fill_bits,
+    (char **) stock_tool_bucket_fill_22,
     "Fill with a color or pattern",
     (gpointer) BUCKET_FILL },
   { (char **) gradient_bits,
+    (char **) stock_tool_blend_22,
     "Fill with a color gradient",
     (gpointer) BLEND },
 
   { (char **) pencil_bits,
+    (char **) stock_tool_pencil_22,
     "Draw sharp pencil strokes",
     (gpointer) PENCIL },
   { (char **) paint_bits,
+    (char **) stock_tool_paintbrush_22,
     "Paint fuzzy brush strokes",
     (gpointer) PAINTBRUSH },
   { (char **) erase_bits,
+    (char **) stock_tool_eraser_22,
     "Erase to background or transparency",
     (gpointer) ERASER },
 
   { (char **) airbrush_bits,
+    (char **) stock_tool_airbrush_22,
     "Airbrush with variable pressure",
     (gpointer) AIRBRUSH },
   { (char **) clone_bits,
+    (char **) stock_tool_clone_22,
     "Clone image regions",
     (gpointer) CLONE },
   { (char **) blur_bits,
+    (char **) stock_tool_blur_22,
     "Blur or sharpen",
     (gpointer) CONVOLVE },
 
   { (char **) dodge_bits,
+    (char **) stock_tool_dodge_22,
     "Dodge or burn",
     (gpointer) DODGEBURN },
   { (char **) smudge_bits,
+    (char **) stock_tool_smudge_22,
     "Smudge",
     (gpointer) SMUDGE },
   { (char **) measure_bits,
+    (char **) stock_tool_measure_22,
     "Measure",
     (gpointer) MEASURE },
   { (char **) spline_edit_bits,
+    (char **) stock_tool_edit_spline_22,
     "Spline Edit",
     (gpointer) SPLINE_EDIT },
 };
@@ -484,6 +512,9 @@ create_tools (GtkWidget *parent)
   GtkWidget *button;
   GtkWidget *alignment;
   GtkWidget *pixmap;
+#if GTK_MAJOR_VERSION > 1
+  GdkPixbuf *pixbuf;
+#endif
   GSList *group;
   gint i;
 
@@ -511,7 +542,13 @@ create_tools (GtkWidget *parent)
       gtk_container_border_width (GTK_CONTAINER (alignment), 0);
       gtk_container_add (GTK_CONTAINER (button), alignment);
 
+#if GTK_MAJOR_VERSION > 1
+      pixbuf = gdk_pixbuf_new_from_inline (-1, tool_data[i].tango_icon_data, FALSE, NULL);
+      pixmap = gtk_image_new_from_pixbuf(pixbuf);
+#else
       pixmap = create_pixmap_widget (table->window, tool_data[i].icon_data, 22, 22);
+#endif
+ 
       gtk_container_add (GTK_CONTAINER (alignment), pixmap);
 
       gtk_signal_connect (GTK_OBJECT (button), "toggled",
@@ -655,7 +692,7 @@ create_toolbox ()
   GtkWidget *main_box;
   GtkWidget *box;
   GtkWidget *menubar;
-  GList     *device_list;
+  GList     *tmp_list;
   GtkAccelGroup *table;
   int i = 0;
 
@@ -714,16 +751,20 @@ create_toolbox ()
    * device would change to that and not change back. So we check
    * manually that all devices have a cursor, before establishing the check.
    */
-  device_list = gdk_input_list_devices ();
-  while (device_list)
+#if GTK_MAJOR_VERSION < 2
+#else
+  tmp_list = gdk_devices_list ();
+#endif
+#if GTK_MAJOR_VERSION < 2
+  tmp_list = gdk_input_list_devices ();
+  while (tmp_list)
     {
-      if (!((GdkDeviceInfo *)(device_list->data))->has_cursor)
+      if (!((GdkDeviceInfo *)(tmp_list->data))->has_cursor)
 	break;
-      
-      device_list = device_list->next;
+      tmp_list = tmp_list->next;
     }
 
-  if (!device_list)		/* all devices have cursor */
+  if (!tmp_list)		/* all devices have cursor */
     {
       gtk_signal_connect (GTK_OBJECT (window), "motion_notify_event",
 			  GTK_SIGNAL_FUNC (toolbox_check_device), NULL);
@@ -731,6 +772,10 @@ create_toolbox ()
       gtk_widget_set_events (window, GDK_POINTER_MOTION_MASK);
       gtk_widget_set_extension_events (window, GDK_EXTENSION_EVENTS_CURSOR);
     }
+#else
+      //if (!((GdkDevice *)(tmp_list->data))->has_cursor)
+	//break;
+#endif
 #ifndef VERTICAL_TOOLBAR
   main_box = gtk_vbox_new (FALSE, 1);
 #else
@@ -748,9 +793,11 @@ create_toolbox ()
 #ifdef WIN32
 	/* BUG: rsr suspects this is deprecated for Linux, too. */
 #else
+#if GTK_MAJOR_VERSION < 2
   gtk_tooltips_set_colors (tool_tips,
 			   &colors[11],
 			   &main_box->style->fg[GTK_STATE_NORMAL]);
+#endif
 #endif
   if (!show_tool_tips)
     gtk_tooltips_disable (tool_tips);
@@ -877,8 +924,8 @@ create_display_shell (int   gdisp_unique_id,
 		      (GtkSignalFunc) gdisplay_destroy,
 		      gdisp);
 
- /*  active display callback  */
- gtk_signal_connect (GTK_OBJECT (gdisp->shell), "button_press_event",
+  /*  active display callback  */
+  gtk_signal_connect (GTK_OBJECT (gdisp->shell), "button_press_event",
                       GTK_SIGNAL_FUNC (gdisplay_shell_events),
                       gdisp);
   gtk_signal_connect (GTK_OBJECT (gdisp->shell), "key_press_event",
@@ -915,7 +962,7 @@ create_display_shell (int   gdisp_unique_id,
   gtk_ruler_set_metric (GTK_RULER (gdisp->hrule), ruler_units);
   gtk_signal_connect_object (GTK_OBJECT (gdisp->shell), "motion_notify_event",
 			     (GtkSignalFunc) GTK_WIDGET_CLASS 
-				(GTK_OBJECT (gdisp->hrule)->klass)->motion_notify_event,
+				(GTK_OBJECT_GET_CLASS (gdisp->hrule))->motion_notify_event,
 			     GTK_OBJECT (gdisp->hrule));
   gtk_signal_connect (GTK_OBJECT (gdisp->hrule), "button_press_event",
 		      (GtkSignalFunc) gdisplay_hruler_button_press,
@@ -927,7 +974,7 @@ create_display_shell (int   gdisp_unique_id,
   gtk_ruler_set_metric (GTK_RULER (gdisp->vrule), ruler_units);
   gtk_signal_connect_object (GTK_OBJECT (gdisp->shell), "motion_notify_event",
 			     (GtkSignalFunc) GTK_WIDGET_CLASS 
-				(GTK_OBJECT (gdisp->vrule)->klass)->motion_notify_event,
+				(GTK_OBJECT_GET_CLASS (gdisp->vrule))->motion_notify_event,
 			     GTK_OBJECT (gdisp->vrule));
   gtk_signal_connect (GTK_OBJECT (gdisp->vrule), "button_press_event",
 		      (GtkSignalFunc) gdisplay_vruler_button_press,
@@ -941,7 +988,16 @@ create_display_shell (int   gdisp_unique_id,
   /* canvas */ 
   gdisp->canvas = gtk_drawing_area_new ();
   gtk_drawing_area_size (GTK_DRAWING_AREA (gdisp->canvas), n_width, n_height);
+#if 1
+  gtk_widget_set_events (gdisp->canvas, GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK | \
+                           /*GDK_POINTER_MOTION_HINT_MASK |*/ GDK_BUTTON_PRESS_MASK | \
+                           GDK_BUTTON_RELEASE_MASK | GDK_STRUCTURE_MASK | \
+                           GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK | \
+                           GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK | \
+                           GDK_PROXIMITY_OUT_MASK);
+#else
   gtk_widget_set_events (gdisp->canvas, CANVAS_EVENT_MASK);
+#endif
   gtk_widget_set_extension_events (gdisp->canvas, GDK_EXTENSION_EVENTS_ALL);
   GTK_WIDGET_SET_FLAGS (gdisp->canvas, GTK_CAN_FOCUS);
   gtk_object_set_user_data (GTK_OBJECT (gdisp->canvas), (gpointer) gdisp);
@@ -1354,12 +1410,16 @@ struct MessageBox
 {
   GtkWidget  *mbox;
   GtkCallback callback;
+  int         i;  
   gpointer    data;
 };
 
 static void message_box_close_callback (GtkWidget *, gpointer);
 static gint message_box_delete_callback (GtkWidget *, GdkEvent *, gpointer);
 
+# define MAX_TEXTS 25
+static GtkWidget *label_vbox[MAX_TEXTS+1];
+
 GtkWidget *
 message_box (const char        *orig,
 	     GtkCallback  callback,
@@ -1368,22 +1428,65 @@ message_box (const char        *orig,
   MessageBox *msg_box;
   GtkWidget *mbox;
   GtkWidget *vbox;
-  GtkWidget *label_vbox;
+  static GtkWidget *status_label[MAX_TEXTS+2];
   GtkWidget *label;
   GtkWidget *button;
   char *message = NULL;
   char *str;
   char *memory;
+  static int  texts[MAX_TEXTS+2], i;
+  static char *messages_texts[MAX_TEXTS+2];
+
+  if(!messages_texts[0])
+    for (i=0; i < MAX_TEXTS+2; ++i)
+    {
+      messages_texts[i] = 0;
+      label_vbox[i] = status_label[i] = 0;
+      texts[i] = 0;
+    }
 
   if (orig)
     message = g_strdup (orig);
   else
     return NULL;
 
+  i = 0;
+  while( texts[i] && label_vbox[i] )
+  {
+    if(strcmp(orig, messages_texts[i]) == 0 && label_vbox[i])
+    {
+      char *t = _("Message repeated %d times.");
+      char *m = g_strdup_printf (t, texts[i]);
+      if(!status_label[i])
+      {
+	  status_label[i] = gtk_label_new (m);
+	  gtk_box_pack_start (GTK_BOX (label_vbox[i]), status_label[i], TRUE, FALSE, 0);
+	  gtk_widget_show (status_label[i]);
+      }
+      gtk_label_set_text( GTK_LABEL(status_label[i]), m);
+      ++texts[i];
+      return NULL;
+    } else if(i == MAX_TEXTS) {
+      if(!messages_texts[i+1]) {
+        message = g_strdup (_("Too many massages. Giving up."));
+      } else {
+        ++texts[i+1];
+        return NULL;
+      }
+    }
+    ++i;
+  }
+
+
   memory = message;
+  messages_texts[i] = g_strdup (message);
+  status_label[i] = 0;
+  ++texts[i];
 
   msg_box = (MessageBox *) g_malloc_zero (sizeof (MessageBox));
 
+  msg_box->i = i;
+
   mbox = gtk_dialog_new ();
   gtk_window_set_wmclass (GTK_WINDOW (mbox), "gimp_message", PROGRAM_NAME);
   gtk_window_set_title (GTK_WINDOW (mbox), PROGRAM_NAME " Message");
@@ -1409,9 +1512,9 @@ message_box (const char        *orig,
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (mbox)->vbox), vbox);
   gtk_widget_show (vbox);
 
-  label_vbox = gtk_vbox_new (FALSE, 1);
-  gtk_box_pack_start (GTK_BOX (vbox), label_vbox, TRUE, FALSE, 0);
-  gtk_widget_show (label_vbox);
+  label_vbox[i] = gtk_vbox_new (FALSE, 1);
+  gtk_box_pack_start (GTK_BOX (vbox), label_vbox[i], TRUE, FALSE, 0);
+  gtk_widget_show (label_vbox[i]);
 
   str = message;
   while (*str != '\0')
@@ -1420,7 +1523,7 @@ message_box (const char        *orig,
 	{
 	  *str = '\0';
 	  label = gtk_label_new (message);
-	  gtk_box_pack_start (GTK_BOX (label_vbox), label, TRUE, FALSE, 0);
+	  gtk_box_pack_start (GTK_BOX (label_vbox[i]), label, TRUE, FALSE, 0);
 	  gtk_widget_show (label);
 	  message = str + 1;
 	}
@@ -1430,7 +1533,7 @@ message_box (const char        *orig,
   if (*message != '\0')
     {
       label = gtk_label_new (message);
-      gtk_box_pack_start (GTK_BOX (label_vbox), label, TRUE, FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (label_vbox[i]), label, TRUE, FALSE, 0);
       gtk_widget_show (label);
     }
 
@@ -1467,6 +1570,7 @@ message_box_close_callback (GtkWidget *w,
     (* msg_box->callback) (w, msg_box->data);
 
   /*  Destroy the box  */
+  label_vbox[msg_box->i] = 0;
   gtk_widget_destroy (msg_box->mbox);
 
   g_free (msg_box);
