@@ -157,7 +157,9 @@ layer_select_init (GImage  *gimage,
 	gtk_widget_draw (layer_select->layer_preview, NULL);
     }
 
+#if GTK_MAJOR_VERSION < 2
   gdk_key_repeat_disable ();
+#endif
   gdk_keyboard_grab (layer_select->shell->window, FALSE, time);
 }
 
@@ -244,7 +246,9 @@ static void
 layer_select_end (LayerSelect *layer_select,
 		  guint32      time)
 {
+#if GTK_MAJOR_VERSION < 2
   gdk_key_repeat_restore ();
+#endif
   gdk_keyboard_ungrab (time);
 
   gtk_widget_hide (layer_select->shell);
