@@ -266,13 +266,15 @@ look_profile_create(GImage *image, gint sample_depth)
     GSList *profiles = NULL;
     DWORD lcms_format_out;
     CMSTransform *transform;
+    Tag tag;
 
     gint num_pix = pow(sample_depth, 3);
 
     look_profile = g_new(LookProfile, 1);
     look_profile->image = image;
     look_profile->sample_depth = sample_depth;
-    look_profile->canvas= canvas_new (gimage_tag(image), num_pix, 1,
+    tag = gimage_tag(image);
+    look_profile->canvas= canvas_new (tag, num_pix, 1,
 #ifdef NO_TILES						  
 						  STORAGE_FLAT);
 #else
@@ -289,13 +291,13 @@ look_profile_create(GImage *image, gint sample_depth)
     {   input_profile = cms_get_srgb_profile();
     }
 
-    profiles = g_slist_append(profiles, lab_profile);
-    profiles = g_slist_append(profiles, input_profile);
-    lcms_format_out= cms_get_lcms_format(gimage_tag(image),input_profile);
-    transform = cms_get_transform(profiles, TYPE_Lab_16,
+    profiles = g_slist_append( profiles, lab_profile);
+    profiles = g_slist_append( profiles, input_profile);
+    lcms_format_out= cms_get_lcms_format( tag, input_profile );
+    transform = cms_get_transform( profiles, TYPE_Lab_16,
 						lcms_format_out,
 						INTENT_PERCEPTUAL,
-                                                cms_default_flags, 0, NULL);
+                                                cms_default_flags, 0,tag, NULL);
     g_slist_free(profiles);
 
     /* iterate over Lab space, converting to rgb, filling into picture */
@@ -479,7 +481,7 @@ look_profile_save (LookProfile *profile,
     profiles = g_slist_append(profiles, lab_profile);
     sample_info->transform = cms_get_transform(profiles,
                                        cms_get_lcms_format(t, input_profile),
-                                       TYPE_Lab_16, intent, flags, 0, NULL);
+                                       TYPE_Lab_16, intent, flags, 0, t, NULL);
 
     pixelarea_init(&sample_info->sample_area,
 		   profile->canvas,
@@ -866,6 +868,7 @@ _look_profile_gui_apply(_LookProfileGui *data)
     DWORD lcms_format;
     CMSTransform *transform;
     int i;
+    Tag tag = gimage_tag(data->display->gimage);
 
     if (image_profile == NULL)
     {   image_profile = cms_get_srgb_profile();
@@ -881,7 +884,7 @@ _look_profile_gui_apply(_LookProfileGui *data)
                                    gdisplay_get_cms_intent(data->display),
                                    gdisplay_get_cms_flags(data->display),
                                    gdisplay_get_cms_proof_intent(data->display),
-                                   NULL);
+                                   tag, NULL);
     g_slist_free(profiles);
     gimage_transform_colors(data->display->gimage, transform, TRUE);
     cms_return_transform(transform);
@@ -905,6 +908,7 @@ _look_profile_gui_apply_flipbook (_LookProfileGui *data)
     gint num_images = 0;
     gint count = 0;
     int i;
+    Tag tag = gimage_tag(data->display->gimage);
 
 
     if (data->display->bfm == NULL)
@@ -919,17 +923,23 @@ _look_profile_gui_apply_flipbook (_LookProfileGui *data)
     profiles = g_slist_append(profiles, (gpointer)image_profile);
     profiles = g_slist_concat(profiles, g_slist_copy(gdisplay_get_look_profile_pipe(data->display)));
     profiles = g_slist_append(profiles, (gpointer)image_profile);
-    lcms_format = cms_get_lcms_format(gimage_tag(data->display->gimage), image_profile);
+    lcms_format = cms_get_lcms_format( tag, image_profile);
     transform = cms_get_transform(profiles,
                                    lcms_format, lcms_format,
                                    gdisplay_get_cms_intent(data->display),
                                    gdisplay_get_cms_flags(data->display),
                                    gdisplay_get_cms_proof_intent(data->display),
-                                   NULL);
+                                   tag, NULL);
     g_slist_free(profiles);
 
     /* create progress dialog */
-    progress_dialog = gtk_window_new(GTK_WINDOW_DIALOG);    
+#if GTK_MAJOR_VERSION > 1
+      progress_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_type_hint (GTK_WINDOW(progress_dialog),
+                                GDK_WINDOW_TYPE_HINT_DIALOG);
+#else
+      progress_dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+#endif
     gtk_window_set_wmclass (GTK_WINDOW (progress_dialog), "progress", PROGRAM_NAME);
     gtk_window_set_title (GTK_WINDOW (progress_dialog), "Applying look to flipbook stores...");
     gtk_window_set_position(GTK_WINDOW(progress_dialog), GTK_WIN_POS_CENTER);
