@@ -49,6 +49,14 @@ extern int _fmode;
 #define  WAIT_ANY -1
 #endif   /*  WAIT_ANY  */
 
+#ifdef HAVE_OY
+#include <oyranos/oyranos.h>
+#include <oyranos/oyranos_config.h>
+#include <oyranos/oyranos_version.h>
+char *oyranos_temp_path = NULL;
+void *myAlloc(size_t n) { return calloc(sizeof(char), n); }
+#endif
+
 #define  CP_CHANGE_CODESET 0
 #ifdef __APPLE__
 #include <CoreFoundation/CoreFoundation.h>
@@ -164,10 +172,6 @@ int main (int argc, char **argv)
   /* Initialize variables */
   prog_name = argv[0];
 
-  /* Initialize Gtk toolkit */
-  gtk_set_locale ();
-  gtk_init (&argc, &argv);
-
   /* Where are we? */
   {
     int len = strlen(prog_name) * 2 + 128;
@@ -189,6 +193,30 @@ int main (int argc, char **argv)
       fp = fopen(t,"r");
       if(fp)
       {
+#ifdef HAVE_OY
+        /* set a profile temporary path */
+        if(strcmp(text, GetDirPrefix()) != 0)
+        {
+          int n = oyPathsCount(), i, has_path = 0;
+          oyranos_temp_path = myAlloc (strlen(GetDirPrefix()) +
+                     sizeof(OY_ICCDIRNAME) + 64);
+          sprintf(oyranos_temp_path, "%s%sshare%scolor%s%s",
+              text, DIR_SEPARATOR, DIR_SEPARATOR, DIR_SEPARATOR, OY_ICCDIRNAME);
+          for(i = 0; i < n; ++i)
+          {
+            char *temp = oyPathName(i, myAlloc);
+            if(strcmp(oyranos_temp_path, temp) == 0)
+              has_path = 1;
+            if(temp) free(temp);
+          }
+          if(!has_path)
+            oyPathAdd( oyranos_temp_path );
+          else {
+            free( oyranos_temp_path );
+            oyranos_temp_path = NULL;
+          }
+        }
+#endif
         SetDirPrefix( text );
         fclose(fp);
       }
@@ -199,11 +227,20 @@ int main (int argc, char **argv)
     sprintf (path, "%s%s%s", GetDirPrefix(), DIR_SEPARATOR, "share/locale");
   }
 
+#if GTK_MAJOR_VERSION > 1
+  setlocale(LC_ALL,"");
   cinepaint_init_i18n(path);
 # ifdef DEBUG
-  printf("Translation test: %s\n",gettext("About..."));
+  printf("Translation test: %s\n",gettext("About"));
 # endif
+#endif
+
+  /* Initialize Gtk toolkit */
+  gtk_init (&argc, &argv);
+
+#if GTK_MAJOR_VERSION < 2
   setlocale(LC_NUMERIC, "C");/* must use dot, not comma, as decimal separator */
+#endif
 
 #ifdef HAVE_PUTENV
   display_name = gdk_get_display ();
@@ -382,12 +419,18 @@ int main (int argc, char **argv)
   if (show_version || show_help)
     exit (0);
 
+#if GTK_MAJOR_VERSION > 1
+  g_log_set_handler(NULL,
+                    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+                    message_func_cb, NULL);
+#else
   g_set_message_handler (&message_func);
+#endif
 
 #ifdef WIN32
 
 #else
-# ifndef DEBUG
+# ifndef DEBUG_
   /* Handle some signals */
   signal (SIGHUP, on_signal);
   signal (SIGINT, on_signal);
@@ -419,6 +462,7 @@ int main (int argc, char **argv)
 #endif
   install_verify (init);
 
+
   /* Main application loop */
   if (!app_exit_finish_done ())
     gtk_main ();
@@ -435,14 +479,41 @@ int main (int argc, char **argv)
 #endif
   }
 
+#ifdef HAVE_OY
+  /* remove a profile temporary path */
+  if(oyranos_temp_path)
+  {
+    oyPathRemove( oyranos_temp_path );
+    free( oyranos_temp_path );
+  }
+#endif
+
   return 0;
 }
 
 static void
 init ()
 {
-	/*  Continue initializing  */
-	gimp_init (gimp_argc, gimp_argv);
+  /*  Continue initializing  */
+
+  /* Initialize the application */
+  app_init ();
+
+#if GTK_MAJOR_VERSION > 1
+  /* Why does gtk change LC_NUMERIC with the first window in gtk-2.4 ? beku */
+  {
+    char settxt[64];
+    if(setlocale (LC_NUMERIC, NULL))
+    {
+      snprintf( settxt,63, "export LC_NUMERIC=%s", setlocale(LC_NUMERIC, NULL));
+      putenv( settxt );
+      setenv("LC_NUMERIC", setlocale (LC_NUMERIC, NULL), 1);
+    } else
+      printf("%s:%d %s() no LC_NUMERIC set\n",__FILE__,__LINE__,__func__);
+  }
+#endif
+
+  gimp_init (gimp_argc, gimp_argv);
 }
 
 static int caught_fatal_sig = 0;
@@ -476,7 +547,7 @@ on_signal (int sig_num)
       fatal_error ("sigsegv caught");
       break;
     case SIGPIPE:
-      terminate ("sigpipe caught");
+      /*terminate*/printf ("sigpipe caught\n");
       break;
     case SIGTERM:
       terminate ("sigterm caught");
@@ -506,7 +577,7 @@ on_sig_child (int sig_num)
 
 
 
-#define TEXTLEN 48         
+#define TEXTLEN 128
 
 void
 fl_set_codeset_    ( const char* lang, const char* codeset_,
@@ -522,14 +593,16 @@ fl_set_codeset_    ( const char* lang, const char* codeset_,
         sprintf (codeset, codeset_);
  
           /* merge charset with locale string */
-#if (CP_CHANGE_CODESET == 1)
-        if((pos = strrchr(locale,'.')) != 0)
+        if(set_locale)
         {
-          *pos = 0;
-        } else
-          pos = & locale[strlen(locale)];
-        snprintf(pos, TEXTLEN-strlen(locale), ".%s",codeset);
-#endif
+          if((pos = strrchr(locale,'.')) != 0)
+          {
+            *pos = 0;
+          } else
+            pos = & locale[strlen(locale)];
+          snprintf(pos, TEXTLEN-strlen(locale), ".%s",codeset);
+        }
+
         /* 1b. set correct environment variable LANG */
         {
           char settxt[64];
@@ -541,7 +614,11 @@ fl_set_codeset_    ( const char* lang, const char* codeset_,
         /* 1c. set the locale info after LANG */
         if(set_locale)
         {
+#if GTK_MAJOR_VERSION < 2
           char *ptr = setlocale (LC_MESSAGES, "");
+#else
+          char *ptr = setlocale (LC_ALL, "");
+#endif
           if(ptr) snprintf( locale, TEXTLEN, ptr);
         }
       }
@@ -615,7 +692,11 @@ fl_initialise_locale( const char *domain, const char *locale_path,
   // set the locale info
   if(strlen(locale) && set_locale)
   {
+#if GTK_MAJOR_VERSION < 2
      setlocale (LC_MESSAGES, locale);
+#else
+     setlocale (LC_ALL, locale);
+#endif
   }
   if (tmp)
     snprintf(locale,TEXTLEN, tmp);
@@ -720,7 +801,7 @@ fl_initialise_locale( const char *domain, const char *locale_path,
 
       // good?
     if(getenv("LANG"))
-      printf( "LANG = %s\n", getenv("LANG") );
+      d_printf( getenv("LANG") );
   }
 
   if(strlen(locale))
@@ -749,6 +830,12 @@ cinepaint_init_i18n (const char *exec_path)
 
   int path_nr = 0;
 
+#if GTK_MAJOR_VERSION < 2
+  int set_locale = 1;
+#else
+  int set_locale = 0;
+#endif
+
   locale_paths[0] = LOCALEDIR;
   locale_paths[1] = "../po";
   locale_paths[2] = exec_path;
@@ -759,8 +846,8 @@ cinepaint_init_i18n (const char *exec_path)
 
   if ( path_nr >= 0 )
   {
-    fl_initialise_locale( domain[0], locale_paths[path_nr], 1 );
-    fl_initialise_locale( domain[1], locale_paths[path_nr], 1 );
+    fl_initialise_locale( domain[0], locale_paths[path_nr], set_locale );
+    fl_initialise_locale( domain[1], locale_paths[path_nr], set_locale );
     textdomain (domain[0]);
     printf("Locale found in %s\n", locale_paths[path_nr]);
     setenv("TEXTDOMAINDIR", locale_paths[path_nr], 1);
