@@ -219,8 +219,8 @@ static GtkItemFactoryEntry image_entries[] =
   { "/View/Zoom/1:8", NULL, view_zoom_1_8_callback, 0 },
   { "/View/Zoom/1:16", NULL, view_zoom_1_16_callback, 0 },
   { "/View/Window Info...", "<control><shift>I", view_window_info_cmd_callback, 0 },
-  { "/View/Toggle Rulers", "<control><shift>R", view_toggle_rulers_cmd_callback, 0, "<ToggleItem>" },
-  { "/View/Toggle Guides", "<control><shift>T", view_toggle_guides_cmd_callback, 0, "<ToggleItem>" },
+  { "/View/Show Rulers", "<control><shift>R", view_toggle_rulers_cmd_callback, 0, "<ToggleItem>" },
+  { "/View/Show Guides", "<control><shift>T", view_toggle_guides_cmd_callback, 0, "<ToggleItem>" },
   { "/View/Snap To Guides", NULL, view_snap_to_guides_cmd_callback, 0, "<ToggleItem>" },
   { "/View/---", NULL, NULL, 0, "<Separator>" },
   { "/View/Slide Show", NULL, sfm_slide_show_callback, 0, NULL },
@@ -436,6 +436,9 @@ static void
 menus_dummy_translate()
 {
   _("Help");
+  _("About...");
+  _("Bugs & Kudos...");
+  _("Tips...");
   _("File");
   _("New...");
   _("New From");
@@ -712,7 +715,12 @@ sfm_menu_add_accel_cb(
                       
      if (related_widget) {
         gtk_widget_add_accelerator(
-                related_widget, gtk_signal_name(item->accelerator_signal),
+                related_widget,
+#if GTK_MAJOR_VERSION > 1
+                                "activate",
+#else
+                                gtk_signal_name(item->accelerator_signal),
+#endif
                 cur_gdisp->menubar_fac->accel_group, accel_key, accel_mods, accel_flags);
      }
      else {
@@ -767,7 +775,12 @@ pop_up_menu_add_accel_cb(
                       
      if (related_widget) {
         gtk_widget_add_accelerator(
-                related_widget, gtk_signal_name(item->accelerator_signal),
+                related_widget,
+#if GTK_MAJOR_VERSION > 1
+                                "activate",
+#else
+                                gtk_signal_name(item->accelerator_signal),
+#endif
                 cur_gdisp->menubar_fac->accel_group, accel_key, accel_mods, accel_flags);
      }
      else {
@@ -828,7 +841,12 @@ pull_down_menu_add_accel_cb(
                 gtk_item_factory_get_widget (cur_gdisp->menubar_fac, buff);
         if (related_widget) {
            gtk_widget_add_accelerator(
-                related_widget, gtk_signal_name(item->accelerator_signal),
+                related_widget,
+#if GTK_MAJOR_VERSION > 1
+                                "activate",
+#else
+                                gtk_signal_name(item->accelerator_signal),
+#endif
                 cur_gdisp->menubar_fac->accel_group, accel_key, accel_mods, accel_flags);
         }
         else {
@@ -845,7 +863,12 @@ pull_down_menu_add_accel_cb(
          gtk_item_factory_get_widget (image_factory, buff);
   if (related_widget) {
      gtk_widget_add_accelerator(
-            related_widget, gtk_signal_name(item->accelerator_signal),
+            related_widget,
+#if GTK_MAJOR_VERSION > 1
+                                "activate",
+#else
+                                gtk_signal_name(item->accelerator_signal),
+#endif
             image_factory->accel_group, accel_key, accel_mods, accel_flags);
   }
   else {
@@ -898,8 +921,10 @@ sfm_menu_rem_accel_cb(
         related_widget = 
                 gtk_item_factory_get_widget (cur_gdisp->menubar_fac, buff);
         if (related_widget) {
+#if GTK_MAJOR_VERSION < 2
            gtk_widget_remove_accelerators(
-                related_widget, gtk_signal_name(item->accelerator_signal), TRUE);
+                related_widget, gtk_signal_name(item->accelerator_signal),TRUE);
+#endif
         }
         else {
            d_printf("Could not find widget %s\n", buff);
@@ -914,8 +939,10 @@ sfm_menu_rem_accel_cb(
   related_widget = 
          gtk_item_factory_get_widget (image_factory, buff);
   if (related_widget) {
+#if GTK_MAJOR_VERSION < 2
      gtk_widget_remove_accelerators(
             related_widget, gtk_signal_name(item->accelerator_signal), TRUE);
+#endif
   }
   else {
      d_printf("Could not find widget %s\n", buff);
@@ -966,8 +993,10 @@ pull_down_menu_rem_accel_cb(
         related_widget = 
                 gtk_item_factory_get_widget (cur_gdisp->menubar_fac, buff);
         if (related_widget) {
+#if GTK_MAJOR_VERSION < 2
            gtk_widget_remove_accelerators(
                 related_widget, gtk_signal_name(item->accelerator_signal), TRUE);
+#endif
         }
         else {
            d_printf("Could not find widget %s\n", buff);
@@ -982,8 +1011,10 @@ pull_down_menu_rem_accel_cb(
   related_widget = 
          gtk_item_factory_get_widget (image_factory, buff);
   if (related_widget) {
+#if GTK_MAJOR_VERSION < 2
      gtk_widget_remove_accelerators(
             related_widget, gtk_signal_name(item->accelerator_signal), TRUE);
+#endif
   }
   else {
      d_printf("Could not find widget %s\n", buff);
@@ -1031,8 +1062,10 @@ pop_up_menu_rem_accel_cb(
      related_widget =  gtk_item_factory_get_widget (cur_gdisp->menubar_fac, buff);
                       
      if (related_widget) {
+#if GTK_MAJOR_VERSION < 2
         gtk_widget_remove_accelerators(
                 related_widget, gtk_signal_name(item->accelerator_signal), TRUE);
+#endif
      }
      else {
         d_printf("Could not find widget %s\n", buff);
@@ -1087,10 +1120,12 @@ menus_get_image_menubar(GDisplay *gdisp)
        * synchronized. To do this, we need to be notified when a menu
        * accelerator is added or removed from one of the menus.  We will then
        * propagate these changes to the other menus by hand */
+#if GTK_MAJOR_VERSION < 2
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "add-accelerator", 
                   GTK_SIGNAL_FUNC(pull_down_menu_add_accel_cb), gdisp);
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "remove-accelerator", 
                   GTK_SIGNAL_FUNC(pull_down_menu_rem_accel_cb), gdisp);
+#endif
       cur_wid_list = cur_wid_list->next;
     }
     cur_slist = cur_slist->next;
@@ -1169,7 +1204,11 @@ menus_get_sfm_store_menu (GtkWidget **menu, GtkAccelGroup **accel_group, GDispla
 
 
 	  filename = g_strconcat (gimp_directory (), "/menurc", NULL);
+#if GTK_MAJOR_VERSION > 1
+          gtk_accel_map_load(filename);
+#else
 	  gtk_item_factory_parse_rc (filename);
+#endif
 	  g_free (filename);
 	  sfm_store_factory_init = FALSE; 
   }
@@ -1366,7 +1405,11 @@ menus_quit ()
 
   sprintf(tmp_filename, "%s.%d", "/tmp/.menurc", getpid());
   sprintf(filename, "%s/menurc", gimp_directory ());
+#if GTK_MAJOR_VERSION > 1
+  gtk_accel_map_save(tmp_filename);
+#else
   gtk_item_factory_dump_rc (tmp_filename, NULL, TRUE); 
+#endif
 
   // run through the menurc file and remove all the extra entries
   menus_strip_extra_entries(tmp_filename, filename); 
@@ -1401,10 +1444,12 @@ menus_setup_popup_callbacks(GtkItemFactory *fac)
        * synchronized. To do this, we need to be notified when a menu
        * accelerator is added or removed from one of the menus.  We will then
        * propagate these changes to the other menus by hand */
+#if GTK_MAJOR_VERSION < 2
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "add-accelerator", 
                   GTK_SIGNAL_FUNC(pop_up_menu_add_accel_cb), 0);
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "remove-accelerator", 
                   GTK_SIGNAL_FUNC(pop_up_menu_rem_accel_cb), 0);
+#endif
       cur_wid_list = cur_wid_list->next;
     }
     cur_slist = cur_slist->next;
@@ -1430,17 +1475,18 @@ menus_setup_sfm_callbacks(GtkItemFactory *fac)
        * synchronized. To do this, we need to be notified when a menu
        * accelerator is added or removed from one of the menus.  We will then
        * propagate these changes to the other menus by hand */
+#if GTK_MAJOR_VERSION < 2
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "add-accelerator", 
                   GTK_SIGNAL_FUNC(sfm_menu_add_accel_cb), 0);
       gtk_signal_connect(GTK_OBJECT(cur_wid_list->data), "remove-accelerator", 
                   GTK_SIGNAL_FUNC(sfm_menu_rem_accel_cb), 0);
+#endif
       cur_wid_list = cur_wid_list->next;
     }
     cur_slist = cur_slist->next;
   }
 }
 
-
 static void
 menus_init ()
 {
@@ -1503,7 +1549,29 @@ menus_init ()
       */menus_setup_sfm_callbacks(sfm_store_factory);
       
       filename = g_strconcat (gimp_directory (), "/menurc", NULL);
+#if GTK_MAJOR_VERSION > 1
+      gtk_accel_map_load(filename);
+
+#if 0
+enum {
+  ADD_ACCELERATOR,
+  REMOVE_ACCELERATOR,
+  LAST_SIGNAL
+};
+
+static gint menu_signals[LAST_SIGNAL] = { 0 };
+
+      menu_signals[ADD_ACCELERATOR] =
+      gtk_signal_new ("add-accelerator",
+                    GTK_RUN_LAST,
+                    G_TYPE_FROM_CLASS (sfm_store_factory),
+                    GTK_SIGNAL_OFFSET (GtkObjectClass, add_accelerator),
+                    gtk_signal_default_marshaller,
+                    GTK_TYPE_NONE, 0);
+#endif
+#else
       gtk_item_factory_parse_rc (filename);
+#endif
       g_free (filename);
     }
 }
