@@ -669,15 +669,15 @@ palette_entries_load (char *filename)
 	{
 	  tok = strtok (str, " \t");
 	  if (tok)
-	    r = atof (tok);
+	    r = atof (tok) / 255.;
 
 	  tok = strtok (NULL, " \t");
 	  if (tok)
-	    g = atof (tok);
+	    g = atof (tok) / 255.;
 
 	  tok = strtok (NULL, " \t");
 	  if (tok)
-	    b = atof (tok);
+	    b = atof (tok) / 255.;
 
 	  tok = strtok (NULL, "\n");
 
@@ -720,6 +720,7 @@ palette_entries_save (PaletteEntriesP  palette,
   FILE * fp;
   GSList * list;
   PaletteEntryP entry;
+  char *lnc = 0, *tmp;
 
   if (! filename)
     return;
@@ -734,16 +735,29 @@ palette_entries_save (PaletteEntriesP  palette,
   fprintf (fp, "GIMP Palette\n");
   fprintf (fp, "# %s -- GIMP Palette file\n", palette->name);
 
+#ifdef ENABLE_NLS
+  lnc = setlocale(LC_NUMERIC, 0);
+  if(lnc) {
+    tmp= strdup(lnc);
+    lnc = tmp;
+  }
+  setlocale(LC_NUMERIC, "C");
+#endif
+
   list = palette->colors;
   while (list)
     {
       entry = (PaletteEntryP) list->data;
-      fprintf (fp, "%f %f %f\t%s\n", entry->color[0], entry->color[1],
-	       entry->color[2], entry->name);
+      fprintf (fp, "%f %f %f\t%s\n", entry->color[0]*255., entry->color[1]*255.,
+	       entry->color[2]*255., entry->name);
       list = g_slist_next (list);
     }
 
   /*  Clean up  */
+#ifdef ENABLE_NLS
+  setlocale(LC_NUMERIC, lnc);
+  if(lnc) free(lnc);
+#endif
   fclose (fp);
 }
 
