@@ -285,7 +285,12 @@ pattern_popup_open (PatternSelectP psp,
   x = (x + pattern_width > scr_w) ? scr_w - pattern_width : x;
   y = (y + pattern_height > scr_h) ? scr_h - pattern_height : y;
   gtk_preview_size (GTK_PREVIEW (psp->pattern_preview), pattern_width, pattern_height);
+#if GTK_MAJOR_VERSION > 1
+  gtk_widget_show (psp->pattern_popup);
+  gtk_window_move (GTK_WINDOW(psp->pattern_popup), x, y); 
+#else
   gtk_widget_popup (psp->pattern_popup, x, y);
+#endif
 
   /*  Draw the pattern  */
   buf = g_new (gchar, pattern_width * 3);
