@@ -952,10 +952,25 @@ procedural_db_proc_arg (Argument *args)
   if (proc != NULL && (arg_num >= 0 && arg_num < proc->num_args))
     {
       arg = &proc->args[arg_num];
-      return_args = procedural_db_return_args (&procedural_db_proc_arg_proc, TRUE);
-      return_args[1].value.pdb_int = arg->arg_type;
-      return_args[2].value.pdb_pointer = g_strdup (arg->name);
-      return_args[3].value.pdb_pointer = g_strdup (arg->description);
+      if(arg)
+      {
+        return_args = procedural_db_return_args (&procedural_db_proc_arg_proc, TRUE);
+        if(return_args)
+        {
+          return_args[1].value.pdb_int = arg->arg_type;
+          return_args[2].value.pdb_pointer = g_strdup (arg->name);
+          return_args[3].value.pdb_pointer = g_strdup (arg->description);
+#ifdef DEBUG_
+          printf("%s:%d proc_name: %s arg[%d,%d] %s \"%s\"\n",__FILE__,__LINE__,
+                  proc_name, arg_num, arg->arg_type, arg->name,
+                  arg->description);
+#endif
+        } else
+          printf("%s:%d no return_args, arg_num: %d/%d %s\n",__FILE__,__LINE__,
+                  arg_num, proc->num_args, proc_name);
+      } else
+        printf("%s:%d no arg, arg_num: %d/%d %s\n",__FILE__,__LINE__,
+                arg_num, proc->num_args, proc_name);
     }
   else
     return_args = procedural_db_return_args (&procedural_db_proc_arg_proc, FALSE);
