@@ -116,6 +116,7 @@ double    default_threshold = .05;
 int       stingy_memory_use = 0;
 int       allow_resize_windows = 0;
 int       no_cursor_updating = 0;
+int       toolbox_icons_bw = 0;
 int       preview_size = 64;
 int       show_rulers = TRUE;
 int       ruler_units = GTK_PIXELS;
@@ -177,7 +178,7 @@ int       cms_open_action = 0;
 int       cms_mismatch_action = 0;
 int       cms_manage_by_default = TRUE;
 #ifdef HAVE_OY
-int       cms_oyranos = FALSE;
+int       cms_oyranos = TRUE;
 #else
 int       cms_oyranos = FALSE;
 #endif
@@ -289,6 +290,8 @@ static ParseFunc funcs[] =
   { "cursor-updating",       TT_BOOLEAN,    NULL, &no_cursor_updating },
   { "no-cursor-updating",    TT_BOOLEAN,    &no_cursor_updating, NULL },
   { "preview-size",          TT_XPREVSIZE,  NULL, NULL },
+  { "toolbox-icons-bw",      TT_BOOLEAN,    &toolbox_icons_bw, NULL },
+  { "toolbox-icons-colour",  TT_BOOLEAN,    NULL, &toolbox_icons_bw },
   { "show-rulers",           TT_BOOLEAN,    &show_rulers, NULL },
   { "dont-show-rulers",      TT_BOOLEAN,    NULL, &show_rulers },
   { "ruler-units",           TT_XRULERUNIT, NULL, NULL },
@@ -1762,6 +1765,10 @@ parse_device (gpointer val1p,
 		axes[i] = GDK_AXIS_XTILT;
 	      else if (!strcmp ("ytilt", token_sym))
 		axes[i] = GDK_AXIS_YTILT;
+#if GTK_MAJOR_VERSION > 1
+	      else if (!strcmp ("wheel", token_sym))
+		axes[i] = GDK_AXIS_WHEEL;
+#endif
 	      else
 		goto error;
 	    }
