@@ -17,6 +17,7 @@
  */
 #include <stdlib.h>
 #include <stdio.h> 
+#include "libgimp/gimpintl.h"
 #include "appenv.h"
 #include "gdisplay.h"
 #include "gimage_mask.h"
@@ -115,25 +116,25 @@ create_selection_options (ToolType tool_type)
   switch (tool_type)
     {
     case RECT_SELECT:
-      label = gtk_label_new ("Rectangular Select Options");
+      label = gtk_label_new (_("Rectangular Select Options"));
       break;
     case ELLIPSE_SELECT:
-      label = gtk_label_new ("Elliptical Selection Options");
+      label = gtk_label_new (_("Elliptical Selection Options"));
       break;
     case FREE_SELECT:
-      label = gtk_label_new ("Free-hand Selection Options");
+      label = gtk_label_new (_("Free-hand Selection Options"));
       break;
     case FUZZY_SELECT:
-      label = gtk_label_new ("Fuzzy Selection Options");
+      label = gtk_label_new (_("Fuzzy Selection Options"));
       break;
     case BEZIER_SELECT:
-      label = gtk_label_new ("Bezier Selection Options");
+      label = gtk_label_new (_("Bezier Selection Options"));
       break;
     case ISCISSORS:
-      label = gtk_label_new ("Intelligent Scissors Options");
+      label = gtk_label_new (_("Intelligent Scissors Options"));
       break;
     case BY_COLOR_SELECT:
-      label = gtk_label_new ("By-Color Select Options");
+      label = gtk_label_new (_("By-Color Select Options"));
       break;
     default:
       break;
@@ -153,7 +154,7 @@ create_selection_options (ToolType tool_type)
     case FUZZY_SELECT:
     case ISCISSORS:
     case BY_COLOR_SELECT:
-      sample_merged_toggle = gtk_check_button_new_with_label ("Sample Merged");
+      sample_merged_toggle = gtk_check_button_new_with_label (_("Sample Merged"));
       gtk_box_pack_start (GTK_BOX (vbox), sample_merged_toggle, FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (sample_merged_toggle), "toggled",
 			  (GtkSignalFunc) selection_toggle_update,
@@ -168,7 +169,7 @@ create_selection_options (ToolType tool_type)
   /*  the antialias toggle button  */
   if (tool_type != RECT_SELECT)
     {
-      antialias_toggle = gtk_check_button_new_with_label ("Antialiasing");
+      antialias_toggle = gtk_check_button_new_with_label (_("Antialiasing"));
       gtk_box_pack_start (GTK_BOX (vbox), antialias_toggle, FALSE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (antialias_toggle), "toggled",
 			  (GtkSignalFunc) selection_toggle_update,
@@ -178,7 +179,7 @@ create_selection_options (ToolType tool_type)
     }
 
   /*  the feather toggle button  */
-  feather_toggle = gtk_check_button_new_with_label ("Feather");
+  feather_toggle = gtk_check_button_new_with_label (_("Feather"));
   gtk_box_pack_start (GTK_BOX (vbox), feather_toggle, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (feather_toggle), "toggled",
 		      (GtkSignalFunc) selection_toggle_update,
@@ -190,7 +191,7 @@ create_selection_options (ToolType tool_type)
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  label = gtk_label_new ("Feather Radius");
+  label = gtk_label_new (_("Feather Radius"));
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -211,7 +212,7 @@ create_selection_options (ToolType tool_type)
 
     hbox = gtk_hbox_new (FALSE, 1);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-    label = gtk_label_new ("Threshold");
+    label = gtk_label_new (_("Threshold"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
     threshold_text = gtk_entry_new ();
@@ -228,7 +229,7 @@ create_selection_options (ToolType tool_type)
     hbox = gtk_hbox_new (FALSE, 1);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new ("Threshold:");
+    label = gtk_label_new (_("Threshold:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
 
