@@ -191,7 +191,7 @@ sfm_delete_callback (GtkWidget *w, GdkEvent *e, gpointer data)
   if (sfm->add_dialog) gtk_widget_hide (sfm->add_dialog);
   if (sfm->chg_frame_dialog) gtk_widget_hide (sfm->chg_frame_dialog);
   gtk_widget_hide (sfm->shell);
-  gtk_widget_destroy (sfm);
+  gtk_widget_destroy (GTK_WIDGET(sfm));
   return TRUE; 
 }
 
@@ -231,6 +231,7 @@ sfm_create_gui (GDisplay *disp)
 
   check_names[0] = _("Auto Save");
   check_names[1] = _("Set AofI");
+  /* Area of Interesst */
   check_names[2] = _("AofI");
 
   flip_button[0].tooltip = _("Play Backwards");
@@ -239,9 +240,12 @@ sfm_create_gui (GDisplay *disp)
   flip_button[3].tooltip = _("Flip Forward");
   flip_button[4].tooltip = _("Play Forward");
 
+  /* "readonly" abbreviation */
   store_col_name[0] = _("RO");
+  /* "advance" abbreviation */
   store_col_name[1] = _("Adv");
   store_col_name[2] = _("F");
+  /* "background" abbreviation */
   store_col_name[3] = _("Bg");
   store_col_name[4] = "*";
   store_col_name[5] = _("Filename");
@@ -259,7 +263,7 @@ sfm_create_gui (GDisplay *disp)
   disp->bfm->sfm->chg_frame_dialog = 0;
   disp->bfm->sfm->readonly = 0; 
   disp->bfm->sfm->play = 0; 
-  disp->bfm->sfm->load_smart = 0; 
+  disp->bfm->sfm->load_smart = 1; 
 
   disp->bfm->sfm->s_x = disp->bfm->sfm->sx = 0;
   disp->bfm->sfm->s_y = disp->bfm->sfm->sy = 0;
@@ -297,6 +301,8 @@ sfm_create_gui (GDisplay *disp)
 #endif
 
   menus_get_sfm_store_menu (&menubar, &disp->bfm->sfm->accel_group, disp);
+  if(disp->bfm->sfm->load_smart)
+    menus_set_state("<sfm_menu>/Dir/Load Smart", TRUE);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (disp->bfm->sfm->shell)->vbox), menubar, FALSE, FALSE, 0);
   gtk_widget_reparent (menubar, GTK_WIDGET (GTK_DIALOG (disp->bfm->sfm->shell)->vbox));
   gtk_widget_show (menubar);
@@ -1488,11 +1494,14 @@ sfm_store_recent_dest_callback (GtkWidget *w, gpointer data)
 }
 
 void 
-sfm_store_load_smart_callback (GtkWidget *w, gpointer data)
+sfm_store_load_smart_callback (GtkWidget *widget, gpointer data)
 {
   GDisplay *disp = (GDisplay *)data;
 
-  disp->bfm->sfm->load_smart = disp->bfm->sfm->load_smart ? 0 : 1; 
+  if(GTK_CHECK_MENU_ITEM (widget)->active)
+    disp->bfm->sfm->load_smart = 1;
+  else
+    disp->bfm->sfm->load_smart = 0;
   bfm_onionskin_rm (disp);
 }
 
@@ -2178,22 +2187,22 @@ sfm_store_add_dialog_create (GDisplay *disp)
   char *options[3] =
     {
       "Load next frames",
-      "Load prev frames",
-      "Load copies of cur frame"
+      "Load previous frames",
+      "Load copies of current frame"
     };
 
   static ActionAreaItem offset_action_items[1] =
     {
-	{ "Ok", sfm_stores_add_dialog_ok_callback, NULL, NULL },
+	{ "OK", sfm_stores_add_dialog_ok_callback, NULL, NULL },
     };
 
   if (sfm_check (disp)) return;
   fm = disp->bfm->sfm;
 
   options[0] = _("Load next frames");
-  options[1] = _("Load prev frames");
-  options[2] = _("Load copies of cur frame");
-  offset_action_items[0].label = _("Ok");
+  options[1] = _("Load previous frames");
+  options[2] = _("Load copies of current frame");
+  offset_action_items[0].label = _("OK");
 
   if (!fm->add_dialog)
     {
@@ -2464,10 +2473,10 @@ sfm_frame_change_dialog_create (GDisplay *disp)
 
   static ActionAreaItem offset_action_items[1] =
     {
-	{ "Ok", sfm_store_change_frame_dialog_ok_callback, NULL, NULL },
+	{ "OK", sfm_store_change_frame_dialog_ok_callback, NULL, NULL },
     };
 
-  offset_action_items[0].label = _("Ok");
+  offset_action_items[0].label = _("OK");
 
   if (!fm)
     return;
