@@ -55,10 +55,16 @@ tips_dialog_create ()
 
   if (!tips_dialog)
     {
+#if GTK_MAJOR_VERSION > 1
+      tips_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_type_hint (GTK_WINDOW(tips_dialog),
+                                GDK_WINDOW_TYPE_HINT_DIALOG);
+#else
       tips_dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+#endif
       minimize_register(tips_dialog);
       gtk_window_set_wmclass (GTK_WINDOW (tips_dialog), "tip_of_the_day", PROGRAM_NAME);
-      gtk_window_set_title (GTK_WINDOW (tips_dialog), PROGRAM_NAME "Tips");
+      gtk_window_set_title (GTK_WINDOW (tips_dialog), _("Tip of the day"));
       gtk_window_position (GTK_WINDOW (tips_dialog), GTK_WIN_POS_CENTER);
       gtk_signal_connect (GTK_OBJECT (tips_dialog), "delete_event",
 			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
@@ -103,27 +109,27 @@ tips_dialog_create ()
       gtk_box_pack_start (GTK_BOX (hbox1), tips_label, TRUE, TRUE, 3);
       gtk_widget_show (tips_label);
 
-      button_close = gtk_button_new_with_label ("Close");
+      button_close = gtk_button_new_with_label (_("Close"));
       gtk_signal_connect (GTK_OBJECT (button_close), "clicked",
 			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
       gtk_box_pack_end (GTK_BOX (hbox2), button_close, FALSE, TRUE, 0);
       gtk_widget_show (button_close);
 
-      button_next = gtk_button_new_with_label ("Next Tip");
+      button_next = gtk_button_new_with_label (_("Next"));
       gtk_signal_connect (GTK_OBJECT (button_next), "clicked",
 			  GTK_SIGNAL_FUNC (tips_show_next),
 			  (gpointer) "next");
       gtk_box_pack_end (GTK_BOX (hbox2), button_next, FALSE, TRUE, 0);
       gtk_widget_show (button_next);
 
-      button_prev = gtk_button_new_with_label ("Prev. Tip");
+      button_prev = gtk_button_new_with_label (_("Previous"));
       gtk_signal_connect (GTK_OBJECT (button_prev), "clicked",
 			  GTK_SIGNAL_FUNC (tips_show_next),
 			  (gpointer) "prev");
       gtk_box_pack_end (GTK_BOX (hbox2), button_prev, FALSE, TRUE, 0);
       gtk_widget_show (button_prev);
 
-      button_check = gtk_check_button_new_with_label ("Show tip next time");
+      button_check = gtk_check_button_new_with_label (_("Show tips at startup"));
       gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button_check),
 				   show_tips);
       gtk_signal_connect (GTK_OBJECT (button_check), "toggled",
