@@ -135,6 +135,7 @@ typedef enum
   EXPOSE_IMAGE
 } ToolType;
 
+
 #define XButtonEvent GdkEventButton
 #define XMotionEvent GdkEventMotion
 
@@ -190,6 +191,9 @@ extern Tool * active_tool;
 extern ToolType active_tool_type;
 extern Layer * active_tool_layer;
 extern ToolInfo tool_info[];
+/* Zum Debuggen von acitve_tool->private->core */
+extern DrawCore* active_draw_core;
+
 
 /*  Function declarations  */
 
@@ -206,4 +210,17 @@ void     active_tool_control       (int, void *);
 /*  Standard member functions  */
 void     standard_arrow_keys_func  (Tool *, GdkEventKey *, gpointer);
 
+
+/*  Debug helpers - added by hartmut.sbosny@gmx.de [hsbo] */
+#ifdef DEBUG
+extern const char* const TOOL_STATE_NAMES[];
+extern const char* const TOOL_ACTION_NAMES[];
+extern const char* const TOOL_TYPE_NAMES[];
+
+const char* tool_state_name (int state);
+const char* tool_action_name (int action);
+const char* tool_type_name (Tool *);
+#endif
+
+
 #endif  /*  __TOOLS_H__  */
