@@ -76,7 +76,14 @@ static void       gimp_loop          (void);
 static void       gimp_config        (GPConfig *config);
 static void       gimp_proc_run      (GPProcRun *proc_run);
 static void       gimp_temp_proc_run (GPProcRun *proc_run);
-static void       gimp_message_func  (char *str);
+#if GTK_MAJOR_VERSION > 1
+DLL_API void      gimp_message_func  (const gchar   *log_domain,
+                                                 GLogLevelFlags log_level,
+                                                 const gchar   *message,
+                                                 gpointer       user_data);
+#else
+DLL_API void      gimp_message_func  (char *str);
+#endif
 
 #ifdef WIN32
 extern int _fmode;
@@ -95,6 +102,9 @@ const guint gimp_major_version = MAJOR_VERSION;
 const guint gimp_minor_version = MINOR_VERSION;
 const guint gimp_micro_version = MICRO_VERSION;
 
+int   argc = 0;
+char **argv = {""};
+
 static gdouble _gamma_val;
 static gint _install_cmap;
 static gint _use_xshm;
@@ -109,6 +119,60 @@ static int is_quitting;
 
 GPlugInInfo PLUG_IN_INFO_LIB;
 
+int plugin_main (int argc_, char **argv_, const GPlugInInfo *p)
+{
+  argc = argc_;
+  argv = argv_;
+
+# ifdef DEBUG
+  printf("%s:%d\n",__FILE__,__LINE__);
+# endif
+  { /* allow for plug-in debugging */
+    int dbg = 0;
+    if(!getenv("CP_DBG_PLUG_INS") &&
+       getenv("CP_DBG_PLUG_IN"))
+    {
+      const char *plugin_name = getenv("CP_DBG_PLUG_IN");
+      if(plugin_name)
+      {
+        if( strstr( argv[0], plugin_name ) != NULL )
+          dbg = 1;
+      } else
+        dbg = 1;
+    }
+    if(dbg)
+    {
+      fprintf(stderr, "%s:%d %s() running %s in GDB:  attach ",
+              __FILE__, __LINE__, __func__, strrchr(argv[0],'/') );
+      system("echo $PPID");
+    }
+    while(dbg)
+    {
+      dbg = dbg;
+    }
+  }
+
+# if GTK_MAJOR_VERSION > 1
+  /* What better idea to prevent gtk2 from taking hands on locale? beku */
+  setlocale(LC_NUMERIC, getenv("LC_NUMERIC"));
+# ifdef DEBUG
+  {
+    char *p[3];
+    p[0] = getenv("LC_NUMERIC");
+    p[1] = setlocale(LC_NUMERIC,NULL);
+    p[2] = getenv("TEXTDOMAINDIR");
+    printf("%s:%d %s() %s %s %s\n",__FILE__,__LINE__,__func__,
+      p[0]?p[0]:"", p[1]?p[1]:"", p[2]?p[2]:"");
+  }
+# endif
+# endif
+
+  gtk_init (&argc, &argv);
+
+  set_gimp_PLUG_IN_INFO(p);
+  return gimp_main (argc, argv);
+}
+
 void set_gimp_PLUG_IN_INFO (const GPlugInInfo *p)
 {
   PLUG_IN_INFO_LIB = *p;
@@ -117,8 +181,8 @@ void set_gimp_PLUG_IN_INFO (const GPlugInInfo *p)
 int
 gimp_main (int   argc,
 	   char *argv[])
-{ 
-	if ((argc < 4) || (strcmp (argv[1], "-gimp") != 0))
+{
+    if ((argc < 4) || (strcmp (argv[1], "-gimp") != 0))
     {
       g_print ("%s is a gimp plug-in and must be run by the gimp to be used\n", argv[0]);
       return 1;
@@ -174,17 +238,37 @@ gimp_main (int   argc,
 	gimp_quit ();
 	return 0;
     }
-  else
-  {
-    int yes = 1;
 
-    if( getenv("CP_DBG_PLUG_IN") )
-      if( strstr( argv[0], getenv("CP_DBG_PLUG_IN") ) )
-        while (yes)
-          ;
-  }
+#if GTK_MAJOR_VERSION > 1
+  g_log_set_handler("Gdk",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
 
+  g_log_set_handler("Gtk",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+		    
+  g_log_set_handler("GLib",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+		    
+  g_log_set_handler("GLib-GObject",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+		    
+  g_log_set_handler("GModule",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+		    
+  g_log_set_handler("GThread",
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+  g_log_set_handler(NULL,
+		    G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION,
+		    gimp_message_func, NULL);
+#else
   g_set_message_handler ((GPrintFunc) gimp_message_func);
+#endif
 
   temp_proc_ht = g_hash_table_new (&g_str_hash, &g_str_equal);
 	is_quitting=0;
@@ -256,7 +340,7 @@ gimp_get_data (gchar *  id,
 }
 
 void
-gimp_message (char *message)
+gimp_message (const char *message)
 {
   GParam *return_vals;
   int nreturn_vals;
@@ -269,13 +353,20 @@ gimp_message (char *message)
   gimp_destroy_params (return_vals, nreturn_vals);
 }
 
-static void
+#if GTK_MAJOR_VERSION > 1
+void
+gimp_message_func (const gchar    *log_domain,
+		   GLogLevelFlags  log_level,
+		   const gchar    *str,
+		   gpointer        data)
+#else
+void
 gimp_message_func (char *str)
+#endif
 {
   gimp_message (str);
 }
 
-
 void
 gimp_query_database (char   *name_regexp,
 		     char   *blurb_regexp,
