@@ -23,12 +23,14 @@
 #include <glib.h>
 
 #include "version.h"
+#include "compat.h"
 #include "wire/wire_types.h"
 #include "wire/libtile.h"
 #include "float16.h"
 #include "unit.h"
 #include "pdb.h"
 #include "libgimp/gimp.h"
+#include "compat.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -41,8 +43,12 @@ extern const guint gimp_micro_version;
 
 
 DLL_API void set_gimp_PLUG_IN_INFO (const GPlugInInfo *p);
+DLL_API int plugin_main (int argc, char **argv, const GPlugInInfo *p);
 
-#define MAIN() int main (int argc, char *argv[]) { set_gimp_PLUG_IN_INFO(&PLUG_IN_INFO); return gimp_main (argc, argv); }
+extern int   argc;
+extern char **argv;
+
+#define MAIN() int main (int argc, char *argv[]) { printf("%s:%d\n",__FILE__,__LINE__); return plugin_main (argc, argv, &PLUG_IN_INFO); }
 
 
 /* The main procedure that should be called with the
@@ -76,8 +82,7 @@ DLL_API void gimp_get_data (gchar *  id,
 /* Pops up a dialog box with "message". Useful for status and
  * error reports. If "message" is NULL, do nothing.
  */
-DLL_API void gimp_message (char *message);
-
+DLL_API void gimp_message (const char *message);
 
 /* Query the gimp application's procedural database.
  *  The arguments are regular expressions which select
@@ -331,6 +336,7 @@ gint32 gimp_display_active  ();
 void   gimp_display_delete (gint32 display_ID);
 void   gimp_displays_delete_image (gint32 image_ID);
 DLL_API void   gimp_displays_flush (void);
+int        gimp_display_get_image_id         ( gint32   display_ID );
 gint32     gimp_display_get_cms_intent        (gint32   display_ID,
                                                CMSProfileType type);
 void       gimp_display_set_cms_intent        (gint32   display_ID,
