@@ -120,7 +120,7 @@ gimp_size_entry_class_init (GimpSizeEntryClass *class)
   gimp_size_entry_signals[VALUE_CHANGED] = 
               gtk_signal_new ("value_changed",
 			      GTK_RUN_FIRST,
-			      object_class->type,
+                              GTK_OBJECT_TYPE( object_class ),
 			      GTK_SIGNAL_OFFSET (GimpSizeEntryClass,
 						 value_changed),
 			      gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
@@ -128,7 +128,7 @@ gimp_size_entry_class_init (GimpSizeEntryClass *class)
   gimp_size_entry_signals[REFVAL_CHANGED] = 
               gtk_signal_new ("refval_changed",
 			      GTK_RUN_FIRST,
-			      object_class->type,
+                              GTK_OBJECT_TYPE( object_class ),
 			      GTK_SIGNAL_OFFSET (GimpSizeEntryClass,
 						 refval_changed),
 			      gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
@@ -136,13 +136,15 @@ gimp_size_entry_class_init (GimpSizeEntryClass *class)
   gimp_size_entry_signals[UNIT_CHANGED] = 
               gtk_signal_new ("unit_changed",
 			      GTK_RUN_FIRST,
-			      object_class->type,
+                              GTK_OBJECT_TYPE( object_class ),
 			      GTK_SIGNAL_OFFSET (GimpSizeEntryClass,
 						 unit_changed),
 			      gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
 
+#if GTK_MAJOR_VERSION < 2
   gtk_object_class_add_signals (object_class, gimp_size_entry_signals, 
 				LAST_SIGNAL);
+#endif
 
   class->value_changed = NULL;
   class->refval_changed = NULL;
@@ -309,8 +311,10 @@ gimp_size_entry_new (gint                       number_of_fields,
 			     (unit == GIMP_UNIT_PIXEL) ? gsef->refval_digits :
 			     (unit == GIMP_UNIT_PERCENT) ? 2 :
 			     GIMP_SIZE_ENTRY_DIGITS (unit));
+#if GTK_MAJOR_VERSION < 2
       gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON(gsef->value_spinbutton),
 				       GTK_SHADOW_NONE);
+#endif
       gtk_widget_set_usize (gsef->value_spinbutton, spinbutton_usize, 0);
       gtk_table_attach_defaults (GTK_TABLE (gse), gsef->value_spinbutton,
 				 i+1, i+2,
@@ -331,8 +335,10 @@ gimp_size_entry_new (gint                       number_of_fields,
 	    gtk_spin_button_new (GTK_ADJUSTMENT (gsef->refval_adjustment),
 				 1.0,
 				 gsef->refval_digits);
+#if GTK_MAJOR_VERSION < 2
 	  gtk_spin_button_set_shadow_type (GTK_SPIN_BUTTON (gsef->refval_spinbutton),
 					   GTK_SHADOW_NONE);
+#endif
 	  gtk_widget_set_usize (gsef->refval_spinbutton, spinbutton_usize, 0);
 	  gtk_table_attach_defaults (GTK_TABLE (gse), gsef->refval_spinbutton,
 				     i + 1, i + 2, 1, 2);
