@@ -197,7 +197,7 @@ int wire_file_flush (int fd)
         {
 	  do {
 	    bytes = write (fd, &wire_buffer->buffer[count], (wire_buffer->buffer_count - count));
-	  } while ((bytes == -1) && (errno == EAGAIN));
+	  } while ((bytes == -1) && (errno == EAGAIN) && (errno != EPIPE));
 
 	  if (bytes == -1)
 	    return FALSE;
@@ -288,7 +288,7 @@ wire_read (int fd,guint8 *buf, gulong count)
 
 	  //while (1)
 	  {
-	    erg = poll( &ev, (unsigned long)1, 1 );
+	    erg = poll( &ev, (unsigned long)1, 10 );
 /*	    if(erg < 0)
 	    {
 	      fprintf(stderr,"Error while polling: %s\n", strerror(errno));
@@ -348,7 +348,7 @@ wire_write (int     fd,
 	do {
 	    bytes = write (fd, (char*) buf, count);
 	} 
-	while ((bytes == -1) && ((errno == EAGAIN) || (errno == EINTR)));
+	while ((bytes == -1) && (errno != EPIPE) && ((errno == EAGAIN) || (errno == EINTR)));
 
         if (bytes == -1) {
 	    g_print ("wire_write: write error 2\n");
