@@ -4,15 +4,15 @@
   From jama_svd.h with minor changes and adds by H.S.
 
   Changes:
-  - Senseless inlining of the most of the member functions (eq of
-    the 480-line-constructor) removed.
+  - Senseless inlining of the most of the member functions (e.g. of the
+     480-line-constructor) removed.
 
   Adds:
   - A solve function
 
-  TODO (HS):
+  @todo (HS):
   - Check the possibility of performing "in place" or "in situ" (or
-    whatever it is called) on[in?] the input matrix `Arg'.
+     whatever it is called) on[in?] the input matrix \a Arg.
   - Make getS() safe for m .<. n.
   - Improve rank() for floats.
 
@@ -26,9 +26,9 @@
 #include "tnt_array2d_utils.hpp"
 #include "tnt_math_utils.hpp"
 
-#include <algorithm>		// HS: like version 1.2.4
+#include <algorithm>		// HS: like TNT version 1.2.4
 // for min(), max() below
-#include <cmath>		// HS: like version 1.2.4
+#include <cmath>		// HS: like TNT version 1.2.4
 // for abs() below
 
 using namespace TNT;
@@ -110,8 +110,8 @@ class SVD
 
 
     /** HS:
-      Solve the (linear least square) problem Ax=b for given (m)-vector b.
-      @return    normal solution (n)-vector x.
+      Solve the (linear least square) problem \a Ax=b for given (m)-vector \a b.
+      @return    normal solution (n)-vector \a x.
     */
     Array1D<Real> solve (const Array1D<Real> b);
     Array1D<Real> solve_1 (const Array1D<Real> b);
@@ -540,10 +540,9 @@ SVD <Real>::SVD (const Array2D<Real> &Arg)
 
 
 
-/** HS:
-    Why not simply return a ref to the intern U? -- Obviously the dimension
-    may differ: intern-U[m,min(m,n)] vs. return-U[m,min(m+1,n)].
-    The intern dim is theoretical clear, but not to me the return dim.
+/** HS: Why not simply return a ref to the intern U? -- Obviously the dimension
+     may differ: intern-U[m,min(m,n)] vs. return-U[m,min(m+1,n)]. The intern
+     dim is theoretical clear, but not to me the return dim.
 */
 template <class Real>
 void SVD<Real>::getU (Array2D<Real> &A)
@@ -559,19 +558,21 @@ void SVD<Real>::getU (Array2D<Real> &A)
 
 
 
-/** Return the diagonal matrix of singular values
-    @return     S
+/** Function fills in the argument Array2D \a A the diagonal matrix \a s of
+     singular values.
+     
+    HS: 
+    FRAGE: Warum \a A als Argument, warum keine Funktion, die \a A als 
+     return-Wert liefert, allokiert wird \a A doch eh - ??
+    
+    @bug Der interne Vektor \a s wird kreiert mit der Dimension min(m+1,n).
+     Falls in Ausgangs-(m,n)-Matrix <i>m+1 .<. n</i>, ist <i>dim(s) .<. n</i> 
+     und es gibt eine  Bereichsueberschreitung bei <i> A[i][i] = s[i], </i> 
+     da \a i bis inkl. \a n-1 laeuft.
 
-    HS:
-    @BUG: Der interne Vektor `s' wird kreiert mit der Dimension min(m+1,n).
-     Falls Ausgangs-(m,n)-Matrix m+1 .<. n, ist dim(s) .<. n und es gibt eine
-     Bereichsueberschreitung bei A[i][i] = s[i], da i bis inkl. n-1 laeuft.
-
-    Kuerzere Formulierung:
-
-    A = Array2D<Real> (n,n, 0.);  // mit eventl. optimiertem Nullsetzen.
-    for (int i=0; i < n; i++)
-       A[i][i] = s[i];
+    Kuerzere Formulierung der Funktion: <pre>
+      A = Array2D<Real> (n,n, 0.);  // mit eventl. optimiertem Nullsetzen.
+      for (int i=0; i < n; i++)  A[i][i] = s[i]; </pre>
 */
 template <class Real>
 void SVD<Real>::getS (Array2D<Real> &A)
@@ -589,10 +590,10 @@ void SVD<Real>::getS (Array2D<Real> &A)
 }
 
 
-/** Effective numerical matrix rank
+/** Effective numerical matrix rank.
     @return: Number of nonnegligible singular values.
 
-    HS: works satisfied only for double
+    TODO HS: works satisfied only for double, not for float.
 */
 template <class Real>
 int SVD<Real>::rank ()
@@ -610,15 +611,14 @@ int SVD<Real>::rank ()
 }
 
 
-/**  
-    HS-add:
-    Solve the (linear least square) problem Ax=b for a given (m)-vector b.
-    @return: normal solution (n)-vector x.
+/** Added by HS:
+    Solve the (linear least square) problem \a Ax=b for a given (m)-vector \a b.
+    @return: normal solution (n)-vector \a x.
 
-    Algorithm: x = V S^{-1} U^T b.
+    Algorithm: <i> x = V S^{-1} U^T b. </i>
 
-    Regularisierte Loesung: Verwenden nur die numerisch relevanten
-    Singulaerwerte as given by rank():
+    Regularisierte Loesung: Verwenden nur die numerisch relevanten Singulaerwerte
+     as given by rank():
 
 */
 template <class Real>
@@ -650,7 +650,10 @@ Array1D<Real> SVD<Real>::solve (const Array1D<Real> b)
     return x;
 }
 
-
+/** Added by HS:
+    Alternative to solve(). 
+    Differeneces: ...
+*/
 template <class Real>
 Array1D<Real> SVD<Real>::solve_1 (const Array1D<Real> b)
 {
@@ -688,6 +691,10 @@ Array1D<Real> SVD<Real>::solve_1 (const Array1D<Real> b)
     return x;
 }
 
+/** Added by HS:
+    Alternative to solve(). 
+    Differeneces: ...
+*/
 template <class Real>
 Array1D<Real> SVD<Real>::solve_2 (const Array1D<Real> b)
 {
