@@ -22,6 +22,7 @@
   Adds:
    o Debug output improved: type infos and ref counter output included
    o Function `is_empty()' added
+   o Function `getArray1D()' added
   Bug Fixes:
    o `n' -> `n_' in subarray()
 */
@@ -64,13 +65,13 @@ class Array2D
 
     inline  operator       T**();               // HS: Cast-Op
     inline  operator const T**();               // HS: Cast-Op
-    inline  Array2D & operator= (const T &a);
-    inline  Array2D & operator= (const Array2D &A);
-    inline  Array2D & ref(const Array2D &A);
-            Array2D   copy() const;
-            Array2D & inject(const Array2D &A);
-    inline        T*  operator[] (int i);
-    inline  const T*  operator[] (int i) const;
+    inline  Array2D& operator= (const T &a);
+    inline  Array2D& operator= (const Array2D &A);
+    inline  Array2D& ref(const Array2D &A);
+            Array2D  copy() const;
+            Array2D& inject(const Array2D &A);
+    inline        T* operator[] (int i);
+    inline  const T* operator[] (int i) const;
     inline  int dim1() const;
     inline  int dim2() const;
             ~Array2D();
@@ -78,13 +79,14 @@ class Array2D
 
     /* extended interface (not part of the standard) */
 
-    inline  int     ref_count();
+    inline  int     ref_count();                        
     inline  int     ref_count_data();
     inline  int     ref_count_dim1();
             Array2D subarray(int i0, int i1, int j0, int j1);
             
     inline  bool    is_empty() const {return dim1()==0;}  // Added by HS
-
+    inline  const T* data() const    {return data_;}	  // Added by HS
+    inline  Array1D<T>  getArray1D() const;		  // Added by HS
 };
 
 
@@ -227,14 +229,14 @@ Array2D<T> & Array2D<T>::inject (const Array2D &A)
 
 
 
-
-template <class T>                              // HS: gives new ref
+/*!  Makes "me" to a new ref of the data referenced by \a A. */
+template <class T>
 Array2D<T> & Array2D<T>::ref (const Array2D<T> &A)
 {
     if (this != &A)
     {
-        v_ = A.v_;                  // HS: handles ref counting
-        data_ = A.data_;            // HS: handles ref counting
+        v_ = A.v_;          // HS: handles ref counting and destroying
+        data_ = A.data_;    // HS: handles ref counting and destroying
         m_ = A.m_;
         n_ = A.n_;
 
@@ -313,8 +315,6 @@ inline int Array2D<T>::ref_count()
     return ref_count_data();
 }
 
-
-
 template <class T>
 inline int Array2D<T>::ref_count_data()
 {
@@ -328,12 +328,23 @@ inline int Array2D<T>::ref_count_dim1()
 }
 
 
-/*
-   HS: data_.ref_count() and v_.ref_count() can be different due to
-    subarray(), in which an Array2d instance is created using the same
-    `data_' presentation as `this' (==> *this.data_.(*ref)++), but with own
-    `v_' representation, i.e *this.v_.(*ref) remains invariant and
-    subarray.v_.(*ref) = 1.
+/*!  Returns an Array1D handle of "my" contiguous data block \a data_. This
+   increases the ref counter of \a data_, but not of the pointer array \a v_.
+   Interesting for someone who wants to hold only the pure data block without
+   the pointer array \a v_. The dim() of the Array1D is the dim of the 
+   underlying contiguous data block; this will differ from dim1()*dim2() if
+   "I" am a subarray. [HS] */
+template <class T>
+inline Array1D<T> Array2D<T>::getArray1D() const
+{
+    return Array1D<T>(data_);  // Ref counting copy
+}
+
+/*   HS: data_.ref_count() and v_.ref_count() can be different due to
+   subarray(), in which an Array2d instance is created using the same `data_'
+   presentation as `this' (==> *this.data_.(*ref)++), but with own `v_' 
+   representation, i.e *this.v_.(*ref) remains invariant and 
+   subarray.v_.(*ref) = 1.
 */
 
 
