@@ -23,42 +23,11 @@
   @file ResponseSolver.hpp
 
   Contents:
-   - Curve2D<>
+   - Curve2D<>          (unused)
    - ResponseSolver<>
     
   Calculation of a response function.
 
-  Wir bieten hier *keinen* Ctor mit Pack-Argument. Vermeidet unnoetige
-   Abhaengigkeiten. Die (eventl.) dort entnehmbare Info `z_max' ist im 
-   Ctor direkt zu uebergeben.
-
-  Der Templateparameter `Real' dient nur internem Gebrauch (Genauigkeit
-   der `Ax=b' Rechnung). Nach aussen werden nur double-Werte [oder
-   `RealCom'?] praesentiert. Dadurch keine Notwendigkeit einer `Real'-
-   Fortfuehrung beim Nutzer. Falls 'Real != RealCom', passieren hier intern
-   lediglich unkritische Konvertierungen.
-   
-  Der Templateparameter `Real' koennte spaeter durch statische Typdefinition
-   ersetzt werden, sofern "normalerweise" nie zwei ResponseCalc-Instanzen
-   verschiedener `Real'-Typen im Gebrauch sein werden. Allenfalls jetzt zum
-   Test.
-
-  Alle Float-Schnittstellen nach aussen derzeit auf Typ `double' gesetzt.
-   Bei den Expose-Werten (`ExposeVals()' etc) kommt vielleicht mal ein 
-   eigener Typ.
-   
-  Schliesslich natuerlich noch die Abhaengigkeit von Datentyp `Tweight' der
-   Wichtungsfunktionen, definiert in "WeightFuncBase.hpp"
-   
-  
-  OBACHT: Die Differenz zweier Integer muss bei signed int's nicht mehr in den
-   Datentyp passen: 128 - (-127) = 255 > 128. Hier muss eigentlich immer dann
-   die unsigned Variante stehen. Aber auch bei Unsigneds passt die ANZAHL
-   moeglicher Werte nicht notwendig in diesen Typ, denn von 0..255 sind es 255+1
-   = 256 Werte > 255. size_t (==uint) waere der vorlaeufige Behelf, der freilich 
-   fuer sizeof(size_t)==sizeof(Unsign) auch versagt (32-Bit Unsign?). Aber
-   da ist das Verfahren hier sowieso nicht mehr anwendbar.
-
 */
 #ifndef ResponseSolver_hpp
 #define ResponseSolver_hpp
@@ -72,7 +41,6 @@
 
 #include "WeightFuncBase.hpp"   // Tweight (type of weight values)
 #include "FilePtr.hpp"          // FilePtr
-#include "ProgressInfo.hpp"     // ProgressInfo
 #include "Exception.hpp"        // IF_FAIL_EXCEPTION()
 #include "br_macros.hpp"
 #include "ResponseSolverBase.hpp"
@@ -84,7 +52,9 @@ using namespace TNT;
  
 /**======================================================================
 
-  @class Curve2D  --  template, currently not used
+  @class Curve2D  
+  
+  Template, currently not used.
 
 *=======================================================================*/  
 template <class Tx, class Ty>
@@ -130,28 +100,64 @@ void Curve2D<Tx,Ty>::list ()
 
 /**===========================================================================
 
-  @class ResponseSolver  --  template
+  @class ResponseSolver
+  
+  Template. Calculation of a response function.
 
   @param Unsign: Type of the z-values (typically unsigned integers)
-  @param Real: Type the QR-decomposition resp. SVD is solved
+  @param Real: Type wherein the QR-decomposition resp. SVD is solved.
 
-  Note: The output of a photo sensor ("pixel") is called pixel-value or
-   z-value and denoted by z. The number of possible z-values is n_zvals; 
-   i.e for a 8-bit resolution n_zvals=256, for 10-bit n_zvals=1024 etc.
+  <b>Zu den Template-Parametern:</b>
+  
+  Wir bieten hier *keinen* Ctor mit Pack-Argument. Vermeidet unnoetige
+   Abhaengigkeiten. Die (eventl.) dort entnehmbare Info \a z_max ist im 
+   Ctor direkt zu uebergeben.
+
+  Der Templateparameter \a Real dient nur internem Gebrauch (Genauigkeit
+   der `Ax=b' Rechnung). Nach aussen werden nur double-Werte [oder
+   \a RealCom?] praesentiert. Dadurch keine Notwendigkeit einer \a Real
+   Fortfuehrung beim Nutzer. Falls <i> Real != RealCom </i>, passieren hier
+   intern lediglich unkritische Konvertierungen.
+   
+  Der Templateparameter \a Real koennte spaeter durch statische Typdefinition
+   ersetzt werden, sofern "normalerweise" nie zwei ResponseSolver Instanzen
+   verschiedener \a Real Typen im Gebrauch sein werden. Allenfalls jetzt zum
+   Test.
+
+  Alle Float-Schnittstellen nach aussen derzeit auf Typ \c double gesetzt.
+   Bei den Expose-Werten (`ExposeVals()' etc) kommt vielleicht mal ein 
+   eigener Typ.
+   
+  Schliesslich natuerlich noch die Abhaengigkeit von Datentyp \a Tweight der
+   Wichtungsfunktionen, definiert in WeightFuncBase.hpp.
+
+  <b>Method:</b>
+    
+  The output of a photo sensor ("pixel") is called pixel-value or z-value and
+   denoted by \a z. The number of possible z-values is \a n_zvals; i.e for a 
+   8-bit resolution \a n_zvals=256, for 10-bit \a n_zvals=1024 etc.
 
   The ansatz is
      <pre>
         z = f(X) = f(E*t)  or  f^-1(z) = X = E*t  or 
         g(z) = log(X) = log(E)+log(t),  where g(z) := log[f^-1(z)]. </pre> 
 
-   We compute the n_zvals values g_i := g(z_i) of the function g(z), i.e.
-   with other words, the n_zvals logarithmic exposure values log(X) to each
-   z-value. We store them in the array `logXcrv'.
+   We compute the \a n_zvals values <i> g_i := g(z_i) </i> of the function 
+   \a g(z), i.e. with other words, the \a n_zvals logarithmic exposure values
+   \a log(X) to each z-value. We store them in the array \a logXcrv.
 
   QUESTION: The TNT::Array Ctor-parameters as value or as refs? - As refs!
    Value parameters would live only temporary in the Ctor, and so we have to
    take copies in every case, since we need them behind the Ctor.
 
+  @warning Die Differenz zweier Integer muss bei signed int's nicht mehr in den
+   Datentyp passen: 128 - (-127) = 255 > 128. Hier muss eigentlich immer dann
+   die unsigned Variante stehen. Aber auch bei Unsigneds passt die ANZAHL
+   moeglicher Werte nicht notwendig in diesen Typ, denn von 0..255 sind es 255+1
+   = 256 Werte > 255. size_t (==uint) waere der vorlaeufige Behelf, der freilich 
+   fuer sizeof(size_t)==sizeof(Unsign) auch versagt (32-Bit Unsign?). Aber da
+   ist dieses Verfahren hier sowieso nicht mehr anwendbar.
+  
 *============================================================================*/
 template <class Unsign, class Real>
 class ResponseSolver : public ResponseSolverBase
@@ -168,42 +174,41 @@ class ResponseSolver : public ResponseSolverBase
                                 //  the main effort of the procedure.
     Array1D<double>  logXcrv_;  // ==log(Xcrv); primary result of the calculation
 
-    ProgressInfo*  progressinfo_;  // Not used till now
-
 public:
-    /*  Ctor:  inits only, doesn't execute the computation */
+    /*  Ctor:  Inits only, doesn't execute the computation */
     ResponseSolver (const Array2D<Unsign> & Z,
                     const Array1D<double> & B, 
-                    Unsign                z_max,
-                    ProgressInfo*         pr = NULL );
+                    Unsign                z_max );
 
     
-    /*  Compute the characteristic g(z_i) for given smoothing and weight function */
-    void compute (double lambda, const Array1D<Tweight> & weight, bool debug=false);
+    /*  Computes the characteristic g(z_i) for given smoothing and weight function */
+    void compute (double smoothing, const Array1D<Tweight> & weight, bool debug=false);
 
     
     /** 
-    *   Return the computed characteristic g(z_i), i.e. the log. exposure
-    *    values log[X(z_i)]. If not been compute()d before, return Null-Array.
+    *   Returns the computed characteristic g(z_i), i.e. the log. exposure
+    *    values log[X(z_i)]. If not been compute()d before, a Null-Array is
+    *    returned.
     */
     const Array1D<double> & getLogExposeVals() const    {return logXcrv_;}
     
     /**
-    *   Return the unlogarithm. computed characteristic g(z_i), i.e. the exposure
-    *    values X(z_i). If not been compute()d before, return Null-Array.
+    *   Returns the unlogarithm. computed characteristic g(z_i), i.e. the
+    *    exposure values X(z_i). If not been compute()d before, a Null-Array
+    *    is returned.
     */
     const Array1D<double> & getExposeVals()    const    {return Xcrv_;}
 
     
-    /*  Write the computed exposure values (the solution) into a text file */
+    /*  Writes the computed exposure values (the solution) into a text file */
     void write_ExposeVals (const char* fname, bool log=false) const;
 
     
-    /*  Exchange the "Z-matrix" given in the Ctor */
+    /*  Exchanges the "Z-matrix" given in the Ctor */
     void exchange_Z_Matrix (const Array2D<Unsign> & Z);
 
     
-    /*  Exchange the vector of log. exposure times given in the Ctor. */
+    /*  Exchanges the vector of log. exposure times given in the Ctor. */
     void exchange_LogExposeTimes (const Array1D<double> & B);
 
 private:
@@ -211,48 +216,45 @@ private:
     /*  Solves the rectangular `Ax=b' problem */
     Array1D <Real> solve_ (const Array2D<Real>&, const Array1D<Real>&, bool);
       
-    /*  Check the given weight function */
+    /*  Checks a weight function */
     bool check_weight_(const Array1D<Tweight> & weight);
     
-    /*  Ouput as debug info `A' and `b' of Ax=b to stdout or into a file */
+    /*  Outputs as debug info `A' and `b' of Ax=b to stdout or into a file */
     void debug_out_ (const Array2D<Real> &A, const Array1D<Real> &b);
     
-    /*  Own weight function (alt, nur noch aufgehoben) */
+    /*  Our own weight function (old, only aufgehoben) */
     Real wicht (Unsign z);    // Gewicht des Pixelwertes z
 
 };
 
 
 /**+*************************************************************************\n
-  Ctor:  inits only, doesn't execute the computation
+  Ctor:  Inits only, doesn't execute the computation.
   
   @param Z: "Z-Matrix"
   @param B: Array of the logarithm exposure times
   @param z_max: maximal possible z-value
-  @param pr: Pointer to a ProgressInfo instance (still unused)
 ******************************************************************************/
 template <class Unsign, class Real>
 ResponseSolver<Unsign,Real>::ResponseSolver (
         
         const Array2D<Unsign> & Z,
         const Array1D<double> & B,
-        Unsign                z_max,
-        ProgressInfo*         pr )
+        Unsign                z_max )
   :                               
     ResponseSolverBase (AUTO),          // solve_mode_ == AUTO
     z_max_        (z_max),
     Z_            (Z),
-    B_            (B),
-    progressinfo_ (pr)
+    B_            (B)
 {
     IF_FAIL_EXCEPTION (Z_.dim2() == B_.dim(), Exception::RESPONSE);
 
-    n_zvals = (size_t)z_max + 1;          // 256 for 8 bit; Problematisch fuer mehr Bits  
+    n_zvals = (size_t)z_max + 1;        // 256 for 8 bit; Problematisch fuer mehr Bits  
 }
 
 
 /**+*************************************************************************\n
-  Klasseneigene Wichtungsfunktion. Unbenutzt, nur noch aufbewahrt.
+  Internal weight function. No more used, only preserved.
 ******************************************************************************/
 template <class Unsign, class Real>     
 Real 
@@ -266,11 +268,12 @@ ResponseSolver<Unsign,Real>::wicht (Unsign z)
 
 
 /**+*************************************************************************\n
-  Exchange the "Z-matrix" given in the Ctor (e.g. Z-matrix is different for
-   each color channel).
+  Exchanges the "Z-matrix" given in the Ctor by \a Z (e.g. the Z-matrix is 
+   usually different for each color channel).
   
-  Z.dim1() (==Zahl selektierter "Orte") kann differieren. Daher nur Invarianz
-   bzgl. Z.dim2() (Zahl der Aufnahmen) zu fordern.
+  @note \a Z.dim2() (number of exposures) has to be identic with \a dim2() of 
+   the current Z-matrix. Otherwise an exception is thrown. Whereas \a Z.dim1()
+   (number of selected "spot points" ["Orte"]) can differ.
 ******************************************************************************/
 template <class Unsign, class Real>
 void 
@@ -282,8 +285,9 @@ ResponseSolver<Unsign,Real>::exchange_Z_Matrix (const Array2D<Unsign>& Z)
 }
 
 /**+*************************************************************************\n
-  Exchange the vector of log. exposure times given in the Ctor.
-   Anzahl der Zeiten muss mit Z.dim2() (Zahl der Aufnahmen) uebereinstimmen.
+  Exchanges the vector of log. exposure times given in the Ctor by \a B.
+  @note \a B.dim() (number of times) has to match with \a Z.dim2() (number
+   of exposures)! Otherwise an exception is thrown.
 ******************************************************************************/
 template <class Unsign, class Real>
 void 
@@ -298,10 +302,11 @@ ResponseSolver<Unsign,Real>::exchange_LogExposeTimes (const Array1D<double>& B)
 /**+*************************************************************************\n
   compute() 
 
-  Compute the characteristic g(z_i) (the log exposure values log(X)) for a
-   certain smoothing coefficient `lambda' and a given weight function.
+  Computes the characteristic <i>g(z_i)</i> (the log exposure values <i>log(X)</i>)
+   for a certain smoothing coefficient \a smoothing and a given weight function
+   \a weight.
   
-  @param lambda: smoothing coefficient.
+  @param smoothing: smoothing coefficient.
   @param weight: weight function: weight[z] = weight of value z.
   @param debug: if true, give debug output.
 
@@ -328,31 +333,35 @@ ResponseSolver<Unsign,Real>::exchange_LogExposeTimes (const Array1D<double>& B)
    die LogZeiten B[] und die Glaettungsgleichungen wurden also nicht mit einem
    Faktor w in [0..1], sondern mit w in [0..255] multipliziert. Da aber beide
    Seiten damit multipliziert, kann das problemlos geaendert werden (intern hier
-   gehen uns die Wichtungszahlen nichts an). -- Inzwischen Gewichte auf Werte 
-   in [0..1] umgestellt.
+   gehen uns die Wichtungszahlen nichts an). -- Inzwischen Gewichte draussen
+   auf [0..1]-Werte umgestellt.
    
-  @NOTE Since this computation method is applicable ordinarily only for U8 data,
-   I have gone back for the type of 'weight' from WeightFunc<> to TNT::Array1D<>.
+  Since this computation method is applicable ordinarily only for U8 data,
+   I have gone back in type of \a weight from WeightFunc<> to TNT::Array1D<>.
    This reduces dependencies and allows to organize the WeightFunc stuff also
-   in non-template form. The caller has to init the table of his WeightFunc
-   object and to turn over the table.
+   in non-template form. If the caller uses a WeightFunc object he has to init
+   WeightFunc's table and to take over this table.
    
-  @NOTE If the weight function has wider 0-bordes than [1,1] (== at z=0 and 
-   z=zmax), e.g. [2,2], only the inner g_i's g_1...g_254 are determined (build
-   a coupled system), because the columns for g_0 and g_255 in the coeff. matrix
-   `A' are zero-columns, i.e. the unknowns g_0 and g_255 are undefined (completely
-   decoupled from the system). They would have to be determined on another way,
-   e.g. by extrapolation. The same happens for three consecutive zero-weights 
-   w_{i-1}, w_i, w_{i+1}; g_i is then undefined. In such cases the coeff. matrix
-   `A' generated below has a rank defect, and although the SVD method returns 
-   formally here a solution, the undefined unknowns are set only arbitrarily.
-   Therefore only weight functions with one-point-0-borders at z=0 and z=zmax
-   are suitable. The (private) check_weight_() gives a warning on stdout, if an
-   unsuitable weight functions is used.
+  @note The weight function \a weight can have zeros, common are weight
+   functions with zeros at z=0 and z=z_max -- I will call it a weight function
+   with <i>"[1,1] 0-borders"</i> ("[1,1]" == one zero from each end).
+   If however the weight function has wider 0-bordes than [1,1], e.g. [2,2], 
+   then only the inner g_i's <i>g_1...g_254</i> are determined (form a coupled
+   system) because the columns for \a g_0 and \a g_255 in the coeff. matrix `A'
+   become zero-columns then and i.e. the unknowns \a g_0 and \a g_255 are undefined
+   (completely decoupled from the system). They would have to be determined by
+   another way, e.g. by extrapolation. The same happens for three consecutive
+   zero-weights <i>w_{i-1} = w_i = w_{i+1} = 0</i> anywhere in the middle: 
+   \a g_i would be undefined! In such cases the below generated coeff. matrix `A'
+   has a rank defect (the QR method would fail), and although the SVD method
+   returns formally here a solution, the undefined unknowns are set wherein
+   only arbitrarily! Therefore only weight functions maximal with [1,1]
+   0-borders are suitable. The (private) function check_weight_() gives a
+   warning on stdout, if an unsuitable weight function is used.
 ******************************************************************************/
 template <class Unsign,class Real>
 void
-ResponseSolver<Unsign,Real>::compute (double                 lambda,  
+ResponseSolver<Unsign,Real>::compute (double                 smoothing,  
                                       const Array1D<Tweight> & weight, 
                                       bool                   debug)
 {
@@ -409,8 +418,8 @@ ResponseSolver<Unsign,Real>::compute (double                 lambda,
     //  Include the (n-2) smoothness equations:
     for (size_t i=0; i < n_zvals-2; i++)
     {  
-        //Real val = lambda * wicht(i+1);       // Real = double * Real
-        Real val = lambda * weight[i+1];        // Real = double * Tweight
+        //Real val = smoothing * wicht(i+1);    // Real = double * Real
+        Real val = smoothing * weight[i+1];     // Real = double * Tweight
         if (val == 0.0)
             continue;                           // skip zero-rows    
         A [k][i  ] = val;
@@ -443,7 +452,7 @@ ResponseSolver<Unsign,Real>::compute (double                 lambda,
 
 
 /**+*************************************************************************\n
-  solve_()  -  solves `Ax=b' for given `A' and `b' (private helper)
+  solve_()  -  Solves \a Ax=b for given \a A and \a b (private helper).
 
   @param A: coefficient matrix
   @param b: the "right side"
@@ -476,7 +485,7 @@ ResponseSolver<Unsign,Real>::solve_ (const Array2D<Real> & A,
       {
         if (! qr.isFullRank())
         {
-          std::cout << "QR decomposition inapplicably, use SVD...\n";
+          std::cout << "QR decomposition inapplicable, use SVD...\n";
           qr_failed = true;
           goto SOLVE_VIA_SVD;
         }
@@ -561,7 +570,8 @@ SOLVE_VIA_SVD:
 
 
 /**+*************************************************************************\n
-  Check a weight function for usefulness in respect of 0-borders. 
+  Checks the weight function \a weight for usefulness in respect of 0-borders,
+   i.e. whether \a weight would made some unknowns undeterminable. 
   @return False, if weight function makes some of the unknowns indeterminable.
 ******************************************************************************/
 template <class Unsign, class Real>
@@ -616,7 +626,8 @@ ResponseSolver<Unsign,Real>::check_weight_ (const Array1D<Tweight> & weight)
 
 
 /**+*************************************************************************\n
-  Output the coeff. matrix 'A' and the right side `b' of Ax=b to file or stdout.
+  Outputs the coeff. matrix \a A and the right side \a b of \a Ax=b to a file
+   or to stdout. Devel and debugging helper.
 ******************************************************************************/
 template <class Unsign, class Real>
 void
@@ -627,7 +638,8 @@ ResponseSolver<Unsign,Real>::debug_out_ (const Array2D<Real> &A, const Array1D<R
     {
       /* We open the files in append mode to avoid immediate overwriting, because
           mostly ResponseSolver is called for the three channels three times
-          consecutively. */
+          consecutively. Disadvantage of this: After many debug runs could accrue
+          a big "A_" file. */
       char fname[64];
       sprintf(fname, "A_%dx%d.txt", A.dim1(), A.dim2()); 
       std::ofstream  ofs_A (fname, std::ios::app);
@@ -650,9 +662,9 @@ ResponseSolver<Unsign,Real>::debug_out_ (const Array2D<Real> &A, const Array1D<R
   Writes the computed exposure values (the solution) into a text file in gnuplot
    readable form.
 
-  @param fname: file name (an existing file is overwritten without warning!)
+  @param fname: file name (an existing file gets overwritten without warning!)
   @param log: if true, logarithm. exposure values are written, and the prefix
-     "log_" is added automatically to `fname'.
+     "log_" is added automatically to \a fname.
 ******************************************************************************/
 template <class Unsign, class Real>
 void
