@@ -28,12 +28,11 @@ namespace br {
 /// Names of the Br2Hdr::Event enums for debug output...
 const char* const EVENT_NAMES[] =
 {   "NO_EVENT",
+    "IMG_VECTOR_SIZE",
+    "SIZE_ACTIVE",
     "CALCTOR_INIT",
-    "CALCTOR_OUTDATED",
     "CALCTOR_REDATED",
     "CALCTOR_DELETED",
-    "IMAGE_LOADED",
-    "IMAGES_CHANGED",
     "CCD_UPDATED",
     "CCD_OUTDATED",
     "CCD_DELETED",
@@ -43,6 +42,8 @@ const char* const EVENT_NAMES[] =
     "FOLLOWUP_OUTDATED",
     "EXTERN_RESPONSE",
     "WEIGHT_CHANGED",
+    "OFFSET_COMPUTED",
+    "ACTIVE_OFFSETS",
     "UNKNOW_EVENT"
 };
 
