@@ -20,24 +20,23 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 /**
-  @file  bracketing_to_hdr.cpp
+  @file bracketing_to_hdr.cpp
   
   Main source file of the CinePaint plugin "Bracketing to HDR".
   
-  This file contains all CinePaint and Gtk references of the "Bracketing" 
+  This file contains all CinePaint and Gtk references of the "Bracketing"
    project. The only two services we need from CPaint are loading an image and
    showing an float32 (HDR) image: wrapped and provided to the rest of the 
    program by the two functions declared in "bracketing_to_hdr.hpp".
   
-  Internal Note: 
-   `GPrecisionType' is defined in "cinepaint###/lib/wire/precision.h" as an
-   enum. There are also precision strings `PRECISION_U8_STRING' etc,
+  @internal 
+   \c GPrecisionType is defined in "cinepaint???/lib/wire/precision.h" as an
+   enum. There are also precision strings \c PRECISION_U8_STRING etc,
    unfortunately not in an array to have a simple reference to the enums.
     
-  @BUG If "Br2HdrManager.hpp" && "AllWindows.hpp" && "bracketings_to_hdr.hpp" 
-   are included *after* the CPaint headers it gives the compiler error:
- 
-    In file included from /usr/include/g++/i586-suse-linux/bits/c++locale.h:44,
+  @bug If "Br2HdrManager.hpp" && "AllWindows.hpp" && "bracketings_to_hdr.hpp" 
+   are included *after* the CPaint headers it gives the compiler error:<pre>
+     In file included from /usr/include/g++/i586-suse-linux/bits/c++locale.h:44,
                  from /usr/include/g++/iosfwd:46,
                  from /usr/include/g++/bits/stl_algobase.h:70,
                  from /usr/include/g++/vector:67,
@@ -45,24 +44,26 @@
                  from br_core/Br2HdrManager.hpp:19,
                  from bracketing_to_hdr.hpp:11,
                  from bracketing_to_hdr.cpp:49:
-    /usr/include/libintl.h:40: error: syntax error before `char'
-     
+     /usr/include/libintl.h:40: error: syntax error before `char'
+    </pre>
    No idea why, anyhow, thus CPaint headers included behind those.
 */
 
-#include <FL/fl_ask.H>              // fl_alert(), fl_message()
+#include <FL/fl_ask.H>              // fl_alert(), fl_ask()
 #include <FL/filename.H>            // fl_filename_name()
 #include "br_core/br_version.hpp"   // BR_VERSION_LSTRING    
 #include "br_core/Rgb.hpp"          // Rgb<>
 #include "br_core/br_macros.hpp"    // IF_FAIL_DO() etc.
 #include "br_core/Br2HdrManager.hpp"
+#include "br_core/br_messages.hpp"  // br::msg_image_ignored(), e_printf()
+#include "br_core/readEXIF.hpp"     // readEXIF()
 #include "gui/AllWindows.hpp"       // object `allWins'
 #include "bracketing_to_hdr.hpp"    // cpaint_load_image(), cpaint_show_image()
 extern "C" {
 #include "lib/plugin_main.h"
 #include "lib/wire/libtile.h"
 #include "plugin_pdb.h"
-#include "libgimp/stdplugins-intl.h"
+#include "libgimp/stdplugins-intl.h" // macros INIT_I18N_UI(), _()
 }
 
 
@@ -77,17 +78,17 @@ extern "C" {
 #define PLUGIN_COPYRIGHT     "Copyright 2005-2006 Hartmut Sbosny"
 
 
-//======================================
-//  Declaration of the local functions
-//======================================
+//==================================
+//  Declaration of local functions
+//==================================
 void            query                           (void);
-void            run                             (char *    name,
+void            run                             (char*     name,
                                                  int       nparams,
-                                                 GParam *  param,
-                                                 int *     nreturn_vals,
-                                                 GParam ** return_vals);
+                                                 GParam*   param,
+                                                 int*      nreturn_vals,
+                                                 GParam**  return_vals);
 
-int             cpaint_load_image_via_PDB       (const char* fname);
+int             cpaint_load_image_via_PDB       (const char* fname, bool interactive);
 br::BrImage     u8_from_u16                     (const br::BrImage & img16);
 br::BrImage     cpaint_get_BrImage_U8           (int W, int H, gint32 layer_ID);
 br::BrImage     cpaint_get_BrImage_U16          (int W, int H, gint32 layer_ID);
@@ -102,7 +103,7 @@ void            copy_without_alpha              (br::Image &, GimpPixelRgn &);
 //==========================
 //  file-global variables      
 //==========================
-GPlugInInfo  PLUG_IN_INFO =     // required by `MAIN()'
+GPlugInInfo  PLUG_IN_INFO =     // required by macro `MAIN()'
 {
     NULL,    /* init_proc  */
     NULL,    /* quit_proc  */
@@ -119,11 +120,11 @@ static int n_args_;
 
 //==========================================
 //
-//              IMPLEMENTATION 
+//              IMPLEMENTATION
 //
 //==========================================
-MAIN()      // defined in "lib/plugin_main.h"; requires a global GPlugInfo-
-            //  object of name "PLUG_IN_INFO" (defined just above)   
+MAIN()      // Macro defined in "lib/plugin_main.h"; requires a global GPlugInInfo
+            //  object of name "PLUG_IN_INFO" (defined just above).   
 
             
 /**+*************************************************************************\n
@@ -155,6 +156,8 @@ query ()
                           PROC_EXTENSION,
                           n_args_, n_return_vals_,
                           args, return_vals);
+  
+  /*  To get this menupath atom in the ~.po file */
   _("Bracketing to HDR");
 }
 
@@ -162,11 +165,11 @@ query ()
   run()
 ******************************************************************************/
 void
-run (char *    name,            // I - Name of called function resp. plug-in
-     int       nparams,         // I - Number of parameters passed in
-     GParam *  param,           // I - Parameter values
-     int *     nreturn_vals,    // O - Number of return values
-     GParam ** return_vals)     // O - Return values
+run (char*    name,             // I - Name of called function resp. plug-in
+     int      nparams,          // I - Number of parameters passed in
+     GParam*  param,            // I - Parameter values
+     int*     nreturn_vals,     // O - Number of return values
+     GParam** return_vals)      // O - Return values
 {
   GStatusType    status;        // return status
   GRunModeType   run_mode;
@@ -181,6 +184,10 @@ run (char *    name,            // I - Name of called function resp. plug-in
   *nreturn_vals           = n_return_vals_;
   *return_vals            = values;
 
+  /*  Init the internationalization stuff */
+  INIT_I18N_UI();
+  INIT_FLTK1_CODESET();
+  
   if (strcmp (name, PLUGIN_NAME) == 0)
     {
       sprintf (vals.name, getenv("PWD"));     // default for `vals'
@@ -230,16 +237,13 @@ run (char *    name,            // I - Name of called function resp. plug-in
 
 
 /**+*************************************************************************\n
-  u8_from_u16()  --  helper for cpaint_load_image()
+  u8_from_u16()  --  helper for cpaint_load_image().
 
-  Downsamples a RGB_U16 BrImage into a RGB_U8 image allocated here. Meta data
-   of img16 are not copied, they get the default settings.
-    
-  @param img16: BrImage of type RGB_U16.
-  @return  downsampled BrImage of type RGB_U8, created here.
-
-  Open: Metadaten von img16 auch kopieren oder weglassen? Haengt von 
-   Verwendungsweise ab. Hier reicht weglassen.
+  Function downsamples the RGB_U16 br::BrImage object \a img16 into an RGB_U8 
+   br::BrImage object allocated here. Meta data of \a img16 are copied.
+   
+  @param img16: br::BrImage of type RGB_U16.
+  @return  downsampled br::BrImage of type RGB_U8, created here.
 ******************************************************************************/
 br::BrImage 
 u8_from_u16 (const br::BrImage & img16)
@@ -255,42 +259,60 @@ u8_from_u16 (const br::BrImage & img16)
   
   for (int i=0; i < img8.n_pixel(); i++) 
     {
-      u8[i] = u16[i] >> 8;
+      u8[i] = u16[i] >> 8;  // shift operator of the Rgb<> template
     }
+  
+  img8.copy_meta_data (img16);
   return img8;
 }
 
 /**+*************************************************************************\n
   cpaint_load_image()
 
-  Load image `fname' via CinePaint and insert it into the Br2HdrManager object
-   `mBr2Hdr'.
+  Function loads via CinePaint the image with filename \a fname and adds it to
+   the image container of the br::Br2HdrManager object \a mBr2Hdr.
 
-  @param fname: name of file to load.
-  @param mBr2Hdr: Br2HdrManager the image shall be added to. 
+  @param fname: Name of the image to load.
+  @param mBr2Hdr: Br2HdrManager instance the image shall be added to. 
+  @param interactive: Has an effect only for loading of raw-data via the rawphoto
+   plug-in. To avoid that the rawphoto dialog occurs at every image of a series,
+   it should be set true only for the first image and false for the following one.
+   Default: true.
   @return  Successful or not?
 
-  Note: Do not leave an unfreed CPaint image!
-  Note: Erwaegenswert auch Variante, die ein BrImage returniert und kein 
+  @note Do not left behind an unfreed CPaint image!
+  @note Erwaegenswert auch Variante, die ein br::BrImage returniert und kein 
     Manager-Argument besitzt. Verringerte Abhaengigkeiten merklich. Es muessten
     dann aber Informationen bereitgestellt ob es sich um das erste Bild des
     Containers handelt, und wenn nein, welches die Daten des ersten Bildes
-    sind. Also das Manager-Arg. doch nicht so verkehrt. Es sei denn, wir
+    sind. Also das Manager-Argument doch nicht so verkehrt. Es sei denn, wir
     lueden erst komplettes Bild und prueften dann.
 ******************************************************************************/
 bool 
-cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)        
+cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr, bool interactive)
 {
-  static int            base_W;             // to save the values of the first
-  static int            base_H;             //  image
-  static gint           base_gray;          // dito
-  static GPrecisionType base_precis;        // dito
-  static bool           u16_u8_warning = true; // downsampling warning?
+  static int            first_W;       // |to store the values of the first
+  static int            first_H;       // | image in mBr2Hdr's image container,
+  static gint           first_gray;    // | which determines the values for all
+  static GPrecisionType first_precis;  // | others
+  static bool           u16_u8_warning = true; // Downsampling warning?
   char                  tmp[256];
+  
+  /*  To avoid unsubtantial multi-line entries in the .po-file due to '\n' format
+       chars we define coherent strings without format specifiers separately. */
+  const char* str_multi_layer = _("More than one layer in image.");
+  const char* str_no_layer    = _("No layer in image.");
+  const char* str_no_data     = _("Image contains no data.");
+  const char* str_no_rgb      = _("Not an RGB image.");
+  const char* str_other_dim   = _("Image has other dimension than the previous loaded images:");
+  const char* str_other_type  = _("Image has other data type than the previous loaded images:");
+  const char* str_rgbgray     = _("Image has different RGB/Gray layout.");
+  const char* str_16bitdata   = _("16-bit input data");
+  const char* str_downsample  = _("Downsampling to 8-bit will happen");
 
   printf("%s(\"%s\")...\n", __func__, fname);
   
-  int image_ID = cpaint_load_image_via_PDB (fname);
+  int image_ID = cpaint_load_image_via_PDB (fname, interactive);
   if (image_ID < 0)  return false;
     
   gint    nlayers  = -1;             // What for?
@@ -300,7 +322,8 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
   GPrecisionType precis = gimp_drawable_precision (layers[0]);
   gint           gray   = gimp_drawable_gray (layers[0]);
 
-  printf ("Image has %d layer(s); layer_ID = %d, precis = %s, gray = %d\n",
+  //  Debug output
+  printf ("Image has %d layers; layer_ID = %d, precis = %s, gray = %d\n",
       nlayers, layer_ID, cpaint_precision_name(precis), gray);
   
   int W = gimp_image_width (image_ID);
@@ -308,59 +331,54 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
   
   bool ok = false;
   
-  //  Tests for every image, be it the first or not...
+  //  Tests for each image, be it the first in the image container or not...
   if (nlayers > 1) {
-    fl_alert ("More than one layer in image\n\nImage \"%s\" ignored", 
-        fl_filename_name(fname));
+    br::msg_image_ignored (fl_filename_name(fname), "%s", str_multi_layer);
   } 
   else if (nlayers < 1) {
-    fl_alert ("No layer in image\n\nImage \"%s\" ignored", 
-        fl_filename_name(fname));
+    br::msg_image_ignored (fl_filename_name(fname), "%s", str_no_layer);        
   } 
   else if (layers[0] <= 0) {
-    fl_alert ("No data found in image\n\nImage \"%s\" ignored", 
-        fl_filename_name(fname));
+    br::msg_image_ignored (fl_filename_name(fname), "%s", str_no_data);        
   } 
   else if (gray) {
-    fl_alert ("Not an RGB image\n\nImage \"%s\" ignored", 
-        fl_filename_name(fname));
+    br::msg_image_ignored (fl_filename_name(fname), "%s", str_no_rgb);        
   }
   else if (! (precis == PRECISION_U8  ||  
               precis == PRECISION_U16) ) {
-    fl_alert ("\"%s\":\n\nSorry, data type '%s' not (yet) supported for input files.\n\nImage \"%s\" ignored",
-        fl_filename_name(fname),
-        cpaint_precision_name(precis),
-        fl_filename_name(fname));
+    br::msg_image_ignored (fl_filename_name(fname), 
+        _("Sorry, input images of data type '%s' are not supported."),
+        cpaint_precision_name(precis));
   } 
-  //  Now differentiate: first image in container or a following one?
+  //  Now differentiate: first image in image container or a following one?
   else if (mBr2Hdr.size() == 0)    // first image  
     {  
-      base_W = W;
-      base_H = H; 
-      base_precis = precis;
-      base_gray = gray;
+      first_W = W;
+      first_H = H; 
+      first_precis = precis;
+      first_gray = gray;
       ok = true;
     }   
-  else   // image behind first: check consistency with the first one...
+  else   // image behind the first: check consistency with the first image...
     {
-      if (W != base_W || H != base_H) 
+      if (W != first_W || H != first_H) 
         {
-          fl_alert ("\"%s\":\n\nDimension of the image to add doesn't fit to the existing image(s):\n\t\"%d x %d\"  vs.  \"%d x %d\".\n\nImage \"%s\" ignored.",
-              fl_filename_name(fname), W, H, base_W, base_H,
-              fl_filename_name(fname));
+          br::msg_image_ignored (fl_filename_name(fname), 
+              "%s\n\t\"%d x %d\"  vs.  \"%d x %d\".",  
+              str_other_dim, W, H, first_W, first_H);
         }
-      else if ((base_precis != precis) && (precis != PRECISION_U16)) // != U16 weil downgesampelt, veraltet
+      else if ((first_precis != precis) && ! ((first_precis == PRECISION_U8) &&
+               (precis == PRECISION_U16) && allWins.main->downsample_U16()) )
         {
-          fl_alert ("\"%s\":\n\nType of the image to add doesn't fit to the existing image(s):\n\t\"%s\"  vs.  \"%s\".\n\nImage \"%s\" ignored.",
-              fl_filename_name(fname),
+          br::msg_image_ignored (fl_filename_name(fname),
+              "%s\n\t\"%s\"  vs.  \"%s\".",
+              str_other_type, 
               cpaint_precision_name(precis),
-              cpaint_precision_name(base_precis),
-              fl_filename_name(fname));
+              cpaint_precision_name(first_precis));
         } 
-      else if (base_gray != gimp_drawable_gray(layers[0]))   // erledigt oben
+      else if (first_gray != gimp_drawable_gray(layers[0]))  // done above in "if (gray)"
         {  
-          fl_alert ("Other RGB/Gray layout in image.\n\nImage \"%s\" ignored.",
-              fl_filename_name(fname));
+          br::msg_image_ignored (fl_filename_name(fname), "%s", str_rgbgray);
         } 
       else 
         {
@@ -370,8 +388,7 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
   
   //  Take over the data..
   if (ok)
-    {  
-      // If allWinw.main->downsample_U16()==true we offer downsampling to U8
+    { // If allWinw.main->downsample_U16()==true, we offer downsampling to U8
       //  data. To note, that we *must not* scale down each image individually
       //  onto the full 8-bit range, because this would change the relation 
       //  between the various input images. We can only cut "stupidly" to the
@@ -393,13 +410,13 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
           if (allWins.main->downsample_U16()) {
             if (u16_u8_warning) 
             {
-              snprintf(tmp, 256, "\"%s\":  16-bit input data\n\nDownsampling to 8-bit will happen",
-                  fl_filename_name(fname));
-              int choice = fl_choice (tmp, "Abbort", "Downsample", "No more warn");
-              if (choice == 0)        // Abbort
+              snprintf (tmp, 256, "\"%s\":  %s\n\n%s",
+                  fl_filename_name(fname), str_16bitdata, str_downsample);
+              int choice = fl_choice (tmp, _("Cancel"), _("Downsample"), _("No more warn"));
+              if (choice == 0)        // Cancel
                 {      
                   ok = false; 
-                  break; 
+                  break;              // skips this image
                 }  
               else if (choice == 2)   // "Do no more warn"      
                 { 
@@ -407,8 +424,8 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
                 }  
             }
             img = u8_from_u16 (cpaint_get_BrImage_U16 (W,H, layer_ID));
-            //  If it is the first image, also base_precis is now U8
-            if (mBr2Hdr.size()==0) base_precis = PRECISION_U8;
+            //  If it is the first image, also first_precis is now U8
+            if (mBr2Hdr.size()==0) first_precis = PRECISION_U8;
           }
           else 
             img = cpaint_get_BrImage_U16 (W,H, layer_ID);            
@@ -420,21 +437,22 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
     
         default:  
           //  Might never be reached if tests above are complete
-          printf ("\"%s\":  Not supported data type %d: '%s'\n", 
+          e_printf ("\"%s\":  Not supported data type #%d: '%s'\n", 
               fl_filename_name(fname), precis, 
               cpaint_precision_name(precis));
           ok = false;
           break;
         }
 
-      // cpaint_get_BrImage() or u8_from_u16() could have returned Null-images:
+      //  cpaint_get_BrImage() or u8_from_u16() could have returned Null-images:
       ok = !img.is_null();  
               
       //  Set some meta data and add the image to the Br2HdrManager
       if (ok) 
         { 
           img.name (fname);
-          img.set_time (1.0);       // z.Z. nichts Besseres
+          readEXIF (fname, &img.exposure.shutter, &img.exposure.aperture, &img.exposure.ISO);
+          img.time_by_EXIF();  // default behaviour
           mBr2Hdr.add_Image (img);
           //mBr2Hdr.report_Images();
         }
@@ -452,14 +470,17 @@ cpaint_load_image (const char* fname, br::Br2HdrManager & mBr2Hdr)
 /**+*************************************************************************\n
   cpaint_load_image_via_PDB()  --  Helper for cpaint_load_image().
 
-  Asks CPaint for loading the file `fname' and returns its image_ID.
-   Function wraps the PDB and "return_vals" stuff.
+  Function asks CPaint for loading the image with filename \a fname and returns
+   its image_ID. Function wraps the PDB and "return_vals" stuff.
 
-  @param fname: name of file the CPaint image_ID is asked for
+  @param fname: Name of file the CPaint image_ID is asked for.
+  @param interactive: Has an effect only for loading of raw-data via the rawphoto
+   plug-in. To avoid that the rawphoto dialog occurs at every image of a bundle, 
+   it should be set true only for the first image and false for the following one.
   @return image_ID  (-1 for failure).
 ******************************************************************************/
 int 
-cpaint_load_image_via_PDB (const char* fname)
+cpaint_load_image_via_PDB (const char* fname, bool interactive)
 {
   int         image_ID;
   int         n_retvals;
@@ -467,14 +488,15 @@ cpaint_load_image_via_PDB (const char* fname)
   
   return_vals = gimp_run_procedure ("gimp_file_load",
                                     & n_retvals,
-                                    GIMP_PDB_INT32, GIMP_RUN_INTERACTIVE,
+                                    GIMP_PDB_INT32, 
+                 interactive ? GIMP_RUN_INTERACTIVE : GIMP_RUN_NONINTERACTIVE,
                                     GIMP_PDB_STRING, fname,
                                     GIMP_PDB_STRING, fname,
                                     GIMP_PDB_END);
   
   if (return_vals[0].data.d_status != GIMP_PDB_SUCCESS)
     image_ID = -1;
-  else
+  else 
     image_ID = return_vals[1].data.d_image;
   
   gimp_destroy_params (return_vals, n_retvals);
@@ -483,17 +505,17 @@ cpaint_load_image_via_PDB (const char* fname)
 
 
 /**+*************************************************************************\n
-  cpaint_get_BrImage_U8()  --  Helper for cpaint_load_image()
+  cpaint_get_BrImage_U8()  --  Helper for cpaint_load_image().
 
-  Allocates a BrImage and fills-in the CPaint image buffer related to 
-   `layer_ID'. A possible alpha channel in CPaints image buffer gets removed. 
-   Default settings for name and exposure time and all other meta data.
-   Type dependence (U8, U16...) concerns the template copy_without_alpha<>.
+  Allocates a br::BrImage and fills-in the CPaint image buffer related to 
+   \a layer_ID. A possible alpha channel in CPaint's image buffer gets removed. 
+   Default settings for name and exposure time and all other meta data. Type
+   dependence (U8, U16...) are handled by the template copy_without_alpha<>().
    Could be done also by a br::ImageType parameter and a switch statement.
 
-  @param W,H: width, height of the layer
+  @param W,H: width, height of the CPaint layer.
   @param layer_ID: as got by cpaint_load_image(). Data type must be U8!
-  @return  An allocated and filled BrImage of type RGB_U8
+  @return  An allocated and filled br::BrImage of type RGB_U8
 ******************************************************************************/
 br::BrImage 
 cpaint_get_BrImage_U8 (int W, int H, gint32 layer_ID)
@@ -508,7 +530,7 @@ cpaint_get_BrImage_U8 (int W, int H, gint32 layer_ID)
 
   if (gimp_drawable_has_alpha (layer_ID))     
     { 
-      //  Have alpha: re-copy
+      //  Has alpha: re-copy
       copy_without_alpha <guint8> (img, pixel_rgn);
     }
   else
@@ -522,9 +544,9 @@ cpaint_get_BrImage_U8 (int W, int H, gint32 layer_ID)
 
 
 /**+*************************************************************************\n
-  cpaint_get_BrImage_U16()  --  Helper for cpaint_load_image()
-
-  See cpaint_get_BrImage_U8().
+  cpaint_get_BrImage_U16()  --  Helper for cpaint_load_image().
+  
+  Description see: cpaint_get_BrImage_U8().
 ******************************************************************************/
 br::BrImage 
 cpaint_get_BrImage_U16 (int W, int H, gint32 layer_ID)
@@ -539,7 +561,7 @@ cpaint_get_BrImage_U16 (int W, int H, gint32 layer_ID)
 
   if (gimp_drawable_has_alpha (layer_ID))     
     { 
-      //  Have alpha: re-copy  
+      //  Has alpha: re-copy  
       copy_without_alpha <guint16> (img, pixel_rgn);
     }
   else  
@@ -551,14 +573,19 @@ cpaint_get_BrImage_U16 (int W, int H, gint32 layer_ID)
 }
 
 /**+*************************************************************************\n
-  copy_without_alpha<>()  --  helper of cpaint_get_BrImage()
+  copy_without_alpha<>()  --  Helper of cpaint_get_BrImage().
 
-  @param <T>: type of the image data (guint8, guint16, ...)
-  @param img: RGB<T> br::Image. Extern allocated. The destination.
-  @param rgn: CPaint pixel region of RGBA<T> data of same dimension as img.
+  Function copies the data of the CinePaint pixel region \a rgn, which has an
+   alpha channel, into the (extern allocated) br::Image \a img under removing 
+   the alpha channel.
+  
+  @pre \a img.width() and \a img.height() must be the dimensions also of the
+    pixel region \a rgn!
+  
+  @param <T>: Type of the image data (guint8, guint16, ...)
+  @param img: br::Image of RGB<T> data. Extern allocated. The destination.
+  @param rgn: CPaint pixel region of RGBA<T> data of same dimension as \a img.
                The source.
-  Copies the data of `rgn' into `img' under removing the alpha channel. 
-   img.width() and img.height() must be the dimensions also of `rgn'!
 ******************************************************************************/
 template <typename T>
 void 
@@ -584,16 +611,25 @@ copy_without_alpha (br::Image & img, GPixelRgn & rgn)
 
 
 /**+*************************************************************************\n
-  cpaint_show_rgb_imgbuf()  --  Plot of an RGB buffer without alpha.
+  cpaint_show_rgb_imgbuf() 
+   
+  Function plots via CinePaint a contiguous RGB buffer \a imgbuf (without 
+   alpha channel!) of data type \a prec. Intended for CPaint plot of an 
+   br::BrImage with RGB data or an Array2D< Rgb<T> > array. For messages we use
+   the "abstract" function pointer br::v_alert(), so they can appear on the GUI
+   screen.
 
   @param W,H: image dimensions width and height
   @param imgbuf: contiguous (W x H)-buffer of RGB data (no alpha)
   @param prec: data type (CinePaint enum)
 
-  Intended for CPaint plot of an RGB-BrImage or an Array2D< Rgb<T> > array.
-  For br::Image and TNT::Array2D: width==dim2, height==dim1. Array2D example:
-
-  cpaint_show_rgb_imgbuf (A.dim2(), A.dim1(), (uchar*)A[0], PRECISION_FLOAT);
+  @note For br::Image and TNT::Array2D<> is width==dim2(), height==dim1()! 
+  
+  Example of usage: Be \a A a TNT::Array2D<Rgb<float> > array. The following
+   creates a CinePaint image display of the array data: 
+  <pre>
+    cpaint_show_rgb_imgbuf (A.dim2(), A.dim1(), (uchar*)A[0], PRECISION_FLOAT);
+  </pre>  
 ******************************************************************************/
 void 
 cpaint_show_rgb_imgbuf (int W, int H, const uchar* imgbuf, GPrecisionType prec)
@@ -621,8 +657,8 @@ cpaint_show_rgb_imgbuf (int W, int H, const uchar* imgbuf, GPrecisionType prec)
         drawable_type = FLOAT16_RGB_IMAGE; break;
     
     default:
-        fl_alert ("%s: Precision %d ('%s') not supported\n",
-            PLUGIN_NAME, prec, cpaint_precision_name(prec));
+        br::v_alert (_("Precision #%d ('%s') not supported."),
+            prec, cpaint_precision_name(prec));
         return;
     }       
   
@@ -630,19 +666,19 @@ cpaint_show_rgb_imgbuf (int W, int H, const uchar* imgbuf, GPrecisionType prec)
 
   if (image_ID == -1) 
     {
-      fl_alert ("%s: Can't create a new image\n%d x %d, image_type %d",
-          PLUGIN_NAME, W, H, image_type);
+      const char* str_could_not = _("Could not create a new image");
+      br::v_alert ("%s\n%d x %d, image_type #%d", str_could_not, W, H, image_type);
       return;
     }
 
   layer_ID = gimp_layer_new (image_ID,
-                             "HDR bracketing",
+                             "Br2HDR",          // where does this apear?
                              (guint)W, (guint)H,
                              drawable_type,
-                             100.0,          // opacity
+                             100.0,             // opacity
                              NORMAL_MODE );
   
-  gimp_image_add_layer (image_ID, layer_ID, 0);   // Wozu?
+  gimp_image_add_layer (image_ID, layer_ID, 0);  // Wozu?
 
   GDrawable* drawable = gimp_drawable_get (layer_ID);
 
@@ -659,9 +695,13 @@ cpaint_show_rgb_imgbuf (int W, int H, const uchar* imgbuf, GPrecisionType prec)
 
 /**+*************************************************************************\n
   cpaint_show_image()
-  Typepruefung koennte neuerdings auch an ImageType abgehandelt werden, zumal
+  
+  Function plots via CinePaint the image data stored in the br::Image object 
+   \a img. The type of the image data should be handled here appropriately.
+   
+  Typpruefung koennte neuerdings auch an br::ImageType abgehandelt werden, zumal
    durch CinePaint ohnehin nur RGB-Puffer (STORING_INTERLEAVE) zu verarbeiten
-   sind. Momentaner Mangel der Metavariable `ImageType noch, dass zu wenig
+   sind. Momentaner Mangel der Metavariable br::ImageType noch, dass zu wenig
    Varianten erfasst und Fehlermeldungen dadurch zu duerftig sind (IMAGE_NONE
    oder IMAGE_UNKNOWN).
 ******************************************************************************/
@@ -689,7 +729,8 @@ cpaint_show_image (const br::Image & img)
 
 
 /**+*************************************************************************\n
-  @return  Name of GPrecisionTypes  --  for messages and warnings.
+  Returns a human readable name of the GPrecisionType enum value \a precis; 
+   useful for messages and warnings.
 ******************************************************************************/
 const char* 
 cpaint_precision_name (GPrecisionType precis)
