@@ -61,7 +61,7 @@ int	do_collect	();
 int	file_load	(const char*	 filename,
                          int             interactiv);
 
-//#define DEBUG
+#define DEBUG
 #ifdef DEBUG
 #include <iostream>
 #define cout std::cout
@@ -116,14 +116,14 @@ query ()
                            PLUG_IN_AUTHOR,
                            PLUG_IN_COPYRIGHT,
                            PLUG_IN_VERSION,
-                           "<Toolbox>/File/New From/Collect" ,
+                           "<Toolbox>/File/New From/Collect..." ,
                            "*",
                            PROC_EXTENSION,
                            n_args_, n_return_vals_,
                            args, return_vals);
 
    // translation workaround
-   _("File"); _("New From"); _("Collect");
+   _("File"); _("New From"); _("Collect...");
 }
 
 void
@@ -150,6 +150,7 @@ run (char    *name,		// I - Name of called function resp. plug-in
   if (strcmp (name, PLUG_IN_NAME) == 0)
   {
     INIT_I18N_UI();
+    INIT_FLTK1_CODESET();
 
     sprintf (vals.name, getenv("PWD"));
     gimp_get_data ("collect", &vals);
@@ -226,8 +227,14 @@ raw_check( const char* fname, uchar *header, int len )
                 command[1024];  // Command
   int stat;
 
+  const char *endung = strrchr(fname,'.');
+  if(strstr(endung+1,"png") != 0) return NULL;
+  if(strstr(endung+1,"xbm") != 0) return NULL;
+  if(strstr(endung+1,"jpg") != 0) return NULL;
+
   sprintf (command, "dcraw -i '%s'\n", fname);
-  fputs (command, stderr);
+  //fputs (command, stderr);
+
   stat = system (command);
 
   if (stat) {
@@ -265,7 +272,7 @@ do_collect ()
 
         Fl_Shared_Image::add_handler(raw_check);
         Fl_File_Icon::load_system_icons();
-        fc = new Fl_File_Chooser(vals.name, "*.*", Fl_File_Chooser::MULTI, "Select images");
+        fc = new Fl_File_Chooser(vals.name, "*.*", Fl_File_Chooser::MULTI, _("Select images"));
         fc->show();
 
         while (fc->visible())
@@ -277,16 +284,22 @@ do_collect ()
           // take the first image as reference
           unsigned int max_w = 0, max_h = 0;
 
-          #ifdef DBEUG
+          #ifdef DEBUG
           cout << "adding image " << fc->value(1) << endl;
           #endif
           int load_image_ID = file_load(fc->value(1), 1);
           image_ID = load_image_ID;
 
-          // renaming of the first selected image
-          gimp_image_set_filename (image_ID, "Collect");
+          // if solo, renaming to the first selected image
+          if(count > 1)
+            gimp_image_set_filename (image_ID, _("Collect"));
+          else
+            gimp_image_set_filename (image_ID, (char*)fc->value(1));
           layers = gimp_image_get_layers (load_image_ID, &nlayers);
 
+          if(!layers)
+            return -1;
+
           // renaming the layer to the original filename
           gimp_layer_set_name (layers[0], strrchr(fc->value(1),'/')+1);
           GPrecisionType image_base_prec = gimp_drawable_precision (layers[0]);
