@@ -48,7 +48,7 @@ static gint32    compose (char *compose_type,
                           gint32 *compose_ID);
 
 static gint32    create_new_image (char *filename, guint width, guint height,
-                   GDrawableType gdtype, gint32 *layer_ID, TileDrawable **drawable,
+                   GDrawableType gdtype, GImageType itype, gint32 *layer_ID, TileDrawable **drawable,
                    GPixelRgn *pixel_rgn);
 
 static int       cmp_icase (char *s1, char *s2);
@@ -92,6 +92,8 @@ typedef struct {
 /* Array of available compositions. */
 static COMPOSE_DSC compose_dsc[] = {
  { "FLOAT16_RGB",  3, { "Red:",   "Green:     ", "Blue:" },
+              "rgb-compose",  compose_rgb },
+ { "U16_RGB",  3, { "Red:",   "Green:     ", "Blue:" },
               "rgb-compose",  compose_rgb }
 };
 
@@ -168,7 +170,7 @@ query ()
 			  "Peter Kirchgessner (pkirchg@aol.com)",
 			  "1997",
 			  "<Image>/Image/Channel Ops/Compose",
-			  "FLOAT16_GRAY",
+			  "FLOAT16_GRAY,U16_GRAY",
 			  PROC_PLUG_IN,
 			  nargs, nreturn_vals,
 			  args, return_vals);
@@ -337,11 +339,41 @@ compose (char *compose_type,
   }
 
   /* Create new image */
-  gdtype_dst = (compose_dsc[compose_idx].compose_fun == compose_rgba)
-              ? FLOAT16_RGBA_IMAGE : FLOAT16_RGB_IMAGE;
-  image_ID_dst = create_new_image (compose_dsc[compose_idx].filename,
-                      width, height, gdtype_dst,
+  {
+    GDrawableType drawable_type = gimp_drawable_type (g32[0]);
+    GImageType image_type = gimp_image_base_type (g32[0]);
+    int alpha = gimp_drawable_has_alpha(g32[0]);
+    GDrawableType dtype = 0;
+    GImageType itype = 0;
+
+    switch (drawable_type) {
+    case U16_GRAY_IMAGE:
+    case U16_GRAYA_IMAGE:
+         itype = U16_RGB;
+         dtype = U16_RGB_IMAGE;
+         break;
+    case BFP_GRAY_IMAGE:
+    case BFP_GRAYA_IMAGE:
+         itype = BFP_RGB;
+         dtype = BFP_RGB_IMAGE;
+         break;
+    case FLOAT16_GRAY_IMAGE:
+    case FLOAT16_GRAYA_IMAGE:
+         itype = FLOAT16_RGB;
+         dtype = FLOAT16_RGB_IMAGE;
+         break;
+    case FLOAT_GRAY_IMAGE:
+    case FLOAT_GRAYA_IMAGE:
+         itype = FLOAT_RGB;
+         dtype = FLOAT_RGB_IMAGE;
+         break;
+    }
+
+    image_ID_dst = create_new_image (compose_dsc[compose_idx].filename,
+                      width, height, dtype, itype,
                       &layer_ID_dst, &drawable_dst, &pixel_rgn_dst);
+  }
+
   dst = (unsigned char *)g_malloc (tile_height * width * drawable_dst->bpp);
   if (dst == NULL)
   {
@@ -393,18 +425,19 @@ create_new_image (char *filename,
                   guint width,
                   guint height,
                   GDrawableType gdtype,
+                  GImageType gitype,
                   gint32 *layer_ID,
                   TileDrawable **drawable,
                   GPixelRgn *pixel_rgn)
 
 {gint32 image_ID;
- GImageType gitype;
+ /*GImageType gitype;
 
  if ((gdtype == FLOAT16_GRAY_IMAGE) || (gdtype == FLOAT16_GRAYA_IMAGE))
    gitype = FLOAT16_GRAY;
  else
    gitype = FLOAT16_RGB;
-
+ */
  image_ID = gimp_image_new (width, height, gitype);
  gimp_image_set_filename (image_ID, filename);
 
