@@ -49,15 +49,15 @@ static gint32    decompose (gint32  image_id,
                             gint32  *drawable_ID_dst);
 
 static gint32 create_new_image (char *filename, guint width, guint height,
-                GImageType type, gint32 *layer_ID, TileDrawable **drawable,
+                GDrawableType dtype, GImageType itype, gint32 *layer_ID, TileDrawable **drawable,
                 GPixelRgn *pixel_rgn);
 
 static int cmp_icase (char *s1, char *s2);
 
-static void extract_float16_rgb      
+static void extract_16_rgb      
 			     (guchar *src, int bpp, int numpix,
                               guchar **dst);
-static void extract_float16_rgba      
+static void extract_16_rgba      
 			     (guchar *src, int bpp, int numpix,
                               guchar **dst);
 static void extract_red      (guchar *src, int bpp, int numpix,
@@ -95,8 +95,12 @@ typedef struct {
 } EXTRACT;
 
 static EXTRACT extract[] = {
-  { "FLOAT16_RGB", 1,  3, { "red", "green", "blue"        }, extract_float16_rgb },
-  { "FLOAT16_RGBA", 1,  3, { "red", "green", "blue", "alpha" }, extract_float16_rgba },
+  { "U16_RGB", 1,  3, { "red", "green", "blue"        }, extract_16_rgb },
+  { "U16_RGBA", 1,  4, { "red", "green", "blue", "alpha" }, extract_16_rgba },
+  { "FLOAT16_RGB", 1,  3, { "red", "green", "blue"        }, extract_16_rgb },
+  { "FLOAT16_RGBA", 1,  4, { "red","green","blue", "alpha" }, extract_16_rgba },
+  { "BFP_RGB", 1,  3, { "red", "green", "blue"        }, extract_16_rgb },
+  { "BFP_RGBA", 1,  4, { "red", "green", "blue", "alpha" }, extract_16_rgba },
   { "Red",     0,  1, { "red"                             }, extract_red },
   { "Green",   0,  1, { "green"                           }, extract_green },
   { "Blue",    0,  1, { "blue"                            }, extract_blue }
@@ -168,7 +172,7 @@ query ()
 			  "Peter Kirchgessner (pkirchg@aol.com)",
 			  "1997",
 			  "<Image>/Image/Channel Ops/Decompose",
-			  "FLOAT16_RGB*",
+			  "U16_RGB*,FLOAT16_RGB*",
 			  PROC_PLUG_IN,
 			  nargs, nreturn_vals,
 			  args, return_vals);
@@ -208,8 +212,8 @@ run (char    *name,
       gimp_get_data ("plug_in_decompose", &decovals);
 
       /*  First acquire information with a dialog  */
-      if (! decompose_dialog ())
-	return;
+      /*if (! decompose_dialog ())
+	return;*/
       break;
 
     case RUN_NONINTERACTIVE:
@@ -235,7 +239,7 @@ run (char    *name,
 
   /*  Make sure that the drawable is RGB color  */
   drawable_type = gimp_drawable_type (param[2].data.d_drawable);
-  if ((drawable_type != FLOAT16_RGB_IMAGE) && (drawable_type != FLOAT16_RGBA_IMAGE))
+  if ((drawable_type != FLOAT16_RGB_IMAGE) && (drawable_type != FLOAT16_RGBA_IMAGE && drawable_type != U16_RGB_IMAGE && drawable_type != U16_RGBA_IMAGE))
   {
     e_printf ("plug_in_decompose: Can only work on RGB*_IMAGE\n");
     status = STATUS_CALLING_ERROR;
@@ -290,7 +294,8 @@ decompose (gint32 image_ID,
   char filename[1024];
   guchar *dst[MAX_EXTRACT_IMAGES];
   gint32 layer_ID_dst[MAX_EXTRACT_IMAGES];
-  TileDrawable *drawable_src, *drawable_dst[MAX_EXTRACT_IMAGES];
+  GimpDrawable *drawable_src;
+  TileDrawable *drawable_dst[MAX_EXTRACT_IMAGES];
   GPixelRgn pixel_rgn_src, pixel_rgn_dst[MAX_EXTRACT_IMAGES];
   
 
@@ -341,10 +346,40 @@ decompose (gint32 image_ID,
 
   for (j = 0; j < num_images; j++)
   {
+    GDrawableType drawable_type = gimp_drawable_type (drawable_src->id);
+    GImageType image_type = gimp_image_base_type (image_ID);
+    int alpha = gimp_drawable_has_alpha(drawable_src->id);
+    GDrawableType dtype = 0;
+    GImageType itype = 0;
+
+    switch (drawable_type) {
+    case U16_RGB_IMAGE:
+    case U16_RGBA_IMAGE:
+         itype = U16_GRAY;
+         dtype = alpha ? U16_GRAYA_IMAGE : U16_GRAY_IMAGE;
+         break;
+    case BFP_RGB_IMAGE:
+    case BFP_RGBA_IMAGE:
+         itype = BFP_GRAY;
+         dtype = alpha ? BFP_GRAYA_IMAGE : BFP_GRAY_IMAGE;
+         break;
+    case FLOAT16_RGB_IMAGE:
+    case FLOAT16_RGBA_IMAGE:
+         itype = FLOAT16_GRAY;
+         dtype = alpha ? FLOAT16_GRAYA_IMAGE : FLOAT16_GRAY_IMAGE;
+         break;
+    case FLOAT_RGB_IMAGE:
+    case FLOAT_RGBA_IMAGE:
+         itype = FLOAT_GRAY;
+         dtype = alpha ? FLOAT_GRAYA_IMAGE : FLOAT_GRAY_IMAGE;
+         break;
+    }
+
     sprintf (filename, "%s-%s", gimp_image_get_filename (image_ID),
              extract[extract_idx].channel_name[j]);
 
-    image_ID_dst[j] = create_new_image (filename, width, height, FLOAT16_GRAY,
+    image_ID_dst[j] = create_new_image (filename, width, height,
+                         dtype, itype,
                          layer_ID_dst+j, drawable_dst+j, pixel_rgn_dst+j);
     dst[j] = (guchar*) g_malloc (tile_height * width * drawable_src->bpp);
   }
@@ -398,27 +433,19 @@ static gint32
 create_new_image (char *filename,
                   guint width,
                   guint height,
+                  GDrawableType dtype,
                   GImageType type,
                   gint32 *layer_ID,
                   TileDrawable **drawable,
                   GPixelRgn *pixel_rgn)
 
 {gint32 image_ID;
- GDrawableType gdtype;
-
- if (type == FLOAT16_GRAY) gdtype = FLOAT16_GRAY_IMAGE;
- else if (type == FLOAT16_RGB) gdtype = FLOAT16_RGBA_IMAGE; 
- else 
-   {
-     type = FLOAT16_RGB; 
-     gdtype = FLOAT16_RGB_IMAGE;
-   }
 
  image_ID = gimp_image_new (width, height, type);
  gimp_image_set_filename (image_ID, filename);
 
  *layer_ID = gimp_layer_new (image_ID, "Background", width, height,
-                            gdtype, 100, NORMAL_MODE);
+                             dtype, 100, NORMAL_MODE);
  gimp_image_add_layer (image_ID, *layer_ID, 0);
 
  *drawable = gimp_drawable_get (*layer_ID);
@@ -445,7 +472,7 @@ static int cmp_icase (char *s1, char *s2)
 }
 
 
-static void extract_float16_rgb (guchar *src, int bpp, int numpix,
+static void extract_16_rgb (guchar *src, int bpp, int numpix,
                          guchar **dst)
 
 {register guchar *rgb_src = src;
@@ -467,7 +494,7 @@ static void extract_float16_rgb (guchar *src, int bpp, int numpix,
 }
 
 
-static void extract_float16_rgba (guchar *src, int bpp, int numpix,
+static void extract_16_rgba (guchar *src, int bpp, int numpix,
                          guchar **dst)
 
 {register guchar *rgb_src = src;
