@@ -124,6 +124,7 @@ int c_sp, i;
 static void push_c(int addr);
 static int pop_c(void);
 static void reset(void);
+static void yyerror(char *string);
 
 
 
@@ -141,13 +142,13 @@ static void reset(void);
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 43 "parser.y"
+#line 44 "parser.y"
 typedef union YYSTYPE {
 	float val;
 	int sptr;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 150 "parser.tab.c"
+#line 151 "parser.tab.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -159,7 +160,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 162 "parser.tab.c"
+#line 163 "parser.tab.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -349,11 +350,11 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    57,    57,    58,    61,    62,    63,    64,    65,    66,
-      67,    68,    69,    70,    71,    74,    75,    76,    77,    78,
-      79,    80,    81,    82,    83,    86,    87,    88,    89,    90,
-      91,    92,    93,    94,    95,    96,   102,   106,   110,   114,
-     118,   122,   128,   131,   138
+       0,    58,    58,    59,    62,    63,    64,    65,    66,    67,
+      68,    69,    70,    71,    72,    75,    76,    77,    78,    79,
+      80,    81,    82,    83,    84,    87,    88,    89,    90,    91,
+      92,    93,    94,    95,    96,    97,   103,   107,   111,   115,
+     119,   123,   129,   132,   139
 };
 #endif
 
@@ -1157,152 +1158,152 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 61 "parser.y"
+#line 62 "parser.y"
     { inp(yyvsp[-4].sptr,yyvsp[-3].sptr,yyvsp[-2].sptr,yyvsp[-1].sptr); }
     break;
 
   case 5:
-#line 62 "parser.y"
+#line 63 "parser.y"
     { outp(yyvsp[-4].sptr,yyvsp[-3].sptr,yyvsp[-2].sptr,yyvsp[-1].sptr); }
     break;
 
   case 6:
-#line 63 "parser.y"
+#line 64 "parser.y"
     { size(yyvsp[-2].sptr,yyvsp[-1].sptr); }
     break;
 
   case 7:
-#line 64 "parser.y"
+#line 65 "parser.y"
     { pos(yyvsp[-2].sptr,yyvsp[-1].sptr); }
     break;
 
   case 10:
-#line 67 "parser.y"
+#line 68 "parser.y"
     { pop_var(yyvsp[-3].sptr); }
     break;
 
   case 11:
-#line 68 "parser.y"
+#line 69 "parser.y"
     { code[pc++].i = 0x17; }
     break;
 
   case 12:
-#line 69 "parser.y"
+#line 70 "parser.y"
     { /* so we can have empty ELSE statements */ }
     break;
 
   case 13:
-#line 70 "parser.y"
-    { yyerrok; yyclearin; }
-    break;
-
-  case 14:
 #line 71 "parser.y"
     { yyerrok; yyclearin; }
     break;
 
+  case 14:
+#line 72 "parser.y"
+    { yyerrok; yyclearin; }
+    break;
+
   case 16:
-#line 75 "parser.y"
+#line 76 "parser.y"
     { code[pc++].i = 0x01; }
     break;
 
   case 17:
-#line 76 "parser.y"
+#line 77 "parser.y"
     { code[pc++].i = 0x02; }
     break;
 
   case 18:
-#line 77 "parser.y"
+#line 78 "parser.y"
     { code[pc++].i = 0x03; }
     break;
 
   case 19:
-#line 78 "parser.y"
+#line 79 "parser.y"
     { code[pc++].i = 0x04; }
     break;
 
   case 20:
-#line 79 "parser.y"
+#line 80 "parser.y"
     { code[pc++].i = 0x16; }
     break;
 
   case 21:
-#line 80 "parser.y"
+#line 81 "parser.y"
     { ; }
     break;
 
   case 22:
-#line 81 "parser.y"
+#line 82 "parser.y"
     { yyerrok; yyclearin; }
     break;
 
   case 23:
-#line 82 "parser.y"
+#line 83 "parser.y"
     { push_val(yyvsp[0].val); }
     break;
 
   case 24:
-#line 83 "parser.y"
+#line 84 "parser.y"
     { push_var(yyvsp[0].sptr); }
     break;
 
   case 25:
-#line 86 "parser.y"
+#line 87 "parser.y"
     { code[pc++].i = 0x0A; }
     break;
 
   case 26:
-#line 87 "parser.y"
+#line 88 "parser.y"
     { code[pc++].i = 0x0B; }
     break;
 
   case 27:
-#line 88 "parser.y"
+#line 89 "parser.y"
     { code[pc++].i = 0x0C; }
     break;
 
   case 28:
-#line 89 "parser.y"
+#line 90 "parser.y"
     { code[pc++].i = 0x0D; }
     break;
 
   case 29:
-#line 90 "parser.y"
+#line 91 "parser.y"
     { code[pc++].i = 0x0E; }
     break;
 
   case 30:
-#line 91 "parser.y"
+#line 92 "parser.y"
     { code[pc++].i = 0x0F; }
     break;
 
   case 31:
-#line 92 "parser.y"
+#line 93 "parser.y"
     { code[pc++].i = 0x10; }
     break;
 
   case 32:
-#line 93 "parser.y"
+#line 94 "parser.y"
     { code[pc++].i = 0x11; }
     break;
 
   case 33:
-#line 94 "parser.y"
+#line 95 "parser.y"
     { code[pc++].i = 0x12; }
     break;
 
   case 34:
-#line 95 "parser.y"
+#line 96 "parser.y"
     { code[pc++].i = 0x13; }
     break;
 
   case 35:
-#line 96 "parser.y"
+#line 97 "parser.y"
     { code[pc++].i = 0x14; }
     break;
 
   case 36:
-#line 102 "parser.y"
+#line 103 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x1C;
 							push_c(pc);
@@ -1310,7 +1311,7 @@ yyreduce:
     break;
 
   case 37:
-#line 106 "parser.y"
+#line 107 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x1B;
 							push_c(pc);
@@ -1318,7 +1319,7 @@ yyreduce:
     break;
 
   case 38:
-#line 110 "parser.y"
+#line 111 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x1D;
 							push_c(pc);
@@ -1326,7 +1327,7 @@ yyreduce:
     break;
 
   case 39:
-#line 114 "parser.y"
+#line 115 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x1E;
 							push_c(pc);
@@ -1334,7 +1335,7 @@ yyreduce:
     break;
 
   case 40:
-#line 118 "parser.y"
+#line 119 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x19;
 							push_c(pc);
@@ -1342,7 +1343,7 @@ yyreduce:
     break;
 
   case 41:
-#line 122 "parser.y"
+#line 123 "parser.y"
     {	code[pc++].i = 0x02;
 							code[pc++].i = 0x1A;
 							push_c(pc);
@@ -1350,12 +1351,12 @@ yyreduce:
     break;
 
   case 42:
-#line 128 "parser.y"
+#line 129 "parser.y"
     { code[pop_c()].i = pc; }
     break;
 
   case 43:
-#line 131 "parser.y"
+#line 132 "parser.y"
     {	code[pc++].i = 0x01F;
 							i = pop_c();
 							push_c(pc);
@@ -1364,7 +1365,7 @@ yyreduce:
     break;
 
   case 44:
-#line 138 "parser.y"
+#line 139 "parser.y"
     { code[pop_c()].i = pc; }
     break;
 
@@ -1372,7 +1373,7 @@ yyreduce:
     }
 
 /* Line 991 of yacc.c.  */
-#line 1375 "parser.tab.c"
+#line 1376 "parser.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1582,7 +1583,7 @@ yyreturn:
 }
 
 
-#line 140 "parser.y"
+#line 141 "parser.y"
 
 
 /* look up an entry in the symbol table. If not found, add it */
@@ -1690,8 +1691,9 @@ int compile(void)
 	return yyparse();
 }
 
-yyerror(char *string)
+void yyerror(char *string)
 {
 	fprintf(stderr,"IOL error (line %d): %s\n",lineno,string);
 }
 
+
