@@ -148,7 +148,7 @@ query ()
                           "Spencer Kimball & Peter Mattis",
                           "1995-1996",
                           "<Save>/Jpeg",
-                          "RGB*, GRAY*",
+                          "*",
                           PROC_PLUG_IN,
                           nsave_args, 0,
                           save_args, NULL);
@@ -487,6 +487,11 @@ save_image (char   *filename,
   guchar *src, *s;
   char *name;
   int has_alpha;
+  GimpExportReturnType export = GIMP_EXPORT_CANCEL;
+  gint32 e_image_ID = -1;
+  gint32 e_drawable_ID = -1;
+  GPrecisionType precision;
+
   int rowstride, yend;
   int i, j;
 
@@ -546,30 +551,10 @@ save_image (char   *filename,
 
   /* Get the input image and a pointer to its data.
    */
-  switch (drawable_type)
-    {
-    case RGB_IMAGE:
-    case GRAY_IMAGE:
-      /* # of color components per pixel */
-      cinfo.input_components = drawable->bpp;
-      has_alpha = 0;
-      break;
-    case RGBA_IMAGE:
-    case GRAYA_IMAGE:
-      /*gimp_message ("jpeg: image contains a-channel info which will be lost");*/
-      /* # of color components per pixel (minus the GIMP alpha channel) */
-      cinfo.input_components = drawable->bpp - 1;
-      has_alpha = 1;
-      break;
-    case INDEXED_IMAGE:
-      /*gimp_message ("jpeg: cannot operate on indexed color images");*/
-      return FALSE;
-      break;
-    default:
-      /*gimp_message ("jpeg: cannot operate on unknown image types");*/
-      return FALSE;
-      break;
-    }
+  cinfo.input_components = gimp_drawable_num_channels(drawable_ID);
+  has_alpha = gimp_drawable_has_alpha(drawable_ID);
+  if(has_alpha)
+    --cinfo.input_components;
 
   /* Step 3: set parameters for compression */
 
@@ -580,9 +565,9 @@ save_image (char   *filename,
   cinfo.image_width = drawable->width;
   cinfo.image_height = drawable->height;
   /* colorspace of input image */
-  cinfo.in_color_space = (drawable_type == RGB_IMAGE ||
-			  drawable_type == RGBA_IMAGE)
+  cinfo.in_color_space = gimp_drawable_color(drawable_ID) 
     ? JCS_RGB : JCS_GRAYSCALE;
+
   /* Now use the library's routine to set default compression parameters.
    * (You must set at least cinfo.in_color_space before calling this,
    * since the defaults depend on the source color space.)
@@ -626,11 +611,37 @@ save_image (char   *filename,
    */
   /* JSAMPLEs per row in image_buffer */
   rowstride = drawable->bpp * drawable->width;
-  temp = (guchar *) malloc (cinfo.image_width * cinfo.input_components);
+  temp = (guchar *) malloc (cinfo.image_width * cinfo.input_components * 4);
   data = (guchar *) malloc (rowstride * gimp_tile_height ());
 
+        export = gimp_export_image (&image_ID, &drawable_ID, "Jpeg",
+                                    (GIMP_EXPORT_CAN_HANDLE_RGB |
+                                     GIMP_EXPORT_CAN_HANDLE_GRAY |
+                                     GIMP_EXPORT_CAN_HANDLE_INDEXED));
+        if (export == GIMP_EXPORT_CANCEL)
+        {
+          gimp_message("An error during export occured.");
+          return FALSE;
+        } else if (export == GIMP_EXPORT_EXPORT) {
+          e_image_ID = image_ID;
+          e_drawable_ID = drawable_ID;
+          drawable_type = gimp_drawable_type(e_drawable_ID);
+        }
+
+  precision = gimp_drawable_precision(drawable_ID);
+
+/* taken from app/depth/bfp.h */
+#define ONE_BFP 32768
+#define BFP_TO_U8(x) (x < ONE_BFP ? x >> 7 : 255)
+
   while (cinfo.next_scanline < cinfo.image_height)
     {
+      guint16 *s16;
+      gfloat *f32;
+      gfloat f;
+      ShortsFloat u;
+      guint16 bfp;
+
       if ((cinfo.next_scanline % gimp_tile_height ()) == 0)
 	{
 	  yend = cinfo.next_scanline + gimp_tile_height ();
@@ -643,13 +654,61 @@ save_image (char   *filename,
       t = temp;
       s = src;
       i = cinfo.image_width;
+      s16 = (guint16*) s;
+      f32 = (gfloat*) s;
 
       while (i--)
 	{
-	  for (j = 0; j < cinfo.input_components; j++)
-	    *t++ = *s++;
-	  if (has_alpha)  /* ignore alpha channel */
-	    s++;
+          switch(precision)
+          {
+          case PRECISION_U8:
+  	    for (j = 0; j < cinfo.input_components; j++)
+	      *t++ = *s++;
+	    if (has_alpha)  /* ignore alpha channel */
+	      s++;
+          break;
+          case PRECISION_U16:
+            {
+  	    for (j = 0; j < cinfo.input_components; j++)
+	      *t++ = (guint8)((*s16++)/257);
+	    if (has_alpha)  /* ignore alpha channel */
+	      s16++;
+            }
+          break;
+          case PRECISION_FLOAT16:
+            {
+  	    for (j = 0; j < cinfo.input_components; j++)
+            {
+              f = (FLT(*s16++,u)) * 255.;
+	      *t++ = (guint8)(CLAMP(f, 0, 255));
+            }
+	    if (has_alpha)  /* ignore alpha channel */
+	      s16++;
+            }
+          break;
+          case PRECISION_FLOAT:
+            {
+  	    for (j = 0; j < cinfo.input_components; j++)
+            {
+              f = (*f32++) * 255.;
+	      *t++ = (guint8)(CLAMP(f, 0, 255));
+            }
+	    if (has_alpha)  /* ignore alpha channel */
+	      f32++;
+            }
+          break;
+          case PRECISION_BFP:
+            {
+  	    for (j = 0; j < cinfo.input_components; j++)
+            {
+              bfp = *s16++;
+	      *t++ = (guint8)(BFP_TO_U8(bfp));
+            }
+	    if (has_alpha)  /* ignore alpha channel */
+	      s16++;
+            }
+          break;
+          }
 	}
 
       src += rowstride;
@@ -675,6 +734,11 @@ save_image (char   *filename,
   /* And we're done! */
   /*gimp_do_progress (1, 1);*/
 
+  if (export == GIMP_EXPORT_EXPORT) {
+    gimp_image_delete (e_image_ID);
+    gimp_image_clean_all (e_image_ID);
+  }
+
   gimp_drawable_detach (drawable);
 
   return TRUE;
