@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: noisify.c,v 1.1 2004/02/10 01:12:53 robinrowe Exp $
+ * $Id: noisify.c,v 1.2 2006/10/11 08:05:32 beku Exp $
  */
 
 /*
@@ -32,6 +32,7 @@
 #include <time.h>
 #include "gtk/gtk.h"
 #include "lib/plugin_main.h"
+#include "libgimp/stdplugins-intl.h"
 
 #define ENTRY_WIDTH  60
 #define SCALE_WIDTH 125
@@ -133,6 +134,8 @@ query ()
 			  PROC_PLUG_IN,
 			  nargs, nreturn_vals,
 			  args, return_vals);
+  _("Noise");
+  _("Noisify");
 }
 
 static void
@@ -148,6 +151,8 @@ run (char    *name,
   GRunModeType run_mode;
   GStatusType status = STATUS_SUCCESS;
 
+  INIT_I18N_UI();
+
   run_mode = param[0].data.d_int32;
 
   *nreturn_vals = 1;
@@ -199,7 +204,7 @@ run (char    *name,
   /*  Make sure that the drawable is gray or RGB color  */
   if (gimp_drawable_color (drawable->id) || gimp_drawable_gray (drawable->id))
     {
-      gimp_progress_init ("Adding Noise...");
+      gimp_progress_init (_("Adding Noise..."));
       gimp_tile_cache_ntiles (TILE_CACHE_SIZE);
 
       /*  seed the random number generator  */
@@ -566,14 +571,14 @@ noisify_dialog (gint channels)
   gtk_rc_parse (gimp_gtkrc ());
 
   dlg = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dlg), "Noisify");
+  gtk_window_set_title (GTK_WINDOW (dlg), _("Noisify"));
   gtk_window_position (GTK_WINDOW (dlg), GTK_WIN_POS_MOUSE);
   gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
 		      (GtkSignalFunc) noisify_close_callback,
 		      NULL);
 
   /*  Action area  */
-  button = gtk_button_new_with_label ("OK");
+  button = gtk_button_new_with_label (_("OK"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       (GtkSignalFunc) noisify_ok_callback,
@@ -582,7 +587,7 @@ noisify_dialog (gint channels)
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label (_("Cancel"));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
 			     (GtkSignalFunc) gtk_widget_destroy,
@@ -591,7 +596,7 @@ noisify_dialog (gint channels)
   gtk_widget_show (button);
 
   /*  parameter settings  */
-  frame = gtk_frame_new ("Parameter Settings");
+  frame = gtk_frame_new (_("Parameter Settings"));
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
   gtk_container_border_width (GTK_CONTAINER (frame), 10);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), frame, TRUE, TRUE, 0);
@@ -599,7 +604,7 @@ noisify_dialog (gint channels)
   gtk_container_border_width (GTK_CONTAINER (table), 10);
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  toggle = gtk_check_button_new_with_label ("Independent");
+  toggle = gtk_check_button_new_with_label (_("Independent"));
   gtk_table_attach (GTK_TABLE (table), toggle, 0, 2, 0, 1, GTK_FILL, 0, 0, 0);
   gtk_signal_connect (GTK_OBJECT (toggle), "toggled",
 		      (GtkSignalFunc) noisify_toggle_update,
@@ -616,37 +621,37 @@ noisify_dialog (gint channels)
   
   if (channels == 1) 
     {
-      sprintf (buffer, "Gray");
+      sprintf (buffer, _("Gray"));
       dialog_create_value(buffer, GTK_TABLE(table), 1, &nvals.noise[0], 0.0, 1.0);
     }
 
   else if (channels == 2)
     {
-      sprintf (buffer, "Gray");
+      sprintf (buffer, _("Gray"));
       dialog_create_value(buffer, GTK_TABLE(table), 1, &nvals.noise[0], 0.0, 1.0);
-      sprintf (buffer, "Alpha");
+      sprintf (buffer, _("Alpha"));
       dialog_create_value(buffer, GTK_TABLE(table), 2, &nvals.noise[1], 0.0, 1.0);
     }
   
   else if (channels == 3)
     {
-      sprintf (buffer, "Red");
+      sprintf (buffer, _("1. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 1, &nvals.noise[0], 0.0, 1.0);
-      sprintf (buffer, "Green");
+      sprintf (buffer, _("2. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 2, &nvals.noise[1], 0.0, 1.0);
-      sprintf (buffer, "Blue");
+      sprintf (buffer, _("3. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 3, &nvals.noise[2], 0.0, 1.0);
     }
 
   else if (channels == 4)
     {
-      sprintf (buffer, "Red");
+      sprintf (buffer, _("1. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 1, &nvals.noise[0], 0.0, 1.0);
-      sprintf (buffer, "Green");
+      sprintf (buffer, _("2. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 2, &nvals.noise[1], 0.0, 1.0);
-      sprintf (buffer, "Blue");
+      sprintf (buffer, _("3. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 3, &nvals.noise[2], 0.0, 1.0);
-      sprintf (buffer, "Alpha");
+      sprintf (buffer, _("4. Channel"));
       dialog_create_value(buffer, GTK_TABLE(table), 4, &nvals.noise[3], 0.0, 1.0);
     }
   
@@ -654,7 +659,7 @@ noisify_dialog (gint channels)
     {
       for (i = 0; i < channels; i++)
 	{
-	  sprintf (buffer, "Channel #%d", i);
+	  sprintf (buffer, _("Channel #%d"), i);
 	  dialog_create_value(buffer, GTK_TABLE(table), i+1, &nvals.noise[i], 0.0, 1.0);
 	}
     }
