@@ -326,7 +326,7 @@ load_image ( gchar *filename)
   size_t start, end;
 
 # ifdef DEBUG
-  printf("%s:%d %s() 0x%x\n",__FILE__,__LINE__,__func__,(int)filename);
+  printf("%s:%d %s() 0x%x\n",__FILE__,__LINE__,__func__,(intptr_t)filename);
 #endif
 
   name = g_strdup_printf( _("Opening '%s'..."), filename);
@@ -358,7 +358,7 @@ load_image ( gchar *filename)
   fclose (fp);
   fp = NULL;
 
-  // parse Infos
+  /* parse Infos */
   if(data[fpos] == 'P')
   {
     if(isdigit(data[++fpos])) {
@@ -368,9 +368,9 @@ load_image ( gchar *filename)
     } else
     if (!isspace(data[fpos]))
     {
-      if(data[fpos] == 'F') // PFM rgb
+      if(data[fpos] == 'F') /* PFM rgb */
         type = -6;
-      else if (data[fpos] == 'f') // PFM gray
+      else if (data[fpos] == 'f') /* PFM gray */
         type = -5;
       else
         info_good = 0;
@@ -380,14 +380,14 @@ load_image ( gchar *filename)
   }
   fpos++;
 
-  // parse variables
+  /* parse variables */
   {
-    int in_c = 0;    // within comment
-    int v_read = 0;  // number of variables allready read
-    int v_need = 3;  // number of needed variable; start with three
-    int l_end = 0;   // line end position
-    int l_pos = 0;   // line position
-    int l_rdg = 1;   // line reading
+    int in_c = 0;    /* within comment */
+    int v_read = 0;  /* number of variables allready read */
+    int v_need = 3;  /* number of needed variable; start with three */
+    int l_end = 0;   /* line end position */
+    int l_pos = 0;   /* line position */
+    int l_rdg = 1;   /* line reading */
 
     if(type == 1 || type == 4)
            v_need = 2;
@@ -523,7 +523,7 @@ load_image ( gchar *filename)
   {
     if (mem_n > fsize-fpos)
     {
-      g_message ("%s:%d  storage size of %s is too small: %d",__FILE__,__LINE__,filename , mem_n-fsize-fpos);
+      g_message ("%s:%d  storage size of %s is too small: %d",__FILE__,__LINE__,filename , (int)mem_n-fsize-fpos);
       m_free( data )
       return FALSE;
     }
@@ -561,8 +561,8 @@ load_image ( gchar *filename)
 
   {
     int   h, p, n_samples, n_bytes;
-    int   j_h,         // jump_height
-          c_h;         // current_height
+    int   j_h,         /* jump_height */
+          c_h;         /* current_height */
     unsigned char *buf = 0,
                   *d_8 = 0;
     unsigned char *src;
@@ -814,13 +814,13 @@ save_image                  (   gchar           *filename,
 
     if (gimp_image_has_icc_profile(image_ID, ICC_IMAGE_PROFILE))
     {
-      if (strcmp (gimp_image_get_icc_profile_color_space_name(image_ID, ICC_IMAGE_PROFILE) , "Rgb")
+      /*if (strcmp (gimp_image_get_icc_profile_color_space_name(image_ID, ICC_IMAGE_PROFILE) , "Rgb")
         != 0)
       {
           g_message (_("This Colourspace is not supported\n"));
           m_free (drawable)
           return 0;
-      }
+      }*/
       colourspacename = gimp_image_get_icc_profile_description( image_ID, ICC_IMAGE_PROFILE );
     }
 
@@ -850,9 +850,9 @@ save_image                  (   gchar           *filename,
         if (byteps == 4)
         {
           if(spp == 1)
-            fputc( 'f', fp ); // PFM gray
+            fputc( 'f', fp ); /* PFM gray */
           else
-            fputc( 'F', fp ); // PFM rgb
+            fputc( 'F', fp ); /* PFM rgb */
         }
 
       fputc( '\n', fp );
