@@ -1,5 +1,5 @@
 /*
- * "$Id: print-image-gimp.c,v 1.6 2006/04/15 08:00:49 beku Exp $"
+ * "$Id: print-image-gimp.c,v 1.7 2007/01/13 21:59:12 beku Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -498,8 +498,9 @@ Image_get_row             ( stp_image_t       *image,
   //g_print ("%s:%d %s() im->base_type %d\nim->real_bpp %d im->alpha_table %d im->cmap %d im->mirror %d im->tmp %d im->columns %d drawable->id %d\n",__FILE__,__LINE__,__func__, im->base_type, im->real_bpp, (int)im->alpha_table, (int)im->cmap, im->mirror, (int)im->tmp, im->columns, im->drawable->id);
 
   if (im->cmap)
-    { printf ("%s:%d %s(): using cmap\n",__FILE__,__LINE__,__func__);
+    {
       int i;
+      printf ("%s:%d %s(): using cmap\n",__FILE__,__LINE__,__func__);
       if (im->alpha_table)
 	{
 	  for (i = 0; i < im->w; i++)
@@ -525,8 +526,9 @@ Image_get_row             ( stp_image_t       *image,
 	}
     }
   else if (im->alpha_table)
-    { printf ("%s:%d %s(): using alpha_table\n",__FILE__,__LINE__,__func__);
+    {
       int i;
+      printf ("%s:%d %s(): using alpha_table\n",__FILE__,__LINE__,__func__);
       for (i = 0; i < im->w; i++)
 	{
 	  int j;
@@ -554,8 +556,8 @@ Image_get_row             ( stp_image_t       *image,
         if((im->real_bpp >= 4 && im->samples <= 2) ||
            (im->real_bpp > 4 && im->samples > 2 ))
         {
-          if(mirror){printf("16bit spiegeln\n");mirror=0;};
           guint16 tmp16;
+          if(mirror){printf("16bit spiegeln\n");mirror=0;};
           for (c = 0; c < samples; c++)
 	      {
 	        tmp16 = dest[f*samples + c];
@@ -635,6 +637,6 @@ Image_get_appname(stp_image_t *image)
 
 
 /*
- * End of "$Id: print-image-gimp.c,v 1.6 2006/04/15 08:00:49 beku Exp $".
+ * End of "$Id: print-image-gimp.c,v 1.7 2007/01/13 21:59:12 beku Exp $".
  */
 
