@@ -1,5 +1,5 @@
 /*
- * "$Id: print-lcms-funcs.h,v 1.2 2005/07/12 20:51:17 beku Exp $"
+ * "$Id: print-lcms-funcs.h,v 1.4 2006/04/08 08:35:52 beku Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -39,12 +39,17 @@ typedef struct
   gchar  l_profile[MAX_PATH];         // linearisation profile
   gchar  image_filename [MAX_PATH];         // name of the image
   gchar  tiff_file[MAX_PATH];         // tiff filename
+
   gint32 intent;            // rendering intent
+  gint32 disp_intent;       // displays rendering intent
   gint32 matrix;            // conversion matrix
   gint32 precalc;           // precalculation
-  gint32 bpc;               // black point compensation
+  gint32 flags;             // flags
+  gint32 disp_flags;        // flags of the active display
+  gint32 preserveblack;     // preserve black in cmyk -> cmyk transform
   gint32 bitpersample;      // bit per pixel
   gchar  color_type[64];    // color type
+  gint32 display_ID;
   gint32 o_image_ID;        // original image
   gint32 e_image_ID;        // exported image
   gint32 s_image_ID;        // separated image
