@@ -1,5 +1,5 @@
 /*
- * "$Id: print.c,v 1.15 2006/10/11 08:08:21 beku Exp $"
+ * "$Id: print.c,v 1.16 2006/12/15 22:20:22 beku Exp $"
  *
  *   Print plug-in for the GIMP.
  *
@@ -482,6 +482,12 @@ run (char   *name,		/* I - Name of print program. */
 
     stp_init();
 
+#if GTK_MAJOR_VERSION > 1
+    stp_set_output_codeset("UTF-8");
+    INIT_I18N_UI();
+    gimp_ui_init("print", TRUE);
+#endif
+
     stpui_printer_initialize(&gimp_vars);
 
     stpui_set_image_filename(vals.image_filename);
@@ -569,8 +575,8 @@ run (char   *name,		/* I - Name of print program. */
         break;
       }
 
-    /*if (stp_verify(gimp_vars.v))
-      g_message ("error");*/
+    if (stp_verify(gimp_vars.v))
+      g_message ("error");
 
     switch (run_mode)
       {
