@@ -62,7 +62,7 @@
 
 /* Defines */
 #define PLUG_IN_VERSION     "v1.0 (2000/06/18)"
-#define PLUG_IN_IMAGE_TYPES "RGB*, INDEXED*, GRAY*"
+#define PLUG_IN_IMAGE_TYPES "*"
 #define PLUG_IN_AUTHOR      "Sven Neumann <sven@gimp.org>, Adam D. Moss <adam@gimp.org>"
 #define PLUG_IN_COPYRIGHT   "Sven Neumann, Adam D. Moss"
 
