@@ -16,19 +16,41 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <sys/types.h>
+#if HAVE_DIRENT_H
 #include <dirent.h>
+#endif
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <sys/stat.h>
+
+
+#ifndef GTK_ENABLE_BROKEN
+#define GTK_ENABLE_BROKEN
+#endif
 #include "gdk/gdkkeysyms.h"
 #include "gtk/gtk.h"
+
 #include "libgimp/gimp.h"
 #include "libgimp/gimpui.h"
+
+#include "script-fu-intl.h"
+
 #include "siod.h"
 #include "script-fu-console.h"
-#include <plug-ins/dbbrowser/dbbrowser.h>
+
+#include <plug-ins/dbbrowser/dbbrowser_utils.h>
+
+#ifdef G_OS_WIN32
+#include <fcntl.h>
+#include <io.h>
+#endif
 
 #define TEXT_WIDTH  400
 #define TEXT_HEIGHT 400
@@ -36,6 +58,18 @@
 
 #define BUFSIZE 256
 
+void
+gimp_table_attach_aligned (GtkTable    *table,
+                           gint         column,
+                           gint         row,
+                           const gchar *label_text,
+                           gfloat       xalign,
+                           gfloat       yalign,
+                           GtkWidget   *widget,
+                           gint         colspan,
+                           gboolean     left_align);
+
+
 typedef struct
 {
   GtkWidget *console;
@@ -59,9 +93,9 @@ static void  script_fu_close_callback    (GtkWidget        *widget,
 					  gpointer          data);
 static void  script_fu_browse_callback    (GtkWidget        *widget,
 					  gpointer          data);
-static void  script_fu_siod_read         (gpointer          data,
-					  gint              id,
-					  GdkInputCondition cond);
+static gboolean script_fu_siod_read      (GIOChannel  *channel,
+					  GIOCondition cond,
+					  gpointer     data);
 static gint  script_fu_cc_is_empty       (void);
 static gint  script_fu_cc_key_function   (GtkWidget         *widget,
 					  GdkEventKey       *event,
@@ -95,11 +129,13 @@ static int    history_cur = 0;
 static int    history_max = 50;
 
 static int   siod_output_pipe[2];
-extern int   siod_verbose_level;
+extern long  siod_verbose_level;
 extern char  siod_err_msg[];
 extern FILE *siod_output;
 
 
+#define message(string) printf("(%s): %d ::: %s\n", __PRETTY_FUNCTION__, __LINE__, string)
+
 /*
  *  Function definitions
  */
@@ -107,19 +143,19 @@ extern FILE *siod_output;
 void
 script_fu_console_run (char     *name,
 		       int       nparams,
-		       GParam   *params,
+		       GimpParam   *params,
 		       int      *nreturn_vals,
-		       GParam  **return_vals)
+		       GimpParam  **return_vals)
 {
-  static GParam values[1];
-  GStatusType status = STATUS_SUCCESS;
-  GRunModeType run_mode;
+  static GimpParam values[1];
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;
+  GimpRunModeType run_mode;
 
   run_mode = params[0].data.d_int32;
 
   switch (run_mode)
     {
-    case RUN_INTERACTIVE:
+    case GIMP_RUN_INTERACTIVE:
       /*  Enable SIOD output  */
       script_fu_open_siod_console ();
 
@@ -130,10 +166,10 @@ script_fu_console_run (char     *name,
       script_fu_close_siod_console ();
       break;
 
-    case RUN_WITH_LAST_VALS:
-    case RUN_NONINTERACTIVE:
-      status = STATUS_CALLING_ERROR;
-      gimp_message ("Script-Fu console mode allows only interactive invocation");
+    case GIMP_RUN_WITH_LAST_VALS:
+    case GIMP_RUN_NONINTERACTIVE:
+      status = GIMP_PDB_CALLING_ERROR;
+      gimp_message (_("Script-Fu console mode allows only interactive invocation"));
       break;
 
     default:
@@ -143,12 +179,12 @@ script_fu_console_run (char     *name,
   *nreturn_vals = 1;
   *return_vals = values;
 
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
 }
 
 static void
-script_fu_console_interface ()
+script_fu_console_interface (void)
 {
   GtkWidget *dlg;
   GtkWidget *button;
@@ -156,34 +192,31 @@ script_fu_console_interface ()
   GtkWidget *vsb;
   GtkWidget *table;
   GtkWidget *hbox;
-  gchar **argv;
-  gint argc;
-  const char *text = NULL;
+  GIOChannel *input_channel;
 
-  argc = 1;
-  argv = g_new (gchar *, 1);
-  argv[0] = g_strdup ("script-fu");
+  INIT_I18N_UI();
+  textdomain("cinepaint-script-fu");
 
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
+  gimp_ui_init ("script-fu", FALSE);
 
   dlg = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (dlg), _("Script-Fu Console"));
+  gimp_help_connect_help_accel (dlg, gimp_standard_help_func, 
+				"filters/script-fu.html");
   gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
 		      (GtkSignalFunc) script_fu_close_callback,
 		      NULL);
-  gtk_signal_connect (GTK_OBJECT (dlg),
-		      "destroy",
+  gtk_signal_connect (GTK_OBJECT (dlg), "destroy",
 		      GTK_SIGNAL_FUNC (gtk_widget_destroyed),
 		      &dlg);
-  gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->vbox), 2);
-  gtk_container_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 2);
+  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->vbox), 2);
+  gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 0);
 
   /*  Action area  */
   button = gtk_button_new_with_label (_("Close"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      (GtkSignalFunc) script_fu_close_callback,
-                      NULL);
+  gtk_signal_connect_object (GTK_OBJECT (button), "clicked",
+			     (GtkSignalFunc) gtk_widget_destroy,
+			     (gpointer)dlg);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->action_area), button, TRUE, TRUE, 0);
   gtk_widget_show (button);
 
@@ -211,12 +244,12 @@ script_fu_console_interface ()
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
 
-  gtk_container_border_width (GTK_CONTAINER (table), 2);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 2);
 
   cint.font_strong = gdk_font_load ("-*-helvetica-bold-r-normal-*-*-120-*-*-*-*-*-*");
   cint.font_emphasis = gdk_font_load ("-*-helvetica-medium-o-normal-*-*-100-*-*-*-*-*-*");
   cint.font_weak = gdk_font_load ("-*-helvetica-medium-r-normal-*-*-100-*-*-*-*-*-*");
-  cint.font = gdk_font_load ("-*-*-medium-r-normal-*-*-100-*-*-c-*-*-*");
+  cint.font = gdk_fontset_load ("-*-*-medium-r-normal-*-*-100-*-*-c-*-iso8859-1,*");
 
   /*  Realize the widget before allowing new text to be inserted  */
   gtk_widget_realize (cint.console);
@@ -224,7 +257,9 @@ script_fu_console_interface ()
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_strong, NULL, NULL,
 		   "The GIMP - GNU Image Manipulation Program\n\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_emphasis, NULL, NULL,
-		   "Copyright (C) 1995 Spencer Kimball and Peter Mattis\n", -1);
+		   "Copyright (C) 1995-2001\n", -1);
+  gtk_text_insert (GTK_TEXT (cint.console), cint.font_emphasis, NULL, NULL,
+		   "Spencer Kimball, Peter Mattis and the GIMP Development Team\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
 		   "\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
@@ -252,21 +287,24 @@ script_fu_console_interface ()
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
 		   "along with this program; if not, write to the Free Software\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
-		   "Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n", -1);
+		   "Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n\n", -1);
+  gtk_text_insert (GTK_TEXT (cint.console), cint.font_strong, NULL, NULL,
+		   "Welcome to SIOD, Scheme In One Defun\n", -1); 
+  gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
+		   "(C) Copyright 1988-1994 Paradigm Associates Inc.\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
 		   "\n\n", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_strong, NULL, NULL,
-		   _("Script-Fu Console - "), -1);
+		   "Script-Fu Console - ", -1);
   gtk_text_insert (GTK_TEXT (cint.console), cint.font_emphasis, NULL, NULL,
-		   _("Interactive Scheme Development\n\n"), -1);
+		   "Interactive Scheme Development\n\n", -1);
 
   gtk_widget_show (vsb);
   gtk_widget_show (cint.console);
   gtk_widget_show (table);
 
   /*  The current command  */
-  text = _("Current Command");
-  label = gtk_label_new (text);
+  label = gtk_label_new (_("Current Command"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), label, FALSE, TRUE, 0);
   gtk_widget_show (label);
@@ -280,7 +318,7 @@ script_fu_console_interface ()
   
   gtk_box_pack_start (GTK_BOX (hbox), cint.cc, 
 		      TRUE, TRUE, 0);
-  gtk_widget_set_usize (cint.cc, (ENTRY_WIDTH*5)/6, 0); 
+/*    gtk_widget_set_usize (cint.cc, (ENTRY_WIDTH*5)/6, 0);  */
   GTK_WIDGET_SET_FLAGS (cint.cc, GTK_CAN_DEFAULT);
   gtk_widget_grab_default (cint.cc);
   gtk_signal_connect (GTK_OBJECT (cint.cc), "key_press_event",
@@ -288,7 +326,7 @@ script_fu_console_interface ()
 		      NULL);
 
   button = gtk_button_new_with_label (_("Browse..."));
-  gtk_widget_set_usize (button, (ENTRY_WIDTH)/6, 0);
+/*    gtk_widget_set_usize (button, (ENTRY_WIDTH)/6, 0); */
   gtk_box_pack_start (GTK_BOX (hbox), button, 
 		      FALSE, TRUE, 0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -297,10 +335,11 @@ script_fu_console_interface ()
   gtk_widget_show (button);
   gtk_widget_show (cint.cc);
 
-  cint.input_id = gdk_input_add (siod_output_pipe[0],
-				 GDK_INPUT_READ,
-				 script_fu_siod_read,
-				 NULL);
+  input_channel = g_io_channel_unix_new (siod_output_pipe[0]);
+  cint.input_id = g_io_add_watch (input_channel,
+				  G_IO_IN,
+				  script_fu_siod_read,
+				  NULL);
 
   /*  Initialize the history  */
   history = g_list_append (history, NULL);
@@ -310,7 +349,7 @@ script_fu_console_interface ()
 
   gtk_main ();
 
-  gdk_input_remove (cint.input_id);
+  g_source_remove (cint.input_id);
   if (dlg)
     gtk_widget_destroy (dlg);
   gdk_flush ();
@@ -323,37 +362,42 @@ script_fu_close_callback (GtkWidget *widget,
   gtk_main_quit ();
 }
 
-void apply_callback( gchar *proc_name,
-			   gchar *scheme_proc_name,
-			   gchar *proc_blurb,
-			   gchar *proc_help,
-			   gchar *proc_author,
-			   gchar *proc_copyright,
-			   gchar *proc_date,
-			   int proc_type,
-			   int nparams,
-			   int nreturn_vals,
-			   GParamDef *params,
-			   GParamDef *return_vals )
+void 
+apply_callback (gchar           *proc_name,
+		gchar           *scheme_proc_name,
+		gchar           *proc_blurb,
+		gchar           *proc_help,
+		gchar           *proc_author,
+		gchar           *proc_copyright,
+		gchar           *proc_date,
+		GimpPDBProcType  proc_type,
+		gint             nparams,
+		gint             nreturn_vals,
+		GimpParamDef    *params,
+		GimpParamDef    *return_vals)
 {
   gint i;
+  GString *text;
 
-  if (proc_name==NULL) return;
-  gtk_widget_hide(cint.cc);
-  gtk_entry_set_text( GTK_ENTRY(cint.cc), "(" );
-  gtk_entry_append_text( GTK_ENTRY(cint.cc), scheme_proc_name );
-  if ((nparams==0) || (params==NULL)) return;
-  for (i=0;i<nparams;i++) {
-    gtk_entry_append_text( GTK_ENTRY(cint.cc), " " );
-    gtk_entry_append_text( GTK_ENTRY(cint.cc), params[i].name);
-  }
-  gtk_entry_append_text( GTK_ENTRY(cint.cc), ")" );
-  gtk_widget_show(cint.cc);
+  if (proc_name == NULL) 
+    return;
+  
+  text = g_string_new ("(");
+  text = g_string_append (text, scheme_proc_name);
+  for (i=0; i<nparams; i++) 
+    {
+      text = g_string_append_c (text, ' ');
+      text = g_string_append (text, params[i].name);
+    }
+  text = g_string_append_c (text, ')');
+
+  gtk_entry_set_text (GTK_ENTRY (cint.cc), text->str);
+  g_string_free (text, TRUE);
 }
 
 static void
-script_fu_browse_callback(GtkWidget *widget,
-			  gpointer   data)
+script_fu_browse_callback (GtkWidget *widget,
+			   gpointer   data)
 {
   gtk_quit_add_destroy (1, (GtkObject*) gimp_db_browser (apply_callback));
 }
@@ -376,26 +420,48 @@ script_fu_console_scroll_end (gpointer data)
   return FALSE;
 }
 
-static void
-script_fu_siod_read (gpointer          data,
-		     gint              id,
-		     GdkInputCondition cond)
+static gboolean
+script_fu_siod_read (GIOChannel  *channel,
+		     GIOCondition cond,
+		     gpointer     data)
 {
   int count;
+  static int hack = 0;
+  GIOError error;
 
-  if ((count = read (id, read_buffer, BUFSIZE - 1)) != 0)
+  count = 0;
+  error = g_io_channel_read (channel, read_buffer, BUFSIZE - 1, &count);
+
+  if (error == G_IO_ERROR_NONE)
     {
+#ifndef G_OS_WIN32
+      /* Is this needed any longer on Unix? */
+      if (!hack) /* this is a stupid hack, but as of 10/27/98
+		 * the script-fu-console will hang on my system without it.
+		 * the real cause of this needs to be tracked down.
+		 * posibly a problem with the text widget, or the
+		 * signal handlers not getting fully initialized or...
+		 * no reports of hangs on other platforms, could just be a
+		 * problem with my system.
+		 */
+      {
+	hack = 1;
+	return TRUE;
+      }
+#endif
       read_buffer[count] = '\0';
       gtk_text_freeze (GTK_TEXT (cint.console));
-      gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL, read_buffer, -1);
+      gtk_text_insert (GTK_TEXT (cint.console), cint.font_weak, NULL, NULL,
+		       read_buffer, -1);
       gtk_text_thaw (GTK_TEXT (cint.console));
 
       script_fu_console_scroll_end (NULL);
     }
+  return TRUE;
 }
 
 static gint
-script_fu_cc_is_empty ()
+script_fu_cc_is_empty (void)
 {
   char *str;
 
@@ -525,7 +591,7 @@ script_fu_cc_key_function (GtkWidget   *widget,
 
 
 static FILE *
-script_fu_open_siod_console ()
+script_fu_open_siod_console (void)
 {
   if (siod_output == stdout)
     {
@@ -549,7 +615,7 @@ script_fu_open_siod_console ()
 }
 
 static void
-script_fu_close_siod_console ()
+script_fu_close_siod_console (void)
 {
   if (siod_output != stdout)
     fclose (siod_output);
@@ -560,26 +626,26 @@ script_fu_close_siod_console ()
 void
 script_fu_eval_run (char     *name,
 		    int       nparams,
-		    GParam   *params,
+		    GimpParam   *params,
 		    int      *nreturn_vals,
-		    GParam  **return_vals)
+		    GimpParam  **return_vals)
 {
-  static GParam values[1];
-  GStatusType status = STATUS_SUCCESS;
-  GRunModeType run_mode;
+  static GimpParam values[1];
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;
+  GimpRunModeType run_mode;
 
   run_mode = params[0].data.d_int32;
 
   switch (run_mode)
     {
-    case RUN_NONINTERACTIVE:
+    case GIMP_RUN_NONINTERACTIVE:
       if (repl_c_string (params[1].data.d_string, 0, 0, 1) != 0)
-	status = STATUS_EXECUTION_ERROR;
+	status = GIMP_PDB_EXECUTION_ERROR;
       break;
 
-    case RUN_INTERACTIVE:
-    case RUN_WITH_LAST_VALS:
-      status = STATUS_CALLING_ERROR;
+    case GIMP_RUN_INTERACTIVE:
+    case GIMP_RUN_WITH_LAST_VALS:
+      status = GIMP_PDB_CALLING_ERROR;
       gimp_message (_("Script-Fu evaluate mode allows only noninteractive invocation"));
       break;
 
@@ -590,6 +656,6 @@ script_fu_eval_run (char     *name,
   *nreturn_vals = 1;
   *return_vals = values;
 
-  values[0].type = PARAM_STATUS;
+  values[0].type = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
 }
