@@ -1,4 +1,4 @@
-/* $Id: unsharp.c,v 1.7 2006/10/04 18:33:31 beku Exp $
+/* $Id: unsharp.c,v 1.9 2006/12/31 09:01:31 beku Exp $
  *
  * unsharp.c 0.10 -- This is a plug-in for the GIMP 1.0
  *  http://www.stdout.org/~winston/gimp/unsharp.html
@@ -213,7 +213,6 @@ run (gchar   *name,
 #ifdef TIMER
   timerstart();
 #endif
-  printf("dru\n");
 
   run_mode = param[0].data.d_int32;
 
@@ -222,6 +221,7 @@ run (gchar   *name,
   *return_vals = values;
   *nreturn_vals = 1;
 
+
   INIT_I18N_UI(); 
 
   switch (run_mode)
@@ -855,9 +855,11 @@ gimp_dialog_delete_callback (GtkWidget *widget,
     (GtkWidget*) gtk_object_get_data (GTK_OBJECT (widget),
 				      "gimp_dialog_cancel_widget");
 
+#if GTK_MAJOR_VERSION < 2
   /*  the cancel callback has to destroy the dialog  */
   if (cancel_callback)
     (* cancel_callback) (cancel_widget, data);
+#endif
 
   return TRUE;
 }
