@@ -63,6 +63,7 @@ static char ident[] = "@(#) GIMP XWD file-plugin v1.95  02-Jul-2001";
 
 #include "lib/plugin_main.h"
 #include "libgimp/gimp1.2.h"
+#include "libgimp/stdplugins-intl.h"
 #include "lib/export.h"
 #include "lib/dialog.h"
 
@@ -288,7 +289,7 @@ run (gchar   *name,
 
   if (strcmp (name, "file_xwd_load") == 0)
     {
-      INIT_I18N();
+      INIT_I18N_UI();
 
       image_ID = load_image (param[1].data.d_string);
 
@@ -305,7 +306,7 @@ run (gchar   *name,
     }
   else if (strcmp (name, "file_xwd_save") == 0)
     {
-      INIT_I18N();
+      INIT_I18N_UI();
 
       image_ID = param[1].data.d_int32;
       drawable_ID = param[2].data.d_int32;
